/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/build/cython/src/cython/Cython/Compiler/Scanning.pxd"
        ],
        "name": "Cython.Compiler.Scanning",
        "sources": [
            "/build/cython/src/cython/Cython/Compiler/Scanning.py"
        ]
    },
    "module_name": "Cython.Compiler.Scanning"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Cython__Compiler__Scanning
#define __PYX_HAVE_API__Cython__Compiler__Scanning
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "Cython/Compiler/Scanning.py",
  "Cython/Compiler/Scanning.pxd",
  "Cython/Plex/Actions.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6Cython_4Plex_7Actions_Action;
struct __pyx_obj_6Cython_4Plex_7Actions_Return;
struct __pyx_obj_6Cython_4Plex_7Actions_Call;
struct __pyx_obj_6Cython_4Plex_7Actions_Method;
struct __pyx_obj_6Cython_4Plex_7Actions_Begin;
struct __pyx_obj_6Cython_4Plex_7Actions_Ignore;
struct __pyx_obj_6Cython_4Plex_7Actions_Text;
struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner;
struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope;
struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner;
struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState;
struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan;
struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce;

/* "Plex/Scanners.pxd":45
 * 
 *     cdef inline begin(self, state)
 *     cdef inline produce(self, value, text = *)             # <<<<<<<<<<<<<<
*/
struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce {
  int __pyx_n;
  PyObject *text;
};

/* "Cython/Plex/Actions.pxd":1
 * cdef class Action:             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Action {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action *__pyx_vtab;
};


/* "Cython/Plex/Actions.pxd":4
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Return(Action):             # <<<<<<<<<<<<<<
 *     cdef object value
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Return {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *value;
};


/* "Cython/Plex/Actions.pxd":8
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Call(Action):             # <<<<<<<<<<<<<<
 *     cdef object function
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Call {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *function;
};


/* "Cython/Plex/Actions.pxd":12
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Method(Action):             # <<<<<<<<<<<<<<
 *     cdef str name
 *     cdef dict kwargs
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Method {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *name;
  PyObject *kwargs;
};


/* "Cython/Plex/Actions.pxd":16
 *     cdef dict kwargs
 * 
 * cdef class Begin(Action):             # <<<<<<<<<<<<<<
 *     cdef object state_name
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Begin {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *state_name;
};


/* "Cython/Plex/Actions.pxd":20
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Ignore(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Ignore {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
};


/* "Cython/Plex/Actions.pxd":23
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Text(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Text {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
};


/* "Plex/Scanners.pxd":7
 * from Cython.Plex.Actions cimport Action
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 * 
 *     cdef public lexicon
*/
struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner *__pyx_vtab;
  PyObject *lexicon;
  PyObject *stream;
  PyObject *name;
  PyObject *buffer;
  Py_ssize_t buf_start_pos;
  Py_ssize_t next_pos;
  Py_ssize_t cur_pos;
  Py_ssize_t cur_line;
  Py_ssize_t cur_line_start;
  Py_ssize_t start_pos;
  PyObject *current_scanner_position_tuple;
  PyObject *last_token_position_tuple;
  PyObject *text;
  PyObject *initial_state;
  PyObject *state_name;
  PyObject *queue;
  int trace;
  PyObject *cur_char;
  long input_state;
  PyObject *level;
};


/* "Cython/Compiler/Scanning.pxd":12
 * ## methods commented with '##' out are used by Parsing.py when compiled.
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class CompileTimeScope:
 *     cdef public dict entries
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope {
  PyObject_HEAD
  PyObject *entries;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *outer;
};


/* "Cython/Compiler/Scanning.pxd":20
 *     ##cpdef lookup(self, name)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class PyrexScanner(Scanner):
 *     cdef public context
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner {
  struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner __pyx_base;
  PyObject *context;
  PyObject *included_files;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *compile_time_env;
  int compile_time_eval;
  int compile_time_expr;
  int parse_comments;
  int in_python_file;
  PyObject *source_encoding;
  PyObject *keywords;
  PyObject *indentation_stack;
  Py_UCS4 indentation_char;
  int bracket_nesting_level;
  int async_enabled;
  PyObject *sy;
  PyObject *systring;
  PyObject *put_back_on_failure;
  PyObject *ft_string_state_stack;
  int in_ft_string_expr_prescan;
};


/* "Cython/Compiler/Scanning.pxd":46
 * 
 * 
 * cdef class FTStringState:             # <<<<<<<<<<<<<<
 *     cdef list bracket_states
 *     cdef readonly str scanner_state
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState {
  PyObject_HEAD
  PyObject *bracket_states;
  PyObject *scanner_state;
};


/* "Cython/Compiler/Scanning.py":654
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan {
  PyObject_HEAD
  PyObject *__pyx_v_errors;
  PyObject *__pyx_v_initial_state;
  PyObject *__pyx_v_put_back;
  PyObject *__pyx_v_put_back_on_failure;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_scanner;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};



/* "Cython/Plex/Actions.pxd":1
 * cdef class Action:             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action {
  PyObject *(*perform)(struct __pyx_obj_6Cython_4Plex_7Actions_Action *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action *__pyx_vtabptr_6Cython_4Plex_7Actions_Action;


/* "Cython/Plex/Actions.pxd":4
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Return(Action):             # <<<<<<<<<<<<<<
 *     cdef object value
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return *__pyx_vtabptr_6Cython_4Plex_7Actions_Return;


/* "Cython/Plex/Actions.pxd":8
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Call(Action):             # <<<<<<<<<<<<<<
 *     cdef object function
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call *__pyx_vtabptr_6Cython_4Plex_7Actions_Call;


/* "Cython/Plex/Actions.pxd":12
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Method(Action):             # <<<<<<<<<<<<<<
 *     cdef str name
 *     cdef dict kwargs
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method *__pyx_vtabptr_6Cython_4Plex_7Actions_Method;


/* "Cython/Plex/Actions.pxd":16
 *     cdef dict kwargs
 * 
 * cdef class Begin(Action):             # <<<<<<<<<<<<<<
 *     cdef object state_name
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin *__pyx_vtabptr_6Cython_4Plex_7Actions_Begin;


/* "Cython/Plex/Actions.pxd":20
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Ignore(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore *__pyx_vtabptr_6Cython_4Plex_7Actions_Ignore;


/* "Cython/Plex/Actions.pxd":23
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Text(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text *__pyx_vtabptr_6Cython_4Plex_7Actions_Text;


/* "Plex/Scanners.pxd":7
 * from Cython.Plex.Actions cimport Action
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 * 
 *     cdef public lexicon
*/

struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner {
  PyObject *(*read)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, int __pyx_skip_dispatch);
  PyObject *(*unread)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *, PyObject *, PyObject *);
  PyObject *(*get_current_scan_pos)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*scan_a_token)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*position)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, int __pyx_skip_dispatch);
  PyObject *(*run_machine_inlined)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*begin)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *);
  PyObject *(*produce)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *, struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner *__pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner;


/* "Cython/Compiler/Scanning.py":299
 * #------------------------------------------------------------------
 * 
 * class PyrexScanner(Scanner):             # <<<<<<<<<<<<<<
 *     #  context            Context  Compilation context
 *     #  included_files     [string] Files included with 'include' statement
*/

struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner {
  struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner __pyx_base;
  Py_ssize_t (*current_level)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *);
  int (*error_at_scanpos)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner;
static Py_ssize_t __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *);
static int __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *);
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyRange_Check.proto */
#if CYTHON_COMPILING_IN_PYPY && !defined(PyRange_Check)
  #define PyRange_Check(obj)  __Pyx_TypeCheck((obj), &PyRange_Type)
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* SetStringIndexingError.proto (used by GetItemIntUnicode) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil);

/* GetItemIntUnicode.proto */
#define __Pyx_GetItemInt_Unicode(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Unicode_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, has_gil) :\
    (__Pyx_SetStringIndexingError("string index out of range", has_gil), (Py_UCS4)-1))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck, int has_gil);

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* DivInt[Py_ssize_t].proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t, int b_is_constant);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* py_dict_pop_ignore.proto */
static CYTHON_INLINE int __Pyx_PyDict_Pop_ignore(PyObject *d, PyObject *key, PyObject *default_value);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* pyint_simplify.proto */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* CalculateMetaclass.proto (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* PyObjectCall2Args.proto (used by Py3ClassCreate) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* PyUCS4InUnicode.proto */
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character);

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* ObjectAsUCS4.proto */
static Py_UCS4 __Pyx__PyObject_AsPy_UCS4(PyObject*);
static CYTHON_INLINE Py_UCS4 __Pyx_PyObject_AsPy_UCS4(PyObject *x) {
    return (likely(PyUnicode_Check(x)) ? __Pyx_PyUnicode_AsPy_UCS4(x) : __Pyx__PyObject_AsPy_UCS4(x));
}

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* IterNextPlain.proto (used by CoroutineBase) */
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator);
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void);
#endif

/* PyObjectCallMethod1.proto (used by CoroutineBase) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* ReturnWithStopIteration.proto (used by CoroutineBase) */
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext);

/* CoroutineBase.proto (used by Generator) */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *gi_weakreflist;
#endif
    PyObject *classobj;
    PyObject *yieldfrom;
    __Pyx_pyiter_sendfunc yieldfrom_am_send;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
#if CYTHON_USE_SYS_MONITORING && (CYTHON_PROFILE || CYTHON_TRACE)
    PyMonitoringState __pyx_pymonitoring_state[__Pyx_MonitoringEventTypes_CyGen_count];
    uint64_t __pyx_pymonitoring_version;
#endif
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static __Pyx_PySendResult __Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static __Pyx_PySendResult __Pyx_Coroutine_Close(PyObject *self, PyObject **retval);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen);
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen);
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen);
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure);
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send);
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_mstate_global->__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);
static CYTHON_INLINE PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

static Py_ssize_t __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto*/
static int __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "Cython.Plex.Actions" */

/* Module declarations from "Cython.Plex.Scanners" */

/* Module declarations from "Cython.Compiler.Scanning" */
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_IDENT = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_lexicon = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_print_function = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_error = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_warning = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_os = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_platform = 0;
static PyObject *__pyx_v_6Cython_8Compiler_8Scanning_Path = 0;
static PyObject *__pyx_f_6Cython_8Compiler_8Scanning_get_lexicon(void); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_8Scanning_initial_compile_time_env(void); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "Cython.Compiler.Scanning"
extern int __pyx_module_is_main_Cython__Compiler__Scanning;
int __pyx_module_is_main_Cython__Compiler__Scanning = 0;

/* Implementation of "Cython.Compiler.Scanning" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_reversed;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_outer); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_2declare(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_4update(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_6lookup_here(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_8__contains__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_10lookup(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor___str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_2set_file_type_from_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_filename); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_4is_cython_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_6is_python_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_8get_escaped_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_10__gt__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_12__lt__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_14__le__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_16__copy__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_18__deepcopy__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_filename, PyObject *__pyx_v_path_description); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_2get_lines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_4get_file_object(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_6get_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_8get_relative_path(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_10get_error_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_12get_filenametable_entry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_14__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_16__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_18__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_2get_lines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_4get_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_6get_relative_path(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_8get_filenametable_entry(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_10__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_12__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_14__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_file, PyObject *__pyx_v_filename, PyObject *__pyx_v_parent_scanner, PyObject *__pyx_v_scope, PyObject *__pyx_v_context, PyObject *__pyx_v_source_encoding, PyObject *__pyx_v_parse_comments, PyObject *__pyx_v_initial_pos); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2normalize_ident(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_4commentline(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_6strip_underscores(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8open_bracket_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_10close_bracket_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_12open_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14close_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16colon_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_18newline_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_20begin_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_22end_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_24begin_ft_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_26end_ft_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_28_handle_open_single_ft_string_brace(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_started_ft_string_expr); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_30open_ft_string_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_32_handle_close_single_ft_string_brace(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_34close_ft_string_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_36unclosed_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_38indentation_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_40eof_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_42next(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_44peek(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_46put_back(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_sy, PyObject *__pyx_v_systring, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_48error(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message, PyObject *__pyx_v_pos, PyObject *__pyx_v_fatal); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_50expect(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_52expect_keyword(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_54expected(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_56expect_indent(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_58expect_dedent(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_60expect_newline(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message, int __pyx_v_ignore_semicolon); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_62enter_async(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_64exit_async(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_tentatively_scan(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_scanner); /* proto */
static int __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self, PyObject *__pyx_v_scanner_state); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_2bracket_nesting_level(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_4in_format_specifier(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_6set_in_format_specifier(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_8push_bracket_state(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_10pop_bracket_state(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FTStringBracketState___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level); /* proto */
static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_CompileTimeScope(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_PyrexScanner(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_FTStringState(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Action;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Return;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Call;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Method;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Begin;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Ignore;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Text;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_8Scanners_Scanner;
  PyObject *__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope;
  PyObject *__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner;
  PyObject *__pyx_type_6Cython_8Compiler_8Scanning_FTStringState;
  PyObject *__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop;
  PyObject *__pyx_slice[1];
  PyObject *__pyx_tuple[12];
  PyObject *__pyx_codeobj_tab[71];
  PyObject *__pyx_string_tab[521];
  PyObject *__pyx_number_tab[3];
/* #### Code section: module_state_contents ### */

#if CYTHON_USE_FREELISTS
struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *__pyx_freelist_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan[8];
int __pyx_freecount_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan;
#endif
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* IterNextPlain.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
PyObject *__Pyx_GetBuiltinNext_LimitedAPI_cache;
#endif

/* Generator.module_state_decls */
PyTypeObject *__pyx_GeneratorType;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_A_SourceDescriptor_should_be_co __pyx_string_tab[1]
#define __pyx_kp_u_Cython __pyx_string_tab[2]
#define __pyx_kp_u_Cython_Compiler_Errors __pyx_string_tab[3]
#define __pyx_kp_u_Cython_Compiler_Future __pyx_string_tab[4]
#define __pyx_kp_u_Cython_Compiler_Lexicon __pyx_string_tab[5]
#define __pyx_kp_u_Cython_Compiler_Scanning_py __pyx_string_tab[6]
#define __pyx_kp_u_Cython_Plex_Errors __pyx_string_tab[7]
#define __pyx_kp_u_Cython_Plex_Scanners __pyx_string_tab[8]
#define __pyx_kp_u_Expected __pyx_string_tab[9]
#define __pyx_kp_u_Expected_a_decrease_in_indentati __pyx_string_tab[10]
#define __pyx_kp_u_Expected_a_newline __pyx_string_tab[11]
#define __pyx_kp_u_Expected_an_increase_in_indentat __pyx_string_tab[12]
#define __pyx_kp_u_FileSourceDescriptor_s __pyx_string_tab[13]
#define __pyx_kp_u_Inconsistent_indentation __pyx_string_tab[14]
#define __pyx_kp_u_Instances_of_this_class_can_be __pyx_string_tab[15]
#define __pyx_kp_u_Mixed_use_of_tabs_and_spaces __pyx_string_tab[16]
#define __pyx_kp_u_None __pyx_string_tab[17]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[18]
#define __pyx_kp_u_Possible_inconsistent_indentatio __pyx_string_tab[19]
#define __pyx_kp_u_Represents_a_code_source_A_code __pyx_string_tab[20]
#define __pyx_kp_u_StringSourceDescriptor_s __pyx_string_tab[21]
#define __pyx_kp_u_Unclosed_string_literal __pyx_string_tab[22]
#define __pyx_kp_u_Unrecognized_character __pyx_string_tab[23]
#define __pyx_kp_u__10 __pyx_string_tab[24]
#define __pyx_kp_u__11 __pyx_string_tab[25]
#define __pyx_kp_u__12 __pyx_string_tab[26]
#define __pyx_kp_u__13 __pyx_string_tab[27]
#define __pyx_kp_u__2 __pyx_string_tab[28]
#define __pyx_kp_u__3 __pyx_string_tab[29]
#define __pyx_kp_u__4 __pyx_string_tab[30]
#define __pyx_kp_u__6 __pyx_string_tab[31]
#define __pyx_kp_u__7 __pyx_string_tab[32]
#define __pyx_kp_u__8 __pyx_string_tab[33]
#define __pyx_kp_u__9 __pyx_string_tab[34]
#define __pyx_kp_u_add_note __pyx_string_tab[35]
#define __pyx_kp_u_cython_bint __pyx_string_tab[36]
#define __pyx_kp_u_disable __pyx_string_tab[37]
#define __pyx_kp_u_enable __pyx_string_tab[38]
#define __pyx_kp_u_f_string_or_t_string_single_is_n __pyx_string_tab[39]
#define __pyx_kp_u_found __pyx_string_tab[40]
#define __pyx_kp_u_gc __pyx_string_tab[41]
#define __pyx_kp_u_isenabled __pyx_string_tab[42]
#define __pyx_kp_u_pxd __pyx_string_tab[43]
#define __pyx_kp_u_py __pyx_string_tab[44]
#define __pyx_kp_u_pyx __pyx_string_tab[45]
#define __pyx_kp_u_stringsource __pyx_string_tab[46]
#define __pyx_kp_u_useless_trailing_semicolon __pyx_string_tab[47]
#define __pyx_n_u_BEGIN_FT_STRING __pyx_string_tab[48]
#define __pyx_n_u_BEGIN_STRING __pyx_string_tab[49]
#define __pyx_n_u_CHARS __pyx_string_tab[50]
#define __pyx_n_u_CompileError __pyx_string_tab[51]
#define __pyx_n_u_CompileTimeScope __pyx_string_tab[52]
#define __pyx_n_u_CompileTimeScope_declare __pyx_string_tab[53]
#define __pyx_n_u_CompileTimeScope_lookup __pyx_string_tab[54]
#define __pyx_n_u_CompileTimeScope_lookup_here __pyx_string_tab[55]
#define __pyx_n_u_CompileTimeScope_update __pyx_string_tab[56]
#define __pyx_n_u_Cython_Compiler_Scanning __pyx_string_tab[57]
#define __pyx_n_u_DEDENT __pyx_string_tab[58]
#define __pyx_n_u_DEF __pyx_string_tab[59]
#define __pyx_n_u_DQ_STRING __pyx_string_tab[60]
#define __pyx_n_u_ELIF __pyx_string_tab[61]
#define __pyx_n_u_ELSE __pyx_string_tab[62]
#define __pyx_n_u_END_FT_STRING __pyx_string_tab[63]
#define __pyx_n_u_END_FT_STRING_EXPR __pyx_string_tab[64]
#define __pyx_n_u_END_STRING __pyx_string_tab[65]
#define __pyx_n_u_EOF __pyx_string_tab[66]
#define __pyx_n_u_Errors __pyx_string_tab[67]
#define __pyx_n_u_FT __pyx_string_tab[68]
#define __pyx_n_u_FTStringBracketState __pyx_string_tab[69]
#define __pyx_n_u_FTStringBracketState___init __pyx_string_tab[70]
#define __pyx_n_u_FTStringState __pyx_string_tab[71]
#define __pyx_n_u_FTStringState_bracket_nesting_le __pyx_string_tab[72]
#define __pyx_n_u_FTStringState_in_format_specifie __pyx_string_tab[73]
#define __pyx_n_u_FTStringState_pop_bracket_state __pyx_string_tab[74]
#define __pyx_n_u_FTStringState_push_bracket_state __pyx_string_tab[75]
#define __pyx_n_u_FTStringState_set_in_format_spec __pyx_string_tab[76]
#define __pyx_n_u_FT_STRING_EXPR_PRESCAN __pyx_string_tab[77]
#define __pyx_n_u_False __pyx_string_tab[78]
#define __pyx_n_u_FileSourceDescriptor __pyx_string_tab[79]
#define __pyx_n_u_FileSourceDescriptor___eq __pyx_string_tab[80]
#define __pyx_n_u_FileSourceDescriptor___hash __pyx_string_tab[81]
#define __pyx_n_u_FileSourceDescriptor___init __pyx_string_tab[82]
#define __pyx_n_u_FileSourceDescriptor___repr __pyx_string_tab[83]
#define __pyx_n_u_FileSourceDescriptor_get_descrip __pyx_string_tab[84]
#define __pyx_n_u_FileSourceDescriptor_get_error_d __pyx_string_tab[85]
#define __pyx_n_u_FileSourceDescriptor_get_file_ob __pyx_string_tab[86]
#define __pyx_n_u_FileSourceDescriptor_get_filenam __pyx_string_tab[87]
#define __pyx_n_u_FileSourceDescriptor_get_lines __pyx_string_tab[88]
#define __pyx_n_u_FileSourceDescriptor_get_relativ __pyx_string_tab[89]
#define __pyx_n_u_Future __pyx_string_tab[90]
#define __pyx_n_u_IDENT __pyx_string_tab[91]
#define __pyx_n_u_IF __pyx_string_tab[92]
#define __pyx_n_u_INDENT __pyx_string_tab[93]
#define __pyx_n_u_Lexicon __pyx_string_tab[94]
#define __pyx_n_u_NEWLINE __pyx_string_tab[95]
#define __pyx_n_u_NFKC __pyx_string_tab[96]
#define __pyx_n_u_Path __pyx_string_tab[97]
#define __pyx_n_u_Plex_Errors __pyx_string_tab[98]
#define __pyx_n_u_Plex_Scanners __pyx_string_tab[99]
#define __pyx_n_u_PyrexScanner __pyx_string_tab[100]
#define __pyx_n_u_PyrexScanner__handle_close_singl __pyx_string_tab[101]
#define __pyx_n_u_PyrexScanner__handle_open_single __pyx_string_tab[102]
#define __pyx_n_u_PyrexScanner_begin_ft_string_act __pyx_string_tab[103]
#define __pyx_n_u_PyrexScanner_begin_string_action __pyx_string_tab[104]
#define __pyx_n_u_PyrexScanner_close_brace_action __pyx_string_tab[105]
#define __pyx_n_u_PyrexScanner_close_bracket_actio __pyx_string_tab[106]
#define __pyx_n_u_PyrexScanner_close_ft_string_bra __pyx_string_tab[107]
#define __pyx_n_u_PyrexScanner_colon_action __pyx_string_tab[108]
#define __pyx_n_u_PyrexScanner_commentline __pyx_string_tab[109]
#define __pyx_n_u_PyrexScanner_end_ft_string_actio __pyx_string_tab[110]
#define __pyx_n_u_PyrexScanner_end_string_action __pyx_string_tab[111]
#define __pyx_n_u_PyrexScanner_enter_async __pyx_string_tab[112]
#define __pyx_n_u_PyrexScanner_eof_action __pyx_string_tab[113]
#define __pyx_n_u_PyrexScanner_error __pyx_string_tab[114]
#define __pyx_n_u_PyrexScanner_exit_async __pyx_string_tab[115]
#define __pyx_n_u_PyrexScanner_expect __pyx_string_tab[116]
#define __pyx_n_u_PyrexScanner_expect_dedent __pyx_string_tab[117]
#define __pyx_n_u_PyrexScanner_expect_indent __pyx_string_tab[118]
#define __pyx_n_u_PyrexScanner_expect_keyword __pyx_string_tab[119]
#define __pyx_n_u_PyrexScanner_expect_newline __pyx_string_tab[120]
#define __pyx_n_u_PyrexScanner_expected __pyx_string_tab[121]
#define __pyx_n_u_PyrexScanner_indentation_action __pyx_string_tab[122]
#define __pyx_n_u_PyrexScanner_newline_action __pyx_string_tab[123]
#define __pyx_n_u_PyrexScanner_next __pyx_string_tab[124]
#define __pyx_n_u_PyrexScanner_normalize_ident __pyx_string_tab[125]
#define __pyx_n_u_PyrexScanner_open_brace_action __pyx_string_tab[126]
#define __pyx_n_u_PyrexScanner_open_bracket_action __pyx_string_tab[127]
#define __pyx_n_u_PyrexScanner_open_ft_string_brac __pyx_string_tab[128]
#define __pyx_n_u_PyrexScanner_peek __pyx_string_tab[129]
#define __pyx_n_u_PyrexScanner_put_back __pyx_string_tab[130]
#define __pyx_n_u_PyrexScanner_strip_underscores __pyx_string_tab[131]
#define __pyx_n_u_PyrexScanner_unclosed_string_act __pyx_string_tab[132]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[133]
#define __pyx_n_u_R __pyx_string_tab[134]
#define __pyx_n_u_SQ_STRING __pyx_string_tab[135]
#define __pyx_n_u_Scanner __pyx_string_tab[136]
#define __pyx_n_u_SourceDescriptor __pyx_string_tab[137]
#define __pyx_n_u_SourceDescriptor___copy __pyx_string_tab[138]
#define __pyx_n_u_SourceDescriptor___deepcopy __pyx_string_tab[139]
#define __pyx_n_u_SourceDescriptor___gt __pyx_string_tab[140]
#define __pyx_n_u_SourceDescriptor___le __pyx_string_tab[141]
#define __pyx_n_u_SourceDescriptor___lt __pyx_string_tab[142]
#define __pyx_n_u_SourceDescriptor___str __pyx_string_tab[143]
#define __pyx_n_u_SourceDescriptor_get_escaped_des __pyx_string_tab[144]
#define __pyx_n_u_SourceDescriptor_is_cython_file __pyx_string_tab[145]
#define __pyx_n_u_SourceDescriptor_is_python_file __pyx_string_tab[146]
#define __pyx_n_u_SourceDescriptor_set_file_type_f __pyx_string_tab[147]
#define __pyx_n_u_StringSourceDescriptor __pyx_string_tab[148]
#define __pyx_n_u_StringSourceDescriptor___eq __pyx_string_tab[149]
#define __pyx_n_u_StringSourceDescriptor___hash __pyx_string_tab[150]
#define __pyx_n_u_StringSourceDescriptor___init __pyx_string_tab[151]
#define __pyx_n_u_StringSourceDescriptor___repr __pyx_string_tab[152]
#define __pyx_n_u_StringSourceDescriptor_get_descr __pyx_string_tab[153]
#define __pyx_n_u_StringSourceDescriptor_get_filen __pyx_string_tab[154]
#define __pyx_n_u_StringSourceDescriptor_get_lines __pyx_string_tab[155]
#define __pyx_n_u_StringSourceDescriptor_get_relat __pyx_string_tab[156]
#define __pyx_n_u_TDQ_STRING __pyx_string_tab[157]
#define __pyx_n_u_TSQ_STRING __pyx_string_tab[158]
#define __pyx_n_u_True __pyx_string_tab[159]
#define __pyx_n_u_UNAME_MACHINE __pyx_string_tab[160]
#define __pyx_n_u_UNAME_NODENAME __pyx_string_tab[161]
#define __pyx_n_u_UNAME_RELEASE __pyx_string_tab[162]
#define __pyx_n_u_UNAME_SYSNAME __pyx_string_tab[163]
#define __pyx_n_u_UNAME_VERSION __pyx_string_tab[164]
#define __pyx_n_u_UnrecognizedInput __pyx_string_tab[165]
#define __pyx_n_u_Utils __pyx_string_tab[166]
#define __pyx_n_u__4 __pyx_string_tab[167]
#define __pyx_n_u__5 __pyx_string_tab[168]
#define __pyx_n_u_abs __pyx_string_tab[169]
#define __pyx_n_u_abspath __pyx_string_tab[170]
#define __pyx_n_u_all __pyx_string_tab[171]
#define __pyx_n_u_and __pyx_string_tab[172]
#define __pyx_n_u_annotations __pyx_string_tab[173]
#define __pyx_n_u_any __pyx_string_tab[174]
#define __pyx_n_u_any_string_prefix __pyx_string_tab[175]
#define __pyx_n_u_ascii __pyx_string_tab[176]
#define __pyx_n_u_assert __pyx_string_tab[177]
#define __pyx_n_u_async __pyx_string_tab[178]
#define __pyx_n_u_async_enabled __pyx_string_tab[179]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[180]
#define __pyx_n_u_await __pyx_string_tab[181]
#define __pyx_n_u_begin_ft_string_action __pyx_string_tab[182]
#define __pyx_n_u_begin_string_action __pyx_string_tab[183]
#define __pyx_n_u_bin __pyx_string_tab[184]
#define __pyx_n_u_bool __pyx_string_tab[185]
#define __pyx_n_u_bracket_nesting_level __pyx_string_tab[186]
#define __pyx_n_u_break __pyx_string_tab[187]
#define __pyx_n_u_builtins __pyx_string_tab[188]
#define __pyx_n_u_bytearray __pyx_string_tab[189]
#define __pyx_n_u_bytes __pyx_string_tab[190]
#define __pyx_n_u_c __pyx_string_tab[191]
#define __pyx_n_u_cdef __pyx_string_tab[192]
#define __pyx_n_u_chr __pyx_string_tab[193]
#define __pyx_n_u_cimport __pyx_string_tab[194]
#define __pyx_n_u_class __pyx_string_tab[195]
#define __pyx_n_u_class_getitem __pyx_string_tab[196]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[197]
#define __pyx_n_u_close __pyx_string_tab[198]
#define __pyx_n_u_close_brace_action __pyx_string_tab[199]
#define __pyx_n_u_close_bracket_action __pyx_string_tab[200]
#define __pyx_n_u_close_ft_string_brace_action __pyx_string_tab[201]
#define __pyx_n_u_cmp_name __pyx_string_tab[202]
#define __pyx_n_u_code __pyx_string_tab[203]
#define __pyx_n_u_codelines __pyx_string_tab[204]
#define __pyx_n_u_colon_action __pyx_string_tab[205]
#define __pyx_n_u_commentline __pyx_string_tab[206]
#define __pyx_n_u_compile_time_env __pyx_string_tab[207]
#define __pyx_n_u_compile_time_eval __pyx_string_tab[208]
#define __pyx_n_u_compile_time_expr __pyx_string_tab[209]
#define __pyx_n_u_complex __pyx_string_tab[210]
#define __pyx_n_u_context __pyx_string_tab[211]
#define __pyx_n_u_contextlib __pyx_string_tab[212]
#define __pyx_n_u_contextmanager __pyx_string_tab[213]
#define __pyx_n_u_continue __pyx_string_tab[214]
#define __pyx_n_u_copy __pyx_string_tab[215]
#define __pyx_n_u_cpdef __pyx_string_tab[216]
#define __pyx_n_u_ctypedef __pyx_string_tab[217]
#define __pyx_n_u_current_level __pyx_string_tab[218]
#define __pyx_n_u_cwd __pyx_string_tab[219]
#define __pyx_n_u_debug_scanner __pyx_string_tab[220]
#define __pyx_n_u_declare __pyx_string_tab[221]
#define __pyx_n_u_decode __pyx_string_tab[222]
#define __pyx_n_u_decode_filename __pyx_string_tab[223]
#define __pyx_n_u_deepcopy __pyx_string_tab[224]
#define __pyx_n_u_def __pyx_string_tab[225]
#define __pyx_n_u_del __pyx_string_tab[226]
#define __pyx_n_u_dict __pyx_string_tab[227]
#define __pyx_n_u_divmod __pyx_string_tab[228]
#define __pyx_n_u_doc __pyx_string_tab[229]
#define __pyx_n_u_double_braces __pyx_string_tab[230]
#define __pyx_n_u_elif __pyx_string_tab[231]
#define __pyx_n_u_else __pyx_string_tab[232]
#define __pyx_n_u_encode __pyx_string_tab[233]
#define __pyx_n_u_encoding __pyx_string_tab[234]
#define __pyx_n_u_end_ft_string_action __pyx_string_tab[235]
#define __pyx_n_u_end_string_action __pyx_string_tab[236]
#define __pyx_n_u_enter __pyx_string_tab[237]
#define __pyx_n_u_enter_async __pyx_string_tab[238]
#define __pyx_n_u_enumerate __pyx_string_tab[239]
#define __pyx_n_u_eof_action __pyx_string_tab[240]
#define __pyx_n_u_eq __pyx_string_tab[241]
#define __pyx_n_u_err __pyx_string_tab[242]
#define __pyx_n_u_error __pyx_string_tab[243]
#define __pyx_n_u_error_handling __pyx_string_tab[244]
#define __pyx_n_u_errors __pyx_string_tab[245]
#define __pyx_n_u_escaped_description __pyx_string_tab[246]
#define __pyx_n_u_except __pyx_string_tab[247]
#define __pyx_n_u_exec __pyx_string_tab[248]
#define __pyx_n_u_exit __pyx_string_tab[249]
#define __pyx_n_u_exit_async __pyx_string_tab[250]
#define __pyx_n_u_expect __pyx_string_tab[251]
#define __pyx_n_u_expect_dedent __pyx_string_tab[252]
#define __pyx_n_u_expect_indent __pyx_string_tab[253]
#define __pyx_n_u_expect_keyword __pyx_string_tab[254]
#define __pyx_n_u_expect_newline __pyx_string_tab[255]
#define __pyx_n_u_expected __pyx_string_tab[256]
#define __pyx_n_u_ext __pyx_string_tab[257]
#define __pyx_n_u_f __pyx_string_tab[258]
#define __pyx_n_u_fatal __pyx_string_tab[259]
#define __pyx_n_u_file __pyx_string_tab[260]
#define __pyx_n_u_file_path __pyx_string_tab[261]
#define __pyx_n_u_file_type __pyx_string_tab[262]
#define __pyx_n_u_filename __pyx_string_tab[263]
#define __pyx_n_u_filter __pyx_string_tab[264]
#define __pyx_n_u_finally __pyx_string_tab[265]
#define __pyx_n_u_float __pyx_string_tab[266]
#define __pyx_n_u_for __pyx_string_tab[267]
#define __pyx_n_u_format __pyx_string_tab[268]
#define __pyx_n_u_found_2 __pyx_string_tab[269]
#define __pyx_n_u_from __pyx_string_tab[270]
#define __pyx_n_u_frozenset __pyx_string_tab[271]
#define __pyx_n_u_ft_string_bracket_level __pyx_string_tab[272]
#define __pyx_n_u_ft_string_prefixes __pyx_string_tab[273]
#define __pyx_n_u_ft_string_state __pyx_string_tab[274]
#define __pyx_n_u_func __pyx_string_tab[275]
#define __pyx_n_u_functools __pyx_string_tab[276]
#define __pyx_n_u_future_directives __pyx_string_tab[277]
#define __pyx_n_u_get __pyx_string_tab[278]
#define __pyx_n_u_get_description __pyx_string_tab[279]
#define __pyx_n_u_get_error_description __pyx_string_tab[280]
#define __pyx_n_u_get_escaped_description __pyx_string_tab[281]
#define __pyx_n_u_get_file_object __pyx_string_tab[282]
#define __pyx_n_u_get_filenametable_entry __pyx_string_tab[283]
#define __pyx_n_u_get_lines __pyx_string_tab[284]
#define __pyx_n_u_get_relative_path __pyx_string_tab[285]
#define __pyx_n_u_getcwd __pyx_string_tab[286]
#define __pyx_n_u_global __pyx_string_tab[287]
#define __pyx_n_u_gt __pyx_string_tab[288]
#define __pyx_n_u_handle_close_single_ft_string_b __pyx_string_tab[289]
#define __pyx_n_u_handle_open_single_ft_string_br __pyx_string_tab[290]
#define __pyx_n_u_hash __pyx_string_tab[291]
#define __pyx_n_u_hash_2 __pyx_string_tab[292]
#define __pyx_n_u_hex __pyx_string_tab[293]
#define __pyx_n_u_hold_errors __pyx_string_tab[294]
#define __pyx_n_u_id __pyx_string_tab[295]
#define __pyx_n_u_if __pyx_string_tab[296]
#define __pyx_n_u_ignore __pyx_string_tab[297]
#define __pyx_n_u_ignore_semicolon __pyx_string_tab[298]
#define __pyx_n_u_import __pyx_string_tab[299]
#define __pyx_n_u_in __pyx_string_tab[300]
#define __pyx_n_u_in_format_specifier __pyx_string_tab[301]
#define __pyx_n_u_in_utility_code __pyx_string_tab[302]
#define __pyx_n_u_include __pyx_string_tab[303]
#define __pyx_n_u_included_files __pyx_string_tab[304]
#define __pyx_n_u_indentation_action __pyx_string_tab[305]
#define __pyx_n_u_init __pyx_string_tab[306]
#define __pyx_n_u_initial_pos __pyx_string_tab[307]
#define __pyx_n_u_initial_state __pyx_string_tab[308]
#define __pyx_n_u_int __pyx_string_tab[309]
#define __pyx_n_u_intern_ustring __pyx_string_tab[310]
#define __pyx_n_u_is __pyx_string_tab[311]
#define __pyx_n_u_is_absolute __pyx_string_tab[312]
#define __pyx_n_u_is_coroutine __pyx_string_tab[313]
#define __pyx_n_u_is_cython_file __pyx_string_tab[314]
#define __pyx_n_u_is_python_file __pyx_string_tab[315]
#define __pyx_n_u_is_raw __pyx_string_tab[316]
#define __pyx_n_u_isascii __pyx_string_tab[317]
#define __pyx_n_u_items __pyx_string_tab[318]
#define __pyx_n_u_key __pyx_string_tab[319]
#define __pyx_n_u_lambda __pyx_string_tab[320]
#define __pyx_n_u_language_level __pyx_string_tab[321]
#define __pyx_n_u_le __pyx_string_tab[322]
#define __pyx_n_u_len __pyx_string_tab[323]
#define __pyx_n_u_len_text __pyx_string_tab[324]
#define __pyx_n_u_line __pyx_string_tab[325]
#define __pyx_n_u_lines __pyx_string_tab[326]
#define __pyx_n_u_lines_2 __pyx_string_tab[327]
#define __pyx_n_u_list __pyx_string_tab[328]
#define __pyx_n_u_long __pyx_string_tab[329]
#define __pyx_n_u_lookup __pyx_string_tab[330]
#define __pyx_n_u_lookup_here __pyx_string_tab[331]
#define __pyx_n_u_lt __pyx_string_tab[332]
#define __pyx_n_u_main __pyx_string_tab[333]
#define __pyx_n_u_make_lexicon __pyx_string_tab[334]
#define __pyx_n_u_map __pyx_string_tab[335]
#define __pyx_n_u_max __pyx_string_tab[336]
#define __pyx_n_u_memo __pyx_string_tab[337]
#define __pyx_n_u_message __pyx_string_tab[338]
#define __pyx_n_u_metaclass __pyx_string_tab[339]
#define __pyx_n_u_min __pyx_string_tab[340]
#define __pyx_n_u_module __pyx_string_tab[341]
#define __pyx_n_u_mro_entries __pyx_string_tab[342]
#define __pyx_n_u_name __pyx_string_tab[343]
#define __pyx_n_u_name_2 __pyx_string_tab[344]
#define __pyx_n_u_new_level __pyx_string_tab[345]
#define __pyx_n_u_newline_action __pyx_string_tab[346]
#define __pyx_n_u_next __pyx_string_tab[347]
#define __pyx_n_u_nonlocal __pyx_string_tab[348]
#define __pyx_n_u_normalize __pyx_string_tab[349]
#define __pyx_n_u_normalize_ident __pyx_string_tab[350]
#define __pyx_n_u_not __pyx_string_tab[351]
#define __pyx_n_u_oct __pyx_string_tab[352]
#define __pyx_n_u_open_brace_action __pyx_string_tab[353]
#define __pyx_n_u_open_bracket_action __pyx_string_tab[354]
#define __pyx_n_u_open_ft_string_brace_action __pyx_string_tab[355]
#define __pyx_n_u_open_source_file __pyx_string_tab[356]
#define __pyx_n_u_options __pyx_string_tab[357]
#define __pyx_n_u_or __pyx_string_tab[358]
#define __pyx_n_u_ord __pyx_string_tab[359]
#define __pyx_n_u_os __pyx_string_tab[360]
#define __pyx_n_u_other __pyx_string_tab[361]
#define __pyx_n_u_outer __pyx_string_tab[362]
#define __pyx_n_u_parent_scanner __pyx_string_tab[363]
#define __pyx_n_u_parse_comments __pyx_string_tab[364]
#define __pyx_n_u_pass __pyx_string_tab[365]
#define __pyx_n_u_path __pyx_string_tab[366]
#define __pyx_n_u_path_description __pyx_string_tab[367]
#define __pyx_n_u_pathlib __pyx_string_tab[368]
#define __pyx_n_u_peek __pyx_string_tab[369]
#define __pyx_n_u_platform __pyx_string_tab[370]
#define __pyx_n_u_pop __pyx_string_tab[371]
#define __pyx_n_u_pop_bracket_state __pyx_string_tab[372]
#define __pyx_n_u_pos __pyx_string_tab[373]
#define __pyx_n_u_pow __pyx_string_tab[374]
#define __pyx_n_u_prepare __pyx_string_tab[375]
#define __pyx_n_u_print __pyx_string_tab[376]
#define __pyx_n_u_print_function __pyx_string_tab[377]
#define __pyx_n_u_push_bracket_state __pyx_string_tab[378]
#define __pyx_n_u_put_back __pyx_string_tab[379]
#define __pyx_n_u_put_back_on_failure __pyx_string_tab[380]
#define __pyx_n_u_pxd_2 __pyx_string_tab[381]
#define __pyx_n_u_py_2 __pyx_string_tab[382]
#define __pyx_n_u_py_reserved_words __pyx_string_tab[383]
#define __pyx_n_u_pyx_2 __pyx_string_tab[384]
#define __pyx_n_u_pyx_capi __pyx_string_tab[385]
#define __pyx_n_u_pyx_reserved_words __pyx_string_tab[386]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[387]
#define __pyx_n_u_qualname __pyx_string_tab[388]
#define __pyx_n_u_r __pyx_string_tab[389]
#define __pyx_n_u_raise __pyx_string_tab[390]
#define __pyx_n_u_range __pyx_string_tab[391]
#define __pyx_n_u_readlines __pyx_string_tab[392]
#define __pyx_n_u_reduce __pyx_string_tab[393]
#define __pyx_n_u_release_errors __pyx_string_tab[394]
#define __pyx_n_u_relpath __pyx_string_tab[395]
#define __pyx_n_u_replace __pyx_string_tab[396]
#define __pyx_n_u_repr __pyx_string_tab[397]
#define __pyx_n_u_repr_2 __pyx_string_tab[398]
#define __pyx_n_u_return __pyx_string_tab[399]
#define __pyx_n_u_reversed __pyx_string_tab[400]
#define __pyx_n_u_round __pyx_string_tab[401]
#define __pyx_n_u_rstrip __pyx_string_tab[402]
#define __pyx_n_u_saved __pyx_string_tab[403]
#define __pyx_n_u_saved_pos __pyx_string_tab[404]
#define __pyx_n_u_scanner __pyx_string_tab[405]
#define __pyx_n_u_scanner_debug_flags __pyx_string_tab[406]
#define __pyx_n_u_scanner_dump_file __pyx_string_tab[407]
#define __pyx_n_u_scanner_state __pyx_string_tab[408]
#define __pyx_n_u_scope __pyx_string_tab[409]
#define __pyx_n_u_self __pyx_string_tab[410]
#define __pyx_n_u_send __pyx_string_tab[411]
#define __pyx_n_u_sep __pyx_string_tab[412]
#define __pyx_n_u_set __pyx_string_tab[413]
#define __pyx_n_u_set_file_type_from_name __pyx_string_tab[414]
#define __pyx_n_u_set_in_format_specifier __pyx_string_tab[415]
#define __pyx_n_u_set_name __pyx_string_tab[416]
#define __pyx_n_u_setdefault __pyx_string_tab[417]
#define __pyx_n_u_short_path_description __pyx_string_tab[418]
#define __pyx_n_u_slice __pyx_string_tab[419]
#define __pyx_n_u_slots __pyx_string_tab[420]
#define __pyx_n_u_sorted __pyx_string_tab[421]
#define __pyx_n_u_source_encoding __pyx_string_tab[422]
#define __pyx_n_u_splitext __pyx_string_tab[423]
#define __pyx_n_u_splitlines __pyx_string_tab[424]
#define __pyx_n_u_started_ft_string_expr __pyx_string_tab[425]
#define __pyx_n_u_startswith __pyx_string_tab[426]
#define __pyx_n_u_str __pyx_string_tab[427]
#define __pyx_n_u_str_2 __pyx_string_tab[428]
#define __pyx_n_u_string_states __pyx_string_tab[429]
#define __pyx_n_u_strip_underscores __pyx_string_tab[430]
#define __pyx_n_u_sum __pyx_string_tab[431]
#define __pyx_n_u_sy __pyx_string_tab[432]
#define __pyx_n_u_symbol __pyx_string_tab[433]
#define __pyx_n_u_systring __pyx_string_tab[434]
#define __pyx_n_u_tentatively_scan __pyx_string_tab[435]
#define __pyx_n_u_text __pyx_string_tab[436]
#define __pyx_n_u_throw __pyx_string_tab[437]
#define __pyx_n_u_trace_scanner __pyx_string_tab[438]
#define __pyx_n_u_try __pyx_string_tab[439]
#define __pyx_n_u_tuple __pyx_string_tab[440]
#define __pyx_n_u_uname __pyx_string_tab[441]
#define __pyx_n_u_unclosed_string_action __pyx_string_tab[442]
#define __pyx_n_u_unicode __pyx_string_tab[443]
#define __pyx_n_u_unicodedata __pyx_string_tab[444]
#define __pyx_n_u_update __pyx_string_tab[445]
#define __pyx_n_u_useless_trailing_semicolon_2 __pyx_string_tab[446]
#define __pyx_n_u_value __pyx_string_tab[447]
#define __pyx_n_u_values __pyx_string_tab[448]
#define __pyx_n_u_warning __pyx_string_tab[449]
#define __pyx_n_u_what __pyx_string_tab[450]
#define __pyx_n_u_while __pyx_string_tab[451]
#define __pyx_n_u_with __pyx_string_tab[452]
#define __pyx_n_u_workdir __pyx_string_tab[453]
#define __pyx_n_u_xrange __pyx_string_tab[454]
#define __pyx_n_u_yield __pyx_string_tab[455]
#define __pyx_n_u_zip __pyx_string_tab[456]
#define __pyx_kp_b_PyObject_IDENT_any_string_prefix __pyx_string_tab[457]
#define __pyx_kp_b_PyObject_void_get_lexicon_initia __pyx_string_tab[458]
#define __pyx_kp_b_iso88591_1_4t3a_Q __pyx_string_tab[459]
#define __pyx_kp_b_iso88591_1_4t3fD_Jc_Q __pyx_string_tab[460]
#define __pyx_kp_b_iso88591_1_D_Q_9L_4q_A_1 __pyx_string_tab[461]
#define __pyx_kp_b_iso88591_5_L_1_A_2U_4q_4q_E_r_1_M_QnHKq __pyx_string_tab[462]
#define __pyx_kp_b_iso88591_8_O7_7q __pyx_string_tab[463]
#define __pyx_kp_b_iso88591_A_2T __pyx_string_tab[464]
#define __pyx_kp_b_iso88591_A_3aq_4_Rr_Q_4AQ_Q_t4_Rr1EQ_A_E __pyx_string_tab[465]
#define __pyx_kp_b_iso88591_A_3aq_it4_5Rr9MQ_5Q_A_E_aq_M_1_5 __pyx_string_tab[466]
#define __pyx_kp_b_iso88591_A_4_1A_D_q_uG1A __pyx_string_tab[467]
#define __pyx_kp_b_iso88591_A_4_E_1 __pyx_string_tab[468]
#define __pyx_kp_b_iso88591_A_4_S_BhavQ_t1 __pyx_string_tab[469]
#define __pyx_kp_b_iso88591_A_4_U_1 __pyx_string_tab[470]
#define __pyx_kp_b_iso88591_A_4_c_aq_A __pyx_string_tab[471]
#define __pyx_kp_b_iso88591_A_4q __pyx_string_tab[472]
#define __pyx_kp_b_iso88591_A_4t1_1_t_Ba __pyx_string_tab[473]
#define __pyx_kp_b_iso88591_A_4t81_9AXQ_HAWA __pyx_string_tab[474]
#define __pyx_kp_b_iso88591_A_4uA_3c_y_4q_9Cxt_T_Qiq_c_D_8H __pyx_string_tab[475]
#define __pyx_kp_b_iso88591_A_Bb_VVW_3e3d2I_1_a_D_Q_a_a_0_q __pyx_string_tab[476]
#define __pyx_kp_b_iso88591_A_D_q_B_DCs_a_a_t_c_HAQ_at_1_2Q __pyx_string_tab[477]
#define __pyx_kp_b_iso88591_A_E_Q_D_E_t5_A_G1D_T_D_E_q __pyx_string_tab[478]
#define __pyx_kp_b_iso88591_A_F_t3SST_HAQ __pyx_string_tab[479]
#define __pyx_kp_b_iso88591_A_G1D_T_D_F_L __pyx_string_tab[480]
#define __pyx_kp_b_iso88591_A_G1Ja __pyx_string_tab[481]
#define __pyx_kp_b_iso88591_A_HAXQ __pyx_string_tab[482]
#define __pyx_kp_b_iso88591_A_HAXT_q __pyx_string_tab[483]
#define __pyx_kp_b_iso88591_A_HA_M_gS_HD_1_M __pyx_string_tab[484]
#define __pyx_kp_b_iso88591_A_HG1A __pyx_string_tab[485]
#define __pyx_kp_b_iso88591_A_O2R_6a __pyx_string_tab[486]
#define __pyx_kp_b_iso88591_A_O4q __pyx_string_tab[487]
#define __pyx_kp_b_iso88591_A_Rt1 __pyx_string_tab[488]
#define __pyx_kp_b_iso88591_A_S_S_Cq_e5_AS_5S_AS_1_4q_AT_q_Q __pyx_string_tab[489]
#define __pyx_kp_b_iso88591_A_a_4_c_Q_Q __pyx_string_tab[490]
#define __pyx_kp_b_iso88591_A_a_4q_b_Qd_aq_a_HAQ __pyx_string_tab[491]
#define __pyx_kp_b_iso88591_A_a_F_t3SST_HAQ __pyx_string_tab[492]
#define __pyx_kp_b_iso88591_A_a_q __pyx_string_tab[493]
#define __pyx_kp_b_iso88591_A_aq_Qa __pyx_string_tab[494]
#define __pyx_kp_b_iso88591_A_c_A_1_a_HAWA __pyx_string_tab[495]
#define __pyx_kp_b_iso88591_A_fBe9AQ_N_d_S_S __pyx_string_tab[496]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[497]
#define __pyx_kp_b_iso88591_A_r __pyx_string_tab[498]
#define __pyx_kp_b_iso88591_A_t1 __pyx_string_tab[499]
#define __pyx_kp_b_iso88591_A_t1D __pyx_string_tab[500]
#define __pyx_kp_b_iso88591_A_t1D_2 __pyx_string_tab[501]
#define __pyx_kp_b_iso88591_A_t1_e_1BgS_E_4_1_4q_1A_q __pyx_string_tab[502]
#define __pyx_kp_b_iso88591_A_t81A __pyx_string_tab[503]
#define __pyx_kp_b_iso88591_A_t_A_a_4t1_IQa_IQa_t4t9A_E_HO1D __pyx_string_tab[504]
#define __pyx_kp_b_iso88591_A_t_q __pyx_string_tab[505]
#define __pyx_kp_b_iso88591_A_t_s __pyx_string_tab[506]
#define __pyx_kp_b_iso88591_A_t_t7 __pyx_string_tab[507]
#define __pyx_kp_b_iso88591_A_uCq_D_q_B_DCs_a_t4_Rr1EQ_2_4_2 __pyx_string_tab[508]
#define __pyx_kp_b_iso88591_A_z_7t4z_EQR __pyx_string_tab[509]
#define __pyx_kp_b_iso88591_A_z_9_T_s_q __pyx_string_tab[510]
#define __pyx_kp_b_iso88591_M_Q_D_D_1_Ya_Q_4t3a_q_1_gQ_1_0 __pyx_string_tab[511]
#define __pyx_kp_b_iso88591_Q_1_aq_t4s_A_A_a_6fA __pyx_string_tab[512]
#define __pyx_kp_b_iso88591_Q_4s_iq_4t3a_q_e1E_7 __pyx_string_tab[513]
#define __pyx_kp_b_iso88591__14 __pyx_string_tab[514]
#define __pyx_kp_b_iso88591_a_Q_1 __pyx_string_tab[515]
#define __pyx_kp_b_iso88591_e4t1Cs_4q_F_4_Qa_HAQ __pyx_string_tab[516]
#define __pyx_kp_b_iso88591_oQ_u_Qd_Zq __pyx_string_tab[517]
#define __pyx_kp_b_iso88591_q_4q_4q_1D_q_A __pyx_string_tab[518]
#define __pyx_kp_b_iso88591_q_F_1_1_AQ_t_S_4_A_t81Ct3a_Qa_4 __pyx_string_tab[519]
#define __pyx_kp_b_iso88591_q_z_G4q_6_1__DWWX_AT_4xq_G1G9D __pyx_string_tab[520]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
#define __pyx_int_3 __pyx_number_tab[2]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Action);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Return);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Call);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Method);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Begin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Ignore);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Text);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_8Scanning_FTStringState);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan);
  for (int i=0; i<1; ++i) { Py_CLEAR(clear_module_state->__pyx_slice[i]); }
  for (int i=0; i<12; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<71; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<521; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* Generator.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Action);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Return);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Call);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Method);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Begin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Ignore);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Text);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_8Scanning_FTStringState);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan);
  for (int i=0; i<1; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_slice[i]); }
  for (int i=0; i<12; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<71; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<521; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* Generator.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "Cython/Compiler/Scanning.py":35
 * 
 * 
 * def get_lexicon():             # <<<<<<<<<<<<<<
 *     global lexicon
 *     if not lexicon:
*/

static PyObject *__pyx_f_6Cython_8Compiler_8Scanning_get_lexicon(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lexicon", 0);

  /* "Cython/Compiler/Scanning.py":37
 * def get_lexicon():
 *     global lexicon
 *     if not lexicon:             # <<<<<<<<<<<<<<
 *         lexicon = make_lexicon()
 *     return lexicon
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_6Cython_8Compiler_8Scanning_lexicon); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 37, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":38
 *     global lexicon
 *     if not lexicon:
 *         lexicon = make_lexicon()             # <<<<<<<<<<<<<<
 *     return lexicon
 * 
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_8Scanning_make_lexicon; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 38, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_lexicon);
    __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_lexicon, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":37
 * def get_lexicon():
 *     global lexicon
 *     if not lexicon:             # <<<<<<<<<<<<<<
 *         lexicon = make_lexicon()
 *     return lexicon
*/
  }

  /* "Cython/Compiler/Scanning.py":39
 *     if not lexicon:
 *         lexicon = make_lexicon()
 *     return lexicon             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_lexicon);
  __pyx_r = __pyx_v_6Cython_8Compiler_8Scanning_lexicon;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":35
 * 
 * 
 * def get_lexicon():             # <<<<<<<<<<<<<<
 *     global lexicon
 *     if not lexicon:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.get_lexicon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":62
 * class CompileTimeScope:
 * 
 *     def __init__(self, outer=None):             # <<<<<<<<<<<<<<
 *         self.entries = {}
 *         self.outer = outer
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_outer = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_outer,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 62, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 62, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 62, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 62, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_outer = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 62, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope___init__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), __pyx_v_outer);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_outer) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Scanning.py":63
 * 
 *     def __init__(self, outer=None):
 *         self.entries = {}             # <<<<<<<<<<<<<<
 *         self.outer = outer
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":64
 *     def __init__(self, outer=None):
 *         self.entries = {}
 *         self.outer = outer             # <<<<<<<<<<<<<<
 * 
 *     def declare(self, name, value):
*/
  __pyx_t_1 = __pyx_v_outer;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope))))) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->outer);
  __Pyx_DECREF((PyObject *)__pyx_v_self->outer);
  __pyx_v_self->outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":62
 * class CompileTimeScope:
 * 
 *     def __init__(self, outer=None):             # <<<<<<<<<<<<<<
 *         self.entries = {}
 *         self.outer = outer
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":66
 *         self.outer = outer
 * 
 *     def declare(self, name, value):             # <<<<<<<<<<<<<<
 *         self.entries[name] = value
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare = {"declare", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("declare (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_value,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 66, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 66, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 66, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "declare", 0) < (0)) __PYX_ERR(0, 66, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("declare", 1, 2, 2, i); __PYX_ERR(0, 66, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 66, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 66, __pyx_L3_error)
    }
    __pyx_v_name = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("declare", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 66, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.declare", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_2declare(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), __pyx_v_name, __pyx_v_value);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_2declare(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("declare", 0);

  /* "Cython/Compiler/Scanning.py":67
 * 
 *     def declare(self, name, value):
 *         self.entries[name] = value             # <<<<<<<<<<<<<<
 * 
 *     def update(self, other):
*/
  if (unlikely(__pyx_v_self->entries == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 67, __pyx_L1_error)
  }
  if (unlikely((PyDict_SetItem(__pyx_v_self->entries, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 67, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":66
 *         self.outer = outer
 * 
 *     def declare(self, name, value):             # <<<<<<<<<<<<<<
 *         self.entries[name] = value
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.declare", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":69
 *         self.entries[name] = value
 * 
 *     def update(self, other):             # <<<<<<<<<<<<<<
 *         self.entries.update(other)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update = {"update", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_4update(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_4update(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);

  /* "Cython/Compiler/Scanning.py":70
 * 
 *     def update(self, other):
 *         self.entries.update(other)             # <<<<<<<<<<<<<<
 * 
 *     def lookup_here(self, name):
*/
  __pyx_t_2 = __pyx_v_self->entries;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":69
 *         self.entries[name] = value
 * 
 *     def update(self, other):             # <<<<<<<<<<<<<<
 *         self.entries.update(other)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":72
 *         self.entries.update(other)
 * 
 *     def lookup_here(self, name):             # <<<<<<<<<<<<<<
 *         return self.entries[name]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here = {"lookup_here", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup_here (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_6lookup_here(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_6lookup_here(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup_here", 0);

  /* "Cython/Compiler/Scanning.py":73
 * 
 *     def lookup_here(self, name):
 *         return self.entries[name]             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, name):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->entries == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 73, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->entries, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":72
 *         self.entries.update(other)
 * 
 *     def lookup_here(self, name):             # <<<<<<<<<<<<<<
 *         return self.entries[name]
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.lookup_here", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":75
 *         return self.entries[name]
 * 
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.entries
 * 
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_9__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_8__contains__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_8__contains__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "Cython/Compiler/Scanning.py":76
 * 
 *     def __contains__(self, name):
 *         return name in self.entries             # <<<<<<<<<<<<<<
 * 
 *     def lookup(self, name):
*/
  if (unlikely(__pyx_v_self->entries == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 76, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_self->entries, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 76, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":75
 *         return self.entries[name]
 * 
 *     def __contains__(self, name):             # <<<<<<<<<<<<<<
 *         return name in self.entries
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":78
 *         return name in self.entries
 * 
 *     def lookup(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.lookup_here(name)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup = {"lookup", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_10lookup(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_10lookup(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_name) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_outer = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 0);

  /* "Cython/Compiler/Scanning.py":79
 * 
 *     def lookup(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.lookup_here(name)
 *         except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":80
 *     def lookup(self, name):
 *         try:
 *             return self.lookup_here(name)             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             outer = self.outer
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_name};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup_here, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 80, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Compiler/Scanning.py":79
 * 
 *     def lookup(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.lookup_here(name)
 *         except KeyError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Scanning.py":81
 *         try:
 *             return self.lookup_here(name)
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             outer = self.outer
 *             if outer:
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 81, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "Cython/Compiler/Scanning.py":82
 *             return self.lookup_here(name)
 *         except KeyError:
 *             outer = self.outer             # <<<<<<<<<<<<<<
 *             if outer:
 *                 return outer.lookup(name)
*/
      __pyx_t_9 = ((PyObject *)__pyx_v_self->outer);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_v_outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_9);
      __pyx_t_9 = 0;

      /* "Cython/Compiler/Scanning.py":83
 *         except KeyError:
 *             outer = self.outer
 *             if outer:             # <<<<<<<<<<<<<<
 *                 return outer.lookup(name)
 *             else:
*/
      __pyx_t_10 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_outer)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 83, __pyx_L5_except_error)
      if (likely(__pyx_t_10)) {

        /* "Cython/Compiler/Scanning.py":84
 *             outer = self.outer
 *             if outer:
 *                 return outer.lookup(name)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = ((PyObject *)__pyx_v_outer);
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_name};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 84, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __pyx_r = __pyx_t_9;
        __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L6_except_return;

        /* "Cython/Compiler/Scanning.py":83
 *         except KeyError:
 *             outer = self.outer
 *             if outer:             # <<<<<<<<<<<<<<
 *                 return outer.lookup(name)
 *             else:
*/
      }

      /* "Cython/Compiler/Scanning.py":86
 *                 return outer.lookup(name)
 *             else:
 *                 raise             # <<<<<<<<<<<<<<
 * 
 * 
*/
      /*else*/ {
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_8);
        __pyx_t_4 = 0;  __pyx_t_5 = 0;  __pyx_t_8 = 0; 
        __PYX_ERR(0, 86, __pyx_L5_except_error)
      }
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Scanning.py":79
 * 
 *     def lookup(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.lookup_here(name)
 *         except KeyError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":78
 *         return name in self.entries
 * 
 *     def lookup(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.lookup_here(name)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_outer);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":14
 * @cython.final
 * cdef class CompileTimeScope:
 *     cdef public dict entries             # <<<<<<<<<<<<<<
 *     cdef public CompileTimeScope outer
 *     ##cdef declare(self, name, value)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->entries);
  __pyx_r = __pyx_v_self->entries;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.entries.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(__pyx_v_self->entries);
  __pyx_v_self->entries = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":15
 * cdef class CompileTimeScope:
 *     cdef public dict entries
 *     cdef public CompileTimeScope outer             # <<<<<<<<<<<<<<
 *     ##cdef declare(self, name, value)
 *     ##cdef lookup_here(self, name)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->outer);
  __pyx_r = ((PyObject *)__pyx_v_self->outer);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope))))) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->outer);
  __Pyx_DECREF((PyObject *)__pyx_v_self->outer);
  __pyx_v_self->outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.CompileTimeScope.outer.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->outer);
  __Pyx_DECREF((PyObject *)__pyx_v_self->outer);
  __pyx_v_self->outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":89
 * 
 * 
 * def initial_compile_time_env():             # <<<<<<<<<<<<<<
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
*/

static PyObject *__pyx_f_6Cython_8Compiler_8Scanning_initial_compile_time_env(void) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_benv = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_builtins = NULL;
  PyObject *__pyx_v_reduce = NULL;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_denv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("initial_compile_time_env", 0);

  /* "Cython/Compiler/Scanning.py":90
 * 
 * def initial_compile_time_env():
 *     benv = CompileTimeScope()             # <<<<<<<<<<<<<<
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
 *     for name, value in zip(names, platform.uname()):
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_benv = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":91
 * def initial_compile_time_env():
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')             # <<<<<<<<<<<<<<
 *     for name, value in zip(names, platform.uname()):
 *         benv.declare(name, value)
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_tuple[0]);
  __pyx_v_names = __pyx_mstate_global->__pyx_tuple[0];

  /* "Cython/Compiler/Scanning.py":92
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
 *     for name, value in zip(names, platform.uname()):             # <<<<<<<<<<<<<<
 *         benv.declare(name, value)
 *     import builtins
*/
  __pyx_t_2 = NULL;
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_8Scanning_platform;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_uname, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_names, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_zip, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 92, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 92, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_6;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 92, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6);
        #endif
        ++__pyx_t_6;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_4);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 92, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 92, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
      } else {
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 92, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
      }
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 92, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 92, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
      index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_5 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 92, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Scanning.py":93
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
 *     for name, value in zip(names, platform.uname()):
 *         benv.declare(name, value)             # <<<<<<<<<<<<<<
 *     import builtins
 * 
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_benv);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_name, __pyx_v_value};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":92
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
 *     for name, value in zip(names, platform.uname()):             # <<<<<<<<<<<<<<
 *         benv.declare(name, value)
 *     import builtins
*/
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":94
 *     for name, value in zip(names, platform.uname()):
 *         benv.declare(name, value)
 *     import builtins             # <<<<<<<<<<<<<<
 * 
 *     names = (
*/
  __pyx_t_10 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_builtins, 0, 0, NULL, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 94, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_10;
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_builtins = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":97
 * 
 *     names = (
 *         'False', 'True',             # <<<<<<<<<<<<<<
 *         'abs', 'all', 'any', 'ascii', 'bin', 'bool', 'bytearray', 'bytes',
 *         'chr', 'complex', 'dict', 'divmod', 'enumerate', 'filter',
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_DECREF_SET(__pyx_v_names, __pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Compiler/Scanning.py":108
 *     )
 * 
 *     for name in names:             # <<<<<<<<<<<<<<
 *         benv.declare(name, getattr(builtins, name))
 * 
*/
  __pyx_t_4 = __pyx_v_names; __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 108, __pyx_L1_error)
      #endif
      if (__pyx_t_6 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6));
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6);
    #endif
    ++__pyx_t_6;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":109
 * 
 *     for name in names:
 *         benv.declare(name, getattr(builtins, name))             # <<<<<<<<<<<<<<
 * 
 *     # legacy Py2 names
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_benv);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_GetAttr(__pyx_v_builtins, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_name, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":108
 *     )
 * 
 *     for name in names:             # <<<<<<<<<<<<<<
 *         benv.declare(name, getattr(builtins, name))
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":112
 * 
 *     # legacy Py2 names
 *     from functools import reduce             # <<<<<<<<<<<<<<
 *     benv.declare('reduce', reduce)
 *     benv.declare('unicode', str)
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_reduce};
    __pyx_t_10 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_functools, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 112, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_10;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_reduce};
    __pyx_t_6 = 0; {
      __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_6]); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      switch (__pyx_t_6) {
        case 0:
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_reduce = __pyx_t_1;
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":113
 *     # legacy Py2 names
 *     from functools import reduce
 *     benv.declare('reduce', reduce)             # <<<<<<<<<<<<<<
 *     benv.declare('unicode', str)
 *     benv.declare('long', int)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_benv);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_reduce, __pyx_v_reduce};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":114
 *     from functools import reduce
 *     benv.declare('reduce', reduce)
 *     benv.declare('unicode', str)             # <<<<<<<<<<<<<<
 *     benv.declare('long', int)
 *     benv.declare('xrange', range)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_benv);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_unicode, ((PyObject *)(&PyUnicode_Type))};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":115
 *     benv.declare('reduce', reduce)
 *     benv.declare('unicode', str)
 *     benv.declare('long', int)             # <<<<<<<<<<<<<<
 *     benv.declare('xrange', range)
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_benv);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long, ((PyObject *)(&PyLong_Type))};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":116
 *     benv.declare('unicode', str)
 *     benv.declare('long', int)
 *     benv.declare('xrange', range)             # <<<<<<<<<<<<<<
 * 
 *     denv = CompileTimeScope(benv)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_benv);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_xrange, ((PyObject *)(&PyRange_Type))};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":118
 *     benv.declare('xrange', range)
 * 
 *     denv = CompileTimeScope(benv)             # <<<<<<<<<<<<<<
 *     return denv
 * 
*/
  __pyx_t_1 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_v_benv)};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_4);
  }
  __pyx_v_denv = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":119
 * 
 *     denv = CompileTimeScope(benv)
 *     return denv             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_denv);
  __pyx_r = ((PyObject *)__pyx_v_denv);
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":89
 * 
 * 
 * def initial_compile_time_env():             # <<<<<<<<<<<<<<
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.initial_compile_time_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_benv);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_builtins);
  __Pyx_XDECREF(__pyx_v_reduce);
  __Pyx_XDECREF((PyObject *)__pyx_v_denv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":135
 *     _escaped_description = None
 *     _cmp_name = ''
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_1__str__ = {"__str__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_1__str__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor___str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor___str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "Cython/Compiler/Scanning.py":136
 *     _cmp_name = ''
 *     def __str__(self):
 *         assert False  # To catch all places where a descriptor is used directly as a filename             # <<<<<<<<<<<<<<
 * 
 *     def set_file_type_from_name(self, filename):
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    if (unlikely(!0)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 136, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 136, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/Scanning.py":135
 *     _escaped_description = None
 *     _cmp_name = ''
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":138
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
 *     def set_file_type_from_name(self, filename):             # <<<<<<<<<<<<<<
 *         name, ext = os.path.splitext(filename)
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_3set_file_type_from_name(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_3set_file_type_from_name = {"set_file_type_from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_3set_file_type_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_3set_file_type_from_name(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_filename = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_file_type_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_filename,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 138, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 138, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 138, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_file_type_from_name", 0) < (0)) __PYX_ERR(0, 138, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("set_file_type_from_name", 1, 2, 2, i); __PYX_ERR(0, 138, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 138, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 138, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_filename = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_file_type_from_name", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 138, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.set_file_type_from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_2set_file_type_from_name(__pyx_self, __pyx_v_self, __pyx_v_filename);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_2set_file_type_from_name(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_filename) {
  CYTHON_UNUSED PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_ext = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_file_type_from_name", 0);

  /* "Cython/Compiler/Scanning.py":139
 * 
 *     def set_file_type_from_name(self, filename):
 *         name, ext = os.path.splitext(filename)             # <<<<<<<<<<<<<<
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_filename};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_splitext, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 139, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_2);
    } else {
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_2);
    }
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < (0)) __PYX_ERR(0, 139, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 139, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_name = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_ext = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":140
 *     def set_file_type_from_name(self, filename):
 *         name, ext = os.path.splitext(filename)
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'             # <<<<<<<<<<<<<<
 * 
 *     def is_cython_file(self):
*/
  __Pyx_INCREF(__pyx_v_ext);
  __pyx_t_2 = __pyx_v_ext;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_pyx, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 140, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_pxd, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 140, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_py, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 140, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_8;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __pyx_t_7;
  if (!__pyx_t_8) {
    goto __pyx_L6_next_or;
  } else {
  }
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_ext, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 140, __pyx_L1_error)
  if (!__pyx_t_8) {
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_L6_next_or:;
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_pyx_2);
  __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_pyx_2;
  __pyx_L5_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_type, __pyx_t_1) < (0)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":138
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
 *     def set_file_type_from_name(self, filename):             # <<<<<<<<<<<<<<
 *         name, ext = os.path.splitext(filename)
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.set_file_type_from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_ext);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":142
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
 * 
 *     def is_cython_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type in ('pyx', 'pxd')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_5is_cython_file(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_5is_cython_file = {"is_cython_file", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_5is_cython_file, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_5is_cython_file(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_cython_file (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_4is_cython_file(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_4is_cython_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_cython_file", 0);

  /* "Cython/Compiler/Scanning.py":143
 * 
 *     def is_cython_file(self):
 *         return self._file_type in ('pyx', 'pxd')             # <<<<<<<<<<<<<<
 * 
 *     def is_python_file(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 143, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pxd_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 143, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L3_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":142
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
 * 
 *     def is_cython_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type in ('pyx', 'pxd')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.is_cython_file", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":145
 *         return self._file_type in ('pyx', 'pxd')
 * 
 *     def is_python_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type == 'py'
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_7is_python_file(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_7is_python_file = {"is_python_file", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_7is_python_file, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_7is_python_file(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_python_file (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_6is_python_file(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_6is_python_file(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_python_file", 0);

  /* "Cython/Compiler/Scanning.py":146
 * 
 *     def is_python_file(self):
 *         return self._file_type == 'py'             # <<<<<<<<<<<<<<
 * 
 *     def get_escaped_description(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_py_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":145
 *         return self._file_type in ('pyx', 'pxd')
 * 
 *     def is_python_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type == 'py'
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.is_python_file", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":148
 *         return self._file_type == 'py'
 * 
 *     def get_escaped_description(self):             # <<<<<<<<<<<<<<
 *         if self._escaped_description is None:
 *             # Use forward slashes on Windows since these paths
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_9get_escaped_description(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_9get_escaped_description = {"get_escaped_description", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_9get_escaped_description, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_9get_escaped_description(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_escaped_description (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_8get_escaped_description(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_8get_escaped_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_escaped_description", 0);

  /* "Cython/Compiler/Scanning.py":149
 * 
 *     def get_escaped_description(self):
 *         if self._escaped_description is None:             # <<<<<<<<<<<<<<
 *             # Use forward slashes on Windows since these paths
 *             # will be used in the #line directives in the C/C++ files.
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_escaped_description); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":152
 *             # Use forward slashes on Windows since these paths
 *             # will be used in the #line directives in the C/C++ files.
 *             self._escaped_description = self.get_description().replace('\\', '/')             # <<<<<<<<<<<<<<
 *         return self._escaped_description
 * 
*/
    __pyx_t_3 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_description, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_mstate_global->__pyx_tuple[2], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_escaped_description, __pyx_t_1) < (0)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":149
 * 
 *     def get_escaped_description(self):
 *         if self._escaped_description is None:             # <<<<<<<<<<<<<<
 *             # Use forward slashes on Windows since these paths
 *             # will be used in the #line directives in the C/C++ files.
*/
  }

  /* "Cython/Compiler/Scanning.py":153
 *             # will be used in the #line directives in the C/C++ files.
 *             self._escaped_description = self.get_description().replace('\\', '/')
 *         return self._escaped_description             # <<<<<<<<<<<<<<
 * 
 *     def __gt__(self, other):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_escaped_description); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":148
 *         return self._file_type == 'py'
 * 
 *     def get_escaped_description(self):             # <<<<<<<<<<<<<<
 *         if self._escaped_description is None:
 *             # Use forward slashes on Windows since these paths
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.get_escaped_description", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":155
 *         return self._escaped_description
 * 
 *     def __gt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_11__gt__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_11__gt__ = {"__gt__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_11__gt__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_11__gt__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__gt__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 155, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 155, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 155, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__gt__", 0) < (0)) __PYX_ERR(0, 155, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__gt__", 1, 2, 2, i); __PYX_ERR(0, 155, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 155, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 155, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__gt__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 155, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__gt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_10__gt__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_10__gt__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__gt__", 0);

  /* "Cython/Compiler/Scanning.py":157
 *     def __gt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name > other._cmp_name
 *         except AttributeError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":158
 *         # this is only used to provide some sort of order
 *         try:
 *             return self._cmp_name > other._cmp_name             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             return False
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 158, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 158, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Compiler/Scanning.py":157
 *     def __gt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name > other._cmp_name
 *         except AttributeError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Scanning.py":159
 *         try:
 *             return self._cmp_name > other._cmp_name
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);

      /* "Cython/Compiler/Scanning.py":160
 *             return self._cmp_name > other._cmp_name
 *         except AttributeError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def __lt__(self, other):
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Scanning.py":157
 *     def __gt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name > other._cmp_name
 *         except AttributeError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":155
 *         return self._escaped_description
 * 
 *     def __gt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__gt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":162
 *             return False
 * 
 *     def __lt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_13__lt__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_13__lt__ = {"__lt__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_13__lt__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_13__lt__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lt__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 162, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__lt__", 0) < (0)) __PYX_ERR(0, 162, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__lt__", 1, 2, 2, i); __PYX_ERR(0, 162, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 162, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 162, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__lt__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 162, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__lt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_12__lt__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_12__lt__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__lt__", 0);

  /* "Cython/Compiler/Scanning.py":164
 *     def __lt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name < other._cmp_name
 *         except AttributeError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":165
 *         # this is only used to provide some sort of order
 *         try:
 *             return self._cmp_name < other._cmp_name             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             return False
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 165, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Compiler/Scanning.py":164
 *     def __lt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name < other._cmp_name
 *         except AttributeError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Scanning.py":166
 *         try:
 *             return self._cmp_name < other._cmp_name
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);

      /* "Cython/Compiler/Scanning.py":167
 *             return self._cmp_name < other._cmp_name
 *         except AttributeError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def __le__(self, other):
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Scanning.py":164
 *     def __lt__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name < other._cmp_name
 *         except AttributeError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":162
 *             return False
 * 
 *     def __lt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__lt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":169
 *             return False
 * 
 *     def __le__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_15__le__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_15__le__ = {"__le__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_15__le__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_15__le__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__le__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 169, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 169, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 169, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__le__", 0) < (0)) __PYX_ERR(0, 169, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__le__", 1, 2, 2, i); __PYX_ERR(0, 169, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 169, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 169, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__le__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 169, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__le__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_14__le__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_14__le__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__le__", 0);

  /* "Cython/Compiler/Scanning.py":171
 *     def __le__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name <= other._cmp_name
 *         except AttributeError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":172
 *         # this is only used to provide some sort of order
 *         try:
 *             return self._cmp_name <= other._cmp_name             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             return False
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 172, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_cmp_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 172, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_LE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 172, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Compiler/Scanning.py":171
 *     def __le__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name <= other._cmp_name
 *         except AttributeError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Scanning.py":173
 *         try:
 *             return self._cmp_name <= other._cmp_name
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);

      /* "Cython/Compiler/Scanning.py":174
 *             return self._cmp_name <= other._cmp_name
 *         except AttributeError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def __copy__(self):
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Scanning.py":171
 *     def __le__(self, other):
 *         # this is only used to provide some sort of order
 *         try:             # <<<<<<<<<<<<<<
 *             return self._cmp_name <= other._cmp_name
 *         except AttributeError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":169
 *             return False
 * 
 *     def __le__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__le__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":176
 *             return False
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_17__copy__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_17__copy__ = {"__copy__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_17__copy__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_17__copy__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_16__copy__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_16__copy__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__", 0);

  /* "Cython/Compiler/Scanning.py":177
 * 
 *     def __copy__(self):
 *         return self  # immutable, no need to copy             # <<<<<<<<<<<<<<
 * 
 *     def __deepcopy__(self, memo):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":176
 *             return False
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":179
 *         return self  # immutable, no need to copy
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_19__deepcopy__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_19__deepcopy__ = {"__deepcopy__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_19__deepcopy__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_16SourceDescriptor_19__deepcopy__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_memo = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__deepcopy__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_memo,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 179, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 179, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 179, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__deepcopy__", 0) < (0)) __PYX_ERR(0, 179, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__deepcopy__", 1, 2, 2, i); __PYX_ERR(0, 179, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 179, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 179, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_memo = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__deepcopy__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 179, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.SourceDescriptor.__deepcopy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_18__deepcopy__(__pyx_self, __pyx_v_self, __pyx_v_memo);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_16SourceDescriptor_18__deepcopy__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__deepcopy__", 0);

  /* "Cython/Compiler/Scanning.py":180
 * 
 *     def __deepcopy__(self, memo):
 *         return self  # immutable, no need to copy             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":179
 *         return self  # immutable, no need to copy
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":191
 *     the position()-tuple.
 *     """
 *     def __init__(self, filename, path_description=None):             # <<<<<<<<<<<<<<
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_path_description = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_filename,&__pyx_mstate_global->__pyx_n_u_path_description,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 191, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 191, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 191, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 191, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 191, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, i); __PYX_ERR(0, 191, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 191, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 191, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 191, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_filename = values[1];
    __pyx_v_path_description = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 191, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor___init__(__pyx_self, __pyx_v_self, __pyx_v_filename, __pyx_v_path_description);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_filename, PyObject *__pyx_v_path_description) {
  PyObject *__pyx_v_workdir = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_filename);

  /* "Cython/Compiler/Scanning.py":192
 *     """
 *     def __init__(self, filename, path_description=None):
 *         filename = Utils.decode_filename(filename)             # <<<<<<<<<<<<<<
 *         self.filename = filename
 *         self.path_description = path_description or filename
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Utils); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_decode_filename); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_filename};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF_SET(__pyx_v_filename, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":193
 *     def __init__(self, filename, path_description=None):
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename             # <<<<<<<<<<<<<<
 *         self.path_description = path_description or filename
 *         try:
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename, __pyx_v_filename) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":194
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename
 *         self.path_description = path_description or filename             # <<<<<<<<<<<<<<
 *         try:
 *             self._short_path_description = os.path.relpath(self.path_description)
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_path_description); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 194, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __Pyx_INCREF(__pyx_v_path_description);
    __pyx_t_1 = __pyx_v_path_description;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_filename);
  __pyx_t_1 = __pyx_v_filename;
  __pyx_L3_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_path_description, __pyx_t_1) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":195
 *         self.filename = filename
 *         self.path_description = path_description or filename
 *         try:             # <<<<<<<<<<<<<<
 *             self._short_path_description = os.path.relpath(self.path_description)
 *         except ValueError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":196
 *         self.path_description = path_description or filename
 *         try:
 *             self._short_path_description = os.path.relpath(self.path_description)             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             # path not under current directory => use complete file path
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_path_description); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 196, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_relpath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_short_path_description, __pyx_t_1) < (0)) __PYX_ERR(0, 196, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Scanning.py":195
 *         self.filename = filename
 *         self.path_description = path_description or filename
 *         try:             # <<<<<<<<<<<<<<
 *             self._short_path_description = os.path.relpath(self.path_description)
 *         except ValueError:
*/
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":197
 *         try:
 *             self._short_path_description = os.path.relpath(self.path_description)
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             # path not under current directory => use complete file path
 *             self._short_path_description = self.path_description
*/
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(0, 197, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "Cython/Compiler/Scanning.py":199
 *         except ValueError:
 *             # path not under current directory => use complete file path
 *             self._short_path_description = self.path_description             # <<<<<<<<<<<<<<
 *         # Prefer relative paths to current directory (which is most likely the project root) over absolute paths.
 *         workdir = os.path.abspath('.') + os.sep
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_path_description); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 199, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_short_path_description, __pyx_t_4) < (0)) __PYX_ERR(0, 199, __pyx_L7_except_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L6_exception_handled;
    }
    goto __pyx_L7_except_error;

    /* "Cython/Compiler/Scanning.py":195
 *         self.filename = filename
 *         self.path_description = path_description or filename
 *         try:             # <<<<<<<<<<<<<<
 *             self._short_path_description = os.path.relpath(self.path_description)
 *         except ValueError:
*/
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L6_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    __pyx_L10_try_end:;
  }

  /* "Cython/Compiler/Scanning.py":201
 *             self._short_path_description = self.path_description
 *         # Prefer relative paths to current directory (which is most likely the project root) over absolute paths.
 *         workdir = os.path.abspath('.') + os.sep             # <<<<<<<<<<<<<<
 *         self.file_path = filename[len(workdir):] if filename.startswith(workdir) else filename
 *         self.set_file_type_from_name(filename)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_t_1;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_abspath, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_mstate_global->__pyx_n_u_sep); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_workdir = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":202
 *         # Prefer relative paths to current directory (which is most likely the project root) over absolute paths.
 *         workdir = os.path.abspath('.') + os.sep
 *         self.file_path = filename[len(workdir):] if filename.startswith(workdir) else filename             # <<<<<<<<<<<<<<
 *         self.set_file_type_from_name(filename)
 *         self._cmp_name = filename
*/
  __pyx_t_3 = __pyx_v_filename;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_workdir};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {
    __pyx_t_11 = PyObject_Length(__pyx_v_workdir); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 202, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_filename, __pyx_t_11, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
    __pyx_t_1 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_filename);
    __pyx_t_2 = __pyx_v_filename;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_path, __pyx_t_2) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":203
 *         workdir = os.path.abspath('.') + os.sep
 *         self.file_path = filename[len(workdir):] if filename.startswith(workdir) else filename
 *         self.set_file_type_from_name(filename)             # <<<<<<<<<<<<<<
 *         self._cmp_name = filename
 *         self._lines = {}
*/
  __pyx_t_1 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_filename};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set_file_type_from_name, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":204
 *         self.file_path = filename[len(workdir):] if filename.startswith(workdir) else filename
 *         self.set_file_type_from_name(filename)
 *         self._cmp_name = filename             # <<<<<<<<<<<<<<
 *         self._lines = {}
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cmp_name, __pyx_v_filename) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":205
 *         self.set_file_type_from_name(filename)
 *         self._cmp_name = filename
 *         self._lines = {}             # <<<<<<<<<<<<<<
 * 
 *     def get_lines(self, encoding=None, error_handling=None):
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_lines, __pyx_t_2) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":191
 *     the position()-tuple.
 *     """
 *     def __init__(self, filename, path_description=None):             # <<<<<<<<<<<<<<
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_workdir);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":207
 *         self._lines = {}
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         # we cache the lines only the second time this is called, in
 *         # order to save memory when they are only used once
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_3get_lines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_3get_lines = {"get_lines", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_3get_lines, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_3get_lines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_error_handling = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_encoding,&__pyx_mstate_global->__pyx_n_u_error_handling,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 207, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 207, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 207, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 207, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_lines", 0) < (0)) __PYX_ERR(0, 207, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_lines", 0, 1, 3, i); __PYX_ERR(0, 207, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 207, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 207, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 207, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_encoding = values[1];
    __pyx_v_error_handling = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lines", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 207, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_lines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_2get_lines(__pyx_self, __pyx_v_self, __pyx_v_encoding, __pyx_v_error_handling);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_2get_lines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling) {
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_7genexpr__pyx_v_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lines", 0);

  /* "Cython/Compiler/Scanning.py":210
 *         # we cache the lines only the second time this is called, in
 *         # order to save memory when they are only used once
 *         key = (encoding, error_handling)             # <<<<<<<<<<<<<<
 *         lines = self._lines.get(key)
 *         if lines is not None:
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_encoding);
  __Pyx_GIVEREF(__pyx_v_encoding);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_encoding) != (0)) __PYX_ERR(0, 210, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_error_handling);
  __Pyx_GIVEREF(__pyx_v_error_handling);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_error_handling) != (0)) __PYX_ERR(0, 210, __pyx_L1_error);
  __pyx_v_key = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":211
 *         # order to save memory when they are only used once
 *         key = (encoding, error_handling)
 *         lines = self._lines.get(key)             # <<<<<<<<<<<<<<
 *         if lines is not None:
 *             return lines
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_lines); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_key};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_lines = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":212
 *         key = (encoding, error_handling)
 *         lines = self._lines.get(key)
 *         if lines is not None:             # <<<<<<<<<<<<<<
 *             return lines
 * 
*/
  __pyx_t_5 = (__pyx_v_lines != Py_None);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Scanning.py":213
 *         lines = self._lines.get(key)
 *         if lines is not None:
 *             return lines             # <<<<<<<<<<<<<<
 * 
 *         with self.get_file_object(encoding=encoding, error_handling=error_handling) as f:
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_r = __pyx_v_lines;
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":212
 *         key = (encoding, error_handling)
 *         lines = self._lines.get(key)
 *         if lines is not None:             # <<<<<<<<<<<<<<
 *             return lines
 * 
*/
  }

  /* "Cython/Compiler/Scanning.py":215
 *             return lines
 * 
 *         with self.get_file_object(encoding=encoding, error_handling=error_handling) as f:             # <<<<<<<<<<<<<<
 *             lines = [line.rstrip() for line in f.readlines()]
 * 
*/
  /*with:*/ {
    __pyx_t_3 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_encoding, __pyx_v_encoding, __pyx_t_2, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 215, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_error_handling, __pyx_v_error_handling, __pyx_t_2, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 215, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_get_file_object, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 215, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_7 = __pyx_t_2;
    __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {
          __pyx_v_f = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Scanning.py":216
 * 
 *         with self.get_file_object(encoding=encoding, error_handling=error_handling) as f:
 *             lines = [line.rstrip() for line in f.readlines()]             # <<<<<<<<<<<<<<
 * 
 *         # Do not cache the first access, but add the key to remember that we already read it once.
*/
          { /* enter inner scope */
            __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 216, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_2 = __pyx_v_f;
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_4 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
              __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_readlines, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_1);
            }
            if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
              __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
              __pyx_t_11 = 0;
              __pyx_t_12 = NULL;
            } else {
              __pyx_t_11 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 216, __pyx_L16_error)
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            for (;;) {
              if (likely(!__pyx_t_12)) {
                if (likely(PyList_CheckExact(__pyx_t_2))) {
                  {
                    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
                    #if !CYTHON_ASSUME_SAFE_SIZE
                    if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 216, __pyx_L16_error)
                    #endif
                    if (__pyx_t_11 >= __pyx_temp) break;
                  }
                  __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_11, __Pyx_ReferenceSharing_OwnStrongReference);
                  ++__pyx_t_11;
                } else {
                  {
                    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
                    #if !CYTHON_ASSUME_SAFE_SIZE
                    if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 216, __pyx_L16_error)
                    #endif
                    if (__pyx_t_11 >= __pyx_temp) break;
                  }
                  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                  __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_11));
                  #else
                  __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_11);
                  #endif
                  ++__pyx_t_11;
                }
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L16_error)
              } else {
                __pyx_t_1 = __pyx_t_12(__pyx_t_2);
                if (unlikely(!__pyx_t_1)) {
                  PyObject* exc_type = PyErr_Occurred();
                  if (exc_type) {
                    if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 216, __pyx_L16_error)
                    PyErr_Clear();
                  }
                  break;
                }
              }
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_line, __pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_3 = __pyx_7genexpr__pyx_v_line;
              __Pyx_INCREF(__pyx_t_3);
              __pyx_t_4 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
                __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L16_error)
                __Pyx_GOTREF(__pyx_t_1);
              }
              if (unlikely(__Pyx_ListComp_Append(__pyx_t_7, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 216, __pyx_L16_error)
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_7genexpr__pyx_v_line); __pyx_7genexpr__pyx_v_line = 0;
            goto __pyx_L20_exit_scope;
            __pyx_L16_error:;
            __Pyx_XDECREF(__pyx_7genexpr__pyx_v_line); __pyx_7genexpr__pyx_v_line = 0;
            goto __pyx_L8_error;
            __pyx_L20_exit_scope:;
          } /* exit inner scope */
          __Pyx_DECREF_SET(__pyx_v_lines, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Scanning.py":215
 *             return lines
 * 
 *         with self.get_file_object(encoding=encoding, error_handling=error_handling) as f:             # <<<<<<<<<<<<<<
 *             lines = [line.rstrip() for line in f.readlines()]
 * 
*/
        }
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L13_try_end;
        __pyx_L8_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_lines", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_1) < 0) __PYX_ERR(0, 215, __pyx_L10_except_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_2);
          __Pyx_XGOTREF(__pyx_t_1);
          __pyx_t_3 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, NULL);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 215, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_5 < (0)) __PYX_ERR(0, 215, __pyx_L10_except_error)
          __pyx_t_14 = (!__pyx_t_5);
          if (unlikely(__pyx_t_14)) {
            __Pyx_GIVEREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_2);
            __Pyx_XGIVEREF(__pyx_t_1);
            __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_2, __pyx_t_1);
            __pyx_t_7 = 0;  __pyx_t_2 = 0;  __pyx_t_1 = 0; 
            __PYX_ERR(0, 215, __pyx_L10_except_error)
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L9_exception_handled;
        }
        __pyx_L10_except_error:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L9_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        __pyx_L13_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_6) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[3], NULL);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 215, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        goto __pyx_L7;
      }
      __pyx_L7:;
    }
    goto __pyx_L24;
    __pyx_L4_error:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L1_error;
    __pyx_L24:;
  }

  /* "Cython/Compiler/Scanning.py":219
 * 
 *         # Do not cache the first access, but add the key to remember that we already read it once.
 *         self._lines[key] = lines if key in self._lines else None             # <<<<<<<<<<<<<<
 *         return lines
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_lines); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_v_key, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_14) {
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_t_1 = __pyx_v_lines;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_lines); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_key, __pyx_t_1) < 0))) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":220
 *         # Do not cache the first access, but add the key to remember that we already read it once.
 *         self._lines[key] = lines if key in self._lines else None
 *         return lines             # <<<<<<<<<<<<<<
 * 
 *     def get_file_object(self, encoding=None, error_handling=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_lines);
  __pyx_r = __pyx_v_lines;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":207
 *         self._lines = {}
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         # we cache the lines only the second time this is called, in
 *         # order to save memory when they are only used once
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_lines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":222
 *         return lines
 * 
 *     def get_file_object(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_5get_file_object(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_5get_file_object = {"get_file_object", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_5get_file_object, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_5get_file_object(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_error_handling = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_file_object (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_encoding,&__pyx_mstate_global->__pyx_n_u_error_handling,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 222, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 222, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 222, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 222, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_file_object", 0) < (0)) __PYX_ERR(0, 222, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_file_object", 0, 1, 3, i); __PYX_ERR(0, 222, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 222, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 222, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 222, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_encoding = values[1];
    __pyx_v_error_handling = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_file_object", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 222, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_file_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_4get_file_object(__pyx_self, __pyx_v_self, __pyx_v_encoding, __pyx_v_error_handling);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_4get_file_object(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_file_object", 0);

  /* "Cython/Compiler/Scanning.py":223
 * 
 *     def get_file_object(self, encoding=None, error_handling=None):
 *         return Utils.open_source_file(self.filename, encoding, error_handling)             # <<<<<<<<<<<<<<
 * 
 *     def get_description(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Utils); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_open_source_file); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_t_3, __pyx_v_encoding, __pyx_v_error_handling};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":222
 *         return lines
 * 
 *     def get_file_object(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_file_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":225
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self._short_path_description
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_7get_description(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_7get_description = {"get_description", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_7get_description, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_7get_description(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_description (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_6get_description(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_6get_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_description", 0);

  /* "Cython/Compiler/Scanning.py":226
 * 
 *     def get_description(self):
 *         return self._short_path_description             # <<<<<<<<<<<<<<
 * 
 *     def get_relative_path(self) -> Path:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_short_path_description); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":225
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self._short_path_description
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_description", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":228
 *         return self._short_path_description
 * 
 *     def get_relative_path(self) -> Path:             # <<<<<<<<<<<<<<
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_9get_relative_path(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_9get_relative_path = {"get_relative_path", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_9get_relative_path, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_9get_relative_path(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_relative_path (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_8get_relative_path(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_8get_relative_path(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_file_path = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_relative_path", 0);

  /* "Cython/Compiler/Scanning.py":229
 * 
 *     def get_relative_path(self) -> Path:
 *         file_path = Path(self.file_path)             # <<<<<<<<<<<<<<
 *         if file_path.is_absolute():
 *             return Path(self.get_description())
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_Path);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_8Scanning_Path; 
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_file_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":230
 *     def get_relative_path(self) -> Path:
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():             # <<<<<<<<<<<<<<
 *             return Path(self.get_description())
 *         else:
*/
  __pyx_t_3 = __pyx_v_file_path;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_absolute, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Scanning.py":231
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():
 *             return Path(self.get_description())             # <<<<<<<<<<<<<<
 *         else:
 *             return file_path
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_Path);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_8Scanning_Path; 
    __pyx_t_7 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_description, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":230
 *     def get_relative_path(self) -> Path:
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():             # <<<<<<<<<<<<<<
 *             return Path(self.get_description())
 *         else:
*/
  }

  /* "Cython/Compiler/Scanning.py":233
 *             return Path(self.get_description())
 *         else:
 *             return file_path             # <<<<<<<<<<<<<<
 * 
 *     def get_error_description(self):
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_file_path);
    __pyx_r = __pyx_v_file_path;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":228
 *         return self._short_path_description
 * 
 *     def get_relative_path(self) -> Path:             # <<<<<<<<<<<<<<
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_relative_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_file_path);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":235
 *             return file_path
 * 
 *     def get_error_description(self):             # <<<<<<<<<<<<<<
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_11get_error_description(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_11get_error_description = {"get_error_description", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_11get_error_description, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_11get_error_description(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_error_description (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_10get_error_description(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_10get_error_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_v_cwd = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_error_description", 0);

  /* "Cython/Compiler/Scanning.py":236
 * 
 *     def get_error_description(self):
 *         path = self.filename             # <<<<<<<<<<<<<<
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
 *         if path.startswith(cwd):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":237
 *     def get_error_description(self):
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)             # <<<<<<<<<<<<<<
 *         if path.startswith(cwd):
 *             return path[len(cwd):]
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Utils); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_decode_filename); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_8Scanning_os;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getcwd, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_sep); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_cwd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":238
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
 *         if path.startswith(cwd):             # <<<<<<<<<<<<<<
 *             return path[len(cwd):]
 *         return path
*/
  __pyx_t_4 = __pyx_v_path;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_cwd};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Scanning.py":239
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
 *         if path.startswith(cwd):
 *             return path[len(cwd):]             # <<<<<<<<<<<<<<
 *         return path
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = PyObject_Length(__pyx_v_cwd); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 239, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_path, __pyx_t_9, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":238
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
 *         if path.startswith(cwd):             # <<<<<<<<<<<<<<
 *             return path[len(cwd):]
 *         return path
*/
  }

  /* "Cython/Compiler/Scanning.py":240
 *         if path.startswith(cwd):
 *             return path[len(cwd):]
 *         return path             # <<<<<<<<<<<<<<
 * 
 *     def get_filenametable_entry(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_path);
  __pyx_r = __pyx_v_path;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":235
 *             return file_path
 * 
 *     def get_error_description(self):             # <<<<<<<<<<<<<<
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_error_description", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_cwd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":242
 *         return path
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return self.file_path
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_13get_filenametable_entry(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_13get_filenametable_entry = {"get_filenametable_entry", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_13get_filenametable_entry, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_13get_filenametable_entry(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_filenametable_entry (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_12get_filenametable_entry(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_12get_filenametable_entry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_filenametable_entry", 0);

  /* "Cython/Compiler/Scanning.py":243
 * 
 *     def get_filenametable_entry(self):
 *         return self.file_path             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_file_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":242
 *         return path
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return self.file_path
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.get_filenametable_entry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":245
 *         return self.file_path
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_15__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_15__eq__ = {"__eq__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_15__eq__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_15__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 245, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 245, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 245, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__eq__", 0) < (0)) __PYX_ERR(0, 245, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, i); __PYX_ERR(0, 245, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 245, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 245, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 245, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_14__eq__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_14__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "Cython/Compiler/Scanning.py":246
 * 
 *     def __eq__(self, other):
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":245
 *         return self.file_path
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":248
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.filename)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_17__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_17__hash__ = {"__hash__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_17__hash__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_17__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_16__hash__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_16__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_hash_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "Cython/Compiler/Scanning.py":249
 * 
 *     def __hash__(self):
 *         return hash(self.filename)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Hash(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_hash_t)-1))) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyLong_FromHash_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":248
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.filename)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":251
 *         return hash(self.filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<FileSourceDescriptor:%s>" % self.filename
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_19__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_19__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_19__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_19__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_18__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_18__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Compiler/Scanning.py":252
 * 
 *     def __repr__(self):
 *         return "<FileSourceDescriptor:%s>" % self.filename             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_filename); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_FileSourceDescriptor_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":251
 *         return hash(self.filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<FileSourceDescriptor:%s>" % self.filename
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FileSourceDescriptor.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":260
 *     code originates from a string object.
 *     """
 *     def __init__(self, name, code):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         #self.set_file_type_from_name(name)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 260, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 260, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 260, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 260, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 260, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 260, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 260, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 260, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 260, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_code = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 260, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor___init__(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_code);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_code) {
  PyObject *__pyx_8genexpr1__pyx_v_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Scanning.py":261
 *     """
 *     def __init__(self, name, code):
 *         self.name = name             # <<<<<<<<<<<<<<
 *         #self.set_file_type_from_name(name)
 *         self.codelines = [line.rstrip() for line in code.splitlines()]
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name, __pyx_v_name) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":263
 *         self.name = name
 *         #self.set_file_type_from_name(name)
 *         self.codelines = [line.rstrip() for line in code.splitlines()]             # <<<<<<<<<<<<<<
 *         self._cmp_name = name
 * 
*/
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_v_code;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_splitlines, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 263, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 263, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 263, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_5;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 263, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5));
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5);
          #endif
          ++__pyx_t_5;
        }
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L5_error)
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 263, __pyx_L5_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_line, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_8genexpr1__pyx_v_line;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 263, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_line); __pyx_8genexpr1__pyx_v_line = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_line); __pyx_8genexpr1__pyx_v_line = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_codelines, __pyx_t_1) < (0)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":264
 *         #self.set_file_type_from_name(name)
 *         self.codelines = [line.rstrip() for line in code.splitlines()]
 *         self._cmp_name = name             # <<<<<<<<<<<<<<
 * 
 *     def get_lines(self, encoding=None, error_handling=None):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cmp_name, __pyx_v_name) < (0)) __PYX_ERR(0, 264, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":260
 *     code originates from a string object.
 *     """
 *     def __init__(self, name, code):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         #self.set_file_type_from_name(name)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":266
 *         self._cmp_name = name
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         if not encoding:
 *             return self.codelines
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_3get_lines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_3get_lines = {"get_lines", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_3get_lines, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_3get_lines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_error_handling = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_encoding,&__pyx_mstate_global->__pyx_n_u_error_handling,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 266, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 266, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 266, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 266, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_lines", 0) < (0)) __PYX_ERR(0, 266, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_lines", 0, 1, 3, i); __PYX_ERR(0, 266, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 266, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 266, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 266, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_encoding = values[1];
    __pyx_v_error_handling = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lines", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 266, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.get_lines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_2get_lines(__pyx_self, __pyx_v_self, __pyx_v_encoding, __pyx_v_error_handling);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_2get_lines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_encoding, PyObject *__pyx_v_error_handling) {
  PyObject *__pyx_8genexpr2__pyx_v_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lines", 0);

  /* "Cython/Compiler/Scanning.py":267
 * 
 *     def get_lines(self, encoding=None, error_handling=None):
 *         if not encoding:             # <<<<<<<<<<<<<<
 *             return self.codelines
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_encoding); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 267, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":268
 *     def get_lines(self, encoding=None, error_handling=None):
 *         if not encoding:
 *             return self.codelines             # <<<<<<<<<<<<<<
 *         else:
 *             return [line.encode(encoding, error_handling).decode(encoding)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_codelines); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":267
 * 
 *     def get_lines(self, encoding=None, error_handling=None):
 *         if not encoding:             # <<<<<<<<<<<<<<
 *             return self.codelines
 *         else:
*/
  }

  /* "Cython/Compiler/Scanning.py":270
 *             return self.codelines
 *         else:
 *             return [line.encode(encoding, error_handling).decode(encoding)             # <<<<<<<<<<<<<<
 *                     for line in self.codelines]
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 270, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "Cython/Compiler/Scanning.py":271
 *         else:
 *             return [line.encode(encoding, error_handling).decode(encoding)
 *                     for line in self.codelines]             # <<<<<<<<<<<<<<
 * 
 *     def get_description(self):
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_codelines); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 271, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_5 = __pyx_t_4; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 271, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 271, __pyx_L6_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 271, __pyx_L6_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_6;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 271, __pyx_L6_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6));
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6);
            #endif
            ++__pyx_t_6;
          }
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 271, __pyx_L6_error)
        } else {
          __pyx_t_4 = __pyx_t_7(__pyx_t_5);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 271, __pyx_L6_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_line, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Compiler/Scanning.py":270
 *             return self.codelines
 *         else:
 *             return [line.encode(encoding, error_handling).decode(encoding)             # <<<<<<<<<<<<<<
 *                     for line in self.codelines]
 * 
*/
        __pyx_t_10 = __pyx_8genexpr2__pyx_v_line;
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_11 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_encoding, __pyx_v_error_handling};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 270, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __pyx_t_8 = __pyx_t_9;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_11 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_encoding};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decode, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 270, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 270, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "Cython/Compiler/Scanning.py":271
 *         else:
 *             return [line.encode(encoding, error_handling).decode(encoding)
 *                     for line in self.codelines]             # <<<<<<<<<<<<<<
 * 
 *     def get_description(self):
*/
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_line); __pyx_8genexpr2__pyx_v_line = 0;
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_line); __pyx_8genexpr2__pyx_v_line = 0;
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Scanning.py":266
 *         self._cmp_name = name
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         if not encoding:
 *             return self.codelines
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.get_lines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":273
 *                     for line in self.codelines]
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_5get_description(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_5get_description = {"get_description", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_5get_description, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_5get_description(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_description (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_4get_description(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_4get_description(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_description", 0);

  /* "Cython/Compiler/Scanning.py":274
 * 
 *     def get_description(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 *     def get_relative_path(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":273
 *                     for line in self.codelines]
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.get_description", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":276
 *         return self.name
 * 
 *     def get_relative_path(self):             # <<<<<<<<<<<<<<
 *         return Path(self.get_description())
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_7get_relative_path(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_7get_relative_path = {"get_relative_path", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_7get_relative_path, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_7get_relative_path(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_relative_path (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_6get_relative_path(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_6get_relative_path(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_relative_path", 0);

  /* "Cython/Compiler/Scanning.py":277
 * 
 *     def get_relative_path(self):
 *         return Path(self.get_description())             # <<<<<<<<<<<<<<
 * 
 *     get_error_description = get_description
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_Path);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_8Scanning_Path; 
  __pyx_t_5 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_description, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":276
 *         return self.name
 * 
 *     def get_relative_path(self):             # <<<<<<<<<<<<<<
 *         return Path(self.get_description())
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.get_relative_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":281
 *     get_error_description = get_description
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return "<stringsource>"
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_9get_filenametable_entry(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_9get_filenametable_entry = {"get_filenametable_entry", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_9get_filenametable_entry, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_9get_filenametable_entry(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_filenametable_entry (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_8get_filenametable_entry(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_8get_filenametable_entry(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_filenametable_entry", 0);

  /* "Cython/Compiler/Scanning.py":282
 * 
 *     def get_filenametable_entry(self):
 *         return "<stringsource>"             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_stringsource);
  __pyx_r = __pyx_mstate_global->__pyx_kp_u_stringsource;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":281
 *     get_error_description = get_description
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return "<stringsource>"
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":284
 *         return "<stringsource>"
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 *         # Do not hash on the name, an identical string source should be the
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_11__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_11__hash__ = {"__hash__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_11__hash__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_11__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_10__hash__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_10__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "Cython/Compiler/Scanning.py":285
 * 
 *     def __hash__(self):
 *         return id(self)             # <<<<<<<<<<<<<<
 *         # Do not hash on the name, an identical string source should be the
 *         # same object (name is often defaulted in other places)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":284
 *         return "<stringsource>"
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 *         # Do not hash on the name, an identical string source should be the
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":290
 *         # return hash(self.name)
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_13__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_13__eq__ = {"__eq__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_13__eq__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_13__eq__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 290, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 290, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 290, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__eq__", 0) < (0)) __PYX_ERR(0, 290, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, i); __PYX_ERR(0, 290, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 290, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 290, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 290, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_12__eq__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_12__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "Cython/Compiler/Scanning.py":291
 * 
 *     def __eq__(self, other):
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_1 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":290
 *         # return hash(self.name)
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":293
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<StringSourceDescriptor:%s>" % self.name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_15__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_15__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_15__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_15__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_14__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_14__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Compiler/Scanning.py":294
 * 
 *     def __repr__(self):
 *         return "<StringSourceDescriptor:%s>" % self.name             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_StringSourceDescriptor_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":293
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<StringSourceDescriptor:%s>" % self.name
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.StringSourceDescriptor.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":308
 *     #                                       contextmanager can restore it
 * 
 *     def __init__(self, file, filename, parent_scanner=None,             # <<<<<<<<<<<<<<
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_file = 0;
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_parent_scanner = 0;
  PyObject *__pyx_v_scope = 0;
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_source_encoding = 0;
  PyObject *__pyx_v_parse_comments = 0;
  PyObject *__pyx_v_initial_pos = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_file,&__pyx_mstate_global->__pyx_n_u_filename,&__pyx_mstate_global->__pyx_n_u_parent_scanner,&__pyx_mstate_global->__pyx_n_u_scope,&__pyx_mstate_global->__pyx_n_u_context,&__pyx_mstate_global->__pyx_n_u_source_encoding,&__pyx_mstate_global->__pyx_n_u_parse_comments,&__pyx_mstate_global->__pyx_n_u_initial_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 308, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_VARARGS(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_VARARGS(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_VARARGS(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 308, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Compiler/Scanning.py":309
 * 
 *     def __init__(self, file, filename, parent_scanner=None,
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):             # <<<<<<<<<<<<<<
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
 * 
*/
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, i); __PYX_ERR(0, 308, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_VARARGS(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_VARARGS(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_VARARGS(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 308, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 308, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 308, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "Cython/Compiler/Scanning.py":308
 *     #                                       contextmanager can restore it
 * 
 *     def __init__(self, file, filename, parent_scanner=None,             # <<<<<<<<<<<<<<
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Compiler/Scanning.py":309
 * 
 *     def __init__(self, file, filename, parent_scanner=None,
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):             # <<<<<<<<<<<<<<
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
 * 
*/
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_file = values[0];
    __pyx_v_filename = values[1];
    __pyx_v_parent_scanner = values[2];
    __pyx_v_scope = values[3];
    __pyx_v_context = values[4];
    __pyx_v_source_encoding = values[5];
    __pyx_v_parse_comments = values[6];
    __pyx_v_initial_pos = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, __pyx_nargs); __PYX_ERR(0, 308, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner___init__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_file, __pyx_v_filename, __pyx_v_parent_scanner, __pyx_v_scope, __pyx_v_context, __pyx_v_source_encoding, __pyx_v_parse_comments, __pyx_v_initial_pos);

  /* "Cython/Compiler/Scanning.py":308
 *     #                                       contextmanager can restore it
 * 
 *     def __init__(self, file, filename, parent_scanner=None,             # <<<<<<<<<<<<<<
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_file, PyObject *__pyx_v_filename, PyObject *__pyx_v_parent_scanner, PyObject *__pyx_v_scope, PyObject *__pyx_v_context, PyObject *__pyx_v_source_encoding, PyObject *__pyx_v_parse_comments, PyObject *__pyx_v_initial_pos) {
  PyObject *__pyx_v_keywords = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_keyword = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Scanning.py":310
 *     def __init__(self, file, filename, parent_scanner=None,
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)             # <<<<<<<<<<<<<<
 * 
 *         if filename.is_python_file():
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_8Scanning_get_lexicon(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_t_3, __pyx_v_file, __pyx_v_filename, __pyx_v_initial_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_4, (6-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":312
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
 * 
 *         if filename.is_python_file():             # <<<<<<<<<<<<<<
 *             self.in_python_file = True
 *             keywords = py_reserved_words
*/
  __pyx_t_3 = __pyx_v_filename;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_python_file, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Scanning.py":313
 * 
 *         if filename.is_python_file():
 *             self.in_python_file = True             # <<<<<<<<<<<<<<
 *             keywords = py_reserved_words
 *         else:
*/
    __pyx_v_self->in_python_file = 1;

    /* "Cython/Compiler/Scanning.py":314
 *         if filename.is_python_file():
 *             self.in_python_file = True
 *             keywords = py_reserved_words             # <<<<<<<<<<<<<<
 *         else:
 *             self.in_python_file = False
*/
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_py_reserved_words); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_keywords = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":312
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
 * 
 *         if filename.is_python_file():             # <<<<<<<<<<<<<<
 *             self.in_python_file = True
 *             keywords = py_reserved_words
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Scanning.py":316
 *             keywords = py_reserved_words
 *         else:
 *             self.in_python_file = False             # <<<<<<<<<<<<<<
 *             keywords = pyx_reserved_words
 *         self.keywords = {keyword: keyword for keyword in keywords}
*/
  /*else*/ {
    __pyx_v_self->in_python_file = 0;

    /* "Cython/Compiler/Scanning.py":317
 *         else:
 *             self.in_python_file = False
 *             keywords = pyx_reserved_words             # <<<<<<<<<<<<<<
 *         self.keywords = {keyword: keyword for keyword in keywords}
 * 
*/
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_reserved_words); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_keywords = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Scanning.py":318
 *             self.in_python_file = False
 *             keywords = pyx_reserved_words
 *         self.keywords = {keyword: keyword for keyword in keywords}             # <<<<<<<<<<<<<<
 * 
 *         self.async_enabled = 0
*/
  { /* enter inner scope */
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_keywords)) || PyTuple_CheckExact(__pyx_v_keywords)) {
      __pyx_t_3 = __pyx_v_keywords; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_keywords); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 318, __pyx_L6_error)
    }
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 318, __pyx_L6_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_6;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 318, __pyx_L6_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6));
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6);
          #endif
          ++__pyx_t_6;
        }
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L6_error)
      } else {
        __pyx_t_2 = __pyx_t_7(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 318, __pyx_L6_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_keyword, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(PyDict_SetItem(__pyx_t_1, (PyObject*)__pyx_8genexpr3__pyx_v_keyword, (PyObject*)__pyx_8genexpr3__pyx_v_keyword))) __PYX_ERR(0, 318, __pyx_L6_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_keyword); __pyx_8genexpr3__pyx_v_keyword = 0;
    goto __pyx_L10_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_keyword); __pyx_8genexpr3__pyx_v_keyword = 0;
    goto __pyx_L1_error;
    __pyx_L10_exit_scope:;
  } /* exit inner scope */
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->keywords);
  __Pyx_DECREF(__pyx_v_self->keywords);
  __pyx_v_self->keywords = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":320
 *         self.keywords = {keyword: keyword for keyword in keywords}
 * 
 *         self.async_enabled = 0             # <<<<<<<<<<<<<<
 * 
 *         if parent_scanner:
*/
  __pyx_v_self->async_enabled = 0;

  /* "Cython/Compiler/Scanning.py":322
 *         self.async_enabled = 0
 * 
 *         if parent_scanner:             # <<<<<<<<<<<<<<
 *             self.context = parent_scanner.context
 *             self.included_files = parent_scanner.included_files
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_parent_scanner); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 322, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Scanning.py":323
 * 
 *         if parent_scanner:
 *             self.context = parent_scanner.context             # <<<<<<<<<<<<<<
 *             self.included_files = parent_scanner.included_files
 *             self.compile_time_env = parent_scanner.compile_time_env
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":324
 *         if parent_scanner:
 *             self.context = parent_scanner.context
 *             self.included_files = parent_scanner.included_files             # <<<<<<<<<<<<<<
 *             self.compile_time_env = parent_scanner.compile_time_env
 *             self.compile_time_eval = parent_scanner.compile_time_eval
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_included_files); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 324, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->included_files);
    __Pyx_DECREF(__pyx_v_self->included_files);
    __pyx_v_self->included_files = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":325
 *             self.context = parent_scanner.context
 *             self.included_files = parent_scanner.included_files
 *             self.compile_time_env = parent_scanner.compile_time_env             # <<<<<<<<<<<<<<
 *             self.compile_time_eval = parent_scanner.compile_time_eval
 *             self.compile_time_expr = parent_scanner.compile_time_expr
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_compile_time_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope))))) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->compile_time_env);
    __Pyx_DECREF((PyObject *)__pyx_v_self->compile_time_env);
    __pyx_v_self->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":326
 *             self.included_files = parent_scanner.included_files
 *             self.compile_time_env = parent_scanner.compile_time_env
 *             self.compile_time_eval = parent_scanner.compile_time_eval             # <<<<<<<<<<<<<<
 *             self.compile_time_expr = parent_scanner.compile_time_expr
 * 
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_compile_time_eval); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->compile_time_eval = __pyx_t_5;

    /* "Cython/Compiler/Scanning.py":327
 *             self.compile_time_env = parent_scanner.compile_time_env
 *             self.compile_time_eval = parent_scanner.compile_time_eval
 *             self.compile_time_expr = parent_scanner.compile_time_expr             # <<<<<<<<<<<<<<
 * 
 *             if parent_scanner.async_enabled:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_compile_time_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->compile_time_expr = __pyx_t_5;

    /* "Cython/Compiler/Scanning.py":329
 *             self.compile_time_expr = parent_scanner.compile_time_expr
 * 
 *             if parent_scanner.async_enabled:             # <<<<<<<<<<<<<<
 *                 self.enter_async()
 *         else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent_scanner, __pyx_mstate_global->__pyx_n_u_async_enabled); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/Scanning.py":330
 * 
 *             if parent_scanner.async_enabled:
 *                 self.enter_async()             # <<<<<<<<<<<<<<
 *         else:
 *             self.context = context
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_async, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 330, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Scanning.py":329
 *             self.compile_time_expr = parent_scanner.compile_time_expr
 * 
 *             if parent_scanner.async_enabled:             # <<<<<<<<<<<<<<
 *                 self.enter_async()
 *         else:
*/
    }

    /* "Cython/Compiler/Scanning.py":322
 *         self.async_enabled = 0
 * 
 *         if parent_scanner:             # <<<<<<<<<<<<<<
 *             self.context = parent_scanner.context
 *             self.included_files = parent_scanner.included_files
*/
    goto __pyx_L11;
  }

  /* "Cython/Compiler/Scanning.py":332
 *                 self.enter_async()
 *         else:
 *             self.context = context             # <<<<<<<<<<<<<<
 *             self.included_files = scope.included_files
 *             self.compile_time_env = initial_compile_time_env()
*/
  /*else*/ {
    __Pyx_INCREF(__pyx_v_context);
    __Pyx_GIVEREF(__pyx_v_context);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = __pyx_v_context;

    /* "Cython/Compiler/Scanning.py":333
 *         else:
 *             self.context = context
 *             self.included_files = scope.included_files             # <<<<<<<<<<<<<<
 *             self.compile_time_env = initial_compile_time_env()
 *             self.compile_time_eval = 1
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_scope, __pyx_mstate_global->__pyx_n_u_included_files); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 333, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->included_files);
    __Pyx_DECREF(__pyx_v_self->included_files);
    __pyx_v_self->included_files = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":334
 *             self.context = context
 *             self.included_files = scope.included_files
 *             self.compile_time_env = initial_compile_time_env()             # <<<<<<<<<<<<<<
 *             self.compile_time_eval = 1
 *             self.compile_time_expr = 0
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_8Scanning_initial_compile_time_env(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope))))) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->compile_time_env);
    __Pyx_DECREF((PyObject *)__pyx_v_self->compile_time_env);
    __pyx_v_self->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":335
 *             self.included_files = scope.included_files
 *             self.compile_time_env = initial_compile_time_env()
 *             self.compile_time_eval = 1             # <<<<<<<<<<<<<<
 *             self.compile_time_expr = 0
 *             if getattr(context.options, 'compile_time_env', None):
*/
    __pyx_v_self->compile_time_eval = 1;

    /* "Cython/Compiler/Scanning.py":336
 *             self.compile_time_env = initial_compile_time_env()
 *             self.compile_time_eval = 1
 *             self.compile_time_expr = 0             # <<<<<<<<<<<<<<
 *             if getattr(context.options, 'compile_time_env', None):
 *                 self.compile_time_env.update(context.options.compile_time_env)
*/
    __pyx_v_self->compile_time_expr = 0;

    /* "Cython/Compiler/Scanning.py":337
 *             self.compile_time_eval = 1
 *             self.compile_time_expr = 0
 *             if getattr(context.options, 'compile_time_env', None):             # <<<<<<<<<<<<<<
 *                 self.compile_time_env.update(context.options.compile_time_env)
 *         self.parse_comments = parse_comments
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_options); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_GetAttr3(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_compile_time_env, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/Scanning.py":338
 *             self.compile_time_expr = 0
 *             if getattr(context.options, 'compile_time_env', None):
 *                 self.compile_time_env.update(context.options.compile_time_env)             # <<<<<<<<<<<<<<
 *         self.parse_comments = parse_comments
 *         self.source_encoding = source_encoding
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_self->compile_time_env);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_options); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_compile_time_env); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 338, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Scanning.py":337
 *             self.compile_time_eval = 1
 *             self.compile_time_expr = 0
 *             if getattr(context.options, 'compile_time_env', None):             # <<<<<<<<<<<<<<
 *                 self.compile_time_env.update(context.options.compile_time_env)
 *         self.parse_comments = parse_comments
*/
    }
  }
  __pyx_L11:;

  /* "Cython/Compiler/Scanning.py":339
 *             if getattr(context.options, 'compile_time_env', None):
 *                 self.compile_time_env.update(context.options.compile_time_env)
 *         self.parse_comments = parse_comments             # <<<<<<<<<<<<<<
 *         self.source_encoding = source_encoding
 *         self.trace = trace_scanner
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_parse_comments); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 339, __pyx_L1_error)
  __pyx_v_self->parse_comments = __pyx_t_5;

  /* "Cython/Compiler/Scanning.py":340
 *                 self.compile_time_env.update(context.options.compile_time_env)
 *         self.parse_comments = parse_comments
 *         self.source_encoding = source_encoding             # <<<<<<<<<<<<<<
 *         self.trace = trace_scanner
 *         self.indentation_stack = [0]
*/
  __Pyx_INCREF(__pyx_v_source_encoding);
  __Pyx_GIVEREF(__pyx_v_source_encoding);
  __Pyx_GOTREF(__pyx_v_self->source_encoding);
  __Pyx_DECREF(__pyx_v_self->source_encoding);
  __pyx_v_self->source_encoding = __pyx_v_source_encoding;

  /* "Cython/Compiler/Scanning.py":341
 *         self.parse_comments = parse_comments
 *         self.source_encoding = source_encoding
 *         self.trace = trace_scanner             # <<<<<<<<<<<<<<
 *         self.indentation_stack = [0]
 *         self.indentation_char = '\0'
*/
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_trace_scanner); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.trace = __pyx_t_5;

  /* "Cython/Compiler/Scanning.py":342
 *         self.source_encoding = source_encoding
 *         self.trace = trace_scanner
 *         self.indentation_stack = [0]             # <<<<<<<<<<<<<<
 *         self.indentation_char = '\0'
 *         self.bracket_nesting_level = 0
*/
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_mstate_global->__pyx_int_0) != (0)) __PYX_ERR(0, 342, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->indentation_stack);
  __Pyx_DECREF(__pyx_v_self->indentation_stack);
  __pyx_v_self->indentation_stack = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":343
 *         self.trace = trace_scanner
 *         self.indentation_stack = [0]
 *         self.indentation_char = '\0'             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level = 0
 *         # fstrings/tstrings
*/
  __pyx_v_self->indentation_char = 0;

  /* "Cython/Compiler/Scanning.py":344
 *         self.indentation_stack = [0]
 *         self.indentation_char = '\0'
 *         self.bracket_nesting_level = 0             # <<<<<<<<<<<<<<
 *         # fstrings/tstrings
 *         self.ft_string_state_stack = []
*/
  __pyx_v_self->bracket_nesting_level = 0;

  /* "Cython/Compiler/Scanning.py":346
 *         self.bracket_nesting_level = 0
 *         # fstrings/tstrings
 *         self.ft_string_state_stack = []             # <<<<<<<<<<<<<<
 *         self.in_ft_string_expr_prescan = 0
 * 
*/
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->ft_string_state_stack);
  __Pyx_DECREF(__pyx_v_self->ft_string_state_stack);
  __pyx_v_self->ft_string_state_stack = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":347
 *         # fstrings/tstrings
 *         self.ft_string_state_stack = []
 *         self.in_ft_string_expr_prescan = 0             # <<<<<<<<<<<<<<
 * 
 *         self.put_back_on_failure = None
*/
  __pyx_v_self->in_ft_string_expr_prescan = 0;

  /* "Cython/Compiler/Scanning.py":349
 *         self.in_ft_string_expr_prescan = 0
 * 
 *         self.put_back_on_failure = None             # <<<<<<<<<<<<<<
 * 
 *         self.begin('INDENT')
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->put_back_on_failure);
  __Pyx_DECREF(__pyx_v_self->put_back_on_failure);
  __pyx_v_self->put_back_on_failure = ((PyObject*)Py_None);

  /* "Cython/Compiler/Scanning.py":351
 *         self.put_back_on_failure = None
 * 
 *         self.begin('INDENT')             # <<<<<<<<<<<<<<
 *         self.sy = ''
 *         self.next()
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_INDENT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":352
 * 
 *         self.begin('INDENT')
 *         self.sy = ''             # <<<<<<<<<<<<<<
 *         self.next()
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_u__4);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = __pyx_mstate_global->__pyx_kp_u__4;

  /* "Cython/Compiler/Scanning.py":353
 *         self.begin('INDENT')
 *         self.sy = ''
 *         self.next()             # <<<<<<<<<<<<<<
 * 
 *     def normalize_ident(self, text):
*/
  __pyx_t_8 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":308
 *     #                                       contextmanager can restore it
 * 
 *     def __init__(self, file, filename, parent_scanner=None,             # <<<<<<<<<<<<<<
 *                  scope=None, context=None, source_encoding=None, parse_comments=True, initial_pos=None):
 *         Scanner.__init__(self, get_lexicon(), file, filename, initial_pos)
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_keywords);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_keyword);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":355
 *         self.next()
 * 
 *     def normalize_ident(self, text):             # <<<<<<<<<<<<<<
 *         if not text.isascii():
 *             text = normalize('NFKC', text)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident = {"normalize_ident", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalize_ident (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2normalize_ident(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2normalize_ident(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalize_ident", 0);
  __Pyx_INCREF(__pyx_v_text);

  /* "Cython/Compiler/Scanning.py":356
 * 
 *     def normalize_ident(self, text):
 *         if not text.isascii():             # <<<<<<<<<<<<<<
 *             text = normalize('NFKC', text)
 *         self.produce(IDENT, text)
*/
  __pyx_t_2 = __pyx_v_text;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_isascii, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Scanning.py":357
 *     def normalize_ident(self, text):
 *         if not text.isascii():
 *             text = normalize('NFKC', text)             # <<<<<<<<<<<<<<
 *         self.produce(IDENT, text)
 * 
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_normalize); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NFKC, __pyx_v_text};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":356
 * 
 *     def normalize_ident(self, text):
 *         if not text.isascii():             # <<<<<<<<<<<<<<
 *             text = normalize('NFKC', text)
 *         self.produce(IDENT, text)
*/
  }

  /* "Cython/Compiler/Scanning.py":358
 *         if not text.isascii():
 *             text = normalize('NFKC', text)
 *         self.produce(IDENT, text)             # <<<<<<<<<<<<<<
 * 
 *     def commentline(self, text):
*/
  __pyx_t_1 = __pyx_v_6Cython_8Compiler_8Scanning_IDENT;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_7.__pyx_n = 1;
  __pyx_t_7.text = __pyx_v_text;
  __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_1, &__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":355
 *         self.next()
 * 
 *     def normalize_ident(self, text):             # <<<<<<<<<<<<<<
 *         if not text.isascii():
 *             text = normalize('NFKC', text)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.normalize_ident", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":360
 *         self.produce(IDENT, text)
 * 
 *     def commentline(self, text):             # <<<<<<<<<<<<<<
 *         if self.parse_comments:
 *             self.produce('commentline', text)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline = {"commentline", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("commentline (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_4commentline(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_4commentline(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("commentline", 0);

  /* "Cython/Compiler/Scanning.py":361
 * 
 *     def commentline(self, text):
 *         if self.parse_comments:             # <<<<<<<<<<<<<<
 *             self.produce('commentline', text)
 * 
*/
  if (__pyx_v_self->parse_comments) {

    /* "Cython/Compiler/Scanning.py":362
 *     def commentline(self, text):
 *         if self.parse_comments:
 *             self.produce('commentline', text)             # <<<<<<<<<<<<<<
 * 
 *     def strip_underscores(self, text, symbol):
*/
    __pyx_t_2.__pyx_n = 1;
    __pyx_t_2.text = __pyx_v_text;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_commentline, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":361
 * 
 *     def commentline(self, text):
 *         if self.parse_comments:             # <<<<<<<<<<<<<<
 *             self.produce('commentline', text)
 * 
*/
  }

  /* "Cython/Compiler/Scanning.py":360
 *         self.produce(IDENT, text)
 * 
 *     def commentline(self, text):             # <<<<<<<<<<<<<<
 *         if self.parse_comments:
 *             self.produce('commentline', text)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.commentline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":364
 *             self.produce('commentline', text)
 * 
 *     def strip_underscores(self, text, symbol):             # <<<<<<<<<<<<<<
 *         self.produce(symbol, text.replace('_', ''))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores = {"strip_underscores", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("strip_underscores (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_text,&__pyx_mstate_global->__pyx_n_u_symbol,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 364, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 364, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 364, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "strip_underscores", 0) < (0)) __PYX_ERR(0, 364, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("strip_underscores", 1, 2, 2, i); __PYX_ERR(0, 364, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 364, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 364, __pyx_L3_error)
    }
    __pyx_v_text = values[0];
    __pyx_v_symbol = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("strip_underscores", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 364, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.strip_underscores", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_6strip_underscores(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_text, __pyx_v_symbol);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_6strip_underscores(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("strip_underscores", 0);

  /* "Cython/Compiler/Scanning.py":365
 * 
 *     def strip_underscores(self, text, symbol):
 *         self.produce(symbol, text.replace('_', ''))             # <<<<<<<<<<<<<<
 * 
 *     def current_level(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_text, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[4], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.text = __pyx_t_2;
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_v_symbol, &__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":364
 *             self.produce('commentline', text)
 * 
 *     def strip_underscores(self, text, symbol):             # <<<<<<<<<<<<<<
 *         self.produce(symbol, text.replace('_', ''))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.strip_underscores", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":367
 *         self.produce(symbol, text.replace('_', ''))
 * 
 *     def current_level(self):             # <<<<<<<<<<<<<<
 *         return self.indentation_stack[-1]
 * 
*/

static Py_ssize_t __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("current_level", 0);

  /* "Cython/Compiler/Scanning.py":368
 * 
 *     def current_level(self):
 *         return self.indentation_stack[-1]             # <<<<<<<<<<<<<<
 * 
 *     def open_bracket_action(self, text):
*/
  if (unlikely(__pyx_v_self->indentation_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 368, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->indentation_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_2 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":367
 *         self.produce(symbol, text.replace('_', ''))
 * 
 *     def current_level(self):             # <<<<<<<<<<<<<<
 *         return self.indentation_stack[-1]
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.current_level", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":370
 *         return self.indentation_stack[-1]
 * 
 *     def open_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         return text
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action = {"open_bracket_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open_bracket_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8open_bracket_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8open_bracket_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open_bracket_action", 0);

  /* "Cython/Compiler/Scanning.py":371
 * 
 *     def open_bracket_action(self, text):
 *         self.bracket_nesting_level += 1             # <<<<<<<<<<<<<<
 *         return text
 * 
*/
  __pyx_v_self->bracket_nesting_level = (__pyx_v_self->bracket_nesting_level + 1);

  /* "Cython/Compiler/Scanning.py":372
 *     def open_bracket_action(self, text):
 *         self.bracket_nesting_level += 1
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     def close_bracket_action(self, text):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":370
 *         return self.indentation_stack[-1]
 * 
 *     def open_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         return text
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":374
 *         return text
 * 
 *     def close_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level -= 1
 *         return text
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action = {"close_bracket_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close_bracket_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_10close_bracket_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_10close_bracket_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close_bracket_action", 0);

  /* "Cython/Compiler/Scanning.py":375
 * 
 *     def close_bracket_action(self, text):
 *         self.bracket_nesting_level -= 1             # <<<<<<<<<<<<<<
 *         return text
 * 
*/
  __pyx_v_self->bracket_nesting_level = (__pyx_v_self->bracket_nesting_level - 1);

  /* "Cython/Compiler/Scanning.py":376
 *     def close_bracket_action(self, text):
 *         self.bracket_nesting_level -= 1
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     def open_brace_action(self, text):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":374
 *         return text
 * 
 *     def close_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level -= 1
 *         return text
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":378
 *         return text
 * 
 *     def open_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         return self.open_bracket_action(text)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action = {"open_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open_brace_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_12open_brace_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_12open_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("open_brace_action", 0);

  /* "Cython/Compiler/Scanning.py":379
 * 
 *     def open_brace_action(self, text):
 *         return self.open_bracket_action(text)             # <<<<<<<<<<<<<<
 * 
 *     def close_brace_action(self, text):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_text};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_open_bracket_action, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":378
 *         return text
 * 
 *     def open_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         return self.open_bracket_action(text)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.open_brace_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":381
 *         return self.open_bracket_action(text)
 * 
 *     def close_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         assert text == '}'
 *         if (self.ft_string_state_stack and
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action = {"close_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close_brace_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14close_brace_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14close_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close_brace_action", 0);

  /* "Cython/Compiler/Scanning.py":382
 * 
 *     def close_brace_action(self, text):
 *         assert text == '}'             # <<<<<<<<<<<<<<
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_text, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 382, __pyx_L1_error)
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 382, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 382, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/Scanning.py":383
 *     def close_brace_action(self, text):
 *         assert text == '}'
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
*/
  if (__pyx_v_self->ft_string_state_stack == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->ft_string_state_stack);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/Scanning.py":384
 *         assert text == '}'
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):             # <<<<<<<<<<<<<<
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
 *                 self.in_ft_string_expr_prescan -= 1
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 384, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_self->bracket_nesting_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;

  /* "Cython/Compiler/Scanning.py":383
 *     def close_brace_action(self, text):
 *         assert text == '}'
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
*/
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":385
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():             # <<<<<<<<<<<<<<
 *                 self.in_ft_string_expr_prescan -= 1
 *                 if self.in_ft_string_expr_prescan == 0:
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 385, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __pyx_t_3;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = (!__pyx_t_1);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Scanning.py":386
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
 *                 self.in_ft_string_expr_prescan -= 1             # <<<<<<<<<<<<<<
 *                 if self.in_ft_string_expr_prescan == 0:
 *                     self.produce("END_FT_STRING_EXPR")
*/
      __pyx_v_self->in_ft_string_expr_prescan = (__pyx_v_self->in_ft_string_expr_prescan - 1);

      /* "Cython/Compiler/Scanning.py":387
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
 *                 self.in_ft_string_expr_prescan -= 1
 *                 if self.in_ft_string_expr_prescan == 0:             # <<<<<<<<<<<<<<
 *                     self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
*/
      __pyx_t_2 = (__pyx_v_self->in_ft_string_expr_prescan == 0);
      if (__pyx_t_2) {

        /* "Cython/Compiler/Scanning.py":388
 *                 self.in_ft_string_expr_prescan -= 1
 *                 if self.in_ft_string_expr_prescan == 0:
 *                     self.produce("END_FT_STRING_EXPR")             # <<<<<<<<<<<<<<
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].pop_bracket_state()
*/
        __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_END_FT_STRING_EXPR, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 388, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "Cython/Compiler/Scanning.py":387
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
 *                 self.in_ft_string_expr_prescan -= 1
 *                 if self.in_ft_string_expr_prescan == 0:             # <<<<<<<<<<<<<<
 *                     self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
*/
      }

      /* "Cython/Compiler/Scanning.py":385
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():             # <<<<<<<<<<<<<<
 *                 self.in_ft_string_expr_prescan -= 1
 *                 if self.in_ft_string_expr_prescan == 0:
*/
    }

    /* "Cython/Compiler/Scanning.py":389
 *                 if self.in_ft_string_expr_prescan == 0:
 *                     self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)             # <<<<<<<<<<<<<<
 *             self.ft_string_state_stack[-1].pop_bracket_state()
 *         self.bracket_nesting_level -= 1
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 389, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_scanner_state); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":390
 *                     self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].pop_bracket_state()             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level -= 1
 *         return text
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 390, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_pop_bracket_state, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":383
 *     def close_brace_action(self, text):
 *         assert text == '}'
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             if not self.ft_string_state_stack[-1].in_format_specifier():
*/
  }

  /* "Cython/Compiler/Scanning.py":391
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].pop_bracket_state()
 *         self.bracket_nesting_level -= 1             # <<<<<<<<<<<<<<
 *         return text
 * 
*/
  __pyx_v_self->bracket_nesting_level = (__pyx_v_self->bracket_nesting_level - 1);

  /* "Cython/Compiler/Scanning.py":392
 *             self.ft_string_state_stack[-1].pop_bracket_state()
 *         self.bracket_nesting_level -= 1
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     def colon_action(self, text):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":381
 *         return self.open_bracket_action(text)
 * 
 *     def close_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         assert text == '}'
 *         if (self.ft_string_state_stack and
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.close_brace_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":394
 *         return text
 * 
 *     def colon_action(self, text):             # <<<<<<<<<<<<<<
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action = {"colon_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colon_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16colon_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16colon_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colon_action", 0);

  /* "Cython/Compiler/Scanning.py":395
 * 
 *     def colon_action(self, text):
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1
*/
  if (__pyx_v_self->ft_string_state_stack == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->ft_string_state_stack);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 395, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }

  /* "Cython/Compiler/Scanning.py":396
 *     def colon_action(self, text):
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):             # <<<<<<<<<<<<<<
 *             self.in_ft_string_expr_prescan -= 1
 *             if self.in_ft_string_expr_prescan == 0:
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 396, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_self->bracket_nesting_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;

  /* "Cython/Compiler/Scanning.py":395
 * 
 *     def colon_action(self, text):
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1
*/
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":397
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1             # <<<<<<<<<<<<<<
 *             if self.in_ft_string_expr_prescan == 0:
 *                 self.produce("END_FT_STRING_EXPR")
*/
    __pyx_v_self->in_ft_string_expr_prescan = (__pyx_v_self->in_ft_string_expr_prescan - 1);

    /* "Cython/Compiler/Scanning.py":398
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1
 *             if self.in_ft_string_expr_prescan == 0:             # <<<<<<<<<<<<<<
 *                 self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
*/
    __pyx_t_1 = (__pyx_v_self->in_ft_string_expr_prescan == 0);
    if (__pyx_t_1) {

      /* "Cython/Compiler/Scanning.py":399
 *             self.in_ft_string_expr_prescan -= 1
 *             if self.in_ft_string_expr_prescan == 0:
 *                 self.produce("END_FT_STRING_EXPR")             # <<<<<<<<<<<<<<
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].set_in_format_specifier()
*/
      __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_END_FT_STRING_EXPR, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/Scanning.py":398
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1
 *             if self.in_ft_string_expr_prescan == 0:             # <<<<<<<<<<<<<<
 *                 self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
*/
    }

    /* "Cython/Compiler/Scanning.py":400
 *             if self.in_ft_string_expr_prescan == 0:
 *                 self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)             # <<<<<<<<<<<<<<
 *             self.ft_string_state_stack[-1].set_in_format_specifier()
 *         return text
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 400, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 400, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_scanner_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 400, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 400, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":401
 *                 self.produce("END_FT_STRING_EXPR")
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].set_in_format_specifier()             # <<<<<<<<<<<<<<
 *         return text
 * 
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 401, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __pyx_t_3;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set_in_format_specifier, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":395
 * 
 *     def colon_action(self, text):
 *         if (self.ft_string_state_stack and             # <<<<<<<<<<<<<<
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
 *             self.in_ft_string_expr_prescan -= 1
*/
  }

  /* "Cython/Compiler/Scanning.py":402
 *             self.begin(self.ft_string_state_stack[-1].scanner_state)
 *             self.ft_string_state_stack[-1].set_in_format_specifier()
 *         return text             # <<<<<<<<<<<<<<
 * 
 *     def newline_action(self, text):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = __pyx_v_text;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":394
 *         return text
 * 
 *     def colon_action(self, text):             # <<<<<<<<<<<<<<
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.colon_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":404
 *         return text
 * 
 *     def newline_action(self, text):             # <<<<<<<<<<<<<<
 *         if self.bracket_nesting_level == 0:
 *             self.begin('INDENT')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action = {"newline_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newline_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_18newline_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_18newline_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newline_action", 0);

  /* "Cython/Compiler/Scanning.py":405
 * 
 *     def newline_action(self, text):
 *         if self.bracket_nesting_level == 0:             # <<<<<<<<<<<<<<
 *             self.begin('INDENT')
 *             self.produce('NEWLINE', '')
*/
  __pyx_t_1 = (__pyx_v_self->bracket_nesting_level == 0);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":406
 *     def newline_action(self, text):
 *         if self.bracket_nesting_level == 0:
 *             self.begin('INDENT')             # <<<<<<<<<<<<<<
 *             self.produce('NEWLINE', '')
 * 
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_INDENT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":407
 *         if self.bracket_nesting_level == 0:
 *             self.begin('INDENT')
 *             self.produce('NEWLINE', '')             # <<<<<<<<<<<<<<
 * 
 *     string_states = {
*/
    __pyx_t_3.__pyx_n = 1;
    __pyx_t_3.text = __pyx_mstate_global->__pyx_kp_u__4;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_NEWLINE, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":405
 * 
 *     def newline_action(self, text):
 *         if self.bracket_nesting_level == 0:             # <<<<<<<<<<<<<<
 *             self.begin('INDENT')
 *             self.produce('NEWLINE', '')
*/
  }

  /* "Cython/Compiler/Scanning.py":404
 *         return text
 * 
 *     def newline_action(self, text):             # <<<<<<<<<<<<<<
 *         if self.bracket_nesting_level == 0:
 *             self.begin('INDENT')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.newline_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":416
 *     }
 * 
 *     def begin_string_action(self, text: str):             # <<<<<<<<<<<<<<
 *         while text and text[0] in any_string_prefix:
 *             text = text[1:]
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action = {"begin_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("begin_string_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 0, "text", 2))) __PYX_ERR(0, 416, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_20begin_string_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_20begin_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("begin_string_action", 0);
  __Pyx_INCREF(__pyx_v_text);

  /* "Cython/Compiler/Scanning.py":417
 * 
 *     def begin_string_action(self, text: str):
 *         while text and text[0] in any_string_prefix:             # <<<<<<<<<<<<<<
 *             text = text[1:]
 *         self.begin(self.string_states[text])
*/
  while (1) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_text);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 417, __pyx_L1_error)
      __pyx_t_2 = (__pyx_temp != 0);
    }

    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_GetItemInt_Unicode(__pyx_v_text, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(__pyx_t_3 == (Py_UCS4)-1)) __PYX_ERR(0, 417, __pyx_L1_error)
    if (unlikely(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument of type 'NoneType' is not iterable");
      __PYX_ERR(0, 417, __pyx_L1_error)
    }
    __pyx_t_2 = (__Pyx_UnicodeContainsUCS4(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix, __pyx_t_3));
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;
    if (!__pyx_t_1) break;

    /* "Cython/Compiler/Scanning.py":418
 *     def begin_string_action(self, text: str):
 *         while text and text[0] in any_string_prefix:
 *             text = text[1:]             # <<<<<<<<<<<<<<
 *         self.begin(self.string_states[text])
 *         self.produce('BEGIN_STRING')
*/
    __pyx_t_4 = __Pyx_PyUnicode_Substring(__pyx_v_text, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_text, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;
  }

  /* "Cython/Compiler/Scanning.py":419
 *         while text and text[0] in any_string_prefix:
 *             text = text[1:]
 *         self.begin(self.string_states[text])             # <<<<<<<<<<<<<<
 *         self.produce('BEGIN_STRING')
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_string_states); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_v_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":420
 *             text = text[1:]
 *         self.begin(self.string_states[text])
 *         self.produce('BEGIN_STRING')             # <<<<<<<<<<<<<<
 * 
 *     def end_string_action(self, text):
*/
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":416
 *     }
 * 
 *     def begin_string_action(self, text: str):             # <<<<<<<<<<<<<<
 *         while text and text[0] in any_string_prefix:
 *             text = text[1:]
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.begin_string_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":422
 *         self.produce('BEGIN_STRING')
 * 
 *     def end_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_STRING')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action = {"end_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("end_string_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_22end_string_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_22end_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("end_string_action", 0);

  /* "Cython/Compiler/Scanning.py":423
 * 
 *     def end_string_action(self, text):
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')             # <<<<<<<<<<<<<<
 *         self.produce('END_STRING')
 * 
*/
  __pyx_t_2 = (__pyx_v_self->in_ft_string_expr_prescan != 0);
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_FT_STRING_EXPR_PRESCAN);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_FT_STRING_EXPR_PRESCAN;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
    __pyx_t_1 = __pyx_mstate_global->__pyx_kp_u__4;
  }
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":424
 *     def end_string_action(self, text):
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_STRING')             # <<<<<<<<<<<<<<
 * 
 *     def begin_ft_string_action(self, text):
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_END_STRING, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":422
 *         self.produce('BEGIN_STRING')
 * 
 *     def end_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_STRING')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.end_string_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":426
 *         self.produce('END_STRING')
 * 
 *     def begin_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         is_raw = 'r' in text or 'R' in text
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action = {"begin_ft_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("begin_ft_string_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_24begin_ft_string_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_24begin_ft_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_is_raw = NULL;
  PyObject *__pyx_v_ft_string_state = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6[3];
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("begin_ft_string_action", 0);
  __Pyx_INCREF(__pyx_v_text);

  /* "Cython/Compiler/Scanning.py":427
 * 
 *     def begin_ft_string_action(self, text):
 *         is_raw = 'r' in text or 'R' in text             # <<<<<<<<<<<<<<
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
 *             text = text[1:]
*/
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_r, __pyx_v_text, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 427, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_R, __pyx_v_text, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 427, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_v_is_raw = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":428
 *     def begin_ft_string_action(self, text):
 *         is_raw = 'r' in text or 'R' in text
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):             # <<<<<<<<<<<<<<
 *             text = text[1:]
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'
*/
  while (1) {
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_text); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_2 = __pyx_t_4;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_text, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 428, __pyx_L1_error)
    }
    __pyx_t_4 = (__Pyx_PyUnicode_ContainsTF(__pyx_t_1, __pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_4) {
    } else {
      __pyx_t_2 = __pyx_t_4;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_text, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ft_string_prefixes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __pyx_t_4;
    __pyx_L7_bool_binop_done:;
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Scanning.py":429
 *         is_raw = 'r' in text or 'R' in text
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
 *             text = text[1:]             # <<<<<<<<<<<<<<
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'
 *         self.ft_string_state_stack.append(
*/
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_text, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_3);
    __pyx_t_3 = 0;
  }

  /* "Cython/Compiler/Scanning.py":430
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
 *             text = text[1:]
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'             # <<<<<<<<<<<<<<
 *         self.ft_string_state_stack.append(
 *             FTStringState(ft_string_state)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_string_states); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_is_raw); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 430, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_R);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_R;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
    __pyx_t_1 = __pyx_mstate_global->__pyx_kp_u__4;
  }
  __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6[0] = __pyx_t_3;
  __pyx_t_6[1] = __pyx_mstate_global->__pyx_n_u_FT;
  __pyx_t_6[2] = __pyx_t_5;
  __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_6, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_ft_string_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":431
 *             text = text[1:]
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'
 *         self.ft_string_state_stack.append(             # <<<<<<<<<<<<<<
 *             FTStringState(ft_string_state)
 *         )
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 431, __pyx_L1_error)
  }

  /* "Cython/Compiler/Scanning.py":432
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'
 *         self.ft_string_state_stack.append(
 *             FTStringState(ft_string_state)             # <<<<<<<<<<<<<<
 *         )
 *         self.begin(ft_string_state)
*/
  __pyx_t_5 = NULL;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_ft_string_state};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }

  /* "Cython/Compiler/Scanning.py":431
 *             text = text[1:]
 *         ft_string_state = f'{self.string_states[text]}_FT{"R" if is_raw else ""}'
 *         self.ft_string_state_stack.append(             # <<<<<<<<<<<<<<
 *             FTStringState(ft_string_state)
 *         )
*/
  __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_self->ft_string_state_stack, ((PyObject *)__pyx_t_1)); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_DECREF((PyObject *)__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":434
 *             FTStringState(ft_string_state)
 *         )
 *         self.begin(ft_string_state)             # <<<<<<<<<<<<<<
 *         self.produce('BEGIN_FT_STRING')
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_v_ft_string_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":435
 *         )
 *         self.begin(ft_string_state)
 *         self.produce('BEGIN_FT_STRING')             # <<<<<<<<<<<<<<
 * 
 *     def end_ft_string_action(self, text):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_BEGIN_FT_STRING, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":426
 *         self.produce('END_STRING')
 * 
 *     def begin_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         is_raw = 'r' in text or 'R' in text
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.begin_ft_string_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_is_raw);
  __Pyx_XDECREF(__pyx_v_ft_string_state);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":437
 *         self.produce('BEGIN_FT_STRING')
 * 
 *     def end_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.ft_string_state_stack.pop()
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action = {"end_ft_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("end_ft_string_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_26end_ft_string_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_26end_ft_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("end_ft_string_action", 0);

  /* "Cython/Compiler/Scanning.py":438
 * 
 *     def end_ft_string_action(self, text):
 *         self.ft_string_state_stack.pop()             # <<<<<<<<<<<<<<
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_FT_STRING')
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 438, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->ft_string_state_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":439
 *     def end_ft_string_action(self, text):
 *         self.ft_string_state_stack.pop()
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')             # <<<<<<<<<<<<<<
 *         self.produce('END_FT_STRING')
 * 
*/
  __pyx_t_2 = (__pyx_v_self->in_ft_string_expr_prescan != 0);
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_FT_STRING_EXPR_PRESCAN);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_FT_STRING_EXPR_PRESCAN;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
    __pyx_t_1 = __pyx_mstate_global->__pyx_kp_u__4;
  }
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":440
 *         self.ft_string_state_stack.pop()
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_FT_STRING')             # <<<<<<<<<<<<<<
 * 
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_END_FT_STRING, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":437
 *         self.produce('BEGIN_FT_STRING')
 * 
 *     def end_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.ft_string_state_stack.pop()
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.end_ft_string_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":442
 *         self.produce('END_FT_STRING')
 * 
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace(PyObject *__pyx_v_self, PyObject *__pyx_v_started_ft_string_expr); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace = {"_handle_open_single_ft_string_brace", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace(PyObject *__pyx_v_self, PyObject *__pyx_v_started_ft_string_expr) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_open_single_ft_string_brace (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_28_handle_open_single_ft_string_brace(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_started_ft_string_expr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_28_handle_open_single_ft_string_brace(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_started_ft_string_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_handle_open_single_ft_string_brace", 0);

  /* "Cython/Compiler/Scanning.py":443
 * 
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):
 *         self.bracket_nesting_level += 1             # <<<<<<<<<<<<<<
 *         if not started_ft_string_expr:
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)
*/
  __pyx_v_self->bracket_nesting_level = (__pyx_v_self->bracket_nesting_level + 1);

  /* "Cython/Compiler/Scanning.py":444
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:             # <<<<<<<<<<<<<<
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)
 *             self.begin('FT_STRING_EXPR_PRESCAN')
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_started_ft_string_expr); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 444, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":445
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)             # <<<<<<<<<<<<<<
 *             self.begin('FT_STRING_EXPR_PRESCAN')
 *             self.in_ft_string_expr_prescan += 1
*/
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 445, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_self->bracket_nesting_level); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_push_bracket_state, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":446
 *         if not started_ft_string_expr:
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)
 *             self.begin('FT_STRING_EXPR_PRESCAN')             # <<<<<<<<<<<<<<
 *             self.in_ft_string_expr_prescan += 1
 *         self.produce('{')
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_FT_STRING_EXPR_PRESCAN); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":447
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)
 *             self.begin('FT_STRING_EXPR_PRESCAN')
 *             self.in_ft_string_expr_prescan += 1             # <<<<<<<<<<<<<<
 *         self.produce('{')
 * 
*/
    __pyx_v_self->in_ft_string_expr_prescan = (__pyx_v_self->in_ft_string_expr_prescan + 1);

    /* "Cython/Compiler/Scanning.py":444
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:             # <<<<<<<<<<<<<<
 *             self.ft_string_state_stack[-1].push_bracket_state(self.bracket_nesting_level)
 *             self.begin('FT_STRING_EXPR_PRESCAN')
*/
  }

  /* "Cython/Compiler/Scanning.py":448
 *             self.begin('FT_STRING_EXPR_PRESCAN')
 *             self.in_ft_string_expr_prescan += 1
 *         self.produce('{')             # <<<<<<<<<<<<<<
 * 
 *     def open_ft_string_brace_action(self, text):
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_kp_u__7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Scanning.py":442
 *         self.produce('END_FT_STRING')
 * 
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner._handle_open_single_ft_string_brace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":450
 *         self.produce('{')
 * 
 *     def open_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         started_ft_string_expr = False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action = {"open_ft_string_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open_ft_string_brace_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_30open_ft_string_brace_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_30open_ft_string_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  Py_ssize_t __pyx_v_len_text;
  int __pyx_v_started_ft_string_expr;
  Py_ssize_t __pyx_v_double_braces;
  CYTHON_UNUSED Py_ssize_t __pyx_v__;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("open_ft_string_brace_action", 0);

  /* "Cython/Compiler/Scanning.py":451
 * 
 *     def open_ft_string_brace_action(self, text):
 *         len_text = len(text)             # <<<<<<<<<<<<<<
 *         started_ft_string_expr = False
 *         if self.ft_string_state_stack[-1].in_format_specifier():
*/
  __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 451, __pyx_L1_error)
  __pyx_v_len_text = __pyx_t_1;

  /* "Cython/Compiler/Scanning.py":452
 *     def open_ft_string_brace_action(self, text):
 *         len_text = len(text)
 *         started_ft_string_expr = False             # <<<<<<<<<<<<<<
 *         if self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
*/
  __pyx_v_started_ft_string_expr = 0;

  /* "Cython/Compiler/Scanning.py":453
 *         len_text = len(text)
 *         started_ft_string_expr = False
 *         if self.ft_string_state_stack[-1].in_format_specifier():             # <<<<<<<<<<<<<<
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 *             len_text -= 1
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 453, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Scanning.py":454
 *         started_ft_string_expr = False
 *         if self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)             # <<<<<<<<<<<<<<
 *             len_text -= 1
 *             started_ft_string_expr = True
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_started_ft_string_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_open_single_ft_string_br, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":455
 *         if self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 *             len_text -= 1             # <<<<<<<<<<<<<<
 *             started_ft_string_expr = True
 *         assert not self.ft_string_state_stack[-1].in_format_specifier()
*/
    __pyx_v_len_text = (__pyx_v_len_text - 1);

    /* "Cython/Compiler/Scanning.py":456
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 *             len_text -= 1
 *             started_ft_string_expr = True             # <<<<<<<<<<<<<<
 *         assert not self.ft_string_state_stack[-1].in_format_specifier()
 * 
*/
    __pyx_v_started_ft_string_expr = 1;

    /* "Cython/Compiler/Scanning.py":453
 *         len_text = len(text)
 *         started_ft_string_expr = False
 *         if self.ft_string_state_stack[-1].in_format_specifier():             # <<<<<<<<<<<<<<
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 *             len_text -= 1
*/
  }

  /* "Cython/Compiler/Scanning.py":457
 *             len_text -= 1
 *             started_ft_string_expr = True
 *         assert not self.ft_string_state_stack[-1].in_format_specifier()             # <<<<<<<<<<<<<<
 * 
 *         double_braces = len_text // 2
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 457, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 457, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = (!__pyx_t_6);
    if (unlikely(!__pyx_t_7)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 457, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 457, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/Scanning.py":459
 *         assert not self.ft_string_state_stack[-1].in_format_specifier()
 * 
 *         double_braces = len_text // 2             # <<<<<<<<<<<<<<
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '{')
*/
  __pyx_v_double_braces = __Pyx_div_Py_ssize_t(__pyx_v_len_text, 2, 1);

  /* "Cython/Compiler/Scanning.py":460
 * 
 *         double_braces = len_text // 2
 *         for _ in range(double_braces):             # <<<<<<<<<<<<<<
 *             self.produce('CHARS', '{')
 *         len_text -= (double_braces*2)
*/
  __pyx_t_1 = __pyx_v_double_braces;
  __pyx_t_8 = __pyx_t_1;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v__ = __pyx_t_9;

    /* "Cython/Compiler/Scanning.py":461
 *         double_braces = len_text // 2
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '{')             # <<<<<<<<<<<<<<
 *         len_text -= (double_braces*2)
 * 
*/
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.text = __pyx_mstate_global->__pyx_kp_u__7;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_CHARS, &__pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Scanning.py":462
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '{')
 *         len_text -= (double_braces*2)             # <<<<<<<<<<<<<<
 * 
 *         if len_text:
*/
  __pyx_v_len_text = (__pyx_v_len_text - (__pyx_v_double_braces * 2));

  /* "Cython/Compiler/Scanning.py":464
 *         len_text -= (double_braces*2)
 * 
 *         if len_text:             # <<<<<<<<<<<<<<
 *             assert len_text == 1
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
*/
  __pyx_t_7 = (__pyx_v_len_text != 0);
  if (__pyx_t_7) {

    /* "Cython/Compiler/Scanning.py":465
 * 
 *         if len_text:
 *             assert len_text == 1             # <<<<<<<<<<<<<<
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 * 
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_7 = (__pyx_v_len_text == 1);
      if (unlikely(!__pyx_t_7)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 465, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 465, __pyx_L1_error)
    #endif

    /* "Cython/Compiler/Scanning.py":466
 *         if len_text:
 *             assert len_text == 1
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)             # <<<<<<<<<<<<<<
 * 
 *     def _handle_close_single_ft_string_brace(self):
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_started_ft_string_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_open_single_ft_string_br, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":464
 *         len_text -= (double_braces*2)
 * 
 *         if len_text:             # <<<<<<<<<<<<<<
 *             assert len_text == 1
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
*/
  }

  /* "Cython/Compiler/Scanning.py":450
 *         self.produce('{')
 * 
 *     def open_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         started_ft_string_expr = False
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.open_ft_string_brace_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":468
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 * 
 *     def _handle_close_single_ft_string_brace(self):             # <<<<<<<<<<<<<<
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace = {"_handle_close_single_ft_string_brace", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_close_single_ft_string_brace (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_32_handle_close_single_ft_string_brace(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_32_handle_close_single_ft_string_brace(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_v_ft_string_bracket_level = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_handle_close_single_ft_string_brace", 0);

  /* "Cython/Compiler/Scanning.py":469
 * 
 *     def _handle_close_single_ft_string_brace(self):
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()             # <<<<<<<<<<<<<<
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:
 *             # To help try to parse a little further, don't reduce the bracket
*/
  if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 469, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_ft_string_bracket_level = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":470
 *     def _handle_close_single_ft_string_brace(self):
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:             # <<<<<<<<<<<<<<
 *             # To help try to parse a little further, don't reduce the bracket
 *             # nesting level more.
*/
  __pyx_t_6 = (__pyx_v_ft_string_bracket_level == Py_None);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_self->bracket_nesting_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_v_ft_string_bracket_level, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Scanning.py":473
 *             # To help try to parse a little further, don't reduce the bracket
 *             # nesting level more.
 *             self.error(             # <<<<<<<<<<<<<<
 *                 # Unfortunately the scanner doesn't know which
 *                 "f-string or t-string: single '}' is not allowed",
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Scanning.py":476
 *                 # Unfortunately the scanner doesn't know which
 *                 "f-string or t-string: single '}' is not allowed",
 *                 pos=self.get_current_scan_pos(),             # <<<<<<<<<<<<<<
 *                 fatal=False)
 *             self.produce('}', '}')
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.get_current_scan_pos(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "Cython/Compiler/Scanning.py":477
 *                 "f-string or t-string: single '}' is not allowed",
 *                 pos=self.get_current_scan_pos(),
 *                 fatal=False)             # <<<<<<<<<<<<<<
 *             self.produce('}', '}')
 *         else:
*/
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_f_string_or_t_string_single_is_n};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_2, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 473, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 473, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 473, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":478
 *                 pos=self.get_current_scan_pos(),
 *                 fatal=False)
 *             self.produce('}', '}')             # <<<<<<<<<<<<<<
 *         else:
 *             self.produce(self.close_brace_action('}'), '}')
*/
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.text = __pyx_mstate_global->__pyx_kp_u__6;
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_kp_u__6, &__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":470
 *     def _handle_close_single_ft_string_brace(self):
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:             # <<<<<<<<<<<<<<
 *             # To help try to parse a little further, don't reduce the bracket
 *             # nesting level more.
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Scanning.py":480
 *             self.produce('}', '}')
 *         else:
 *             self.produce(self.close_brace_action('}'), '}')             # <<<<<<<<<<<<<<
 * 
 *     def close_ft_string_brace_action(self, text):
*/
  /*else*/ {
    __pyx_t_7 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__6};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close_brace_action, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.text = __pyx_mstate_global->__pyx_kp_u__6;
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_3, &__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Scanning.py":468
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 * 
 *     def _handle_close_single_ft_string_brace(self):             # <<<<<<<<<<<<<<
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner._handle_close_single_ft_string_brace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ft_string_bracket_level);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":482
 *             self.produce(self.close_brace_action('}'), '}')
 * 
 *     def close_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action = {"close_ft_string_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close_ft_string_brace_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_34close_ft_string_brace_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_34close_ft_string_brace_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  Py_ssize_t __pyx_v_len_text;
  Py_ssize_t __pyx_v_double_braces;
  CYTHON_UNUSED Py_ssize_t __pyx_v__;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close_ft_string_brace_action", 0);

  /* "Cython/Compiler/Scanning.py":483
 * 
 *     def close_ft_string_brace_action(self, text):
 *         len_text = len(text)             # <<<<<<<<<<<<<<
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_close_single_ft_string_brace()
*/
  __pyx_t_1 = PyObject_Length(__pyx_v_text); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 483, __pyx_L1_error)
  __pyx_v_len_text = __pyx_t_1;

  /* "Cython/Compiler/Scanning.py":484
 *     def close_ft_string_brace_action(self, text):
 *         len_text = len(text)
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():             # <<<<<<<<<<<<<<
 *             self._handle_close_single_ft_string_brace()
 *             len_text -= 1
*/
  while (1) {
    __pyx_t_3 = (__pyx_v_len_text != 0);
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L5_bool_binop_done;
    }
    if (unlikely(__pyx_v_self->ft_string_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 484, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_self->ft_string_state_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Scanning.py":485
 *         len_text = len(text)
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_close_single_ft_string_brace()             # <<<<<<<<<<<<<<
 *             len_text -= 1
 * 
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_close_single_ft_string_b, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 485, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":486
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
 *             self._handle_close_single_ft_string_brace()
 *             len_text -= 1             # <<<<<<<<<<<<<<
 * 
 *         double_braces = len_text // 2
*/
    __pyx_v_len_text = (__pyx_v_len_text - 1);
  }

  /* "Cython/Compiler/Scanning.py":488
 *             len_text -= 1
 * 
 *         double_braces = len_text // 2             # <<<<<<<<<<<<<<
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '}')
*/
  __pyx_v_double_braces = __Pyx_div_Py_ssize_t(__pyx_v_len_text, 2, 1);

  /* "Cython/Compiler/Scanning.py":489
 * 
 *         double_braces = len_text // 2
 *         for _ in range(double_braces):             # <<<<<<<<<<<<<<
 *             self.produce('CHARS', '}')
 *         len_text -= double_braces*2
*/
  __pyx_t_1 = __pyx_v_double_braces;
  __pyx_t_8 = __pyx_t_1;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v__ = __pyx_t_9;

    /* "Cython/Compiler/Scanning.py":490
 *         double_braces = len_text // 2
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '}')             # <<<<<<<<<<<<<<
 *         len_text -= double_braces*2
 * 
*/
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.text = __pyx_mstate_global->__pyx_kp_u__6;
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_CHARS, &__pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "Cython/Compiler/Scanning.py":491
 *         for _ in range(double_braces):
 *             self.produce('CHARS', '}')
 *         len_text -= double_braces*2             # <<<<<<<<<<<<<<
 * 
 *         if len_text:
*/
  __pyx_v_len_text = (__pyx_v_len_text - (__pyx_v_double_braces * 2));

  /* "Cython/Compiler/Scanning.py":493
 *         len_text -= double_braces*2
 * 
 *         if len_text:             # <<<<<<<<<<<<<<
 *             self._handle_close_single_ft_string_brace()
 * 
*/
  __pyx_t_2 = (__pyx_v_len_text != 0);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":494
 * 
 *         if len_text:
 *             self._handle_close_single_ft_string_brace()             # <<<<<<<<<<<<<<
 * 
 *     def unclosed_string_action(self, text):
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_close_single_ft_string_b, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":493
 *         len_text -= double_braces*2
 * 
 *         if len_text:             # <<<<<<<<<<<<<<
 *             self._handle_close_single_ft_string_brace()
 * 
*/
  }

  /* "Cython/Compiler/Scanning.py":482
 *             self.produce(self.close_brace_action('}'), '}')
 * 
 *     def close_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.close_ft_string_brace_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":496
 *             self._handle_close_single_ft_string_brace()
 * 
 *     def unclosed_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.end_string_action(text)
 *         self.error_at_scanpos("Unclosed string literal")
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action = {"unclosed_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unclosed_string_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_36unclosed_string_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_36unclosed_string_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unclosed_string_action", 0);

  /* "Cython/Compiler/Scanning.py":497
 * 
 *     def unclosed_string_action(self, text):
 *         self.end_string_action(text)             # <<<<<<<<<<<<<<
 *         self.error_at_scanpos("Unclosed string literal")
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_text};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_end_string_action, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":498
 *     def unclosed_string_action(self, text):
 *         self.end_string_action(text)
 *         self.error_at_scanpos("Unclosed string literal")             # <<<<<<<<<<<<<<
 * 
 *     def indentation_action(self, text: str):
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(__pyx_v_self, __pyx_mstate_global->__pyx_kp_u_Unclosed_string_literal); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 498, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":496
 *             self._handle_close_single_ft_string_brace()
 * 
 *     def unclosed_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.end_string_action(text)
 *         self.error_at_scanpos("Unclosed string literal")
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.unclosed_string_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":500
 *         self.error_at_scanpos("Unclosed string literal")
 * 
 *     def indentation_action(self, text: str):             # <<<<<<<<<<<<<<
 *         self.begin('')
 *         # Indentation within brackets should be ignored.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action = {"indentation_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("indentation_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 0, "text", 2))) __PYX_ERR(0, 500, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_38indentation_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_38indentation_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_text) {
  Py_UCS4 __pyx_v_c;
  Py_ssize_t __pyx_v_current_level;
  Py_ssize_t __pyx_v_new_level;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("indentation_action", 0);

  /* "Cython/Compiler/Scanning.py":501
 * 
 *     def indentation_action(self, text: str):
 *         self.begin('')             # <<<<<<<<<<<<<<
 *         # Indentation within brackets should be ignored.
 *         #if self.bracket_nesting_level > 0:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.begin(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_kp_u__4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":506
 *         #    return
 *         # Check that tabs and spaces are being used consistently.
 *         if text:             # <<<<<<<<<<<<<<
 *             c = text[0]
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_text);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":507
 *         # Check that tabs and spaces are being used consistently.
 *         if text:
 *             c = text[0]             # <<<<<<<<<<<<<<
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
 *             if self.indentation_char == '\0':
*/
    __pyx_t_3 = __Pyx_GetItemInt_Unicode(__pyx_v_text, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(__pyx_t_3 == (Py_UCS4)-1)) __PYX_ERR(0, 507, __pyx_L1_error)
    __pyx_v_c = __pyx_t_3;

    /* "Cython/Compiler/Scanning.py":509
 *             c = text[0]
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
 *             if self.indentation_char == '\0':             # <<<<<<<<<<<<<<
 *                 self.indentation_char = c
 *                 #print "Scanner.indentation_action: setting indent_char to", repr(c)
*/
    __pyx_t_2 = (__pyx_v_self->indentation_char == 0);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Scanning.py":510
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
 *             if self.indentation_char == '\0':
 *                 self.indentation_char = c             # <<<<<<<<<<<<<<
 *                 #print "Scanner.indentation_action: setting indent_char to", repr(c)
 *             else:
*/
      __pyx_v_self->indentation_char = __pyx_v_c;

      /* "Cython/Compiler/Scanning.py":509
 *             c = text[0]
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
 *             if self.indentation_char == '\0':             # <<<<<<<<<<<<<<
 *                 self.indentation_char = c
 *                 #print "Scanner.indentation_action: setting indent_char to", repr(c)
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Scanning.py":513
 *                 #print "Scanner.indentation_action: setting indent_char to", repr(c)
 *             else:
 *                 if self.indentation_char != c:             # <<<<<<<<<<<<<<
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")
 *             if text.replace(c, "") != "":
*/
    /*else*/ {
      __pyx_t_2 = (__pyx_v_self->indentation_char != __pyx_v_c);
      if (__pyx_t_2) {

        /* "Cython/Compiler/Scanning.py":514
 *             else:
 *                 if self.indentation_char != c:
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")             # <<<<<<<<<<<<<<
 *             if text.replace(c, "") != "":
 *                 self.error_at_scanpos("Mixed use of tabs and spaces")
*/
        __pyx_t_4 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(__pyx_v_self, __pyx_mstate_global->__pyx_kp_u_Mixed_use_of_tabs_and_spaces); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 514, __pyx_L1_error)

        /* "Cython/Compiler/Scanning.py":513
 *                 #print "Scanner.indentation_action: setting indent_char to", repr(c)
 *             else:
 *                 if self.indentation_char != c:             # <<<<<<<<<<<<<<
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")
 *             if text.replace(c, "") != "":
*/
      }
    }
    __pyx_L4:;

    /* "Cython/Compiler/Scanning.py":515
 *                 if self.indentation_char != c:
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")
 *             if text.replace(c, "") != "":             # <<<<<<<<<<<<<<
 *                 self.error_at_scanpos("Mixed use of tabs and spaces")
 *         # Figure out how many indents/dedents to do
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyUnicode_Replace(__pyx_v_text, __pyx_t_1, __pyx_mstate_global->__pyx_kp_u__4, -1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__4, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Scanning.py":516
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")
 *             if text.replace(c, "") != "":
 *                 self.error_at_scanpos("Mixed use of tabs and spaces")             # <<<<<<<<<<<<<<
 *         # Figure out how many indents/dedents to do
 *         current_level: cython.Py_ssize_t = self.current_level()
*/
      __pyx_t_4 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(__pyx_v_self, __pyx_mstate_global->__pyx_kp_u_Mixed_use_of_tabs_and_spaces); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 516, __pyx_L1_error)

      /* "Cython/Compiler/Scanning.py":515
 *                 if self.indentation_char != c:
 *                     self.error_at_scanpos("Mixed use of tabs and spaces")
 *             if text.replace(c, "") != "":             # <<<<<<<<<<<<<<
 *                 self.error_at_scanpos("Mixed use of tabs and spaces")
 *         # Figure out how many indents/dedents to do
*/
    }

    /* "Cython/Compiler/Scanning.py":506
 *         #    return
 *         # Check that tabs and spaces are being used consistently.
 *         if text:             # <<<<<<<<<<<<<<
 *             c = text[0]
 *             #print "Scanner.indentation_action: indent with", repr(c) ###
*/
  }

  /* "Cython/Compiler/Scanning.py":518
 *                 self.error_at_scanpos("Mixed use of tabs and spaces")
 *         # Figure out how many indents/dedents to do
 *         current_level: cython.Py_ssize_t = self.current_level()             # <<<<<<<<<<<<<<
 *         new_level: cython.Py_ssize_t = len(text)
 *         #print "Changing indent level from", current_level, "to", new_level ###
*/
  __pyx_t_6 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 518, __pyx_L1_error)
  __pyx_v_current_level = __pyx_t_6;

  /* "Cython/Compiler/Scanning.py":519
 *         # Figure out how many indents/dedents to do
 *         current_level: cython.Py_ssize_t = self.current_level()
 *         new_level: cython.Py_ssize_t = len(text)             # <<<<<<<<<<<<<<
 *         #print "Changing indent level from", current_level, "to", new_level ###
 *         if new_level == current_level:
*/
  __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_text); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 519, __pyx_L1_error)
  __pyx_v_new_level = __pyx_t_6;

  /* "Cython/Compiler/Scanning.py":521
 *         new_level: cython.Py_ssize_t = len(text)
 *         #print "Changing indent level from", current_level, "to", new_level ###
 *         if new_level == current_level:             # <<<<<<<<<<<<<<
 *             return
 *         elif new_level > current_level:
*/
  __pyx_t_2 = (__pyx_v_new_level == __pyx_v_current_level);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":522
 *         #print "Changing indent level from", current_level, "to", new_level ###
 *         if new_level == current_level:
 *             return             # <<<<<<<<<<<<<<
 *         elif new_level > current_level:
 *             #print "...pushing level", new_level ###
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":521
 *         new_level: cython.Py_ssize_t = len(text)
 *         #print "Changing indent level from", current_level, "to", new_level ###
 *         if new_level == current_level:             # <<<<<<<<<<<<<<
 *             return
 *         elif new_level > current_level:
*/
  }

  /* "Cython/Compiler/Scanning.py":523
 *         if new_level == current_level:
 *             return
 *         elif new_level > current_level:             # <<<<<<<<<<<<<<
 *             #print "...pushing level", new_level ###
 *             self.indentation_stack.append(new_level)
*/
  __pyx_t_2 = (__pyx_v_new_level > __pyx_v_current_level);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":525
 *         elif new_level > current_level:
 *             #print "...pushing level", new_level ###
 *             self.indentation_stack.append(new_level)             # <<<<<<<<<<<<<<
 *             self.produce('INDENT', '')
 *         else:
*/
    if (unlikely(__pyx_v_self->indentation_stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 525, __pyx_L1_error)
    }
    __pyx_t_5 = PyLong_FromSsize_t(__pyx_v_new_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->indentation_stack, __pyx_t_5); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Scanning.py":526
 *             #print "...pushing level", new_level ###
 *             self.indentation_stack.append(new_level)
 *             self.produce('INDENT', '')             # <<<<<<<<<<<<<<
 *         else:
 *             while new_level < self.current_level():
*/
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.text = __pyx_mstate_global->__pyx_kp_u__4;
    __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_INDENT, &__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Scanning.py":523
 *         if new_level == current_level:
 *             return
 *         elif new_level > current_level:             # <<<<<<<<<<<<<<
 *             #print "...pushing level", new_level ###
 *             self.indentation_stack.append(new_level)
*/
    goto __pyx_L7;
  }

  /* "Cython/Compiler/Scanning.py":528
 *             self.produce('INDENT', '')
 *         else:
 *             while new_level < self.current_level():             # <<<<<<<<<<<<<<
 *                 #print "...popping level", self.indentation_stack[-1] ###
 *                 self.indentation_stack.pop()
*/
  /*else*/ {
    while (1) {
      __pyx_t_6 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 528, __pyx_L1_error)
      __pyx_t_2 = (__pyx_v_new_level < __pyx_t_6);
      if (!__pyx_t_2) break;

      /* "Cython/Compiler/Scanning.py":530
 *             while new_level < self.current_level():
 *                 #print "...popping level", self.indentation_stack[-1] ###
 *                 self.indentation_stack.pop()             # <<<<<<<<<<<<<<
 *                 self.produce('DEDENT', '')
 *             #print "...current level now", self.current_level() ###
*/
      if (unlikely(__pyx_v_self->indentation_stack == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 530, __pyx_L1_error)
      }
      __pyx_t_5 = __Pyx_PyList_Pop(__pyx_v_self->indentation_stack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Compiler/Scanning.py":531
 *                 #print "...popping level", self.indentation_stack[-1] ###
 *                 self.indentation_stack.pop()
 *                 self.produce('DEDENT', '')             # <<<<<<<<<<<<<<
 *             #print "...current level now", self.current_level() ###
 *             if new_level != self.current_level():
*/
      __pyx_t_8.__pyx_n = 1;
      __pyx_t_8.text = __pyx_mstate_global->__pyx_kp_u__4;
      __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_DEDENT, &__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }

    /* "Cython/Compiler/Scanning.py":533
 *                 self.produce('DEDENT', '')
 *             #print "...current level now", self.current_level() ###
 *             if new_level != self.current_level():             # <<<<<<<<<<<<<<
 *                 self.error_at_scanpos("Inconsistent indentation")
 * 
*/
    __pyx_t_6 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 533, __pyx_L1_error)
    __pyx_t_2 = (__pyx_v_new_level != __pyx_t_6);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Scanning.py":534
 *             #print "...current level now", self.current_level() ###
 *             if new_level != self.current_level():
 *                 self.error_at_scanpos("Inconsistent indentation")             # <<<<<<<<<<<<<<
 * 
 *     def eof_action(self, text):
*/
      __pyx_t_4 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(__pyx_v_self, __pyx_mstate_global->__pyx_kp_u_Inconsistent_indentation); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 534, __pyx_L1_error)

      /* "Cython/Compiler/Scanning.py":533
 *                 self.produce('DEDENT', '')
 *             #print "...current level now", self.current_level() ###
 *             if new_level != self.current_level():             # <<<<<<<<<<<<<<
 *                 self.error_at_scanpos("Inconsistent indentation")
 * 
*/
    }
  }
  __pyx_L7:;

  /* "Cython/Compiler/Scanning.py":500
 *         self.error_at_scanpos("Unclosed string literal")
 * 
 *     def indentation_action(self, text: str):             # <<<<<<<<<<<<<<
 *         self.begin('')
 *         # Indentation within brackets should be ignored.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.indentation_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":536
 *                 self.error_at_scanpos("Inconsistent indentation")
 * 
 *     def eof_action(self, text):             # <<<<<<<<<<<<<<
 *         while len(self.indentation_stack) > 1:
 *             self.produce('DEDENT', '')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action = {"eof_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eof_action (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_40eof_action(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_40eof_action(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eof_action", 0);

  /* "Cython/Compiler/Scanning.py":537
 * 
 *     def eof_action(self, text):
 *         while len(self.indentation_stack) > 1:             # <<<<<<<<<<<<<<
 *             self.produce('DEDENT', '')
 *             self.indentation_stack.pop()
*/
  while (1) {
    __pyx_t_1 = __pyx_v_self->indentation_stack;
    __Pyx_INCREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 537, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 537, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 > 1);
    if (!__pyx_t_3) break;

    /* "Cython/Compiler/Scanning.py":538
 *     def eof_action(self, text):
 *         while len(self.indentation_stack) > 1:
 *             self.produce('DEDENT', '')             # <<<<<<<<<<<<<<
 *             self.indentation_stack.pop()
 *         self.produce('EOF', '')
*/
    __pyx_t_4.__pyx_n = 1;
    __pyx_t_4.text = __pyx_mstate_global->__pyx_kp_u__4;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_DEDENT, &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":539
 *         while len(self.indentation_stack) > 1:
 *             self.produce('DEDENT', '')
 *             self.indentation_stack.pop()             # <<<<<<<<<<<<<<
 *         self.produce('EOF', '')
 * 
*/
    if (unlikely(__pyx_v_self->indentation_stack == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 539, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->indentation_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Scanning.py":540
 *             self.produce('DEDENT', '')
 *             self.indentation_stack.pop()
 *         self.produce('EOF', '')             # <<<<<<<<<<<<<<
 * 
 *     def next(self):
*/
  __pyx_t_4.__pyx_n = 1;
  __pyx_t_4.text = __pyx_mstate_global->__pyx_kp_u__4;
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.produce(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_EOF, &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":536
 *                 self.error_at_scanpos("Inconsistent indentation")
 * 
 *     def eof_action(self, text):             # <<<<<<<<<<<<<<
 *         while len(self.indentation_stack) > 1:
 *             self.produce('DEDENT', '')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.eof_action", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":542
 *         self.produce('EOF', '')
 * 
 *     def next(self):             # <<<<<<<<<<<<<<
 *         try:
 *             sy, systring = self.read()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_43next(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_43next = {"next", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_43next, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_43next(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("next (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_42next(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_42next(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_systring = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  size_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next", 0);

  /* "Cython/Compiler/Scanning.py":543
 * 
 *     def next(self):
 *         try:             # <<<<<<<<<<<<<<
 *             sy, systring = self.read()
 *         except UnrecognizedInput:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Scanning.py":544
 *     def next(self):
 *         try:
 *             sy, systring = self.read()             # <<<<<<<<<<<<<<
 *         except UnrecognizedInput:
 *             self.error_at_scanpos("Unrecognized character")
*/
      __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.read(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(__pyx_t_4 != Py_None)) {
        PyObject* sequence = __pyx_t_4;
        Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 544, __pyx_L3_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 544, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 544, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 544, __pyx_L3_error)
      }
      __pyx_v_sy = __pyx_t_5;
      __pyx_t_5 = 0;
      __pyx_v_systring = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Scanning.py":543
 * 
 *     def next(self):
 *         try:             # <<<<<<<<<<<<<<
 *             sy, systring = self.read()
 *         except UnrecognizedInput:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Scanning.py":545
 *         try:
 *             sy, systring = self.read()
 *         except UnrecognizedInput:             # <<<<<<<<<<<<<<
 *             self.error_at_scanpos("Unrecognized character")
 *             return  # just a marker, error() always raises
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_UnrecognizedInput); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 545, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_6, __pyx_t_5);
    __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.next", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 545, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "Cython/Compiler/Scanning.py":546
 *             sy, systring = self.read()
 *         except UnrecognizedInput:
 *             self.error_at_scanpos("Unrecognized character")             # <<<<<<<<<<<<<<
 *             return  # just a marker, error() always raises
 *         if sy == IDENT:
*/
      __pyx_t_8 = __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(__pyx_v_self, __pyx_mstate_global->__pyx_kp_u_Unrecognized_character); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 546, __pyx_L5_except_error)

      /* "Cython/Compiler/Scanning.py":547
 *         except UnrecognizedInput:
 *             self.error_at_scanpos("Unrecognized character")
 *             return  # just a marker, error() always raises             # <<<<<<<<<<<<<<
 *         if sy == IDENT:
 *             if systring in self.keywords:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Scanning.py":543
 * 
 *     def next(self):
 *         try:             # <<<<<<<<<<<<<<
 *             sy, systring = self.read()
 *         except UnrecognizedInput:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "Cython/Compiler/Scanning.py":548
 *             self.error_at_scanpos("Unrecognized character")
 *             return  # just a marker, error() always raises
 *         if sy == IDENT:             # <<<<<<<<<<<<<<
 *             if systring in self.keywords:
 *                 if systring == 'print' and print_function in self.context.future_directives:
*/
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_v_6Cython_8Compiler_8Scanning_IDENT, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 548, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "Cython/Compiler/Scanning.py":549
 *             return  # just a marker, error() always raises
 *         if sy == IDENT:
 *             if systring in self.keywords:             # <<<<<<<<<<<<<<
 *                 if systring == 'print' and print_function in self.context.future_directives:
 *                     self.keywords.pop('print', None)
*/
    if (unlikely(__pyx_v_self->keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 549, __pyx_L1_error)
    }
    __pyx_t_9 = (__Pyx_PyDict_ContainsTF(__pyx_v_systring, __pyx_v_self->keywords, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 549, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "Cython/Compiler/Scanning.py":550
 *         if sy == IDENT:
 *             if systring in self.keywords:
 *                 if systring == 'print' and print_function in self.context.future_directives:             # <<<<<<<<<<<<<<
 *                     self.keywords.pop('print', None)
 *                 elif systring == 'exec' and self.context.language_level >= 3:
*/
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_systring, __pyx_mstate_global->__pyx_n_u_print, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 550, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_9 = __pyx_t_10;
        goto __pyx_L14_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_v_6Cython_8Compiler_8Scanning_print_function, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 550, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __pyx_t_10;
      __pyx_L14_bool_binop_done:;
      if (__pyx_t_9) {

        /* "Cython/Compiler/Scanning.py":551
 *             if systring in self.keywords:
 *                 if systring == 'print' and print_function in self.context.future_directives:
 *                     self.keywords.pop('print', None)             # <<<<<<<<<<<<<<
 *                 elif systring == 'exec' and self.context.language_level >= 3:
 *                     self.keywords.pop('exec', None)
*/
        if (unlikely(__pyx_v_self->keywords == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
          __PYX_ERR(0, 551, __pyx_L1_error)
        }
        __pyx_t_8 = __Pyx_PyDict_Pop_ignore(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_print, Py_None); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 551, __pyx_L1_error)

        /* "Cython/Compiler/Scanning.py":550
 *         if sy == IDENT:
 *             if systring in self.keywords:
 *                 if systring == 'print' and print_function in self.context.future_directives:             # <<<<<<<<<<<<<<
 *                     self.keywords.pop('print', None)
 *                 elif systring == 'exec' and self.context.language_level >= 3:
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Scanning.py":552
 *                 if systring == 'print' and print_function in self.context.future_directives:
 *                     self.keywords.pop('print', None)
 *                 elif systring == 'exec' and self.context.language_level >= 3:             # <<<<<<<<<<<<<<
 *                     self.keywords.pop('exec', None)
 *                 else:
*/
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_systring, __pyx_mstate_global->__pyx_n_u_exec, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 552, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_9 = __pyx_t_10;
        goto __pyx_L16_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 552, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 552, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_9 = __pyx_t_10;
      __pyx_L16_bool_binop_done:;
      if (__pyx_t_9) {

        /* "Cython/Compiler/Scanning.py":553
 *                     self.keywords.pop('print', None)
 *                 elif systring == 'exec' and self.context.language_level >= 3:
 *                     self.keywords.pop('exec', None)             # <<<<<<<<<<<<<<
 *                 else:
 *                     sy = self.keywords[systring]  # intern
*/
        if (unlikely(__pyx_v_self->keywords == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
          __PYX_ERR(0, 553, __pyx_L1_error)
        }
        __pyx_t_8 = __Pyx_PyDict_Pop_ignore(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_exec, Py_None); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 553, __pyx_L1_error)

        /* "Cython/Compiler/Scanning.py":552
 *                 if systring == 'print' and print_function in self.context.future_directives:
 *                     self.keywords.pop('print', None)
 *                 elif systring == 'exec' and self.context.language_level >= 3:             # <<<<<<<<<<<<<<
 *                     self.keywords.pop('exec', None)
 *                 else:
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Scanning.py":555
 *                     self.keywords.pop('exec', None)
 *                 else:
 *                     sy = self.keywords[systring]  # intern             # <<<<<<<<<<<<<<
 *             systring = self.context.intern_ustring(systring)
 *         if self.put_back_on_failure is not None:
*/
      /*else*/ {
        if (unlikely(__pyx_v_self->keywords == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 555, __pyx_L1_error)
        }
        __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_self->keywords, __pyx_v_systring); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 555, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF_SET(__pyx_v_sy, __pyx_t_6);
        __pyx_t_6 = 0;
      }
      __pyx_L13:;

      /* "Cython/Compiler/Scanning.py":549
 *             return  # just a marker, error() always raises
 *         if sy == IDENT:
 *             if systring in self.keywords:             # <<<<<<<<<<<<<<
 *                 if systring == 'print' and print_function in self.context.future_directives:
 *                     self.keywords.pop('print', None)
*/
    }

    /* "Cython/Compiler/Scanning.py":556
 *                 else:
 *                     sy = self.keywords[systring]  # intern
 *             systring = self.context.intern_ustring(systring)             # <<<<<<<<<<<<<<
 *         if self.put_back_on_failure is not None:
 *             self.put_back_on_failure.append((sy, systring, self.position()))
*/
    __pyx_t_4 = __pyx_v_self->context;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_11 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_systring};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF_SET(__pyx_v_systring, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Scanning.py":548
 *             self.error_at_scanpos("Unrecognized character")
 *             return  # just a marker, error() always raises
 *         if sy == IDENT:             # <<<<<<<<<<<<<<
 *             if systring in self.keywords:
 *                 if systring == 'print' and print_function in self.context.future_directives:
*/
  }

  /* "Cython/Compiler/Scanning.py":557
 *                     sy = self.keywords[systring]  # intern
 *             systring = self.context.intern_ustring(systring)
 *         if self.put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *             self.put_back_on_failure.append((sy, systring, self.position()))
 *         self.sy = sy
*/
  __pyx_t_9 = (__pyx_v_self->put_back_on_failure != ((PyObject*)Py_None));
  if (__pyx_t_9) {

    /* "Cython/Compiler/Scanning.py":558
 *             systring = self.context.intern_ustring(systring)
 *         if self.put_back_on_failure is not None:
 *             self.put_back_on_failure.append((sy, systring, self.position()))             # <<<<<<<<<<<<<<
 *         self.sy = sy
 *         self.systring = systring
*/
    if (unlikely(__pyx_v_self->put_back_on_failure == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 558, __pyx_L1_error)
    }
    __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_sy);
    __Pyx_GIVEREF(__pyx_v_sy);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_sy) != (0)) __PYX_ERR(0, 558, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_systring);
    __Pyx_GIVEREF(__pyx_v_systring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_systring) != (0)) __PYX_ERR(0, 558, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6) != (0)) __PYX_ERR(0, 558, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_self->put_back_on_failure, __pyx_t_4); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Scanning.py":557
 *                     sy = self.keywords[systring]  # intern
 *             systring = self.context.intern_ustring(systring)
 *         if self.put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *             self.put_back_on_failure.append((sy, systring, self.position()))
 *         self.sy = sy
*/
  }

  /* "Cython/Compiler/Scanning.py":559
 *         if self.put_back_on_failure is not None:
 *             self.put_back_on_failure.append((sy, systring, self.position()))
 *         self.sy = sy             # <<<<<<<<<<<<<<
 *         self.systring = systring
 *         if False:  # debug_scanner:
*/
  __pyx_t_4 = __pyx_v_sy;
  __Pyx_INCREF(__pyx_t_4);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_4))) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":560
 *             self.put_back_on_failure.append((sy, systring, self.position()))
 *         self.sy = sy
 *         self.systring = systring             # <<<<<<<<<<<<<<
 *         if False:  # debug_scanner:
 *             _, line, col = self.position()
*/
  __Pyx_INCREF(__pyx_v_systring);
  __Pyx_GIVEREF(__pyx_v_systring);
  __Pyx_GOTREF(__pyx_v_self->systring);
  __Pyx_DECREF(__pyx_v_self->systring);
  __pyx_v_self->systring = __pyx_v_systring;

  /* "Cython/Compiler/Scanning.py":542
 *         self.produce('EOF', '')
 * 
 *     def next(self):             # <<<<<<<<<<<<<<
 *         try:
 *             sy, systring = self.read()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.next", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_systring);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":569
 *             print("--- %3d %2d %s" % (line, col, t))
 * 
 *     def peek(self):             # <<<<<<<<<<<<<<
 *         saved = self.sy, self.systring
 *         saved_pos = self.position()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek = {"peek", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peek (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_44peek(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_44peek(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_v_saved = NULL;
  PyObject *__pyx_v_saved_pos = NULL;
  PyObject *__pyx_v_next = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peek", 0);

  /* "Cython/Compiler/Scanning.py":570
 * 
 *     def peek(self):
 *         saved = self.sy, self.systring             # <<<<<<<<<<<<<<
 *         saved_pos = self.position()
 *         self.next()
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->sy);
  __Pyx_GIVEREF(__pyx_v_self->sy);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->sy) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->systring);
  __Pyx_GIVEREF(__pyx_v_self->systring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->systring) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __pyx_v_saved = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":571
 *     def peek(self):
 *         saved = self.sy, self.systring
 *         saved_pos = self.position()             # <<<<<<<<<<<<<<
 *         self.next()
 *         next = self.sy, self.systring
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_saved_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":572
 *         saved = self.sy, self.systring
 *         saved_pos = self.position()
 *         self.next()             # <<<<<<<<<<<<<<
 *         next = self.sy, self.systring
 *         self.unread(self.sy, self.systring, self.position())
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":573
 *         saved_pos = self.position()
 *         self.next()
 *         next = self.sy, self.systring             # <<<<<<<<<<<<<<
 *         self.unread(self.sy, self.systring, self.position())
 *         self.sy, self.systring = saved
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->sy);
  __Pyx_GIVEREF(__pyx_v_self->sy);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->sy) != (0)) __PYX_ERR(0, 573, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->systring);
  __Pyx_GIVEREF(__pyx_v_self->systring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->systring) != (0)) __PYX_ERR(0, 573, __pyx_L1_error);
  __pyx_v_next = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":574
 *         self.next()
 *         next = self.sy, self.systring
 *         self.unread(self.sy, self.systring, self.position())             # <<<<<<<<<<<<<<
 *         self.sy, self.systring = saved
 *         self.last_token_position_tuple = saved_pos
*/
  __pyx_t_1 = __pyx_v_self->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.unread(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_1, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":575
 *         next = self.sy, self.systring
 *         self.unread(self.sy, self.systring, self.position())
 *         self.sy, self.systring = saved             # <<<<<<<<<<<<<<
 *         self.last_token_position_tuple = saved_pos
 *         return next
*/
  if (1) {
    PyObject* sequence = __pyx_v_saved;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 575, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
  }
  if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->systring);
  __Pyx_DECREF(__pyx_v_self->systring);
  __pyx_v_self->systring = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":576
 *         self.unread(self.sy, self.systring, self.position())
 *         self.sy, self.systring = saved
 *         self.last_token_position_tuple = saved_pos             # <<<<<<<<<<<<<<
 *         return next
 * 
*/
  __Pyx_INCREF(__pyx_v_saved_pos);
  __Pyx_GIVEREF(__pyx_v_saved_pos);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.last_token_position_tuple);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.last_token_position_tuple);
  __pyx_v_self->__pyx_base.last_token_position_tuple = __pyx_v_saved_pos;

  /* "Cython/Compiler/Scanning.py":577
 *         self.sy, self.systring = saved
 *         self.last_token_position_tuple = saved_pos
 *         return next             # <<<<<<<<<<<<<<
 * 
 *     def put_back(self, sy, systring, pos):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_next);
  __pyx_r = __pyx_v_next;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":569
 *             print("--- %3d %2d %s" % (line, col, t))
 * 
 *     def peek(self):             # <<<<<<<<<<<<<<
 *         saved = self.sy, self.systring
 *         saved_pos = self.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.peek", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_saved);
  __Pyx_XDECREF(__pyx_v_saved_pos);
  __Pyx_XDECREF(__pyx_v_next);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":579
 *         return next
 * 
 *     def put_back(self, sy, systring, pos):             # <<<<<<<<<<<<<<
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)
 *         self.sy = sy
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back = {"put_back", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_sy = 0;
  PyObject *__pyx_v_systring = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("put_back (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_sy,&__pyx_mstate_global->__pyx_n_u_systring,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 579, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 579, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 579, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 579, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "put_back", 0) < (0)) __PYX_ERR(0, 579, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("put_back", 1, 3, 3, i); __PYX_ERR(0, 579, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 579, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 579, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 579, __pyx_L3_error)
    }
    __pyx_v_sy = values[0];
    __pyx_v_systring = values[1];
    __pyx_v_pos = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("put_back", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 579, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.put_back", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_46put_back(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_sy, __pyx_v_systring, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_46put_back(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_sy, PyObject *__pyx_v_systring, PyObject *__pyx_v_pos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("put_back", 0);

  /* "Cython/Compiler/Scanning.py":580
 * 
 *     def put_back(self, sy, systring, pos):
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)             # <<<<<<<<<<<<<<
 *         self.sy = sy
 *         self.systring = systring
*/
  __pyx_t_1 = __pyx_v_self->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_self->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_v_self->__pyx_base.last_token_position_tuple;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.unread(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), __pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":581
 *     def put_back(self, sy, systring, pos):
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)
 *         self.sy = sy             # <<<<<<<<<<<<<<
 *         self.systring = systring
 *         self.last_token_position_tuple = pos
*/
  __pyx_t_4 = __pyx_v_sy;
  __Pyx_INCREF(__pyx_t_4);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_4))) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":582
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)
 *         self.sy = sy
 *         self.systring = systring             # <<<<<<<<<<<<<<
 *         self.last_token_position_tuple = pos
 * 
*/
  __Pyx_INCREF(__pyx_v_systring);
  __Pyx_GIVEREF(__pyx_v_systring);
  __Pyx_GOTREF(__pyx_v_self->systring);
  __Pyx_DECREF(__pyx_v_self->systring);
  __pyx_v_self->systring = __pyx_v_systring;

  /* "Cython/Compiler/Scanning.py":583
 *         self.sy = sy
 *         self.systring = systring
 *         self.last_token_position_tuple = pos             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = __pyx_v_pos;
  __Pyx_INCREF(__pyx_t_4);
  if (!(likely(PyTuple_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_4))) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.last_token_position_tuple);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.last_token_position_tuple);
  __pyx_v_self->__pyx_base.last_token_position_tuple = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":579
 *         return next
 * 
 *     def put_back(self, sy, systring, pos):             # <<<<<<<<<<<<<<
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)
 *         self.sy = sy
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.put_back", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":586
 * 
 * 
 *     def error(self, message, pos=None, fatal=True):             # <<<<<<<<<<<<<<
 *         if pos is None:
 *             pos = self.position()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_49error(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_49error = {"error", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_49error, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_49error(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_v_pos = 0;
  PyObject *__pyx_v_fatal = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("error (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_message,&__pyx_mstate_global->__pyx_n_u_pos,&__pyx_mstate_global->__pyx_n_u_fatal,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 586, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 586, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 586, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 586, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "error", 0) < (0)) __PYX_ERR(0, 586, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_True));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("error", 0, 1, 3, i); __PYX_ERR(0, 586, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 586, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 586, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 586, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_True));
    }
    __pyx_v_message = values[0];
    __pyx_v_pos = values[1];
    __pyx_v_fatal = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("error", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 586, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_48error(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_message, __pyx_v_pos, __pyx_v_fatal);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_48error(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message, PyObject *__pyx_v_pos, PyObject *__pyx_v_fatal) {
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("error", 0);
  __Pyx_INCREF(__pyx_v_pos);

  /* "Cython/Compiler/Scanning.py":587
 * 
 *     def error(self, message, pos=None, fatal=True):
 *         if pos is None:             # <<<<<<<<<<<<<<
 *             pos = self.position()
 *         if self.sy == 'INDENT':
*/
  __pyx_t_1 = (__pyx_v_pos == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":588
 *     def error(self, message, pos=None, fatal=True):
 *         if pos is None:
 *             pos = self.position()             # <<<<<<<<<<<<<<
 *         if self.sy == 'INDENT':
 *             error(pos, "Possible inconsistent indentation")
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 588, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":587
 * 
 *     def error(self, message, pos=None, fatal=True):
 *         if pos is None:             # <<<<<<<<<<<<<<
 *             pos = self.position()
 *         if self.sy == 'INDENT':
*/
  }

  /* "Cython/Compiler/Scanning.py":589
 *         if pos is None:
 *             pos = self.position()
 *         if self.sy == 'INDENT':             # <<<<<<<<<<<<<<
 *             error(pos, "Possible inconsistent indentation")
 *         err = error(pos, message)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_mstate_global->__pyx_n_u_INDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 589, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":590
 *             pos = self.position()
 *         if self.sy == 'INDENT':
 *             error(pos, "Possible inconsistent indentation")             # <<<<<<<<<<<<<<
 *         err = error(pos, message)
 *         if fatal: raise err
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_error);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_8Scanning_error; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Possible_inconsistent_indentatio};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 590, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":589
 *         if pos is None:
 *             pos = self.position()
 *         if self.sy == 'INDENT':             # <<<<<<<<<<<<<<
 *             error(pos, "Possible inconsistent indentation")
 *         err = error(pos, message)
*/
  }

  /* "Cython/Compiler/Scanning.py":591
 *         if self.sy == 'INDENT':
 *             error(pos, "Possible inconsistent indentation")
 *         err = error(pos, message)             # <<<<<<<<<<<<<<
 *         if fatal: raise err
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_error);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_8Scanning_error; 
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_v_message};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_err = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":592
 *             error(pos, "Possible inconsistent indentation")
 *         err = error(pos, message)
 *         if fatal: raise err             # <<<<<<<<<<<<<<
 * 
 *     def error_at_scanpos(self, message):
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_fatal); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 592, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {
    __Pyx_Raise(__pyx_v_err, 0, 0, 0);
    __PYX_ERR(0, 592, __pyx_L1_error)
  }

  /* "Cython/Compiler/Scanning.py":586
 * 
 * 
 *     def error(self, message, pos=None, fatal=True):             # <<<<<<<<<<<<<<
 *         if pos is None:
 *             pos = self.position()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":594
 *         if fatal: raise err
 * 
 *     def error_at_scanpos(self, message):             # <<<<<<<<<<<<<<
 *         # Like error(fatal=True), but gets the current scanning position rather than
 *         # the position of the last token read.
*/

static int __pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message) {
  PyObject *__pyx_v_pos = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("error_at_scanpos", 0);

  /* "Cython/Compiler/Scanning.py":597
 *         # Like error(fatal=True), but gets the current scanning position rather than
 *         # the position of the last token read.
 *         pos = self.get_current_scan_pos()             # <<<<<<<<<<<<<<
 *         self.error(message, pos, True)
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.get_current_scan_pos(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":598
 *         # the position of the last token read.
 *         pos = self.get_current_scan_pos()
 *         self.error(message, pos, True)             # <<<<<<<<<<<<<<
 * 
 *     def expect(self, what, message=None):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_message, __pyx_v_pos, Py_True};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (4-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":594
 *         if fatal: raise err
 * 
 *     def error_at_scanpos(self, message):             # <<<<<<<<<<<<<<
 *         # Like error(fatal=True), but gets the current scanning position rather than
 *         # the position of the last token read.
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.error_at_scanpos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":600
 *         self.error(message, pos, True)
 * 
 *     def expect(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == what:
 *             self.next()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect = {"expect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_what = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expect (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_what,&__pyx_mstate_global->__pyx_n_u_message,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 600, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 600, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 600, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "expect", 0) < (0)) __PYX_ERR(0, 600, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("expect", 0, 1, 2, i); __PYX_ERR(0, 600, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 600, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 600, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_what = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("expect", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 600, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_50expect(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_what, __pyx_v_message);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_50expect(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect", 0);

  /* "Cython/Compiler/Scanning.py":601
 * 
 *     def expect(self, what, message=None):
 *         if self.sy == what:             # <<<<<<<<<<<<<<
 *             self.next()
 *         else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_v_what, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 601, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":602
 *     def expect(self, what, message=None):
 *         if self.sy == what:
 *             self.next()             # <<<<<<<<<<<<<<
 *         else:
 *             self.expected(what, message)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 602, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":601
 * 
 *     def expect(self, what, message=None):
 *         if self.sy == what:             # <<<<<<<<<<<<<<
 *             self.next()
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Scanning.py":604
 *             self.next()
 *         else:
 *             self.expected(what, message)             # <<<<<<<<<<<<<<
 * 
 *     def expect_keyword(self, what, message=None):
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_what, __pyx_v_message};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Scanning.py":600
 *         self.error(message, pos, True)
 * 
 *     def expect(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == what:
 *             self.next()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":606
 *             self.expected(what, message)
 * 
 *     def expect_keyword(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == IDENT and self.systring == what:
 *             self.next()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword = {"expect_keyword", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_what = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expect_keyword (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_what,&__pyx_mstate_global->__pyx_n_u_message,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 606, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 606, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 606, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "expect_keyword", 0) < (0)) __PYX_ERR(0, 606, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("expect_keyword", 0, 1, 2, i); __PYX_ERR(0, 606, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 606, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 606, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_what = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("expect_keyword", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 606, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_keyword", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_52expect_keyword(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_what, __pyx_v_message);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_52expect_keyword(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect_keyword", 0);

  /* "Cython/Compiler/Scanning.py":607
 * 
 *     def expect_keyword(self, what, message=None):
 *         if self.sy == IDENT and self.systring == what:             # <<<<<<<<<<<<<<
 *             self.next()
 *         else:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_v_6Cython_8Compiler_8Scanning_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_self->systring, __pyx_v_what, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 607, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":608
 *     def expect_keyword(self, what, message=None):
 *         if self.sy == IDENT and self.systring == what:
 *             self.next()             # <<<<<<<<<<<<<<
 *         else:
 *             self.expected(what, message)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":607
 * 
 *     def expect_keyword(self, what, message=None):
 *         if self.sy == IDENT and self.systring == what:             # <<<<<<<<<<<<<<
 *             self.next()
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Scanning.py":610
 *             self.next()
 *         else:
 *             self.expected(what, message)             # <<<<<<<<<<<<<<
 * 
 *     def expected(self, what, message=None):
*/
  /*else*/ {
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_what, __pyx_v_message};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 610, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Scanning.py":606
 *             self.expected(what, message)
 * 
 *     def expect_keyword(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == IDENT and self.systring == what:
 *             self.next()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_keyword", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":612
 *             self.expected(what, message)
 * 
 *     def expected(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if message:
 *             self.error(message)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected = {"expected", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_what = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expected (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_what,&__pyx_mstate_global->__pyx_n_u_message,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 612, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 612, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 612, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "expected", 0) < (0)) __PYX_ERR(0, 612, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("expected", 0, 1, 2, i); __PYX_ERR(0, 612, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 612, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 612, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_what = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("expected", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 612, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_54expected(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_what, __pyx_v_message);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_54expected(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_what, PyObject *__pyx_v_message) {
  PyObject *__pyx_v_found = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[5];
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expected", 0);

  /* "Cython/Compiler/Scanning.py":613
 * 
 *     def expected(self, what, message=None):
 *         if message:             # <<<<<<<<<<<<<<
 *             self.error(message)
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_message); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 613, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":614
 *     def expected(self, what, message=None):
 *         if message:
 *             self.error(message)             # <<<<<<<<<<<<<<
 *         else:
 *             if self.sy == IDENT:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_message};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Scanning.py":613
 * 
 *     def expected(self, what, message=None):
 *         if message:             # <<<<<<<<<<<<<<
 *             self.error(message)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Scanning.py":616
 *             self.error(message)
 *         else:
 *             if self.sy == IDENT:             # <<<<<<<<<<<<<<
 *                 found = self.systring
 *             else:
*/
  /*else*/ {
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_v_6Cython_8Compiler_8Scanning_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Scanning.py":617
 *         else:
 *             if self.sy == IDENT:
 *                 found = self.systring             # <<<<<<<<<<<<<<
 *             else:
 *                 found = self.sy
*/
      __pyx_t_2 = __pyx_v_self->systring;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_found = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Scanning.py":616
 *             self.error(message)
 *         else:
 *             if self.sy == IDENT:             # <<<<<<<<<<<<<<
 *                 found = self.systring
 *             else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Scanning.py":619
 *                 found = self.systring
 *             else:
 *                 found = self.sy             # <<<<<<<<<<<<<<
 *             self.error("Expected '%s', found '%s'" % (what, found))
 * 
*/
    /*else*/ {
      __pyx_t_2 = __pyx_v_self->sy;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_found = __pyx_t_2;
      __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Scanning.py":620
 *             else:
 *                 found = self.sy
 *             self.error("Expected '%s', found '%s'" % (what, found))             # <<<<<<<<<<<<<<
 * 
 *     def expect_indent(self):
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_what), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_found), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_Expected;
    __pyx_t_7[1] = __pyx_t_5;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u_found;
    __pyx_t_7[3] = __pyx_t_6;
    __pyx_t_7[4] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 5, 10 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Scanning.py":612
 *             self.expected(what, message)
 * 
 *     def expected(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if message:
 *             self.error(message)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_found);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":622
 *             self.error("Expected '%s', found '%s'" % (what, found))
 * 
 *     def expect_indent(self):             # <<<<<<<<<<<<<<
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent = {"expect_indent", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expect_indent (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_56expect_indent(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_56expect_indent(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect_indent", 0);

  /* "Cython/Compiler/Scanning.py":623
 * 
 *     def expect_indent(self):
 *         self.expect('INDENT', "Expected an increase in indentation level")             # <<<<<<<<<<<<<<
 * 
 *     def expect_dedent(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_expect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[5], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":622
 *             self.error("Expected '%s', found '%s'" % (what, found))
 * 
 *     def expect_indent(self):             # <<<<<<<<<<<<<<
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_indent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":625
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
 *     def expect_dedent(self):             # <<<<<<<<<<<<<<
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent = {"expect_dedent", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expect_dedent (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_58expect_dedent(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_58expect_dedent(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect_dedent", 0);

  /* "Cython/Compiler/Scanning.py":626
 * 
 *     def expect_dedent(self):
 *         self.expect('DEDENT', "Expected a decrease in indentation level")             # <<<<<<<<<<<<<<
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_expect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[6], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":625
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
 *     def expect_dedent(self):             # <<<<<<<<<<<<<<
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_dedent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":628
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):             # <<<<<<<<<<<<<<
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline = {"expect_newline", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_message = 0;
  int __pyx_v_ignore_semicolon;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expect_newline (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_message,&__pyx_mstate_global->__pyx_n_u_ignore_semicolon,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 628, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 628, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 628, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "expect_newline", 0) < (0)) __PYX_ERR(0, 628, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_kp_u_Expected_a_newline));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 628, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 628, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_kp_u_Expected_a_newline));
    }
    __pyx_v_message = values[0];
    if (values[1]) {
      __pyx_v_ignore_semicolon = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_ignore_semicolon == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 628, __pyx_L3_error)
    } else {
      __pyx_v_ignore_semicolon = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("expect_newline", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 628, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_newline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_60expect_newline(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), __pyx_v_message, __pyx_v_ignore_semicolon);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_60expect_newline(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_message, int __pyx_v_ignore_semicolon) {
  PyObject *__pyx_v_useless_trailing_semicolon = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect_newline", 0);

  /* "Cython/Compiler/Scanning.py":630
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None             # <<<<<<<<<<<<<<
 *         if ignore_semicolon and self.sy == ';':
 *             useless_trailing_semicolon = self.position()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_useless_trailing_semicolon = ((PyObject*)Py_None);

  /* "Cython/Compiler/Scanning.py":631
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
 *         if ignore_semicolon and self.sy == ';':             # <<<<<<<<<<<<<<
 *             useless_trailing_semicolon = self.position()
 *             self.next()
*/
  if (__pyx_v_ignore_semicolon) {
  } else {
    __pyx_t_1 = __pyx_v_ignore_semicolon;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_mstate_global->__pyx_kp_u__9, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 631, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":632
 *         useless_trailing_semicolon = None
 *         if ignore_semicolon and self.sy == ';':
 *             useless_trailing_semicolon = self.position()             # <<<<<<<<<<<<<<
 *             self.next()
 *         if self.sy != 'EOF':
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_self), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_useless_trailing_semicolon, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":633
 *         if ignore_semicolon and self.sy == ';':
 *             useless_trailing_semicolon = self.position()
 *             self.next()             # <<<<<<<<<<<<<<
 *         if self.sy != 'EOF':
 *             self.expect('NEWLINE', message)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":631
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
 *         if ignore_semicolon and self.sy == ';':             # <<<<<<<<<<<<<<
 *             useless_trailing_semicolon = self.position()
 *             self.next()
*/
  }

  /* "Cython/Compiler/Scanning.py":634
 *             useless_trailing_semicolon = self.position()
 *             self.next()
 *         if self.sy != 'EOF':             # <<<<<<<<<<<<<<
 *             self.expect('NEWLINE', message)
 *         if useless_trailing_semicolon is not None:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->sy, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 634, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":635
 *             self.next()
 *         if self.sy != 'EOF':
 *             self.expect('NEWLINE', message)             # <<<<<<<<<<<<<<
 *         if useless_trailing_semicolon is not None:
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NEWLINE, __pyx_v_message};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":634
 *             useless_trailing_semicolon = self.position()
 *             self.next()
 *         if self.sy != 'EOF':             # <<<<<<<<<<<<<<
 *             self.expect('NEWLINE', message)
 *         if useless_trailing_semicolon is not None:
*/
  }

  /* "Cython/Compiler/Scanning.py":636
 *         if self.sy != 'EOF':
 *             self.expect('NEWLINE', message)
 *         if useless_trailing_semicolon is not None:             # <<<<<<<<<<<<<<
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
 * 
*/
  __pyx_t_1 = (__pyx_v_useless_trailing_semicolon != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":637
 *             self.expect('NEWLINE', message)
 *         if useless_trailing_semicolon is not None:
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")             # <<<<<<<<<<<<<<
 * 
 *     def enter_async(self):
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_8Scanning_warning);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_8Scanning_warning; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_useless_trailing_semicolon, __pyx_mstate_global->__pyx_kp_u_useless_trailing_semicolon};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":636
 *         if self.sy != 'EOF':
 *             self.expect('NEWLINE', message)
 *         if useless_trailing_semicolon is not None:             # <<<<<<<<<<<<<<
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
 * 
*/
  }

  /* "Cython/Compiler/Scanning.py":628
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):             # <<<<<<<<<<<<<<
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.expect_newline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_useless_trailing_semicolon);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":639
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
 * 
 *     def enter_async(self):             # <<<<<<<<<<<<<<
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async = {"enter_async", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enter_async (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_62enter_async(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_62enter_async(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enter_async", 0);

  /* "Cython/Compiler/Scanning.py":640
 * 
 *     def enter_async(self):
 *         self.async_enabled += 1             # <<<<<<<<<<<<<<
 *         if self.async_enabled == 1:
 *             self.keywords['async'] = 'async'
*/
  __pyx_v_self->async_enabled = (__pyx_v_self->async_enabled + 1);

  /* "Cython/Compiler/Scanning.py":641
 *     def enter_async(self):
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:             # <<<<<<<<<<<<<<
 *             self.keywords['async'] = 'async'
 *             self.keywords['await'] = 'await'
*/
  __pyx_t_1 = (__pyx_v_self->async_enabled == 1);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":642
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:
 *             self.keywords['async'] = 'async'             # <<<<<<<<<<<<<<
 *             self.keywords['await'] = 'await'
 * 
*/
    if (unlikely(__pyx_v_self->keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 642, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_async, __pyx_mstate_global->__pyx_n_u_async) < 0))) __PYX_ERR(0, 642, __pyx_L1_error)

    /* "Cython/Compiler/Scanning.py":643
 *         if self.async_enabled == 1:
 *             self.keywords['async'] = 'async'
 *             self.keywords['await'] = 'await'             # <<<<<<<<<<<<<<
 * 
 *     def exit_async(self):
*/
    if (unlikely(__pyx_v_self->keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 643, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_await, __pyx_mstate_global->__pyx_n_u_await) < 0))) __PYX_ERR(0, 643, __pyx_L1_error)

    /* "Cython/Compiler/Scanning.py":641
 *     def enter_async(self):
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:             # <<<<<<<<<<<<<<
 *             self.keywords['async'] = 'async'
 *             self.keywords['await'] = 'await'
*/
  }

  /* "Cython/Compiler/Scanning.py":639
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
 * 
 *     def enter_async(self):             # <<<<<<<<<<<<<<
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.enter_async", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":645
 *             self.keywords['await'] = 'await'
 * 
 *     def exit_async(self):             # <<<<<<<<<<<<<<
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async = {"exit_async", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exit_async (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_64exit_async(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_64exit_async(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exit_async", 0);

  /* "Cython/Compiler/Scanning.py":646
 * 
 *     def exit_async(self):
 *         assert self.async_enabled > 0             # <<<<<<<<<<<<<<
 *         self.async_enabled -= 1
 *         if not self.async_enabled:
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_self->async_enabled > 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 646, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 646, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/Scanning.py":647
 *     def exit_async(self):
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1             # <<<<<<<<<<<<<<
 *         if not self.async_enabled:
 *             del self.keywords['await']
*/
  __pyx_v_self->async_enabled = (__pyx_v_self->async_enabled - 1);

  /* "Cython/Compiler/Scanning.py":648
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1
 *         if not self.async_enabled:             # <<<<<<<<<<<<<<
 *             del self.keywords['await']
 *             del self.keywords['async']
*/
  __pyx_t_1 = (!__pyx_v_self->async_enabled);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Scanning.py":649
 *         self.async_enabled -= 1
 *         if not self.async_enabled:
 *             del self.keywords['await']             # <<<<<<<<<<<<<<
 *             del self.keywords['async']
 *             if self.sy in ('async', 'await'):
*/
    if (unlikely(__pyx_v_self->keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 649, __pyx_L1_error)
    }
    if (unlikely((PyDict_DelItem(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_await) < 0))) __PYX_ERR(0, 649, __pyx_L1_error)

    /* "Cython/Compiler/Scanning.py":650
 *         if not self.async_enabled:
 *             del self.keywords['await']
 *             del self.keywords['async']             # <<<<<<<<<<<<<<
 *             if self.sy in ('async', 'await'):
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
*/
    if (unlikely(__pyx_v_self->keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 650, __pyx_L1_error)
    }
    if (unlikely((PyDict_DelItem(__pyx_v_self->keywords, __pyx_mstate_global->__pyx_n_u_async) < 0))) __PYX_ERR(0, 650, __pyx_L1_error)

    /* "Cython/Compiler/Scanning.py":651
 *             del self.keywords['await']
 *             del self.keywords['async']
 *             if self.sy in ('async', 'await'):             # <<<<<<<<<<<<<<
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
*/
    __Pyx_INCREF(__pyx_v_self->sy);
    __pyx_t_2 = __pyx_v_self->sy;
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 651, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_await, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 651, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_1;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Scanning.py":652
 *             del self.keywords['async']
 *             if self.sy in ('async', 'await'):
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)             # <<<<<<<<<<<<<<
 * 
 * @contextmanager
*/
      __pyx_t_4 = __pyx_v_6Cython_8Compiler_8Scanning_IDENT;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = __pyx_v_self->context;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_self->sy};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_v_self->sy);
      __Pyx_DECREF(__pyx_v_self->sy);
      __pyx_v_self->sy = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_v_self->systring);
      __Pyx_DECREF(__pyx_v_self->systring);
      __pyx_v_self->systring = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Scanning.py":651
 *             del self.keywords['await']
 *             del self.keywords['async']
 *             if self.sy in ('async', 'await'):             # <<<<<<<<<<<<<<
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
*/
    }

    /* "Cython/Compiler/Scanning.py":648
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1
 *         if not self.async_enabled:             # <<<<<<<<<<<<<<
 *             del self.keywords['await']
 *             del self.keywords['async']
*/
  }

  /* "Cython/Compiler/Scanning.py":645
 *             self.keywords['await'] = 'await'
 * 
 *     def exit_async(self):             # <<<<<<<<<<<<<<
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.exit_async", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":22
 * @cython.final
 * cdef class PyrexScanner(Scanner):
 *     cdef public context             # <<<<<<<<<<<<<<
 *     cdef public list included_files
 *     cdef public CompileTimeScope compile_time_env
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->context);
  __pyx_r = __pyx_v_self->context;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->context);
  __Pyx_DECREF(__pyx_v_self->context);
  __pyx_v_self->context = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->context);
  __Pyx_DECREF(__pyx_v_self->context);
  __pyx_v_self->context = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":23
 * cdef class PyrexScanner(Scanner):
 *     cdef public context
 *     cdef public list included_files             # <<<<<<<<<<<<<<
 *     cdef public CompileTimeScope compile_time_env
 *     cdef public bint compile_time_eval
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->included_files);
  __pyx_r = __pyx_v_self->included_files;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 23, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->included_files);
  __Pyx_DECREF(__pyx_v_self->included_files);
  __pyx_v_self->included_files = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.included_files.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->included_files);
  __Pyx_DECREF(__pyx_v_self->included_files);
  __pyx_v_self->included_files = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":24
 *     cdef public context
 *     cdef public list included_files
 *     cdef public CompileTimeScope compile_time_env             # <<<<<<<<<<<<<<
 *     cdef public bint compile_time_eval
 *     cdef public bint compile_time_expr
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->compile_time_env);
  __pyx_r = ((PyObject *)__pyx_v_self->compile_time_env);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope))))) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->compile_time_env);
  __Pyx_DECREF((PyObject *)__pyx_v_self->compile_time_env);
  __pyx_v_self->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.compile_time_env.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->compile_time_env);
  __Pyx_DECREF((PyObject *)__pyx_v_self->compile_time_env);
  __pyx_v_self->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":25
 *     cdef public list included_files
 *     cdef public CompileTimeScope compile_time_env
 *     cdef public bint compile_time_eval             # <<<<<<<<<<<<<<
 *     cdef public bint compile_time_expr
 *     cdef public bint parse_comments
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->compile_time_eval); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.compile_time_eval.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 25, __pyx_L1_error)
  __pyx_v_self->compile_time_eval = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.compile_time_eval.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":26
 *     cdef public CompileTimeScope compile_time_env
 *     cdef public bint compile_time_eval
 *     cdef public bint compile_time_expr             # <<<<<<<<<<<<<<
 *     cdef public bint parse_comments
 *     cdef public bint in_python_file
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->compile_time_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.compile_time_expr.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 26, __pyx_L1_error)
  __pyx_v_self->compile_time_expr = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.compile_time_expr.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":27
 *     cdef public bint compile_time_eval
 *     cdef public bint compile_time_expr
 *     cdef public bint parse_comments             # <<<<<<<<<<<<<<
 *     cdef public bint in_python_file
 *     cdef public source_encoding
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->parse_comments); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.parse_comments.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 27, __pyx_L1_error)
  __pyx_v_self->parse_comments = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.parse_comments.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":28
 *     cdef public bint compile_time_expr
 *     cdef public bint parse_comments
 *     cdef public bint in_python_file             # <<<<<<<<<<<<<<
 *     cdef public source_encoding
 *     cdef dict keywords
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->in_python_file); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.in_python_file.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 28, __pyx_L1_error)
  __pyx_v_self->in_python_file = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.in_python_file.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":29
 *     cdef public bint parse_comments
 *     cdef public bint in_python_file
 *     cdef public source_encoding             # <<<<<<<<<<<<<<
 *     cdef dict keywords
 *     cdef public list indentation_stack
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->source_encoding);
  __pyx_r = __pyx_v_self->source_encoding;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->source_encoding);
  __Pyx_DECREF(__pyx_v_self->source_encoding);
  __pyx_v_self->source_encoding = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->source_encoding);
  __Pyx_DECREF(__pyx_v_self->source_encoding);
  __pyx_v_self->source_encoding = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":31
 *     cdef public source_encoding
 *     cdef dict keywords
 *     cdef public list indentation_stack             # <<<<<<<<<<<<<<
 *     cdef public Py_UCS4 indentation_char
 *     cdef public int bracket_nesting_level
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->indentation_stack);
  __pyx_r = __pyx_v_self->indentation_stack;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 31, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->indentation_stack);
  __Pyx_DECREF(__pyx_v_self->indentation_stack);
  __pyx_v_self->indentation_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.indentation_stack.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->indentation_stack);
  __Pyx_DECREF(__pyx_v_self->indentation_stack);
  __pyx_v_self->indentation_stack = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":32
 *     cdef dict keywords
 *     cdef public list indentation_stack
 *     cdef public Py_UCS4 indentation_char             # <<<<<<<<<<<<<<
 *     cdef public int bracket_nesting_level
 *     cdef readonly bint async_enabled
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_self->indentation_char); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.indentation_char.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  Py_UCS4 __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_AsPy_UCS4(__pyx_v_value); if (unlikely((__pyx_t_1 == (Py_UCS4)-1) && PyErr_Occurred())) __PYX_ERR(1, 32, __pyx_L1_error)
  __pyx_v_self->indentation_char = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.indentation_char.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":33
 *     cdef public list indentation_stack
 *     cdef public Py_UCS4 indentation_char
 *     cdef public int bracket_nesting_level             # <<<<<<<<<<<<<<
 *     cdef readonly bint async_enabled
 *     cdef public unicode sy
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_self->bracket_nesting_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.bracket_nesting_level.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyLong_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 33, __pyx_L1_error)
  __pyx_v_self->bracket_nesting_level = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.bracket_nesting_level.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":34
 *     cdef public Py_UCS4 indentation_char
 *     cdef public int bracket_nesting_level
 *     cdef readonly bint async_enabled             # <<<<<<<<<<<<<<
 *     cdef public unicode sy
 *     cdef public systring  # EncodedString
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->async_enabled); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.async_enabled.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":35
 *     cdef public int bracket_nesting_level
 *     cdef readonly bint async_enabled
 *     cdef public unicode sy             # <<<<<<<<<<<<<<
 *     cdef public systring  # EncodedString
 *     cdef public list put_back_on_failure
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->sy);
  __pyx_r = __pyx_v_self->sy;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(1, 35, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.sy.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sy);
  __Pyx_DECREF(__pyx_v_self->sy);
  __pyx_v_self->sy = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":36
 *     cdef readonly bint async_enabled
 *     cdef public unicode sy
 *     cdef public systring  # EncodedString             # <<<<<<<<<<<<<<
 *     cdef public list put_back_on_failure
 *     # fstrings/tstrings
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->systring);
  __pyx_r = __pyx_v_self->systring;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->systring);
  __Pyx_DECREF(__pyx_v_self->systring);
  __pyx_v_self->systring = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->systring);
  __Pyx_DECREF(__pyx_v_self->systring);
  __pyx_v_self->systring = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":37
 *     cdef public unicode sy
 *     cdef public systring  # EncodedString
 *     cdef public list put_back_on_failure             # <<<<<<<<<<<<<<
 *     # fstrings/tstrings
 *     cdef list ft_string_state_stack
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->put_back_on_failure);
  __pyx_r = __pyx_v_self->put_back_on_failure;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_2__set__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_2__set__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->put_back_on_failure);
  __Pyx_DECREF(__pyx_v_self->put_back_on_failure);
  __pyx_v_self->put_back_on_failure = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.PyrexScanner.put_back_on_failure.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_4__del__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_4__del__(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->put_back_on_failure);
  __Pyx_DECREF(__pyx_v_self->put_back_on_failure);
  __pyx_v_self->put_back_on_failure = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6Cython_8Compiler_8Scanning_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "Cython/Compiler/Scanning.py":654
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_1tentatively_scan(PyObject *__pyx_self, PyObject *__pyx_v_scanner); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_1tentatively_scan = {"tentatively_scan", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_1tentatively_scan, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_1tentatively_scan(PyObject *__pyx_self, PyObject *__pyx_v_scanner) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tentatively_scan (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_scanner), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "scanner", 0))) __PYX_ERR(0, 655, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_tentatively_scan(__pyx_self, ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_scanner));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_tentatively_scan(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_scanner) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tentatively_scan", 0);
  __pyx_cur_scope = (struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)__pyx_tp_new_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 654, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_scanner = __pyx_v_scanner;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_scanner);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_scanner);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6Cython_8Compiler_8Scanning_2generator, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_tentatively_scan, __pyx_mstate_global->__pyx_n_u_tentatively_scan, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning); if (unlikely(!gen)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.tentatively_scan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6Cython_8Compiler_8Scanning_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *__pyx_cur_scope = ((struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  char const *__pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tentatively_scan", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L16_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 654, __pyx_L1_error)
  }

  /* "Cython/Compiler/Scanning.py":656
 * @contextmanager
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()             # <<<<<<<<<<<<<<
 *     try:
 *         put_back_on_failure = scanner.put_back_on_failure
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_hold_errors); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_errors = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":657
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()
 *     try:             # <<<<<<<<<<<<<<
 *         put_back_on_failure = scanner.put_back_on_failure
 *         scanner.put_back_on_failure = []
*/
  /*try:*/ {

    /* "Cython/Compiler/Scanning.py":658
 *     errors = hold_errors()
 *     try:
 *         put_back_on_failure = scanner.put_back_on_failure             # <<<<<<<<<<<<<<
 *         scanner.put_back_on_failure = []
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
*/
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_put_back_on_failure = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":659
 *     try:
 *         put_back_on_failure = scanner.put_back_on_failure
 *         scanner.put_back_on_failure = []             # <<<<<<<<<<<<<<
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
 *         try:
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
    __Pyx_DECREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
    __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Scanning.py":660
 *         put_back_on_failure = scanner.put_back_on_failure
 *         scanner.put_back_on_failure = []
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())             # <<<<<<<<<<<<<<
 *         try:
 *             yield errors
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_cur_scope->__pyx_v_scanner->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_cur_scope->__pyx_v_scanner), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_scanner->sy);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_scanner->sy);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_scanner->sy) != (0)) __PYX_ERR(0, 660, __pyx_L5_error);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_scanner->systring);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_scanner->systring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_scanner->systring) != (0)) __PYX_ERR(0, 660, __pyx_L5_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 660, __pyx_L5_error);
    __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_initial_state = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Scanning.py":661
 *         scanner.put_back_on_failure = []
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
 *         try:             # <<<<<<<<<<<<<<
 *             yield errors
 *         except CompileError:
*/
    /*try:*/ {
      {
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        /*try:*/ {

          /* "Cython/Compiler/Scanning.py":662
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
 *         try:
 *             yield errors             # <<<<<<<<<<<<<<
 *         except CompileError:
 *             pass
*/
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_errors);
          __pyx_r = __pyx_cur_scope->__pyx_v_errors;
          __Pyx_XGIVEREF(__pyx_t_5);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
          __Pyx_XGIVEREF(__pyx_t_6);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_6;
          __Pyx_XGIVEREF(__pyx_t_7);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_7;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, yielding value */
          __pyx_generator->resume_label = 1;
          return __pyx_r;
          __pyx_L16_resume_from_yield:;
          __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_5);
          __pyx_t_6 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_7);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 662, __pyx_L10_error)

          /* "Cython/Compiler/Scanning.py":661
 *         scanner.put_back_on_failure = []
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
 *         try:             # <<<<<<<<<<<<<<
 *             yield errors
 *         except CompileError:
*/
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L15_try_end;
        __pyx_L10_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Scanning.py":663
 *         try:
 *             yield errors
 *         except CompileError:             # <<<<<<<<<<<<<<
 *             pass
 *         finally:
*/
        __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CompileError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 663, __pyx_L12_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_ErrRestore(__pyx_t_3, __pyx_t_1, __pyx_t_2);
        __pyx_t_3 = 0; __pyx_t_1 = 0; __pyx_t_2 = 0;
        if (__pyx_t_9) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L11_exception_handled;
        }
        goto __pyx_L12_except_error;

        /* "Cython/Compiler/Scanning.py":661
 *         scanner.put_back_on_failure = []
 *         initial_state = (scanner.sy, scanner.systring, scanner.position())
 *         try:             # <<<<<<<<<<<<<<
 *             yield errors
 *         except CompileError:
*/
        __pyx_L12_except_error:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L8_error;
        __pyx_L11_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        __pyx_L15_try_end:;
      }
    }

    /* "Cython/Compiler/Scanning.py":666
 *             pass
 *         finally:
 *             if errors:             # <<<<<<<<<<<<<<
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
*/
    /*finally:*/ {
      /*normal exit:*/{
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_errors); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 666, __pyx_L5_error)
        if (__pyx_t_10) {

          /* "Cython/Compiler/Scanning.py":667
 *         finally:
 *             if errors:
 *                 if scanner.put_back_on_failure:             # <<<<<<<<<<<<<<
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)
*/
          if (__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure == Py_None) __pyx_t_10 = 0;
          else
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
            if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 667, __pyx_L5_error)
            __pyx_t_10 = (__pyx_temp != 0);
          }

          if (__pyx_t_10) {

            /* "Cython/Compiler/Scanning.py":668
 *             if errors:
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):             # <<<<<<<<<<<<<<
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
*/
            if (unlikely(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure == Py_None)) {
              PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
              __PYX_ERR(0, 668, __pyx_L5_error)
            }
            __pyx_t_2 = __Pyx_PyList_GetSlice(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure, 0, -1L); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
            __pyx_t_11 = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 668, __pyx_L5_error)
            #endif
            --__pyx_t_11;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            for (;;) {
              if (__pyx_t_11 < 0) break;
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 668, __pyx_L5_error)
                #endif
                if (__pyx_t_11 >= __pyx_temp) break;
              }
              __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_11, __Pyx_ReferenceSharing_OwnStrongReference);
              --__pyx_t_11;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L5_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_put_back);
              __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_put_back, __pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_2);
              __pyx_t_2 = 0;

              /* "Cython/Compiler/Scanning.py":669
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)             # <<<<<<<<<<<<<<
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
*/
              __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_scanner), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L5_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_cur_scope->__pyx_v_put_back); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 669, __pyx_L5_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 669, __pyx_L5_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

              /* "Cython/Compiler/Scanning.py":668
 *             if errors:
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):             # <<<<<<<<<<<<<<
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
*/
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "Cython/Compiler/Scanning.py":671
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)             # <<<<<<<<<<<<<<
 *             elif put_back_on_failure is not None:
 *                 # the outer "tentatively_scan" block that we're in might still
*/
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_scanner), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_cur_scope->__pyx_v_initial_state, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 671, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

            /* "Cython/Compiler/Scanning.py":667
 *         finally:
 *             if errors:
 *                 if scanner.put_back_on_failure:             # <<<<<<<<<<<<<<
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)
*/
          }

          /* "Cython/Compiler/Scanning.py":666
 *             pass
 *         finally:
 *             if errors:             # <<<<<<<<<<<<<<
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
*/
          goto __pyx_L19;
        }

        /* "Cython/Compiler/Scanning.py":672
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
 *             elif put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
*/
        __pyx_t_10 = (__pyx_cur_scope->__pyx_v_put_back_on_failure != ((PyObject*)Py_None));
        if (__pyx_t_10) {

          /* "Cython/Compiler/Scanning.py":675
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
 *                 put_back_on_failure.extend(scanner.put_back_on_failure)             # <<<<<<<<<<<<<<
 *             scanner.put_back_on_failure = put_back_on_failure
 *     finally:
*/
          if (unlikely(__pyx_cur_scope->__pyx_v_put_back_on_failure == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
            __PYX_ERR(0, 675, __pyx_L5_error)
          }
          __pyx_t_8 = __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_12 = __Pyx_PyList_Extend(__pyx_cur_scope->__pyx_v_put_back_on_failure, __pyx_t_8); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 675, __pyx_L5_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "Cython/Compiler/Scanning.py":672
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
 *             elif put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
*/
        }
        __pyx_L19:;

        /* "Cython/Compiler/Scanning.py":676
 *                 # want to undo this block
 *                 put_back_on_failure.extend(scanner.put_back_on_failure)
 *             scanner.put_back_on_failure = put_back_on_failure             # <<<<<<<<<<<<<<
 *     finally:
 *         release_errors(ignore=True)
*/
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_put_back_on_failure);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_put_back_on_failure);
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
        __Pyx_DECREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
        __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure = __pyx_cur_scope->__pyx_v_put_back_on_failure;
        goto __pyx_L9;
      }
      __pyx_L8_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_assign
        __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        if ( unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __pyx_t_9 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
        {

          /* "Cython/Compiler/Scanning.py":666
 *             pass
 *         finally:
 *             if errors:             # <<<<<<<<<<<<<<
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
*/
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_errors); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 666, __pyx_L25_error)
          if (__pyx_t_10) {

            /* "Cython/Compiler/Scanning.py":667
 *         finally:
 *             if errors:
 *                 if scanner.put_back_on_failure:             # <<<<<<<<<<<<<<
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)
*/
            if (__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure == Py_None) __pyx_t_10 = 0;
            else
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
              if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 667, __pyx_L25_error)
              __pyx_t_10 = (__pyx_temp != 0);
            }

            if (__pyx_t_10) {

              /* "Cython/Compiler/Scanning.py":668
 *             if errors:
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):             # <<<<<<<<<<<<<<
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
*/
              if (unlikely(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure == Py_None)) {
                PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
                __PYX_ERR(0, 668, __pyx_L25_error)
              }
              __pyx_t_8 = __Pyx_PyList_GetSlice(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure, 0, -1L); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 668, __pyx_L25_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_1 = __pyx_t_8; __Pyx_INCREF(__pyx_t_1);
              __pyx_t_11 = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 668, __pyx_L25_error)
              #endif
              --__pyx_t_11;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              for (;;) {
                if (__pyx_t_11 < 0) break;
                {
                  Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
                  #if !CYTHON_ASSUME_SAFE_SIZE
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 668, __pyx_L25_error)
                  #endif
                  if (__pyx_t_11 >= __pyx_temp) break;
                }
                __pyx_t_8 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_11, __Pyx_ReferenceSharing_OwnStrongReference);
                --__pyx_t_11;
                if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 668, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_8);
                __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_put_back);
                __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_put_back, __pyx_t_8);
                __Pyx_GIVEREF(__pyx_t_8);
                __pyx_t_8 = 0;

                /* "Cython/Compiler/Scanning.py":669
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)             # <<<<<<<<<<<<<<
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
*/
                __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_scanner), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 669, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_8);
                __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_cur_scope->__pyx_v_put_back); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 669, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "Cython/Compiler/Scanning.py":668
 *             if errors:
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):             # <<<<<<<<<<<<<<
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
*/
              }
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "Cython/Compiler/Scanning.py":671
 *                         scanner.put_back(*put_back)
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)             # <<<<<<<<<<<<<<
 *             elif put_back_on_failure is not None:
 *                 # the outer "tentatively_scan" block that we're in might still
*/
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_scanner), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L25_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_cur_scope->__pyx_v_initial_state, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L25_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "Cython/Compiler/Scanning.py":667
 *         finally:
 *             if errors:
 *                 if scanner.put_back_on_failure:             # <<<<<<<<<<<<<<
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
 *                         scanner.put_back(*put_back)
*/
            }

            /* "Cython/Compiler/Scanning.py":666
 *             pass
 *         finally:
 *             if errors:             # <<<<<<<<<<<<<<
 *                 if scanner.put_back_on_failure:
 *                     for put_back in reversed(scanner.put_back_on_failure[:-1]):
*/
            goto __pyx_L26;
          }

          /* "Cython/Compiler/Scanning.py":672
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
 *             elif put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
*/
          __pyx_t_10 = (__pyx_cur_scope->__pyx_v_put_back_on_failure != ((PyObject*)Py_None));
          if (__pyx_t_10) {

            /* "Cython/Compiler/Scanning.py":675
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
 *                 put_back_on_failure.extend(scanner.put_back_on_failure)             # <<<<<<<<<<<<<<
 *             scanner.put_back_on_failure = put_back_on_failure
 *     finally:
*/
            if (unlikely(__pyx_cur_scope->__pyx_v_put_back_on_failure == Py_None)) {
              PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
              __PYX_ERR(0, 675, __pyx_L25_error)
            }
            __pyx_t_2 = __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure;
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_12 = __Pyx_PyList_Extend(__pyx_cur_scope->__pyx_v_put_back_on_failure, __pyx_t_2); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 675, __pyx_L25_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "Cython/Compiler/Scanning.py":672
 *                     # we need to restore the initial state too
 *                     scanner.put_back(*initial_state)
 *             elif put_back_on_failure is not None:             # <<<<<<<<<<<<<<
 *                 # the outer "tentatively_scan" block that we're in might still
 *                 # want to undo this block
*/
          }
          __pyx_L26:;

          /* "Cython/Compiler/Scanning.py":676
 *                 # want to undo this block
 *                 put_back_on_failure.extend(scanner.put_back_on_failure)
 *             scanner.put_back_on_failure = put_back_on_failure             # <<<<<<<<<<<<<<
 *     finally:
 *         release_errors(ignore=True)
*/
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_put_back_on_failure);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_put_back_on_failure);
          __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
          __Pyx_DECREF(__pyx_cur_scope->__pyx_v_scanner->put_back_on_failure);
          __pyx_cur_scope->__pyx_v_scanner->put_back_on_failure = __pyx_cur_scope->__pyx_v_put_back_on_failure;
        }
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ErrRestore(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
        goto __pyx_L5_error;
        __pyx_L25_error:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        goto __pyx_L5_error;
      }
      __pyx_L9:;
    }
  }

  /* "Cython/Compiler/Scanning.py":678
 *             scanner.put_back_on_failure = put_back_on_failure
 *     finally:
 *         release_errors(ignore=True)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_1 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_release_errors); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 678, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, NULL};
        __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 678, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore, Py_True, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 678, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_assign
      __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      if ( unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __pyx_t_13 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
      {
        __pyx_t_3 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_release_errors); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 678, __pyx_L32_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};
          __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 678, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore, Py_True, __pyx_t_1, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 678, __pyx_L32_error)
          __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ErrRestore(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0;
      __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_18;
      goto __pyx_L1_error;
      __pyx_L32_error:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "Cython/Compiler/Scanning.py":654
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("tentatively_scan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":682
 * 
 * class FTStringState:
 *     def __init__(self, scanner_state):             # <<<<<<<<<<<<<<
 *         self.scanner_state = scanner_state
 *         self.bracket_states = []
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_scanner_state = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_scanner_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 682, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 682, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 682, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 682, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 682, __pyx_L3_error)
    }
    __pyx_v_scanner_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 682, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState___init__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self), __pyx_v_scanner_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState___init__(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self, PyObject *__pyx_v_scanner_state) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Scanning.py":683
 * class FTStringState:
 *     def __init__(self, scanner_state):
 *         self.scanner_state = scanner_state             # <<<<<<<<<<<<<<
 *         self.bracket_states = []
 * 
*/
  __pyx_t_1 = __pyx_v_scanner_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->scanner_state);
  __Pyx_DECREF(__pyx_v_self->scanner_state);
  __pyx_v_self->scanner_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":684
 *     def __init__(self, scanner_state):
 *         self.scanner_state = scanner_state
 *         self.bracket_states = []             # <<<<<<<<<<<<<<
 * 
 *     def bracket_nesting_level(self):
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->bracket_states);
  __Pyx_DECREF(__pyx_v_self->bracket_states);
  __pyx_v_self->bracket_states = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":682
 * 
 * class FTStringState:
 *     def __init__(self, scanner_state):             # <<<<<<<<<<<<<<
 *         self.scanner_state = scanner_state
 *         self.bracket_states = []
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":686
 *         self.bracket_states = []
 * 
 *     def bracket_nesting_level(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return None
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level = {"bracket_nesting_level", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bracket_nesting_level (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_2bracket_nesting_level(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_2bracket_nesting_level(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bracket_nesting_level", 0);

  /* "Cython/Compiler/Scanning.py":687
 * 
 *     def bracket_nesting_level(self):
 *         if not self.bracket_states:             # <<<<<<<<<<<<<<
 *             return None
 *         return self.bracket_states[-1].bracket_nesting_level
*/
  if (__pyx_v_self->bracket_states == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->bracket_states);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 687, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":688
 *     def bracket_nesting_level(self):
 *         if not self.bracket_states:
 *             return None             # <<<<<<<<<<<<<<
 *         return self.bracket_states[-1].bracket_nesting_level
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":687
 * 
 *     def bracket_nesting_level(self):
 *         if not self.bracket_states:             # <<<<<<<<<<<<<<
 *             return None
 *         return self.bracket_states[-1].bracket_nesting_level
*/
  }

  /* "Cython/Compiler/Scanning.py":689
 *         if not self.bracket_states:
 *             return None
 *         return self.bracket_states[-1].bracket_nesting_level             # <<<<<<<<<<<<<<
 * 
 *     def in_format_specifier(self):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->bracket_states == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 689, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->bracket_states, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":686
 *         self.bracket_states = []
 * 
 *     def bracket_nesting_level(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.bracket_nesting_level", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":691
 *         return self.bracket_states[-1].bracket_nesting_level
 * 
 *     def in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier = {"in_format_specifier", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("in_format_specifier (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_4in_format_specifier(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_4in_format_specifier(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("in_format_specifier", 0);

  /* "Cython/Compiler/Scanning.py":692
 * 
 *     def in_format_specifier(self):
 *         if not self.bracket_states:             # <<<<<<<<<<<<<<
 *             return False
 *         return self.bracket_states[-1].in_format_specifier
*/
  if (__pyx_v_self->bracket_states == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->bracket_states);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Scanning.py":693
 *     def in_format_specifier(self):
 *         if not self.bracket_states:
 *             return False             # <<<<<<<<<<<<<<
 *         return self.bracket_states[-1].in_format_specifier
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "Cython/Compiler/Scanning.py":692
 * 
 *     def in_format_specifier(self):
 *         if not self.bracket_states:             # <<<<<<<<<<<<<<
 *             return False
 *         return self.bracket_states[-1].in_format_specifier
*/
  }

  /* "Cython/Compiler/Scanning.py":694
 *         if not self.bracket_states:
 *             return False
 *         return self.bracket_states[-1].in_format_specifier             # <<<<<<<<<<<<<<
 * 
 *     def set_in_format_specifier(self):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->bracket_states == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 694, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->bracket_states, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_in_format_specifier); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Scanning.py":691
 *         return self.bracket_states[-1].bracket_nesting_level
 * 
 *     def in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return False
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.in_format_specifier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":696
 *         return self.bracket_states[-1].in_format_specifier
 * 
 *     def set_in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states[-1].in_format_specifier = True
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier = {"set_in_format_specifier", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_in_format_specifier (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_6set_in_format_specifier(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_6set_in_format_specifier(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_in_format_specifier", 0);

  /* "Cython/Compiler/Scanning.py":697
 * 
 *     def set_in_format_specifier(self):
 *         self.bracket_states[-1].in_format_specifier = True             # <<<<<<<<<<<<<<
 * 
 *     def push_bracket_state(self, bracket_nesting_level: int):
*/
  if (unlikely(__pyx_v_self->bracket_states == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 697, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->bracket_states, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_in_format_specifier, Py_True) < (0)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":696
 *         return self.bracket_states[-1].in_format_specifier
 * 
 *     def set_in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states[-1].in_format_specifier = True
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.set_in_format_specifier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":699
 *         self.bracket_states[-1].in_format_specifier = True
 * 
 *     def push_bracket_state(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state(PyObject *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state = {"push_bracket_state", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state(PyObject *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("push_bracket_state (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bracket_nesting_level), (&PyLong_Type), 0, "bracket_nesting_level", 2))) __PYX_ERR(0, 699, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_8push_bracket_state(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self), ((PyObject*)__pyx_v_bracket_nesting_level));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_8push_bracket_state(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push_bracket_state", 0);

  /* "Cython/Compiler/Scanning.py":700
 * 
 *     def push_bracket_state(self, bracket_nesting_level: int):
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))             # <<<<<<<<<<<<<<
 * 
 *     def pop_bracket_state(self):
*/
  if (unlikely(__pyx_v_self->bracket_states == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 700, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_FTStringBracketState); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_bracket_nesting_level};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->bracket_states, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":699
 *         self.bracket_states[-1].in_format_specifier = True
 * 
 *     def push_bracket_state(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.push_bracket_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":702
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
 *     def pop_bracket_state(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states.pop()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state = {"pop_bracket_state", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pop_bracket_state (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_10pop_bracket_state(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_10pop_bracket_state(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pop_bracket_state", 0);

  /* "Cython/Compiler/Scanning.py":703
 * 
 *     def pop_bracket_state(self):
 *         self.bracket_states.pop()             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (unlikely(__pyx_v_self->bracket_states == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 703, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->bracket_states); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Scanning.py":702
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
 *     def pop_bracket_state(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states.pop()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringState.pop_bracket_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.pxd":48
 * cdef class FTStringState:
 *     cdef list bracket_states
 *     cdef readonly str scanner_state             # <<<<<<<<<<<<<<
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state___get__(((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state___get__(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->scanner_state);
  __pyx_r = __pyx_v_self->scanner_state;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Scanning.py":712
 *     bracket_nesting_level: int
 *     in_format_specifier: bool
 *     def __init__(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level = bracket_nesting_level
 *         self.in_format_specifier = False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FTStringBracketState_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_8Scanning_20FTStringBracketState_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_20FTStringBracketState_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_8Scanning_20FTStringBracketState_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_bracket_nesting_level = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_bracket_nesting_level,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 712, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 712, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 712, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 712, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 712, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 712, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 712, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    if (__Pyx_PyInt_FromNumber(&values[1], "bracket_nesting_level", 0) < (0)) __PYX_ERR(0, 712, __pyx_L3_error)
    __pyx_v_bracket_nesting_level = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 712, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringBracketState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bracket_nesting_level), (&PyLong_Type), 0, "bracket_nesting_level", 2))) __PYX_ERR(0, 712, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_8Scanning_20FTStringBracketState___init__(__pyx_self, __pyx_v_self, __pyx_v_bracket_nesting_level);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_8Scanning_20FTStringBracketState___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_bracket_nesting_level) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Scanning.py":713
 *     in_format_specifier: bool
 *     def __init__(self, bracket_nesting_level: int):
 *         self.bracket_nesting_level = bracket_nesting_level             # <<<<<<<<<<<<<<
 *         self.in_format_specifier = False
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_v_bracket_nesting_level) < (0)) __PYX_ERR(0, 713, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":714
 *     def __init__(self, bracket_nesting_level: int):
 *         self.bracket_nesting_level = bracket_nesting_level
 *         self.in_format_specifier = False             # <<<<<<<<<<<<<<
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_in_format_specifier, Py_False) < (0)) __PYX_ERR(0, 714, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":712
 *     bracket_nesting_level: int
 *     in_format_specifier: bool
 *     def __init__(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level = bracket_nesting_level
 *         self.in_format_specifier = False
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Scanning.FTStringBracketState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_CompileTimeScope(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)o);
  p->entries = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_CompileTimeScope(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->entries);
  Py_CLEAR(p->outer);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_8Scanning_CompileTimeScope(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->entries) {
    e = (*v)(p->entries, a); if (e) return e;
  }
  if (p->outer) {
    e = (*v)(((PyObject *)p->outer), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_8Scanning_CompileTimeScope(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)o;
  tmp = ((PyObject*)p->entries);
  p->entries = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->outer);
  p->outer = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_entries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_entries(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7entries_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_outer(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_outer(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5outer_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_8Scanning_CompileTimeScope[] = {
  {"declare", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"update", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update, METH_O, 0},
  {"lookup_here", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here, METH_O, 0},
  {"lookup", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_8Scanning_CompileTimeScope[] = {
  {"entries", __pyx_getprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_entries, __pyx_setprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_entries, 0, 0},
  {"outer", __pyx_getprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_outer, __pyx_setprop_6Cython_8Compiler_8Scanning_16CompileTimeScope_outer, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {Py_sq_contains, (void *)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_9__contains__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_8Scanning_CompileTimeScope},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope_spec = {
  "Cython.Compiler.Scanning.CompileTimeScope",
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_CompileTimeScope = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_9__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyTypeObject __pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Scanning.""CompileTimeScope", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_CompileTimeScope, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_8Scanning_16CompileTimeScope_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_8Scanning_CompileTimeScope, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner __pyx_vtable_6Cython_8Compiler_8Scanning_PyrexScanner;

static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_PyrexScanner(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner*)__pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner;
  p->context = Py_None; Py_INCREF(Py_None);
  p->included_files = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None); Py_INCREF(Py_None);
  p->source_encoding = Py_None; Py_INCREF(Py_None);
  p->keywords = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->indentation_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->sy = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->systring = Py_None; Py_INCREF(Py_None);
  p->put_back_on_failure = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->ft_string_state_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_PyrexScanner(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_PyrexScanner) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->context);
  Py_CLEAR(p->included_files);
  Py_CLEAR(p->compile_time_env);
  Py_CLEAR(p->source_encoding);
  Py_CLEAR(p->keywords);
  Py_CLEAR(p->indentation_stack);
  Py_CLEAR(p->sy);
  Py_CLEAR(p->systring);
  Py_CLEAR(p->put_back_on_failure);
  Py_CLEAR(p->ft_string_state_stack);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_PyrexScanner);
}

static int __pyx_tp_traverse_6Cython_8Compiler_8Scanning_PyrexScanner(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6Cython_8Compiler_8Scanning_PyrexScanner); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->context) {
    e = (*v)(p->context, a); if (e) return e;
  }
  if (p->included_files) {
    e = (*v)(p->included_files, a); if (e) return e;
  }
  if (p->compile_time_env) {
    e = (*v)(((PyObject *)p->compile_time_env), a); if (e) return e;
  }
  if (p->source_encoding) {
    e = (*v)(p->source_encoding, a); if (e) return e;
  }
  if (p->keywords) {
    e = (*v)(p->keywords, a); if (e) return e;
  }
  if (p->indentation_stack) {
    e = (*v)(p->indentation_stack, a); if (e) return e;
  }
  if (p->systring) {
    e = (*v)(p->systring, a); if (e) return e;
  }
  if (p->put_back_on_failure) {
    e = (*v)(p->put_back_on_failure, a); if (e) return e;
  }
  if (p->ft_string_state_stack) {
    e = (*v)(p->ft_string_state_stack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_8Scanning_PyrexScanner(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6Cython_8Compiler_8Scanning_PyrexScanner); }
  tmp = ((PyObject*)p->context);
  p->context = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->included_files);
  p->included_files = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->compile_time_env);
  p->compile_time_env = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->source_encoding);
  p->source_encoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->keywords);
  p->keywords = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->indentation_stack);
  p->indentation_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->systring);
  p->systring = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->put_back_on_failure);
  p->put_back_on_failure = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ft_string_state_stack);
  p->ft_string_state_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_context(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_context(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7context_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_included_files(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_included_files(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14included_files_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_env(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_env(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16compile_time_env_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_eval(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_eval(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_eval_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_expr(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_expr(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17compile_time_expr_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_parse_comments(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_parse_comments(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14parse_comments_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_in_python_file(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_in_python_file(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_14in_python_file_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_source_encoding(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_source_encoding(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15source_encoding_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_stack(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_stack(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17indentation_stack_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_char(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_char(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_16indentation_char_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_bracket_nesting_level(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_bracket_nesting_level(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21bracket_nesting_level_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_async_enabled(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13async_enabled_1__get__(o);
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_sy(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_sy(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_2sy_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_systring(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_systring(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_8systring_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_put_back_on_failure(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_put_back_on_failure(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19put_back_on_failure_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_8Scanning_PyrexScanner[] = {
  {"normalize_ident", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident, METH_O, 0},
  {"commentline", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline, METH_O, 0},
  {"strip_underscores", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"open_bracket_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action, METH_O, 0},
  {"close_bracket_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action, METH_O, 0},
  {"open_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action, METH_O, 0},
  {"close_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action, METH_O, 0},
  {"colon_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action, METH_O, 0},
  {"newline_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action, METH_O, 0},
  {"begin_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action, METH_O, 0},
  {"end_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action, METH_O, 0},
  {"begin_ft_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action, METH_O, 0},
  {"end_ft_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action, METH_O, 0},
  {"_handle_open_single_ft_string_brace", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace, METH_O, 0},
  {"open_ft_string_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action, METH_O, 0},
  {"_handle_close_single_ft_string_brace", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace, METH_NOARGS, 0},
  {"close_ft_string_brace_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action, METH_O, 0},
  {"unclosed_string_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action, METH_O, 0},
  {"indentation_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action, METH_O, 0},
  {"eof_action", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action, METH_O, 0},
  {"next", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_43next, METH_NOARGS, 0},
  {"peek", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek, METH_NOARGS, 0},
  {"put_back", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"error", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_49error, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"expect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"expect_keyword", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"expected", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"expect_indent", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent, METH_NOARGS, 0},
  {"expect_dedent", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent, METH_NOARGS, 0},
  {"expect_newline", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"enter_async", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async, METH_NOARGS, 0},
  {"exit_async", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_8Scanning_PyrexScanner[] = {
  {"context", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_context, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_context, 0, 0},
  {"included_files", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_included_files, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_included_files, 0, 0},
  {"compile_time_env", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_env, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_env, 0, 0},
  {"compile_time_eval", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_eval, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_eval, 0, 0},
  {"compile_time_expr", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_expr, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_compile_time_expr, 0, 0},
  {"parse_comments", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_parse_comments, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_parse_comments, 0, 0},
  {"in_python_file", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_in_python_file, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_in_python_file, 0, 0},
  {"source_encoding", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_source_encoding, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_source_encoding, 0, 0},
  {"indentation_stack", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_stack, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_stack, 0, 0},
  {"indentation_char", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_char, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_indentation_char, 0, 0},
  {"bracket_nesting_level", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_bracket_nesting_level, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_bracket_nesting_level, 0, 0},
  {"async_enabled", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_async_enabled, 0, 0, 0},
  {"sy", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_sy, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_sy, 0, 0},
  {"systring", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_systring, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_systring, 0, 0},
  {"put_back_on_failure", __pyx_getprop_6Cython_8Compiler_8Scanning_12PyrexScanner_put_back_on_failure, __pyx_setprop_6Cython_8Compiler_8Scanning_12PyrexScanner_put_back_on_failure, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_8Scanning_PyrexScanner},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_8Scanning_PyrexScanner},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_8Scanning_PyrexScanner},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_8Scanning_PyrexScanner},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_8Scanning_PyrexScanner},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_8Scanning_PyrexScanner},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner_spec = {
  "Cython.Compiler.Scanning.PyrexScanner",
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Scanning.""PyrexScanner", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_8Scanning_12PyrexScanner_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_8Scanning_PyrexScanner, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning_FTStringState(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)o);
  p->bracket_states = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->scanner_state = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_FTStringState(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_FTStringState) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->bracket_states);
  Py_CLEAR(p->scanner_state);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_8Scanning_FTStringState(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->bracket_states) {
    e = (*v)(p->bracket_states, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_8Scanning_FTStringState(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState *)o;
  tmp = ((PyObject*)p->bracket_states);
  p->bracket_states = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_8Scanning_13FTStringState_scanner_state(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_13scanner_state_1__get__(o);
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_8Scanning_FTStringState[] = {
  {"bracket_nesting_level", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level, METH_NOARGS, 0},
  {"in_format_specifier", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier, METH_NOARGS, 0},
  {"set_in_format_specifier", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier, METH_NOARGS, 0},
  {"push_bracket_state", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state, METH_O, 0},
  {"pop_bracket_state", (PyCFunction)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_8Scanning_FTStringState[] = {
  {"scanner_state", __pyx_getprop_6Cython_8Compiler_8Scanning_13FTStringState_scanner_state, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_8Scanning_FTStringState_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_8Scanning_FTStringState},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_8Scanning_FTStringState},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_8Scanning_FTStringState},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_8Scanning_FTStringState},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_8Scanning_FTStringState},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_8Scanning_FTStringState},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_8Scanning_FTStringState_spec = {
  "Cython.Compiler.Scanning.FTStringState",
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_8Scanning_FTStringState_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_8Scanning_FTStringState = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Scanning.""FTStringState", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_8Scanning_FTStringState, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_8Scanning_FTStringState, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_8Scanning_FTStringState, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_8Scanning_FTStringState, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_8Scanning_FTStringState, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_8Scanning_13FTStringState_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_8Scanning_FTStringState, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan[--__pyx_mstate_global->__pyx_freecount_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_errors);
  Py_CLEAR(p->__pyx_v_initial_state);
  Py_CLEAR(p->__pyx_v_put_back);
  Py_CLEAR(p->__pyx_v_put_back_on_failure);
  Py_CLEAR(p->__pyx_v_scanner);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan))))
  {
    __pyx_mstate_global->__pyx_freelist_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan[__pyx_mstate_global->__pyx_freecount_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan++] = ((struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *p = (struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_errors) {
    e = (*v)(p->__pyx_v_errors, a); if (e) return e;
  }
  if (p->__pyx_v_initial_state) {
    e = (*v)(p->__pyx_v_initial_state, a); if (e) return e;
  }
  if (p->__pyx_v_put_back) {
    e = (*v)(p->__pyx_v_put_back, a); if (e) return e;
  }
  if (p->__pyx_v_put_back_on_failure) {
    e = (*v)(p->__pyx_v_put_back_on_failure, a); if (e) return e;
  }
  if (p->__pyx_v_scanner) {
    e = (*v)(((PyObject *)p->__pyx_v_scanner), a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan_spec = {
  "Cython.Compiler.Scanning.__pyx_scope_struct__tentatively_scan",
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Scanning.""__pyx_scope_struct__tentatively_scan", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_IDENT = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_make_lexicon = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_lexicon = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_print_function = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_error = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_warning = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_os = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_platform = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_8Scanning_Path = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_IDENT_any_string_prefix);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 12;
    void *const __pyx_export_pointers[] = {(void *)&__pyx_v_6Cython_8Compiler_8Scanning_IDENT, (void *)&__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix, (void *) NULL};
    void *const *__pyx_export_pointer = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportVoidPtr(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_void_get_lexicon_initia);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 18;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6Cython_8Compiler_8Scanning_get_lexicon, (void (*)(void))&__pyx_f_6Cython_8Compiler_8Scanning_initial_compile_time_env, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope)) __PYX_ERR(0, 60, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope) < (0)) __PYX_ERR(0, 60, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope = &__pyx_type_6Cython_8Compiler_8Scanning_CompileTimeScope;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope) < (0)) __PYX_ERR(0, 60, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CompileTimeScope, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope) < (0)) __PYX_ERR(0, 60, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("Cython.Plex.Scanners"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Scanners", "Scanner",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner = (struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner = &__pyx_vtable_6Cython_8Compiler_8Scanning_PyrexScanner;
  __pyx_vtable_6Cython_8Compiler_8Scanning_PyrexScanner.__pyx_base = *__pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner;
  __pyx_vtable_6Cython_8Compiler_8Scanning_PyrexScanner.current_level = (Py_ssize_t (*)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *))__pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_current_level;
  __pyx_vtable_6Cython_8Compiler_8Scanning_PyrexScanner.error_at_scanpos = (int (*)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *))__pyx_f_6Cython_8Compiler_8Scanning_12PyrexScanner_error_at_scanpos;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner)) __PYX_ERR(0, 299, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner) < (0)) __PYX_ERR(0, 299, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner = &__pyx_type_6Cython_8Compiler_8Scanning_PyrexScanner;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner) < (0)) __PYX_ERR(0, 299, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner) < (0)) __PYX_ERR(0, 299, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner) < (0)) __PYX_ERR(0, 299, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_PyrexScanner, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner) < (0)) __PYX_ERR(0, 299, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_8Scanning_FTStringState_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState)) __PYX_ERR(0, 681, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_8Scanning_FTStringState_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState) < (0)) __PYX_ERR(0, 681, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState = &__pyx_type_6Cython_8Compiler_8Scanning_FTStringState;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState) < (0)) __PYX_ERR(0, 681, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FTStringState, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState) < (0)) __PYX_ERR(0, 681, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan)) __PYX_ERR(0, 654, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan = &__pyx_type_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning___pyx_scope_struct__tentatively_scan->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Cython.Plex.Actions"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Action",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Action = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Action)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Return",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Return = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Return)) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Call",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call) __PYX_ERR(2, 8, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Call = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Call)) __PYX_ERR(2, 8, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Method",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method) __PYX_ERR(2, 12, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Method = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Method)) __PYX_ERR(2, 12, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Begin",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin) __PYX_ERR(2, 16, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Begin = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Begin)) __PYX_ERR(2, 16, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Ignore",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore) __PYX_ERR(2, 20, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Ignore = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Ignore)) __PYX_ERR(2, 20, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Text",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text) __PYX_ERR(2, 23, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Text = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Text)) __PYX_ERR(2, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_Scanning(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_Scanning},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "Scanning",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_Scanning(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_Scanning(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_Scanning(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'Scanning' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "Scanning" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_Scanning", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_Cython__Compiler__Scanning) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Cython.Compiler.Scanning")) {
      if (unlikely((PyDict_SetItemString(modules, "Cython.Compiler.Scanning", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_variable_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "Cython/Compiler/Scanning.py":13
 *                os=object, platform=object, Path=object)
 * 
 * import os             # <<<<<<<<<<<<<<
 * import platform
 * from contextlib import contextmanager
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_os);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_os, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":14
 * 
 * import os
 * import platform             # <<<<<<<<<<<<<<
 * from contextlib import contextmanager
 * from pathlib import Path
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_platform, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_platform);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_platform, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":15
 * import os
 * import platform
 * from contextlib import contextmanager             # <<<<<<<<<<<<<<
 * from pathlib import Path
 * from unicodedata import normalize
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_contextmanager};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_contextlib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_contextmanager};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":16
 * import platform
 * from contextlib import contextmanager
 * from pathlib import Path             # <<<<<<<<<<<<<<
 * from unicodedata import normalize
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Path};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pathlib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Path};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_Path);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_Path, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":17
 * from contextlib import contextmanager
 * from pathlib import Path
 * from unicodedata import normalize             # <<<<<<<<<<<<<<
 * 
 * from .. import Utils
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_unicodedata, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_normalize};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":19
 * from unicodedata import normalize
 * 
 * from .. import Utils             # <<<<<<<<<<<<<<
 * from ..Plex.Errors import UnrecognizedInput
 * from ..Plex.Scanners import Scanner
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Utils};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__4, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Utils};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":20
 * 
 * from .. import Utils
 * from ..Plex.Errors import UnrecognizedInput             # <<<<<<<<<<<<<<
 * from ..Plex.Scanners import Scanner
 * from .Errors import error, warning, hold_errors, release_errors, CompileError
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_UnrecognizedInput};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Plex_Errors, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Plex_Errors, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_UnrecognizedInput};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":21
 * from .. import Utils
 * from ..Plex.Errors import UnrecognizedInput
 * from ..Plex.Scanners import Scanner             # <<<<<<<<<<<<<<
 * from .Errors import error, warning, hold_errors, release_errors, CompileError
 * from .Lexicon import any_string_prefix, ft_string_prefixes, make_lexicon, IDENT
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Scanner};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Plex_Scanners, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Plex_Scanners, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":22
 * from ..Plex.Errors import UnrecognizedInput
 * from ..Plex.Scanners import Scanner
 * from .Errors import error, warning, hold_errors, release_errors, CompileError             # <<<<<<<<<<<<<<
 * from .Lexicon import any_string_prefix, ft_string_prefixes, make_lexicon, IDENT
 * from .Future import print_function
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_hold_errors,__pyx_mstate_global->__pyx_n_u_release_errors,__pyx_mstate_global->__pyx_n_u_CompileError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Errors, __pyx_imported_names, 5, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Errors, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_hold_errors,__pyx_mstate_global->__pyx_n_u_release_errors,__pyx_mstate_global->__pyx_n_u_CompileError};
    for (__pyx_t_3=0; __pyx_t_3 < 5; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_error);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_error, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_warning);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_warning, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":23
 * from ..Plex.Scanners import Scanner
 * from .Errors import error, warning, hold_errors, release_errors, CompileError
 * from .Lexicon import any_string_prefix, ft_string_prefixes, make_lexicon, IDENT             # <<<<<<<<<<<<<<
 * from .Future import print_function
 * from .Lexicon import IDENT, any_string_prefix, make_lexicon
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_any_string_prefix,__pyx_mstate_global->__pyx_n_u_ft_string_prefixes,__pyx_mstate_global->__pyx_n_u_make_lexicon,__pyx_mstate_global->__pyx_n_u_IDENT};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Lexicon, __pyx_imported_names, 4, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Lexicon, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_any_string_prefix,__pyx_mstate_global->__pyx_n_u_ft_string_prefixes,__pyx_mstate_global->__pyx_n_u_make_lexicon,__pyx_mstate_global->__pyx_n_u_IDENT};
    for (__pyx_t_3=0; __pyx_t_3 < 4; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 2:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 0:
        __pyx_t_5 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_5);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 23, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix, ((PyObject*)__pyx_t_5));
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        break;
        case 3:
        __pyx_t_5 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_5);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 23, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_IDENT);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_IDENT, ((PyObject*)__pyx_t_5));
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 23, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":24
 * from .Errors import error, warning, hold_errors, release_errors, CompileError
 * from .Lexicon import any_string_prefix, ft_string_prefixes, make_lexicon, IDENT
 * from .Future import print_function             # <<<<<<<<<<<<<<
 * from .Lexicon import IDENT, any_string_prefix, make_lexicon
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_print_function};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Future, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Future, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_print_function};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_print_function);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_print_function, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":25
 * from .Lexicon import any_string_prefix, ft_string_prefixes, make_lexicon, IDENT
 * from .Future import print_function
 * from .Lexicon import IDENT, any_string_prefix, make_lexicon             # <<<<<<<<<<<<<<
 * 
 * debug_scanner = 0
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_IDENT,__pyx_mstate_global->__pyx_n_u_any_string_prefix,__pyx_mstate_global->__pyx_n_u_make_lexicon};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Lexicon, __pyx_imported_names, 3, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Lexicon, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_IDENT,__pyx_mstate_global->__pyx_n_u_any_string_prefix,__pyx_mstate_global->__pyx_n_u_make_lexicon};
    for (__pyx_t_3=0; __pyx_t_3 < 3; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 2:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_make_lexicon, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 0:
        __pyx_t_5 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_5);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 25, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_IDENT);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_IDENT, ((PyObject*)__pyx_t_5));
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        break;
        case 1:
        __pyx_t_5 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_5);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 25, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix, ((PyObject*)__pyx_t_5));
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":27
 * from .Lexicon import IDENT, any_string_prefix, make_lexicon
 * 
 * debug_scanner = 0             # <<<<<<<<<<<<<<
 * trace_scanner = 0
 * scanner_debug_flags = 0
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_debug_scanner, __pyx_mstate_global->__pyx_int_0) < (0)) __PYX_ERR(0, 27, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":28
 * 
 * debug_scanner = 0
 * trace_scanner = 0             # <<<<<<<<<<<<<<
 * scanner_debug_flags = 0
 * scanner_dump_file = None
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_trace_scanner, __pyx_mstate_global->__pyx_int_0) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":29
 * debug_scanner = 0
 * trace_scanner = 0
 * scanner_debug_flags = 0             # <<<<<<<<<<<<<<
 * scanner_dump_file = None
 * 
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_scanner_debug_flags, __pyx_mstate_global->__pyx_int_0) < (0)) __PYX_ERR(0, 29, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":30
 * trace_scanner = 0
 * scanner_debug_flags = 0
 * scanner_dump_file = None             # <<<<<<<<<<<<<<
 * 
 * lexicon = None
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_scanner_dump_file, Py_None) < (0)) __PYX_ERR(0, 30, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":32
 * scanner_dump_file = None
 * 
 * lexicon = None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_8Scanning_lexicon);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_8Scanning_lexicon, Py_None);
  __Pyx_GIVEREF(Py_None);

  /* "Cython/Compiler/Scanning.py":44
 * #------------------------------------------------------------------
 * 
 * py_reserved_words = [             # <<<<<<<<<<<<<<
 *     "global", "nonlocal", "def", "class", "print", "del", "pass", "break",
 *     "continue", "return", "raise", "import", "exec", "try",
*/
  __pyx_t_2 = __Pyx_PyList_Pack(31, __pyx_mstate_global->__pyx_n_u_global, __pyx_mstate_global->__pyx_n_u_nonlocal, __pyx_mstate_global->__pyx_n_u_def, __pyx_mstate_global->__pyx_n_u_class, __pyx_mstate_global->__pyx_n_u_print, __pyx_mstate_global->__pyx_n_u_del, __pyx_mstate_global->__pyx_n_u_pass, __pyx_mstate_global->__pyx_n_u_break, __pyx_mstate_global->__pyx_n_u_continue, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_raise, __pyx_mstate_global->__pyx_n_u_import, __pyx_mstate_global->__pyx_n_u_exec, __pyx_mstate_global->__pyx_n_u_try, __pyx_mstate_global->__pyx_n_u_except, __pyx_mstate_global->__pyx_n_u_finally, __pyx_mstate_global->__pyx_n_u_while, __pyx_mstate_global->__pyx_n_u_if, __pyx_mstate_global->__pyx_n_u_elif, __pyx_mstate_global->__pyx_n_u_else, __pyx_mstate_global->__pyx_n_u_for, __pyx_mstate_global->__pyx_n_u_in, __pyx_mstate_global->__pyx_n_u_assert, __pyx_mstate_global->__pyx_n_u_and, __pyx_mstate_global->__pyx_n_u_or, __pyx_mstate_global->__pyx_n_u_not, __pyx_mstate_global->__pyx_n_u_is, __pyx_mstate_global->__pyx_n_u_lambda, __pyx_mstate_global->__pyx_n_u_from, __pyx_mstate_global->__pyx_n_u_yield, __pyx_mstate_global->__pyx_n_u_with); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_py_reserved_words, __pyx_t_2) < (0)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":52
 * ]
 * 
 * pyx_reserved_words = py_reserved_words + [             # <<<<<<<<<<<<<<
 *     "include", "ctypedef", "cdef", "cpdef",
 *     "cimport", "DEF", "IF", "ELIF", "ELSE"
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_py_reserved_words); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyList_Pack(9, __pyx_mstate_global->__pyx_n_u_include, __pyx_mstate_global->__pyx_n_u_ctypedef, __pyx_mstate_global->__pyx_n_u_cdef, __pyx_mstate_global->__pyx_n_u_cpdef, __pyx_mstate_global->__pyx_n_u_cimport, __pyx_mstate_global->__pyx_n_u_DEF, __pyx_mstate_global->__pyx_n_u_IF, __pyx_mstate_global->__pyx_n_u_ELIF, __pyx_mstate_global->__pyx_n_u_ELSE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_reserved_words, __pyx_t_5) < (0)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":66
 *         self.outer = outer
 * 
 *     def declare(self, name, value):             # <<<<<<<<<<<<<<
 *         self.entries[name] = value
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_3declare, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CompileTimeScope_declare, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_mstate_global->__pyx_n_u_declare, __pyx_t_5) < (0)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":69
 *         self.entries[name] = value
 * 
 *     def update(self, other):             # <<<<<<<<<<<<<<
 *         self.entries.update(other)
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_5update, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CompileTimeScope_update, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_mstate_global->__pyx_n_u_update, __pyx_t_5) < (0)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":72
 *         self.entries.update(other)
 * 
 *     def lookup_here(self, name):             # <<<<<<<<<<<<<<
 *         return self.entries[name]
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_7lookup_here, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CompileTimeScope_lookup_here, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_mstate_global->__pyx_n_u_lookup_here, __pyx_t_5) < (0)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":78
 *         return name in self.entries
 * 
 *     def lookup(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.lookup_here(name)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16CompileTimeScope_11lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CompileTimeScope_lookup, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope, __pyx_mstate_global->__pyx_n_u_lookup, __pyx_t_5) < (0)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":124
 * #------------------------------------------------------------------
 * 
 * class SourceDescriptor:             # <<<<<<<<<<<<<<
 *     """
 *     A SourceDescriptor should be considered immutable.
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_SourceDescriptor, __pyx_mstate_global->__pyx_n_u_SourceDescriptor, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_kp_u_A_SourceDescriptor_should_be_co); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Compiler/Scanning.py":128
 *     A SourceDescriptor should be considered immutable.
 *     """
 *     filename = None             # <<<<<<<<<<<<<<
 *     in_utility_code = False
 * 
*/
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_filename, Py_None) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":129
 *     """
 *     filename = None
 *     in_utility_code = False             # <<<<<<<<<<<<<<
 * 
 *     _file_type = 'pyx'
*/
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_in_utility_code, Py_False) < (0)) __PYX_ERR(0, 129, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":131
 *     in_utility_code = False
 * 
 *     _file_type = 'pyx'             # <<<<<<<<<<<<<<
 * 
 *     _escaped_description = None
*/
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_file_type, __pyx_mstate_global->__pyx_n_u_pyx_2) < (0)) __PYX_ERR(0, 131, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":133
 *     _file_type = 'pyx'
 * 
 *     _escaped_description = None             # <<<<<<<<<<<<<<
 *     _cmp_name = ''
 *     def __str__(self):
*/
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_escaped_description, Py_None) < (0)) __PYX_ERR(0, 133, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":134
 * 
 *     _escaped_description = None
 *     _cmp_name = ''             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         assert False  # To catch all places where a descriptor is used directly as a filename
*/
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_cmp_name, __pyx_mstate_global->__pyx_kp_u__4) < (0)) __PYX_ERR(0, 134, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":135
 *     _escaped_description = None
 *     _cmp_name = ''
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_1__str__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___str, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_str_2, __pyx_t_4) < (0)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":138
 *         assert False  # To catch all places where a descriptor is used directly as a filename
 * 
 *     def set_file_type_from_name(self, filename):             # <<<<<<<<<<<<<<
 *         name, ext = os.path.splitext(filename)
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_3set_file_type_from_name, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor_set_file_type_f, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_set_file_type_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":142
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'
 * 
 *     def is_cython_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type in ('pyx', 'pxd')
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_5is_cython_file, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor_is_cython_file, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_is_cython_file, __pyx_t_4) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":145
 *         return self._file_type in ('pyx', 'pxd')
 * 
 *     def is_python_file(self):             # <<<<<<<<<<<<<<
 *         return self._file_type == 'py'
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_7is_python_file, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor_is_python_file, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_is_python_file, __pyx_t_4) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":148
 *         return self._file_type == 'py'
 * 
 *     def get_escaped_description(self):             # <<<<<<<<<<<<<<
 *         if self._escaped_description is None:
 *             # Use forward slashes on Windows since these paths
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_9get_escaped_description, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor_get_escaped_des, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_get_escaped_description, __pyx_t_4) < (0)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":155
 *         return self._escaped_description
 * 
 *     def __gt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_11__gt__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___gt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_gt, __pyx_t_4) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":162
 *             return False
 * 
 *     def __lt__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_13__lt__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___lt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_lt, __pyx_t_4) < (0)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":169
 *             return False
 * 
 *     def __le__(self, other):             # <<<<<<<<<<<<<<
 *         # this is only used to provide some sort of order
 *         try:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_15__le__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___le, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_le, __pyx_t_4) < (0)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":176
 *             return False
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_17__copy__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___copy, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_copy, __pyx_t_4) < (0)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":179
 *         return self  # immutable, no need to copy
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return self  # immutable, no need to copy
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_16SourceDescriptor_19__deepcopy__, 0, __pyx_mstate_global->__pyx_n_u_SourceDescriptor___deepcopy, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_deepcopy, __pyx_t_4) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":124
 * #------------------------------------------------------------------
 * 
 * class SourceDescriptor:             # <<<<<<<<<<<<<<
 *     """
 *     A SourceDescriptor should be considered immutable.
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_SourceDescriptor, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_SourceDescriptor, __pyx_t_4) < (0)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":183
 * 
 * 
 * class FileSourceDescriptor(SourceDescriptor):             # <<<<<<<<<<<<<<
 *     """
 *     Represents a code source. A code source is a more generic abstraction
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_SourceDescriptor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyTuple_Pack(1, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_kp_u_Represents_a_code_source_A_code); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_5 != __pyx_t_4) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_4) < 0))) __PYX_ERR(0, 183, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":191
 *     the position()-tuple.
 *     """
 *     def __init__(self, filename, path_description=None):             # <<<<<<<<<<<<<<
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_1__init__, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_4) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":207
 *         self._lines = {}
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         # we cache the lines only the second time this is called, in
 *         # order to save memory when they are only used once
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_3get_lines, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_lines, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_lines, __pyx_t_4) < (0)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":222
 *         return lines
 * 
 *     def get_file_object(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_5get_file_object, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_file_ob, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_file_object, __pyx_t_4) < (0)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":225
 *         return Utils.open_source_file(self.filename, encoding, error_handling)
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self._short_path_description
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_7get_description, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_descrip, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_description, __pyx_t_4) < (0)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":228
 *         return self._short_path_description
 * 
 *     def get_relative_path(self) -> Path:             # <<<<<<<<<<<<<<
 *         file_path = Path(self.file_path)
 *         if file_path.is_absolute():
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Path) < (0)) __PYX_ERR(0, 228, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_9get_relative_path, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_relativ, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_relative_path, __pyx_t_7) < (0)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":235
 *             return file_path
 * 
 *     def get_error_description(self):             # <<<<<<<<<<<<<<
 *         path = self.filename
 *         cwd = Utils.decode_filename(os.getcwd() + os.path.sep)
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_11get_error_description, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_error_d, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_error_description, __pyx_t_7) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":242
 *         return path
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return self.file_path
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_13get_filenametable_entry, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor_get_filenam, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get_filenametable_entry, __pyx_t_7) < (0)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":245
 *         return self.file_path
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_15__eq__, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor___eq, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_eq, __pyx_t_7) < (0)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":248
 *         return isinstance(other, FileSourceDescriptor) and self.filename == other.filename
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.filename)
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_17__hash__, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor___hash, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_hash_2, __pyx_t_7) < (0)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":251
 *         return hash(self.filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<FileSourceDescriptor:%s>" % self.filename
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FileSourceDescriptor_19__repr__, 0, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_7) < (0)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":183
 * 
 * 
 * class FileSourceDescriptor(SourceDescriptor):             # <<<<<<<<<<<<<<
 *     """
 *     Represents a code source. A code source is a more generic abstraction
*/
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor, __pyx_t_5, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_FileSourceDescriptor, __pyx_t_7) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":255
 * 
 * 
 * class StringSourceDescriptor(SourceDescriptor):             # <<<<<<<<<<<<<<
 *     """
 *     Instances of this class can be used instead of a filenames if the
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_SourceDescriptor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyTuple_Pack(1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_6, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_kp_u_Instances_of_this_class_can_be); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__pyx_t_5 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_7, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 255, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":260
 *     code originates from a string object.
 *     """
 *     def __init__(self, name, code):             # <<<<<<<<<<<<<<
 *         self.name = name
 *         #self.set_file_type_from_name(name)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_1__init__, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":266
 *         self._cmp_name = name
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         if not encoding:
 *             return self.codelines
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_3get_lines, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor_get_lines, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_lines, __pyx_t_2) < (0)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":273
 *                     for line in self.codelines]
 * 
 *     def get_description(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_5get_description, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor_get_descr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_description, __pyx_t_2) < (0)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":276
 *         return self.name
 * 
 *     def get_relative_path(self):             # <<<<<<<<<<<<<<
 *         return Path(self.get_description())
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_7get_relative_path, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor_get_relat, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_relative_path, __pyx_t_2) < (0)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":279
 *         return Path(self.get_description())
 * 
 *     get_error_description = get_description             # <<<<<<<<<<<<<<
 * 
 *     def get_filenametable_entry(self):
*/
  __pyx_t_2 = PyObject_GetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_description);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_get_description);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_error_description, __pyx_t_2) < (0)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":281
 *     get_error_description = get_description
 * 
 *     def get_filenametable_entry(self):             # <<<<<<<<<<<<<<
 *         return "<stringsource>"
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_9get_filenametable_entry, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor_get_filen, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_get_filenametable_entry, __pyx_t_2) < (0)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":284
 *         return "<stringsource>"
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return id(self)
 *         # Do not hash on the name, an identical string source should be the
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_11__hash__, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor___hash, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_hash_2, __pyx_t_2) < (0)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":290
 *         # return hash(self.name)
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_13__eq__, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor___eq, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_eq, __pyx_t_2) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":293
 *         return isinstance(other, StringSourceDescriptor) and self.name == other.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<StringSourceDescriptor:%s>" % self.name
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_22StringSourceDescriptor_15__repr__, 0, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_2) < (0)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Scanning.py":255
 * 
 * 
 * class StringSourceDescriptor(SourceDescriptor):             # <<<<<<<<<<<<<<
 *     """
 *     Instances of this class can be used instead of a filenames if the
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor, __pyx_t_5, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_StringSourceDescriptor, __pyx_t_2) < (0)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":355
 *         self.next()
 * 
 *     def normalize_ident(self, text):             # <<<<<<<<<<<<<<
 *         if not text.isascii():
 *             text = normalize('NFKC', text)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_3normalize_ident, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_normalize_ident, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_normalize_ident, __pyx_t_5) < (0)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":360
 *         self.produce(IDENT, text)
 * 
 *     def commentline(self, text):             # <<<<<<<<<<<<<<
 *         if self.parse_comments:
 *             self.produce('commentline', text)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_5commentline, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_commentline, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_commentline, __pyx_t_5) < (0)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":364
 *             self.produce('commentline', text)
 * 
 *     def strip_underscores(self, text, symbol):             # <<<<<<<<<<<<<<
 *         self.produce(symbol, text.replace('_', ''))
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_7strip_underscores, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_strip_underscores, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_strip_underscores, __pyx_t_5) < (0)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":370
 *         return self.indentation_stack[-1]
 * 
 *     def open_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         return text
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_9open_bracket_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_open_bracket_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_open_bracket_action, __pyx_t_5) < (0)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":374
 *         return text
 * 
 *     def close_bracket_action(self, text):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level -= 1
 *         return text
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_11close_bracket_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_close_bracket_actio, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_close_bracket_action, __pyx_t_5) < (0)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":378
 *         return text
 * 
 *     def open_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         return self.open_bracket_action(text)
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_13open_brace_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_open_brace_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_open_brace_action, __pyx_t_5) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":381
 *         return self.open_bracket_action(text)
 * 
 *     def close_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         assert text == '}'
 *         if (self.ft_string_state_stack and
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_15close_brace_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_close_brace_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_close_brace_action, __pyx_t_5) < (0)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":394
 *         return text
 * 
 *     def colon_action(self, text):             # <<<<<<<<<<<<<<
 *         if (self.ft_string_state_stack and
 *                 self.ft_string_state_stack[-1].bracket_nesting_level() == self.bracket_nesting_level):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_17colon_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_colon_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_colon_action, __pyx_t_5) < (0)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":404
 *         return text
 * 
 *     def newline_action(self, text):             # <<<<<<<<<<<<<<
 *         if self.bracket_nesting_level == 0:
 *             self.begin('INDENT')
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_19newline_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_newline_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_newline_action, __pyx_t_5) < (0)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":410
 * 
 *     string_states = {
 *         "'":   'SQ_STRING',             # <<<<<<<<<<<<<<
 *         '"':   'DQ_STRING',
 *         "'''": 'TSQ_STRING',
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__8, __pyx_mstate_global->__pyx_n_u_SQ_STRING) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__10, __pyx_mstate_global->__pyx_n_u_DQ_STRING) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__11, __pyx_mstate_global->__pyx_n_u_TSQ_STRING) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__12, __pyx_mstate_global->__pyx_n_u_TDQ_STRING) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_string_states, __pyx_t_5) < (0)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":416
 *     }
 * 
 *     def begin_string_action(self, text: str):             # <<<<<<<<<<<<<<
 *         while text and text[0] in any_string_prefix:
 *             text = text[1:]
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_text, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_21begin_string_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_begin_string_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_begin_string_action, __pyx_t_6) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":422
 *         self.produce('BEGIN_STRING')
 * 
 *     def end_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
 *         self.produce('END_STRING')
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_23end_string_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_end_string_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_end_string_action, __pyx_t_6) < (0)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":426
 *         self.produce('END_STRING')
 * 
 *     def begin_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         is_raw = 'r' in text or 'R' in text
 *         while text and (text[0] in any_string_prefix or text[0] in ft_string_prefixes):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_25begin_ft_string_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_begin_ft_string_act, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_begin_ft_string_action, __pyx_t_6) < (0)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":437
 *         self.produce('BEGIN_FT_STRING')
 * 
 *     def end_ft_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.ft_string_state_stack.pop()
 *         self.begin('FT_STRING_EXPR_PRESCAN' if self.in_ft_string_expr_prescan else '')
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_27end_ft_string_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_end_ft_string_actio, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_end_ft_string_action, __pyx_t_6) < (0)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":442
 *         self.produce('END_FT_STRING')
 * 
 *     def _handle_open_single_ft_string_brace(self, started_ft_string_expr):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level += 1
 *         if not started_ft_string_expr:
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_29_handle_open_single_ft_string_brace, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner__handle_open_single, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_handle_open_single_ft_string_br, __pyx_t_6) < (0)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":450
 *         self.produce('{')
 * 
 *     def open_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         started_ft_string_expr = False
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_31open_ft_string_brace_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_open_ft_string_brac, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_open_ft_string_brace_action, __pyx_t_6) < (0)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":468
 *             self._handle_open_single_ft_string_brace(started_ft_string_expr)
 * 
 *     def _handle_close_single_ft_string_brace(self):             # <<<<<<<<<<<<<<
 *         ft_string_bracket_level = self.ft_string_state_stack[-1].bracket_nesting_level()
 *         if ft_string_bracket_level is None or self.bracket_nesting_level < ft_string_bracket_level:
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_33_handle_close_single_ft_string_brace, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner__handle_close_singl, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_handle_close_single_ft_string_b, __pyx_t_6) < (0)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":482
 *             self.produce(self.close_brace_action('}'), '}')
 * 
 *     def close_ft_string_brace_action(self, text):             # <<<<<<<<<<<<<<
 *         len_text = len(text)
 *         while len_text and self.ft_string_state_stack[-1].in_format_specifier():
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_35close_ft_string_brace_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_close_ft_string_bra, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_close_ft_string_brace_action, __pyx_t_6) < (0)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":496
 *             self._handle_close_single_ft_string_brace()
 * 
 *     def unclosed_string_action(self, text):             # <<<<<<<<<<<<<<
 *         self.end_string_action(text)
 *         self.error_at_scanpos("Unclosed string literal")
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_37unclosed_string_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_unclosed_string_act, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_unclosed_string_action, __pyx_t_6) < (0)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":500
 *         self.error_at_scanpos("Unclosed string literal")
 * 
 *     def indentation_action(self, text: str):             # <<<<<<<<<<<<<<
 *         self.begin('')
 *         # Indentation within brackets should be ignored.
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_text, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 500, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_39indentation_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_indentation_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[51])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_indentation_action, __pyx_t_5) < (0)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":536
 *                 self.error_at_scanpos("Inconsistent indentation")
 * 
 *     def eof_action(self, text):             # <<<<<<<<<<<<<<
 *         while len(self.indentation_stack) > 1:
 *             self.produce('DEDENT', '')
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_41eof_action, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_eof_action, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[52])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_eof_action, __pyx_t_5) < (0)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":542
 *         self.produce('EOF', '')
 * 
 *     def next(self):             # <<<<<<<<<<<<<<
 *         try:
 *             sy, systring = self.read()
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_43next, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_next, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[53])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_next, __pyx_t_5) < (0)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":569
 *             print("--- %3d %2d %s" % (line, col, t))
 * 
 *     def peek(self):             # <<<<<<<<<<<<<<
 *         saved = self.sy, self.systring
 *         saved_pos = self.position()
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_45peek, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_peek, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[54])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_peek, __pyx_t_5) < (0)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":579
 *         return next
 * 
 *     def put_back(self, sy, systring, pos):             # <<<<<<<<<<<<<<
 *         self.unread(self.sy, self.systring, self.last_token_position_tuple)
 *         self.sy = sy
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_47put_back, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_put_back, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[55])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_put_back, __pyx_t_5) < (0)) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":586
 * 
 * 
 *     def error(self, message, pos=None, fatal=True):             # <<<<<<<<<<<<<<
 *         if pos is None:
 *             pos = self.position()
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_49error, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_error, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[56])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[9]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_error, __pyx_t_5) < (0)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":600
 *         self.error(message, pos, True)
 * 
 *     def expect(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == what:
 *             self.next()
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_51expect, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expect, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[57])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expect, __pyx_t_5) < (0)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":606
 *             self.expected(what, message)
 * 
 *     def expect_keyword(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if self.sy == IDENT and self.systring == what:
 *             self.next()
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_53expect_keyword, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expect_keyword, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[58])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expect_keyword, __pyx_t_5) < (0)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":612
 *             self.expected(what, message)
 * 
 *     def expected(self, what, message=None):             # <<<<<<<<<<<<<<
 *         if message:
 *             self.error(message)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_55expected, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expected, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[59])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[7]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expected, __pyx_t_5) < (0)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":622
 *             self.error("Expected '%s', found '%s'" % (what, found))
 * 
 *     def expect_indent(self):             # <<<<<<<<<<<<<<
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_57expect_indent, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expect_indent, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[60])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_t_5) < (0)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":625
 *         self.expect('INDENT', "Expected an increase in indentation level")
 * 
 *     def expect_dedent(self):             # <<<<<<<<<<<<<<
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_59expect_dedent, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expect_dedent, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[61])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_t_5) < (0)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Scanning.py":628
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):             # <<<<<<<<<<<<<<
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ignore_semicolon, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 628, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_61expect_newline, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_expect_newline, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[62])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[10]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_t_6) < (0)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":639
 *             warning(useless_trailing_semicolon, "useless trailing semicolon")
 * 
 *     def enter_async(self):             # <<<<<<<<<<<<<<
 *         self.async_enabled += 1
 *         if self.async_enabled == 1:
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_63enter_async, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_enter_async, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[63])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_enter_async, __pyx_t_6) < (0)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":645
 *             self.keywords['await'] = 'await'
 * 
 *     def exit_async(self):             # <<<<<<<<<<<<<<
 *         assert self.async_enabled > 0
 *         self.async_enabled -= 1
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_12PyrexScanner_65exit_async, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PyrexScanner_exit_async, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[64])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_mstate_global->__pyx_n_u_exit_async, __pyx_t_6) < (0)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":654
 *                 self.sy, self.systring = IDENT, self.context.intern_ustring(self.sy)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def tentatively_scan(scanner: PyrexScanner):
 *     errors = hold_errors()
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_contextmanager); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_scanner, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_1tentatively_scan, 0, __pyx_mstate_global->__pyx_n_u_tentatively_scan, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_tentatively_scan, __pyx_t_6) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":686
 *         self.bracket_states = []
 * 
 *     def bracket_nesting_level(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return None
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_3bracket_nesting_level, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FTStringState_bracket_nesting_le, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[65])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_t_6) < (0)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":691
 *         return self.bracket_states[-1].bracket_nesting_level
 * 
 *     def in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         if not self.bracket_states:
 *             return False
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_5in_format_specifier, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FTStringState_in_format_specifie, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[66])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_t_6) < (0)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":696
 *         return self.bracket_states[-1].in_format_specifier
 * 
 *     def set_in_format_specifier(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states[-1].in_format_specifier = True
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_7set_in_format_specifier, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FTStringState_set_in_format_spec, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[67])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_mstate_global->__pyx_n_u_set_in_format_specifier, __pyx_t_6) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":699
 *         self.bracket_states[-1].in_format_specifier = True
 * 
 *     def push_bracket_state(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 699, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_9push_bracket_state, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FTStringState_push_bracket_state, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[68])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_mstate_global->__pyx_n_u_push_bracket_state, __pyx_t_7) < (0)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":702
 *         self.bracket_states.append(FTStringBracketState(bracket_nesting_level))
 * 
 *     def pop_bracket_state(self):             # <<<<<<<<<<<<<<
 *         self.bracket_states.pop()
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_13FTStringState_11pop_bracket_state, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FTStringState_pop_bracket_state, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[69])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState, __pyx_mstate_global->__pyx_n_u_pop_bracket_state, __pyx_t_7) < (0)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "Cython/Compiler/Scanning.py":706
 * 
 * 
 * class FTStringBracketState:             # <<<<<<<<<<<<<<
 *     # Because of the way this is accessed, it probably doesn't make sense as a cdef class
 *     # so just use __slots__ to keep it compact.
*/
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_FTStringBracketState, __pyx_mstate_global->__pyx_n_u_FTStringBracketState, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, (PyObject *) NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 706, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_in_format_specifier, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 706, __pyx_L1_error)
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_annotations, __pyx_t_6) < (0)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Scanning.py":709
 *     # Because of the way this is accessed, it probably doesn't make sense as a cdef class
 *     # so just use __slots__ to keep it compact.
 *     __slots__ = ('bracket_nesting_level', 'in_format_specifier')             # <<<<<<<<<<<<<<
 *     bracket_nesting_level: int
 *     in_format_specifier: bool
*/
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[11]) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)

  /* "Cython/Compiler/Scanning.py":712
 *     bracket_nesting_level: int
 *     in_format_specifier: bool
 *     def __init__(self, bracket_nesting_level: int):             # <<<<<<<<<<<<<<
 *         self.bracket_nesting_level = bracket_nesting_level
 *         self.in_format_specifier = False
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 712, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_8Scanning_20FTStringBracketState_1__init__, 0, __pyx_mstate_global->__pyx_n_u_FTStringBracketState___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Scanning, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[70])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_4) < (0)) __PYX_ERR(0, 712, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Scanning.py":706
 * 
 * 
 * class FTStringBracketState:             # <<<<<<<<<<<<<<
 *     # Because of the way this is accessed, it probably doesn't make sense as a cdef class
 *     # so just use __slots__ to keep it compact.
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_FTStringBracketState, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_FTStringBracketState, __pyx_t_4) < (0)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init Cython.Compiler.Scanning", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Cython.Compiler.Scanning");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 92, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 285, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 668, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "Cython/Compiler/Scanning.py":91
 * def initial_compile_time_env():
 *     benv = CompileTimeScope()
 *     names = ('UNAME_SYSNAME', 'UNAME_NODENAME', 'UNAME_RELEASE', 'UNAME_VERSION', 'UNAME_MACHINE')             # <<<<<<<<<<<<<<
 *     for name, value in zip(names, platform.uname()):
 *         benv.declare(name, value)
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(5, __pyx_mstate_global->__pyx_n_u_UNAME_SYSNAME, __pyx_mstate_global->__pyx_n_u_UNAME_NODENAME, __pyx_mstate_global->__pyx_n_u_UNAME_RELEASE, __pyx_mstate_global->__pyx_n_u_UNAME_VERSION, __pyx_mstate_global->__pyx_n_u_UNAME_MACHINE); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "Cython/Compiler/Scanning.py":97
 * 
 *     names = (
 *         'False', 'True',             # <<<<<<<<<<<<<<
 *         'abs', 'all', 'any', 'ascii', 'bin', 'bool', 'bytearray', 'bytes',
 *         'chr', 'complex', 'dict', 'divmod', 'enumerate', 'filter',
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(42, __pyx_mstate_global->__pyx_n_u_False, __pyx_mstate_global->__pyx_n_u_True, __pyx_mstate_global->__pyx_n_u_abs, __pyx_mstate_global->__pyx_n_u_all, __pyx_mstate_global->__pyx_n_u_any, __pyx_mstate_global->__pyx_n_u_ascii, __pyx_mstate_global->__pyx_n_u_bin, __pyx_mstate_global->__pyx_n_u_bool, __pyx_mstate_global->__pyx_n_u_bytearray, __pyx_mstate_global->__pyx_n_u_bytes, __pyx_mstate_global->__pyx_n_u_chr, __pyx_mstate_global->__pyx_n_u_complex, __pyx_mstate_global->__pyx_n_u_dict, __pyx_mstate_global->__pyx_n_u_divmod, __pyx_mstate_global->__pyx_n_u_enumerate, __pyx_mstate_global->__pyx_n_u_filter, __pyx_mstate_global->__pyx_n_u_float, __pyx_mstate_global->__pyx_n_u_format, __pyx_mstate_global->__pyx_n_u_frozenset, __pyx_mstate_global->__pyx_n_u_hash, __pyx_mstate_global->__pyx_n_u_hex, __pyx_mstate_global->__pyx_n_u_int, __pyx_mstate_global->__pyx_n_u_len, __pyx_mstate_global->__pyx_n_u_list, __pyx_mstate_global->__pyx_n_u_map, __pyx_mstate_global->__pyx_n_u_max, __pyx_mstate_global->__pyx_n_u_min, __pyx_mstate_global->__pyx_n_u_next, __pyx_mstate_global->__pyx_n_u_oct, __pyx_mstate_global->__pyx_n_u_ord, __pyx_mstate_global->__pyx_n_u_pow, __pyx_mstate_global->__pyx_n_u_range, __pyx_mstate_global->__pyx_n_u_repr, __pyx_mstate_global->__pyx_n_u_reversed, __pyx_mstate_global->__pyx_n_u_round, __pyx_mstate_global->__pyx_n_u_set, __pyx_mstate_global->__pyx_n_u_slice, __pyx_mstate_global->__pyx_n_u_sorted, __pyx_mstate_global->__pyx_n_u_str, __pyx_mstate_global->__pyx_n_u_sum, __pyx_mstate_global->__pyx_n_u_tuple, __pyx_mstate_global->__pyx_n_u_zip); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Compiler/Scanning.py":140
 *     def set_file_type_from_name(self, filename):
 *         name, ext = os.path.splitext(filename)
 *         self._file_type = ext in ('.pyx', '.pxd', '.py') and ext[1:] or 'pyx'             # <<<<<<<<<<<<<<
 * 
 *     def is_cython_file(self):
*/
  __pyx_mstate_global->__pyx_slice[0] = PySlice_New(__pyx_mstate_global->__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[0])) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[0]);

  /* "Cython/Compiler/Scanning.py":152
 *             # Use forward slashes on Windows since these paths
 *             # will be used in the #line directives in the C/C++ files.
 *             self._escaped_description = self.get_description().replace('\\', '/')             # <<<<<<<<<<<<<<
 *         return self._escaped_description
 * 
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__2, __pyx_mstate_global->__pyx_kp_u__3); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "Cython/Compiler/Scanning.py":215
 *             return lines
 * 
 *         with self.get_file_object(encoding=encoding, error_handling=error_handling) as f:             # <<<<<<<<<<<<<<
 *             lines = [line.rstrip() for line in f.readlines()]
 * 
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "Cython/Compiler/Scanning.py":365
 * 
 *     def strip_underscores(self, text, symbol):
 *         self.produce(symbol, text.replace('_', ''))             # <<<<<<<<<<<<<<
 * 
 *     def current_level(self):
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u__5, __pyx_mstate_global->__pyx_kp_u__4); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "Cython/Compiler/Scanning.py":623
 * 
 *     def expect_indent(self):
 *         self.expect('INDENT', "Expected an increase in indentation level")             # <<<<<<<<<<<<<<
 * 
 *     def expect_dedent(self):
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_INDENT, __pyx_mstate_global->__pyx_kp_u_Expected_an_increase_in_indentat); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "Cython/Compiler/Scanning.py":626
 * 
 *     def expect_dedent(self):
 *         self.expect('DEDENT', "Expected a decrease in indentation level")             # <<<<<<<<<<<<<<
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_DEDENT, __pyx_mstate_global->__pyx_kp_u_Expected_a_decrease_in_indentati); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "Cython/Compiler/Scanning.py":191
 *     the position()-tuple.
 *     """
 *     def __init__(self, filename, path_description=None):             # <<<<<<<<<<<<<<
 *         filename = Utils.decode_filename(filename)
 *         self.filename = filename
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);

  /* "Cython/Compiler/Scanning.py":207
 *         self._lines = {}
 * 
 *     def get_lines(self, encoding=None, error_handling=None):             # <<<<<<<<<<<<<<
 *         # we cache the lines only the second time this is called, in
 *         # order to save memory when they are only used once
*/
  __pyx_mstate_global->__pyx_tuple[8] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[8])) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[8]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[8]);

  /* "Cython/Compiler/Scanning.py":586
 * 
 * 
 *     def error(self, message, pos=None, fatal=True):             # <<<<<<<<<<<<<<
 *         if pos is None:
 *             pos = self.position()
*/
  __pyx_mstate_global->__pyx_tuple[9] = PyTuple_Pack(2, Py_None, Py_True); if (unlikely(!__pyx_mstate_global->__pyx_tuple[9])) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[9]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[9]);

  /* "Cython/Compiler/Scanning.py":628
 *         self.expect('DEDENT', "Expected a decrease in indentation level")
 * 
 *     def expect_newline(self, message="Expected a newline", ignore_semicolon: cython.bint = False):             # <<<<<<<<<<<<<<
 *         # Expect either a newline or end of file
 *         useless_trailing_semicolon = None
*/
  __pyx_mstate_global->__pyx_tuple[10] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline, Py_False); if (unlikely(!__pyx_mstate_global->__pyx_tuple[10])) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[10]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[10]);

  /* "Cython/Compiler/Scanning.py":709
 *     # Because of the way this is accessed, it probably doesn't make sense as a cdef class
 *     # so just use __slots__ to keep it compact.
 *     __slots__ = ('bracket_nesting_level', 'in_format_specifier')             # <<<<<<<<<<<<<<
 *     bracket_nesting_level: int
 *     in_format_specifier: bool
*/
  __pyx_mstate_global->__pyx_tuple[11] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_bracket_nesting_level, __pyx_mstate_global->__pyx_n_u_in_format_specifier); if (unlikely(!__pyx_mstate_global->__pyx_tuple[11])) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[11]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[11]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<12; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_slice;
    for (Py_ssize_t i=0; i<1; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{1},{60},{7},{22},{22},{23},{27},{18},{20},{10},{40},{18},{41},{25},{24},{117},{28},{4},{179},{33},{311},{27},{23},{22},{1},{3},{3},{1},{1},{1},{0},{1},{1},{1},{1},{8},{11},{7},{6},{47},{10},{2},{9},{4},{3},{4},{14},{26},{15},{12},{5},{12},{16},{24},{23},{28},{23},{24},{6},{3},{9},{4},{4},{13},{18},{10},{3},{6},{3},{20},{29},{13},{35},{33},{31},{32},{37},{22},{5},{20},{27},{29},{29},{29},{36},{42},{36},{44},{30},{38},{6},{5},{2},{6},{7},{7},{4},{4},{11},{13},{12},{49},{48},{35},{32},{31},{33},{41},{25},{24},{33},{30},{24},{23},{18},{23},{19},{26},{26},{27},{27},{21},{31},{27},{17},{28},{30},{32},{40},{17},{21},{30},{35},{20},{1},{9},{7},{16},{25},{29},{23},{23},{23},{24},{40},{31},{31},{40},{22},{29},{31},{31},{31},{38},{46},{32},{40},{10},{10},{4},{13},{14},{13},{13},{13},{17},{5},{0},{1},{3},{7},{3},{3},{15},{3},{17},{5},{6},{5},{13},{18},{5},{22},{19},{3},{4},{21},{5},{8},{9},{5},{1},{4},{3},{7},{5},{17},{18},{5},{18},{20},{28},{9},{4},{9},{12},{11},{16},{17},{17},{7},{7},{10},{14},{8},{8},{5},{8},{13},{3},{13},{7},{6},{15},{12},{3},{3},{4},{6},{7},{13},{4},{4},{6},{8},{20},{17},{9},{11},{9},{10},{6},{3},{5},{14},{6},{20},{6},{4},{8},{10},{6},{13},{13},{14},{14},{8},{3},{1},{5},{4},{9},{10},{8},{6},{7},{5},{3},{6},{5},{4},{9},{23},{18},{15},{8},{9},{17},{3},{15},{21},{23},{15},{23},{9},{17},{6},{6},{6},{36},{35},{4},{8},{3},{11},{2},{2},{6},{16},{6},{2},{19},{15},{7},{14},{18},{8},{11},{13},{3},{14},{2},{11},{13},{14},{14},{6},{7},{5},{3},{6},{14},{6},{3},{8},{4},{6},{5},{4},{4},{6},{11},{6},{8},{12},{3},{3},{4},{7},{13},{3},{10},{15},{4},{8},{9},{14},{4},{8},{9},{15},{3},{3},{17},{19},{27},{16},{7},{2},{3},{2},{5},{5},{14},{14},{4},{4},{16},{7},{4},{8},{3},{17},{3},{3},{11},{5},{14},{18},{8},{19},{3},{2},{17},{3},{12},{18},{14},{12},{1},{5},{5},{9},{6},{14},{7},{7},{4},{8},{6},{8},{5},{6},{5},{9},{7},{19},{17},{13},{5},{4},{4},{3},{3},{23},{23},{12},{10},{23},{5},{9},{6},{15},{8},{10},{22},{10},{3},{7},{13},{17},{3},{2},{6},{8},{16},{4},{5},{13},{3},{5},{5},{22},{7},{11},{6},{26},{5},{6},{7},{4},{5},{4},{7},{6},{5},{3},{35},{54},{34},{44},{44},{140},{21},{14},{136},{98},{45},{26},{44},{26},{34},{20},{29},{35},{189},{97},{100},{85},{29},{43},{13},{13},{21},{39},{13},{16},{11},{14},{116},{43},{62},{39},{15},{22},{50},{44},{7},{11},{9},{13},{16},{62},{13},{89},{14},{13},{15},{136},{27},{26},{90},{58},{65},{5},{21},{55},{25},{51},{218},{112}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (4147 bytes) */
const char* const cstring = "(\265/\375`\313$M\201\000\372\225\274\036H\340\2628\0070\314\363D\236\2060\030\217\265\020\006\302@\0300;\302@\030\206`f\252\376\270\245H\333\"\247\006i\373\\RnDD!\rq3\036\212\036\236\231\231Q\257$ \201CP\014f\316\321D\237\250\300\202\244l(\265\001\252\001\360\0017\250\231\024*g\225B\245P\274z`\3700\n\206:9_]o\367^\351\301\334\261rX8\247\032\031\232\225\n'\207Esf\350JE\223\212\301\371\346\316~\277\257\345\366\376\373;\034\021bF\233\201%o\333\356\205C\n$\357e\371\336\312\221r\334\315}\250\340\302\277\255\307\261muO=\257\202 \335\310aA\006\211\224\224\024\022\211\224Ru\205u6,~\345\3565^q\253~no\276\035^\301\n\001\206\274\302\213\213\335\031\324\331U\306\351t\265\325\342\356\2652\216\377\013_\334\255`\336\225\243\224[l)-\275.\275t\034'\341\375\331\373,\377oW\027.%EgWW[\225{\374/\356u\376,w\342J{\277\006\037\347\266\354\336\331\246\364\373\326\231\337\261\332z\034\211f\214+\211\343\2779\274+\310e\036f\032\347Rq\245\375 \215\363k\303V+\334\334~\r\323\001\246\202M\312\206\303\232v\365\267\354\335\226\343\365y^=\316\253\nn\316\333\255\352\375\314\246\340\335\327heN\363\375e\355\342\025\333\227\325\231{/wo\277\212]\\\365\352\357\020\327]o\307m\013\343\234+s\373;\\\371\306*\276\261j\304f\371\360\327\316\204xl\257\354\361\375\235\277\034\316\226W\216\337\303\226\373]_w\357q\225\304y\317\273\007g\251\255\177\366\327\206\006\226^\330b\\;\226\005\013v\366(^\207<\234\331:k\235*\351\277\026\374r\tg\030\247\311\374mU\036~\237\345\274\327\357\331\215s\307}\213\363n\230a\233\323\231\203Vw\373Q\337\3510\263\270\023G\240\024\267v\371\342\214e\3776\353\277\241\227?\272\367\177\371\373oV?\260~:\330\326\357\362\375\230\376\253\206\257\352\265\276z\367\266\262\252\351\363\360f\273\255\345\330\356\014\332\355\205\226\322\270\275\330\322\327\031\277\254\313zv{7\303f\177k+\337\327\246\256}s\346.J\367\277\016\377\215\337\206\316.^\363u\321\356\255\330\272n\345\325\345\342\017\376\326\372\277\020?\305\217\377\367}\227\275\277o+\354\262\227\277\035\353\361\316z\233\276\302\326{\236\254\343\370""\265\016\301\356Cl\365\277*\256\037\307\271\233\375\325\340\354\326\235\235\317\202\340\327Q\376=\267\224r\235\301\317v\032\326\271\336\353\272M\253Z\327\347\264\326\326\251\177sna\313m\225U\036f\235-\345\332\332n\327\231u\275\006i\233R\017\327{\353nU\272\257\345+\260j\245B\305\302I\261`\275`\261N)\024)\234\024J\305\252F\346\224\202\246R\234V+>\324\254\234\034J7H\267\365\036\254\177\371\013\374\367(\245\261p\\\217\263\262\250\031\315\206\322p\277\316\335\326\357\341\220\202]mQ\036\352\374\203\226^>{Og\031\355u\260\345v\346\312\035\246\355J\365s\017\377\207\355\353[\370)wQJ\377z\2704{M\263\261\22191\263J\255T(Z\244V+\325\214J\005\343\025\244\365\276\3364\315\361S\372\036\345\377\322\340k\330\2560Jc\277:\311\260\350\206\355\020\334\024\314\240~\353\262\233\362\372Ql)\337\217i\213\263\370\353\230\234\231\031\02586.R\024\265J\245X(R3*\024\2511\322\212D\266P\r\245'\307T1I\220\274\317@FZH\354x2\030\030\tG\230\261\300il!\236\304\032\027\343i\354P{\014\211\017\031\201\347\324\033\010 \273\3362\"W\230j;=\265\007f\306\230!(\234 \322\245\344\014\031\370\020\320\343C\262R=\245\337\270\225\334h\306P<)\261\305xHFl\247n\3528DF)4\324Rx8u\211Sj\210p\302\214\\\264<\007b\243\314\350\301t3\365Q\237!&\010\261\215\372\202\220\004b\352\324M\272\310\210\022r\273\351I\231NM\342\220\025NN\030\022\226\021\245<\22507\246\210\227Sw\234\316Br\206\330b\242I\250\314!9Ix|\314X\311A\345\034u\016\243\212\217\331\001tV\321\304M?\365\225\026,\316\003\265X\317\t\263\246\304\375\246\253\2440\221\010H\335Yz\250\243\214)1ED\020r\213\2210\267\022\022[\314\2041G\246K\271\202\304@N(9EBl\247\322\2444q'7r~F\024<#\344\207tA95\210&!\266P\037\201N\323\355DRpp\202\306\230\010#\232\214\330>\035\205\350\341f\024\215\237\021%\212BeG\232\350\240\216\032]\344\004\320\371\351-ch\024\271\335\210\001\304\222\021[\0253\210\234\007\206\247@\210\315\324U@\347\007\377\327\307\307\213g\363\216\313\307\307\207\004N\005\315\006\2646\274\373\2266\323\326\323\201\311x\205\311\260\256\262\375!\245\225W\317\3420\224e\032\247\355\233[""\037m\323\366\027\356\r\343V\266\355\005\267\367\233\347\333Q\2563\354\206\225R\376\033\374\355\341\337\256\r~\341~\325\353\242uk\355i|\177\327\277]\350\325\257\366\3260\266c)\270\251\367;\372\367k\032\350\315\302k+\245\262\014\202\027\334\025\324\3770\236w\326y\363.\0071\036\222\020\333\311\314\341\301\300\310$0\3530\035\244\237\2149.Z\234-P'-?\220/\241\333\211\270\341\323iJD\310\003&\035\206\327[n\237\262\0243J\270\221n\241Q\213'\006>\037\310\021\271;\311\324\021r\253\225\223(\347\2114!_D!\027\320\210\310\007\201\036\241\023\323\002I\240\307\306\001\261N2\242\2300\312\t\244\307\":\363\010\001t\352\220\031M\240\363\004\235\021 \330>-\"\007\223\310\022\212\215V\\\021\021\210\233tp2]\345\206\223\363\2062\356\233\250\305\324\013\014(_\220\"\020\022\345 \344&#\306I\243\226\202\345d\001\235\261\032\213\002\221\351\001\347\346L\325Lj6x\311at\222l\230!B\375\323CnJ\225\022\303\250\304\020\023e\304\220\344\320\371\250\3571\204\315\211\252\231j*@\345\t)\203\213*\220q4\336\010\231\2512\245\004P\262\310\227\3119\3225V\217\250\347#2I\245\013\351\322\275\225\207\361\305\030\321\325\031\234\024\234+\342\201\233\361\201g\306z\313M\237\260\243\216\020L\342\002ROq\320C2c$\204\323\23022\000\351a\231'\023d\262J\r*'\310w\031\026+T\362Zn\210p\342\214\030L#\215\251\247\200\211*kX\3755\256\214\267\030\311B\206H\224\233\321E\035M\344\260NV\206\223\223\026L\316\020\371\"C\024\231\"\rz\316\030\300$\322\214\240QC(\224\022Ab\311\250'F\302\t\200l\365\226\022C\211\240458\371MM\311\344$K\265\266R\333=2=\250\322\031C\246\220\022Dg\254\223JN\024\217X\251\240\374\224\027\036\234\242[\035\023TQA\211\355\206\254\200r\226\330L5\0045\025\206\323#3\220\3373t\225\002g\001\026%\316V\313\271\322SF\342L\215\306\200\244\351+\246rT\222\350\035Nz\355/\026\210n\225\204\231j \265\232\016gH\211\"A\344I\357F\010\tl\001\203\353\250\242\233\226tP\215\214\214$I\322\034B\020\014\022\214\206Y\246h\363\001\322\301\032\t\0312\306\030$2\"$2R\220\202\024\206\003Z\201\245\330\362\317Si\2107\321<\013\360d.\013\271P\261\221cH""\337\2033&\022\341\034h\r\203\003\221YBdX\034[\212\013\n\204d\315\263\205+\324-5\364\243\344R\323\200\377s\235\001t\233g\323\324\353\274B\236-\360\212\020B/)\226\272br\251P\202n\345d\227\215\023\"p%D?\210'\004\t\017\367\234m\241&s1P\021\365\341\232E\017\033a3W\367-\333\263\261\334\244\372\305BN<f=\242\212\202,\027\240\316A/\027\367\020X\241&\007`\355\000A\256\032\342]x\211Rb}1\007\223\003yL'\373q\347\200\310\000\254\272\264\331\375\301(\321\256\264S\260\353cs\222\361\375\334\221\263\337\244\236n\302\351m:Z\322r\2617g\253\263?\345D\374\234\204\360\357\335\327\235\362\230n\"V\300'Z\246\257\206O\354\025\252Do\310\"tV\300+\347p^\2447\207b\212`\205\332q\2041\301ODVC\201\325\214\3716\346\\Q\3544g\330\334\332\264\353\310:\251\203\366UCVjh\2410\244\341\352pd?3g\222\333\220(\374\275\020\324\261Na?t\0077Q3\365\335\030\272\215b\206\024\034\273\\\014u\024\300O\006/\210\253\300\005\017\023\216\226\372#\001{\325\362\254^C\367\244\026\324mn\253\324Ue\206\240\310\247\236\216\202\327\367=\224\243\225\214M\356\300*;0z8\247\255\303\323L\370\035[\351]\301J\344\322vMS\030\032\000\227\350\203\017\002\022\260\300qa4\017\226W\353\334\265\302F\327\216)w\254c\271\"Bo\240\353\314\020\316\310;<\222\210\025\232M\250l\324Q#I\"\265\020q\025\257\037\331]\0015\036\212\016\344\017\020\264\\\203\014 \217\033\000z`W\275\317^\337h\315\327nI\034\014\254\177A\235A\005\251K\256\270G\343\266\264 e\256J\017\252P\tZ\347\004\300&\211\255F\037\207\263\355\244\3200Dz\274/?t\032\303&<)\357\317I\247\247\314\362b9;\2052_\252\002?wk*\000\356\211\242\253\027\254D \023B3Hmu\203\336\356\310@\301\223\223Q,\t+\232\351\204\367\253l#m\212[qg\302\316\341\373\276!_\230\304D\225\006\252Z\360\274L|\202`$\270\252\2324\361.\253\207\256\256\313\206!\307\247\316]\003!\356oO\232\214H\306L\252\224y< M*\007\002\366jx,\r\277\006\260f#\007\227\366\252\364\356A2W\345\320z\020a\223\210\025\235\302\260\213\374\034\024\353\300\366\243i\rd\362\020E#\310v\034\212\251\360u\204{\253_\245\nJ\356y\224D\023\005\372d \000\252\034t\007\325Y,|\021""\t\366c\236C4\207\323\242td\336q\210\221\326\304\350\017\373m\344J\310AE\226\024b\233j||\250\336(\270\230*lS\021N\033\317\354C\3352\307\002\235\257\304#\036eWP\367\323\021 \034R\313\376<\315\265tNI\377Sh\032\002[*\213\354\320-\315\316ANL\363(H}H\001\003B0\\\3445&\304\344Jz'\030J\362\326\276\324\006#+\261Bld\204\251\225\002\257|\214\374fz\231[~\3140\363v\264#\246\033\256\026\361\030\247\256d\321\302\313(o\317:\250\016\210\013\222\002/V\331z\251\335JO\014>\271\"\250\r\376\t\235\206t\002\236x\354\027\020\354\343\320\226\306\262\276P\274\003\004C\311\036\022\344E\227\325X\201\265\265\r\263\r\211z\034Z\301\247O\023\031\264\226\363\242\341\200\266\222\264\345\017l\317L\312-T>\307\364\252\324w\240p.\202\237@\364\001D\251\2242\346\324\207\332\264\022\350\325\260\006}\367U\257i\307\324f\022\216I\203n\367\314\243\25645&\314\230\314\376D\001E\030\351y#*\235*\317\345\026&|\227\245\3325\323{\236Sn\252\324\353\351\036,N1;\311\351\240h*eM\366\nD?\005\205\024\013\233K\277^\237\375\327\252U\242O\311lk\211\310\007\032\316\t\177\354\355\313\202-\0206:'|\240*O4\301\010\335\312\230\314\\\202\224\205\234?%\343\002\262\340Z'\007\003\252E^\2341\273\237%\370M\271)\324\271-\222l\021I\321\357\304+\242\337\201\273X\0108\021\215\034\363\266\364\235_\355\032\242\215\323+?d\037\326Fd\"\276\014\177\211\366\205!\266o{H\224R\244C\002@P.\272w\311\351\3311\336!W\322<7\027k\374#\241\177\210\345\235\014rq\266\330\357\313'\312j\325~\230\203\212\003\177.\247\006\034V]\354\267\007\247\226\363T\017\211\216\322\273\374m\036^~\370\362\177_\3128\226\231#5}\261\031\010\255d\243{\r\355\321s!F\334\031\014\340z\002#'\010;9U\002\013\227'\322\371W\333\374\245\034f\006\306\205\365?f|`\243\204\231\010\003P\351\312z\225e\236[\304>w\027)\237\315\001Fn5WZ\332\357\312\261\263\205'\nb\202\241Qc\347>\251v/\301\355\271B\302\233\366\200\300D\t\266\334\3052\2276\354>\227?6\372\203\273\216\223\335amP\343V\020\200jh{\321\256Qt\014$\010\264\320\350\3321\332\302ATI\332\037Q,\311\220\335\266\222\202)\252\210_\264m\005\220\370g\371D""\232\177\220NuUR>\336C\320\020#\231\013\377\232\3521\233\206)\360z\326\215\0041' \231n\330\2728'\266G\241#\235m\336nx\326Lul\227\346\010\323\257Z\215\021\266Y\307\357be\264`\377\352iP\256\325\320\\\316f\202!\023\304H7\320\002\232\232t\315\273\210ij1v`wA\374[\337\030R\315lKS\177\304\223c\340T1y\201\321\307\264\303\212\334\210>\031:~\005\277z\262/\010f\216\347\030b\260\025\240\010\014\367I\033\203\303A([\305\310\360\345\212X`Q\\\002\223\205\250\r\331\354E\301\354i\013\216|1\327]\2330\350\314l\213\254\277\217_\344\017TQ5\220\276\270\356R\r\372\3034\310\240\366\312\266\325\023\031\211\265Z\0143r\005\366\336\271t\3557\026\007\301\363n\332\3016B-\201L\2669G\250\361^\237A\031\3341\n\207Lr\241\261\247\004\267\371\323\247\030\362(\340\257\0036\243\320\000Fa3\035\340wo)\371\263\307&\356\367\363H\000SG\177\313\335\240k0\306\234\322{\341\361\247\320\241\323\311\377p}\204:Z2\264\342\317\321\265\364$u?\t\362\360\230\273\200Bs\037\001\214'\3048\007\236`\207@\275A\376\363\276\232\"F\0353E\375\245\001H\300\263\366'\202\314<\236\344\013\n\237\211\246\2716\t\276\371H\316\213\303\277\035\343'{\\\311HT\264\037\261\320\000\222\236(\303\013c\334\020\221!\211\004\261\354\221\362\233XP\351\034\344\315\\\322\033h!\322\344\245\001\242\025\225\370i\334Kn\305\345\372\301\037\306\310`\036\2644\255\303\013\244}\025\"I\224#\314x8\327\307\351\235\020\230\316\356\026\331ih\321\026\275\242\314\356\265\266\326\n)\304i\231?b\344\311P\343G\322jS\016a\373\t\243\223\310\310n\211\301 \2038\275\257\003\315kR\204\243g\360\321\202\331\367\0330\365\312\366;B\312K\343\"\001E\030\025\233\303i\232\270\247\324\233\265\321^\345\351k|fYW\310\300\317\026\343\231\263\202\037\242\004'\250 \314\227\230HB}Y(4q\212`\242f\350W\376<\"T\277\035B\033\362\023\315u\265\326\235\254\t\260\334Jk\r\030\002o\031\347\262j\340\022zT\346\372\347\214\216\334\304\227G4\221\264l\311\234\342d~\324\036$a\306\370Q\23389\013#\024\3250\306o\345\031w\005T-\320\235LVZ\317\\\205\212v~}\r\204`\212 \322\007\201c\261\254\210J\352\207\336o\205\351""\021";
    PyObject *data = __Pyx_DecompressString(cstring, 4147, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (4152 bytes) */
const char* const cstring = "BZh91AY&SY\322sSb\000\002f\177\377\377\377\377\377\377\377\377\377\377\377\377\377\277\377\377\377\300@@@@@@@@@@@@\000@\000`\021\033\357R\361\3571\275\336\356\200\366\332\361\340\345\353U\261Z\005\353u\212H\026\314\275\333\2551U\267\243\275\357SA\361\030\004\240\221M2i\251\2612\236\206Sh\305Oj\032O&\006\230\221\030L\232\014\312a4\315@\321\221\2325\036\004\232y4\233S!\220J\020\t\210 & \210z\236\251\342\2157\252d=L\232\001\220\000\000\000\000\000\r\000\365\0002\001\251\342\021!!=@\320\031=CG\265\010\307\250\200\003@\321\240\000\001\246\206\200h\000\00023P\004\232\221\020)?E2=G\222m\250\310\200\310\000d\320\000\000\000\000\000h\000\320\000\000\000\211\352\232\220\000\000\r\032~\250=@\036&\243O\325\006\2004\003\324\364\236\240\032\000\000\001\240\000\006\203@H\210 \231M12FI\265Li4\364\2324\323 =A\240\000\003@\000\000\000\0004\000\321\240\323\247FV\033\026\222\007\236B\345\373A\223\314\376v\222\034\364,9\317\237\264\032\")\323\024B\256=\030\254\215\250)\005\357>\220\227\244\213\004\205\213\343I\252\205\377\221\000W\372\177\302#\010,\005\201\024\204\213\"1[\001b\373T\204\242N\264_\332\206\346\377;\177\313[\363,\020,\262\346\225\252\325\246\306\321\026D`\260P\024F@\304\202\301\340\334\220\232\306\027\276\341\204\2327\270C)/&\t\030\305\005QG9FS\000\024M\324A\205\2520\021\336FU\337\216\2767{\014v\253\001\314\214\026\333\216h\341\236\345\203\234\324{\205(\355\332K\n\222\211\013\010\364H\n\004\331\206\225\t\316y\241\246\010\035\230UV\240\267,\026-\211\214\221!i\314ua\214\234\206V\204\245kZa\"G|\260\247\220P\245\237%y\025/A\2447cM\323\311S\301X\300\237\233Q\0001\221\r\215\232j\266\270K\332\255\276\330\315\333\307\341\223\301\274\356\373\322_\351\211\326\377\225}\031\300\322c\203Z:\t\312\034\370\215\217\307\216\344\234\225\263`\020\332\301\027\306\177\341e\030C\005\255shx\327\364\357V\257\350\345\002\266\346\223\333\020\235\007\222\177\272\235\336\344i\335iV\335\354\357\266z\341yw\274\024\036\247y\222\014\256sApr\307>\177#r\3718KL\362V\252Y/\241\355\341\241\340\221\035-b]\266""\221\345\221kt\216\362\222\371\340a\222\323:\312\270\\\242])l\373\236\256\343o/Szt\256\315.m\332ssk)O;\336\030k\256\034+\227\306\350\343\302\253\350\2551 \234\275\034MF|\372\033f\322\223\325\375\253|\034\371\363\313\354\036%\2126\263\210\205\361c\332(\344N:\003* \354\310d\265I\005\210\310\217\000\342q\255tv9\307wo>?\205\315\237\013\201\256j\233\254\rP\317o$lof\t\315t\367\360\203\377\221M8\3108\275#L\346\251\266~\2570\221\225\305\211\177\253\363j\205PY\005\254\270\036B\260X,\312\037#\317\232\316\221lm\347\3705\305#\302y\020H$t\360\210\246rmt\361\344\231}\273\215g \257\235xP\227:\372\256\316\322'\217c\313JJ\244\244\203\n7N\021^\035\231(K\240R\027E\262\020t\33661\247\207/b\231\034\"$\024$\033\322:[OD\366-^\260~\034v\304\210\302\315y\363\247\004\354\243\007\263\273\267\206\2656\342\252\351\306\020\t\222\321%\244\263\t*N,\221\231\273\273\230\213\270y\352\316\206\013\302l\001\372>\210\242\263%[Td(`%\365L\274\270\247\204\360\243C\310Q\301\247Qp0%TYu\330\2005h\331\303\034\350U\237\265{G\212\202$\2440\005A\202\202c\3212\210\"\020+R4\354\313\261\307\250\331x\302\025\314|M\336\224\242a\261\200\323\245\346Q7\327\nl\204\221\213\230\211}\000\206\346\305\354\335\364>\007E+\264\227\020\224\341\220\343\326\304\227\215y\035r\t>\030Y|\022\226\265\033\013~\261g\351\362\260\t\342*\232\312\355\313Lh\226!\305N\361(\2233;\rW\225\310\311R\272\347B\t\004JQ71\240\341\226\252\257t\025\321\035\0108\360\2634\222\324;\004<~\237\220\375\236\263\305\225\322\371\323\327\366\331\277\232\343\221\r\201\341\352\200\035F\341\311x0\303s%\2715T\264UUSIJ\274*\224\260j*\202\255\360\361\204vj\347\336\336\tL\240RJT\261NF\351\222Y\314b\270\205'\004\305\006\275\302\305I\021\356\007\261\360\327\206\224\337\322x\250\330\235\357@x\343?g\233`\273\351\342\224=M\223~\024\nm;\2140L'X\261\010T\274\344\264\206F!\020\202\252H;U\032\265j\303\335\030\252n\366R\017\003p9[3\231%<-\031\250-\021\233\nv4!\254\010\030\272\233\243\007Y\0246\217E\316\212\032\302I\r\260\206\364Fc\223\032\223\020`D6\0146\303+X^\t\001\2102BJ\310\"W""\023lN\214\n\025\256\266\36046g\231)\306\350n#\"\365)\3172|\350D\005\313\314`\342\203\327b\240e\005%=p\265B\203\226\341Cl\213\331\340\315\255\327d\254G%\206\310\024A\013\031rnr\323\240\2702m0K2\251\353\230K6\323\025c`\323\262\205\273t\025\246\024sB\223\314\334\216EL`\326jM^I\303\206#\001\224\246\000\362\205\032\014\317\003\304\362\200\305\0250q\2114\330%\246Q\350\202\240\213&$\"%\277\252\323\357\327\t\034\332\333d\335\027\333\202i\352e$\346\325Lx\366\2233\200\004\241)\320d\214\020\270\321\021\020\367\273\033\316\340\347\006\023\244\367\252\266\315\216\271\366\241\307\232\313\020\24684\3160F\206\231\301\307\rC\246j&\321\275\266pd\370Y\337?\003\003\020/\034\371\353^h\312\365\\]\267\244\200\333\256l6\036\235\024\2565\253\034%\035*Vg\217\003\223\337\330t\353e\336\347}5q\347\030*}\363\026\2267\246B\0149@,P\261n\315\335\315i\341\255\214\250\303S\315D\002\210(\242\212\027\203uqA\003S&\004\014+\331\276iB\007\227^\201\221j\372\213\210*_\224\351\343\217\215\234\325\\md\032}j\2213XA\234\341\206\225\330\213\241\030\257g6S\t\310\325\2261\340\2153\360\333\2025x\353@Hh\330\300lO\236\006$\250\340\2161\300\327\323l\307jj6\266\3143\241\225\232,P.\361\337;\326\372jdl<F\225M\212k0\354\230\231\317efCw&$*\2339\355'\306;\246\320\313R\210\312\302\222\020}`\374t\224I\317\226$\303E|*\332\355\007\263+-!]\306\343\243\177ZC\270\3348:\334\210\360hF\022rk\350\205(\224\244N*\242\242\271pG8@!\251\301\030;\0012C\022E\206\323\032\311lu\\\244\3112 \246S\024G\013Z@z\226~\004\010\n;\325'\206\034\035\020\304U\225\250=\022n\025F}M\366\010.\364e\314\243\322\013\000:\017$_ZB\351\313\257K_\025\224k\210\313P\302,F1hZ$\243(\251\007\371\216A\243\214\323Xf\321)I\217\310\2602)\036\207]\036\366VwM\034\260K6\343\024\n\303\225\234\210\243uo\\\242\350\353+S$\310Q\033\014\025\304\005`\243\264q\013aF\026\212\032\3517\276h\304\202\350\000\272\206\034\3122,\253\257(h6V'\n4U\325\311K\224a\351CU\334\245iw8f\325\007\340\327\\\252\224r\324C\330\010\005)D\256\351\336\254t\253\020j\311\2169q\023D\006\025\024f\006a\221B@\316""\025\225\2437\345L\351\000#\20440\204\001\021]\361\347\016\374\033*\333o\027\313uL|\313\335\251g6\325\216\231\025ZxR^\215\370\304\272\216\204R\225\n\321\004\025&\251\330W\203\010\324\025\032\314,\343@\264Q\262M\375\274\244\025\\uB{wz\236)$u\2646\274\256\371\032D\034\345\225\225UTl\330\321Kt\2562\326\033XMk\274p\305\2421\265{\374L\223A\030c\r\264\3366\350\030-\n\322n$\230\216(d\350\370v\232w\346E\305q9\322\241\327\256:\363(n\352\010p\266\240\243\366E\346M\247h\203\n2\014\214\030\223C:zN\034\235:\312y\250\2429\263\345\004\327\227WAo\024#v\311\361\367\231\226a\207)\342\203F6.\366j8i)\260AQ\2523\224F\010r\353\\\021\335v\234\355\244\3511\271\241\013\277)$f\257\311\230\345\267&\313r\317\243~\006\232\007B\251\014\370\300\241\024\223\210\t\206\343\341\253\310\213\327\327\343oCM\025L\227s2\026\274\007Y\354\014\355D\306\327o^\312\322\340V\312\356\217\2730r\323\215\342\001\032^a\360\032\260T\221\201z\004-\355+0(a\332(*yaI-\023z\362\326\334\036\251\243\r!\352C\030TgZ\243\352\212\2415\331\236Z\222\252r)\014\201-\262\266\260\32426A&DhD\223\014\247D\367\24692\030\341\275f\271\241\211\203:\365\356\2474uk8\207\242\230T\362&\235\027\347\270\006\230\033ol\354\031\321\226%Ln\224\200\201\204\203\024\n\020\306\343\010\225ZNT\315\263s me[\017\230\226\260\031C\336\320\251eN\374\224W\n\204\201*P\346j\322\311\221\275$\024h\224\031*\276;\"\363k\000\226.\212 P\324<I\212\032@\034L\352\\\022\033\0160\250c\\\366dl\303\003MM'L\241\025&D\332\006\323d\255&%C\023p2Ws\004\204\254Z\247\007G^\324DW\305\n\2177]\016NA\2727\334\037\203\234\344\364\204P`\232\323+\030\032maB\024\213\255p\2518\254.sx\332F1\203\224g\317\326U\034\245\335\274\207J\365n\220\356\030pbKklk\302\0337\344M\313\336\325R-\365,\226\355\224{A3\213;\270\256\016\316\336\025\360\314\312I\332 \n\214\225\233\035\376\3477\023[\205q=\2626#\267\230\250\313\243ZF\006\313!\250\210w@:Q\334y4P\025_\242\";\017&\243\360\0324\331\004\313J4\352\340\322\201\035Q<(0\253\023b\003-\303\326\260\331P\346\351\304\246p\274[\333\252\337>\t\003\247;\313\004:\330""\023\303\337\360\346\256\222F\303\000\264\345\240\360%\223\270\r\004dY\030A\220Q\001c\021Qy\335\206\310\320\324\215\276\244\211\031\361\006\221\325+\262\247m\233\347\270\002;3\256m\243\022*+3\235\207Q\316t\017\227\n$\372n\221\205\345+\304\212\336\222X\274e\257B\000I\370\306\322b\004\n\343Z\202E\004R\271w|4lE\230\035\333\311\255d\3276kq\330 \314\202\250\313\264s\031\252\315\322\253\245\243}\254\033[;&\321\253\013v\260\351\222\006\326u\244I\017\337\235\n\006\333}\252\023\266\376.!{Bo(\213n\303\033\332z\010d\006\301\224\030$A\321\231\300+HE\353\020\312V\205\216S-\275\367v\016\024\217\217\232\276f9:\312d\027#L'\214\237\000\312\361\033\216\016\221\025\322o|\234z\355\036\343I]\341\027\312T\275FTR0r\n\256J\224\215\000u\310\n\356Kk\247\322\034\200\231\372][oy\215mQ\311\023f\316~\177\030\350\353N\351>no1\232\355\262\223\304n\207E;k\253\236\034APeUI\022\273 \"\000\203k#\245`pt\200K\312rYa\274)\337\001\200\300L\305\205\343\224\310c{\202\331\217*U\030\267e\221cl\2251U\333\031W&\273/P\353x=l\265\"\310\231\211\336\\\334\313Q\021NX!\177.\341\\\236hjvf\006Ja\240\341\021\020\260\265DA\005\252+3`y\234W\034\326-\2555\3613\020\nYz\255b\361\024a\300@\322J\026\257\014t\234\352\3737\363\253m\333\241\233\325\367\022!L)\224\354X\211\"\034\233\207s\004{\030E\n,W\010\242\235{\033\310\237\213Y\230\2218Ro\344\253e\330M\200D-\037.G\273\313\260\330\303\306\303\0323\3159\272zz\243#q\326\033\272G@%\263\301\263\307\276\226\277.\005;]\034]\255qv\031\235\374h\024\326\020\004\" \3448\030\0304\036H4s\261\033\3757N\007\227f8\r\256\233\326M\n\031\201\244\304\235\020\001\347Q\346\001\265V\n\264\240\322P\346\355\324\206\316\353\301\037\n\352m\331q\267\214\307\333\307\342\225\271\363\006\221<\270M\3248\001:\217R\3542\342\224qp\243\0342\335\267\273\357\300\214\223\345@\237o\212\223\225'\251\021`\221\221A<\n\303\010\227\252\"T\344=\226fO[sQ+\357\216q7\214\262\232\2036C\216aB\221\244\240`\335\251nU\213^\251\214C\322\207\265\205C\217\331\357\3561Ubn\304o\010\0146\263\343!\276\252l\273\240\273\225\005=\010{\025""\315\265mF\376\252\207\r\255^b$6\024\264\314\3430y\273\335\365\335\0031\305\325\205\346\341\016\247\3668\361\306\216*\201\221\310\346\037\330{`\216\013z\217q\024P\344Sb\337\226\255\\\337qZ\332\276\216o\tq\017\300&{\370\340\272\013\026\2775W77;9\336\nmA\305\337\265\245\245\263\374\371\r\"\336\332\351\306\243\020U\271\325\364\242\234\357{\334\323V\321.\333\267v\036V\025\232\345\323B\355\333q-\262%\311\316\2661o\322\332\035H\002\351$\027G\375\371.\226\240\273e\326\\\304e;\214\276\355\017J\\^|\305\266\372m\316\365dZ\271\242q\264m\304\256\261\016\361\217\355\352{\324\317&1kDb5O\322,\356\013YR\331X\371\235\220Vh\235;\375\225\315\320c\335\t}\330mZ\342\363h)\242/\205-\026\341\017Y'J\323\350\303\261\253\002\345\255\034\363{C\350G\225<EaZ\276K\243\207\003\241,\227\257\242(I\263\003'y\236\322!\004\311\3546\3047\017h\274\025\333a\351\267\311B\212LH\256\301\331\003\035\202\2773'\305\236\212+\326\250\255\256)\222V\022\260\325\326\201(AH\000\2546\2670\206\335\2650v\325+\314\273\241v\325U%\272\037\274m\024Z\272\034`\220_\256\004\240!\266\303U\206a\331,K\030w\235>\317J\251T\231w\333\250Y\324\231\342\245g\257\370\370\272\351\341\300\322\273o\255\303\367\035\323\251\1777\036\366\274\212\244o\007\356^TMtD\256\035\323]\023\030\314`\027\265\315L\322\271\254\2411pe\005\374\256\206+I3\244^s\266\371\206,\314K\376\367\312\222\262\2072\257\317\003\353y\346\346|'\263\267\257\357\260\226\177v\251f\014\370\257\006|x\2351\262\250e7\251\004*WA[\267\250G\006\000\277PMI0/\205dX\313\016\321\205L\335\243\022\201\302\03060\200\242\031\260f\305\270\027\275D@\270F\367D\242[SR.\025!\023\306\3540\"L,\027\005\336\203\214\241\005W\263\034\253\305\306W\255l\361\231]\026\313\316/#\000\302\234\033\315!R\n\210\257w\020\312C\031\262\234#XK)\231\007\377\027rE8P\220\322sSb";
    PyObject *data = __Pyx_DecompressString(cstring, 4152, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (4168 bytes) */
const char* const cstring = "x\332\215X\317_\334F\2267cf\006\307\304\320\206\004\362c\234nl\214\235\304x\333\306\261\235\365N\246\r\215M\306\306@\3438\231\315\256>\352V5h\255\226\204J\002\332\331\314\346\310QG\035u\324\261\217}\344\310QG\216\375'\314\237\260\337W%5\335\240&\346\323H\252\252\247WU\357}\337\367\275\322\374\007y\374\225\362\025\313sjl\211\361\232\243\333\256\345\344\371\266\345\031Z\276\312\3625\313\344\272\306\034\246\345\365F\303s\325\252\301\346\305k\213Mw\3332\347\323\233\325\260u\2039\363e\307\261\034~\272w\331s=\207\235\356}\301\366uL \273\357\246\335w+5\3254usk\336n&o\254\031l\277_\263\350\021\202\314\341\345}\233\325\\,q\256\373\244\3465Vs\230\312Y^7\361\323\230\351\252\256n\231y\203\3552\243G\316d{\206n\262\223\036\022?\347\325'\313X\344i\213};\313\377\272b\ncq\027\362\275\257\tk\255\230\334U\315\032\343y\253\236w\267u\236\257\031*\307\025\323\301\314\036'\003C\206\251\032I\250\371:f1\325\006^\320\351\005&\264\324,\215\345-G\337\322M\325\305P\335\261\032\220\345\256\003s\345\255\352\377`\013\322;/\365}h\204Z1\237Z\345\330\227\226\347\266\212%\254Z&[\265\\\006\265\252\233\3701\217\025i\314\320\253\314\201f\243)t\302\036\016\t\231\371\265\362\332\235\205G\013B\211\303h\032\236\347^U\354A\356\251\352\351\206\013{\271M\233\361\371\374J=\337\264<\030\027\253p\255\274M{\355y\001\0332\363\234\271\364\220\237\203\027-i+\005\257c+syMw0\211\276\313\350\355e\325\340l~\315\342\\\007\374\310=\203\r\275\301l\207qta\307\322^\\\370j\0368\357i\322~\325|\303rX~\213\001Cz-\017#\271\216Z\353j\252#\020\324\374L\352\210\231\374-\025{\260\032\314\325\033r\013R\241f1n\316\271h4X\352\021z\351\366\374Y\317\367\254\000\363cr2\2144Q\002\346yE\321M\335U\224\274\312\273~\267lZ\225j\344i!xo\313k\320\336\311\033{\272a\020\202\022EU\265\3666\277G\326U\371[\002\005v!T\320rm\213\353\244\350\326\355;\256g\247\201\374\244\"\340\223\005\351\327f\315\260Hm\2020C\007\"T\343\265\t\347X[\246\376\016C\265m\225\254\306\234\231\271\271\271\231\231\231\357~\276\373\353/s\377\256j\232\002\257\262\232\214\327\252n\272""\232\316\211>`M\\\353wR\324\002b\311\363\267y\216+<<\367\353\0349\010\357\347U\303\260\366\2306\3675v\342a\277s[5\235K\025\332\274\275\217\377&~\373O\244\006i\332\277\002\367\006\003\342\340O\335\240I8k\200i\014\313|Z~\266\262\252,o*\225\315\215\225\325g\262)\237\027\237\2276*\t\t\t\256I\2367\341\356J\315\262\331\351\366<(\306\200\023\317\364\033\226\365\326\263\007t+\333,\343\025\317\326\020w\247\t2e\302\245\362Ryus\251\274\274\264\236,\266\374be\271\374\242R.\257.\235\354\246\257\241\224\177\\\333\240\236d\354\325\262$PH,oJ\227?\205\343\3362\267\202\360aY}],\246\203}\222R\244*\345\025\223q\204\377\226\"8\262_D7\025\240\260\241\272\n\007\307\352u\2359\375\002\266e+\251\036~v\n\333\343\333\347\215\203G\224\3149z-\241\300\030\225\305\322\252\340\222,\n\317\352\203\001\330\016\266\237=\264\255b]\203\006\023\303e\017: \251\001\203[\330\214\2264\021\252\003e\0309\363\275$\211\213\024\231\033\316\225!n\021\371]\001\2678\315\201\262\224-\371\300Q\207\031*\361\266b\253\356\266L\373+\004\336\225\345\225U\272'9\177\265\374\346\305\312jyu\371\357\213k\020\354I\360}\231}\255\351\260\375\244\321\373<\017\343\233\032\226*\370I\221\264\241\324\t\036\204\013\201\026\226\371\002\202\315|\037\371*\333\"Lu%db\310\020\031<.\327&T\237?L\270\036(pj\221\231\202\304l\331\003\rJ\024\344\261\276~fj\347o\215\004\316\033\005\335+*o\232\265\376~\253\236)N~\355\357\331Gpd\274/j\260\214.\340\234\262|\326\210\314\377Y#oYs\317r\264\254\241\244\346\313\030b\375\362=\325E\326\316\022=\331C\373\375\2532\211\236\014\244LE?\263b\001\312\201\356\355\216\016\300\211\030\177\017\230\330\214\275\355\357\360\\\205\n\206\276N\322b+H\265\010\277\032\352\243\276\030\234\367\222\212\240\037\035\212\262\326\334\307\377\022JFe\025;\337`\365\215J\232\253\222wO\323E\006/\"\0256\025%c@c\314\0368\270\345fv#\3003\273\263\245\261\237\214~\301\264\274\246\332\330q\017\327\236\221\323\271\"\013\035\301\244Y\303\3669\303<ei*\236\025*!\025\"\343\354\272,\2737\311T\003\007e\256\0328,\263\325\300a\231\257\006\014\237\312X""\347Hed\231s\244E\2369g\274/\323lv+\243\315.\3566\035\217\275^-\275,+/K\213\317\221mdc\365\025\362\020\036dk\243\374\242\\\252$\215\312O\225\223\221\037\312\033\225\225W\253\275\305\356\212\211\220y\355\352\006WpZ\300\217\246F\205\212\324\242('\247\030N\215&~i\224\340HR\327\367U^\323u*\323\035Wp\237\270(I-+\032\272\005\312v,\317\245\255\253{\252\356f\247\241\214\314\203\002\273jYFf9V\305i\366mr@\343\325&\016\231\216\2436\351\201\327j\032\253\327\266\235\232\336\260-\307\025\3473\304\241\270\301\310\250\367\033\324$\222\303\214t>b\304\030\202\004\316\346\267\254\224v^\026Sj\r[@\235\316E\364/|\336\233\316z2XMV\305\n\035\277`\265\335\376\366\256j\364w\354\333\016u\240\232@\271\341\202\223\222\033\316\270\311SC5\325-\346PK7=\226\322O\315&\223P(\322\335s\034\314/\355X\333\3234V\365\266\024.\031-\251\377\345\322\345\265\213\361^\316\202\036lM\0039j\372n\303\002V4\253F\027\217\342@\030\004\007\026\275\316P\2322\223\324\210+\254\225\225\250\317\344fE\221\tY\351\311\313\314\304\021\221\216\362'9Y2\004\222\261\310\307\262~\024E\021\315#\217\006\031T\007\3631\033\326bX\260H\333\312I\362NRfo\212\356\313\312\375\211\270?\367\246\351\026~\250\327UW5\310p\202\004)\246N\3500\265'\356\330\\]\307)\330h\326\rKuQ\357\313\222_\034\014\2115\361\377\216\231`\323~\264\021\026\205\377N\272e@2~\322#\316\025\212RG\202\223W\027\321\304\353\242\200U\272_#8b\342\024\337e\026\343\003\362\306\251r|\000'v\311\357\014\313\241\003\030\3342\254\252j\310\274\367>u\360{\224\2762=$W\266\277m\031\232\334\024\3275\034\246\266P\2740yU\272Gi\311\030\310\034g\217^\350\002\207\031\272\333T\010\315:H\300\353\3364\261g~\266\264J\323\020]ul\220>W$\217\302;:\305)@\000\345r\355:\327\005\021[\206\007\337Q\016N\311\263?\037\367\247_\264\034uO\347\202\216\211\3408\000j\250\215\252\246\202\310\267<p\202\204\213,!\340\036\374\024I\035\240A\341\231\344\302]\330aK\236\353{N\367\262\310P\224\206\nC\340\372\226\024\212cOC\265\033\352~\2035\254\006\343\234fR\310\365\t\3556\204\270\245y4/\236\034K\000Bg\030\223\234\222\\\331""\236\\a\177\375I%\247i\231\206US\215n\265y\252\354D\212\262\000\355\323\365fF\211yNU)\201$r\262\260\250\374<\305a|G\263\270\345\302\006p\003slUpg\302\226h\001\242\t\241s\372^E\220\026\321\336\023\"\324\006ES\255j\033\"\310\0013\373\314\027\002`\303\266\366\024\nd\232\205\036\200\rq\221\321K\252\316|7H\013\336\364\256\020$T\335@\214\333\373\232\335\004Y\323\307Cg\027 %\312\3426\312Z\205.\010e]>\365\013\310\276]\031\275\370\333\361`{\341$\244X\035\222*\221+S5\201\030\344\n\257\206\246A_\227\223\000C\213\366\214\025\030*\215Q\245\225^A>\250>vQ\2113\315!\226sDu\316U\314/.\024#\211y\223\233\"3T\335P\267x\267\313C\232\025A\227t\010cp\372\360\204\274S\347\310(\234\331\340\315\001\205\350\200\017,(\232\251\322\020\273\305\023\262\234\352\001\370|\033\264\240\234\366+\242\245Fr\206\345\302h\300\n\270?\201P\232\354\270M\337\027\367]q\027\366\302:I\256\007\206\224\326E/\337\323\335mQ\264\247\227.\213\3633G\030\3565x\2237\033UPzS\212\272\222|\020DM\001P\232\030^\260\366D\215\223b\026l,\276\224z\264\313\354\263\217g\352\304q\311MC*\223\337\362\222o\220J\372\r\362\2048Q\252xL\\\370\236\352\320\367\275\275m\325\335\333\206\341iS\300\325[$\234}\001\235\246\216\302\341\235n\2575_\211\224\221\377\362\302\005\361=\345\302\231\362\362D\344\326\256\245k\267/\\\020\211D\022\317\205\224IOWQ\361\360\365\260x<r\371`\341\300\365\357\373\352\361\350\270\377G\177\275\203\333\245 \027\334\014\207\342\341\257\242\036\211z\260\024\016\207\337G\265V.KVh\233\364\227\202\241`2X\247\327\036\373/\302\241\343\321\t\177\301\337\t\206\343\317\277\216J\035\264\212\361p!\314\035\217L\370\017\342\351[\321P\204\347\321\203\027\301\020n\361h>\316\027[\023\255\322\361\310%\314\022\217\177\025\335\213^\267n\265\013\355\205\366\316\361\330xGv.D;\235\221\253\376\214_\016\246\303\\8\033:\321UZ\354\350\301K\321q=\\\017\315\326\363\366\337\017w\216\256\304?\274\021\272o\204\245p]\312\2109\277\367\325x\370Q\233&>x\025<\014\013\361\365\207\255\235\366\320o\230},\036\243\2517[9jM\220\205\374\235\343\021\261rX$\036\233""\r7B'\276\375\037\355u\261\316\205V\251\205\247ilct\226f\031\203\321\026\342\251;\321F\344\304\305\362\341zgd:\270\024N\204%\232\256\354\177$\024\302\202#\260\330'a\341x\344#\377\277\302BX\354@\177\221\314\3668X\014vN\224\367\255\343\312\201\356\273\301B\374\305\203\326F\313\211\037\277<\222\313x\220,\342w'\233\364_\302L\205d2\371\346o\322\352\344\260\377\r\213xwl\374xT\270\364xt\354`\347x|\312\367\202g4\322\031\207Y:\251\360/\341LX\206\033I\034\376%5\211\211*\321\320\277\376t\341\303\\<~+\032\216\277~\322~\332\336>T\017w\217\022\003\025\373\264\\\017_G\2053Zn\206\265H \356O\275\233\370,,%\022\007\335\276/\242\241\264\017\252\205\0269\315wX\340\323P=\031|\024$\026.\005?JH<\367K\376\233\240\224\230`\334\277\034,\004^b\002X\247@\306:\036\375\220\024\334?\250\3719\262H3\270\010)\330E\372j?t\243\357\332\327\333\233\207\323G\271\343Ir\300$`\250G;\307\037]\013j\341T4\034-\265F\342G\317\217.\036\025O\004\266#\2653\371\t\242\346\247P\r\261\231)x\366Q\370]\253\320*&&\270\021>\213\244\227\350\211P\371)\302\241y$\220\273\354\027\222\000\242\305\317\2047\342\233d\347j\374\267\037\004\360/\307\227\257\207\367C\026\335\217\264\370\336\312\321\325\243\242\360\t\331\023~<\036\207\207\343\351;\321\372\361\370\307\222\006\310\226\037\005j'y\234\214\377\362o\255\241\326\307\255\235\337\004\234\226\342\3619\254s|2\236\3742\232\211\236\306\363K\207\213\207\374\350\306\221*\3268\037\251d\0357\236\230\027d\201\t\236\303\320\353\251\017\335\370\263b\353j\353^KB\366fX\215\376\020\177\371\364\260@\316\022s\214\373\303\010lA#\004\277KaN\3028'\335\371 \030\016\304J\236\371E\014\3771\330\014?\203e/\265\023\261I\377g\361F<z;\312u\225\nK\305\023w#7\276_\211+\233\251\327\327\177\313\320u\312\262\251\262\023\321\357\003U6H\305\217\301zoc3\234\216r\321l\264\323\355\354H\322\tn\004[\210\211\341\350yk\251}\3710\341\253\\*\366,(J\004\022\035\335\0136\342/\276i\251i\033@Kx\211(\305m\211\000\311a\257\025,\272\002f^\014\005/0i\036t]\214\257?hU\332\303\355R\273rx\361\260\230R1v\363i0\003\221\315\360Z\264Cf""k\317\035~N!\211M\316\204s\024m\237`\261\205\216\264\201_\3547U<z-Pe$\375\037`-b\223\322\300W\341z\317c\"z3TO\242\264\353l\260f[\203\303{\242Z\342\346\324D@s\250\376\236\353\222IR7\213\345!*\351\351/\301\272\364\323\025\212Y\377F\3741!\266\224\202\374\323PFUw\232\036\026\270rP\367\237\372,x\234&\215UxO\013oE\267Zs\355IXt\350p\362\260r$\223\205\234z\354\300\301$\005\371\350J\n\023\017D\241=\r\221\366\272m\341\264x\002\371\023\034\265\025UZ\177h\315\264\312m\231g\016~\t\nA\327s\027\t =\323\t\"\223\313Mi\356\224\203\004\017R8\255\220%\372\036E\202\002\325`\203\024\242\024o?GS\255ad\315WG\305\243\245xm=Q\034O \336OV\374$\340a\341\244\341\206\017\243\244\351\371\213\224\234~\207\"\316dF!w\257U \"\305\300\275\326uP\003\350q$\034\ns\347\263\306\223\366Y\004\214\035\274\003\004\347\342\302\303\226\013\232|w4qT\216\3277\372\206\036\303\205\233\207\037cI\263G;\361\360l<\373\362\350\277\343\377\374\2713\"\22278\363sQ\356,E\027\211yoG\223\321O\255\264F:U5\375\031\236\271,j\251\370\362Mxp]d\236x\022\244\t\315B\235\310\261\022\352\235\304\360<\300~\247)T;\362\226H\304S\337\264\352\355\022\025I\237G\311T\034D4z\325\277\341\353\204\353\236\311s\300\333\254\237\304}\021>\024\250y\350\337\004\336\206\216\257}\021\017\313\240\212eM\202;`\026\017\003~\362\025\362\177\021\251\213Sr\353\262\203\214\372\005\377\237HN'!\031\017_\013\254H$n/\236\204\276P\213\276j\375\243\r\363M\007c\341N7\314\205\036Q\351\001\367\177\016v\302\017\242\273\355)\304KN:u8\304\356\010\036)\275\374\353\203\013\227F\017\022\240\226\250\256\024\240\023\345\203\300\306-QF\344&\t\035\267\243\t\004\360\344t<\r>F\2710\232\206\301\"\220x\037\353\245\027hujg\204\352\304\177\242@\033\231\013yT\210Di\365-\010s\2102\371\207S\276\023\344:2\376\347\244\256.-t`\356/\203\247\010\370\371\326P\207T\336\304v\013i.\373G(\374\370.\230\000J\256D=\223&\306\300r/\215\023\330d2{F\364\215b\030\363\177\343O\005\242*.vP\027\345\250\260\270\035}\333R\342\2457\361\233\037\251\336*\371\233\301Tx1\\\010\367A\317\037\264\013\244\354C\221u\236!Z""\t\222\013\321\257mI\004\377\017;\251\316$";
    PyObject *data = __Pyx_DecompressString(cstring, 4168, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (9675 bytes) */
const char* const bytes = ".\n    A SourceDescriptor should be considered immutable.\n    Cython.Cython.Compiler.ErrorsCython.Compiler.FutureCython.Compiler.LexiconCython/Compiler/Scanning.pyCython.Plex.ErrorsCython.Plex.ScannersExpected 'Expected a decrease in indentation levelExpected a newlineExpected an increase in indentation level<FileSourceDescriptor:%s>Inconsistent indentation\n    Instances of this class can be used instead of a filenames if the\n    code originates from a string object.\n    Mixed use of tabs and spacesNoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Possible inconsistent indentation\n    Represents a code source. A code source is a more generic abstraction\n    for a \"filename\" (as sometimes the code doesn't come from a file).\n    Instances of code sources are passed to Scanner.__init__ as the\n    optional name argument and will be passed back when asking for\n    the position()-tuple.\n    <StringSourceDescriptor:%s>Unclosed string literalUnrecognized character\"'''\"\"\"?\\/}{';add_notecython.bintdisableenablef-string or t-string: single '}' is not allowed', found 'gcisenabled.pxd.py.pyx<stringsource>useless trailing semicolonBEGIN_FT_STRINGBEGIN_STRINGCHARSCompileErrorCompileTimeScopeCompileTimeScope.declareCompileTimeScope.lookupCompileTimeScope.lookup_hereCompileTimeScope.updateCython.Compiler.ScanningDEDENTDEFDQ_STRINGELIFELSEEND_FT_STRINGEND_FT_STRING_EXPREND_STRINGEOFErrors_FTFTStringBracketStateFTStringBracketState.__init__FTStringStateFTStringState.bracket_nesting_levelFTStringState.in_format_specifierFTStringState.pop_bracket_stateFTStringState.push_bracket_stateFTStringState.set_in_format_specifierFT_STRING_EXPR_PRESCANFalseFileSourceDescriptorFileSourceDescriptor.__eq__FileSourceDescriptor.__hash__FileSourceDescriptor.__init__FileSourceDescriptor.__repr__FileSourceDescriptor.get_descriptionFileSourceDescriptor.get_er""ror_descriptionFileSourceDescriptor.get_file_objectFileSourceDescriptor.get_filenametable_entryFileSourceDescriptor.get_linesFileSourceDescriptor.get_relative_pathFutureIDENTIFINDENTLexiconNEWLINENFKCPathPlex.ErrorsPlex.ScannersPyrexScannerPyrexScanner._handle_close_single_ft_string_bracePyrexScanner._handle_open_single_ft_string_bracePyrexScanner.begin_ft_string_actionPyrexScanner.begin_string_actionPyrexScanner.close_brace_actionPyrexScanner.close_bracket_actionPyrexScanner.close_ft_string_brace_actionPyrexScanner.colon_actionPyrexScanner.commentlinePyrexScanner.end_ft_string_actionPyrexScanner.end_string_actionPyrexScanner.enter_asyncPyrexScanner.eof_actionPyrexScanner.errorPyrexScanner.exit_asyncPyrexScanner.expectPyrexScanner.expect_dedentPyrexScanner.expect_indentPyrexScanner.expect_keywordPyrexScanner.expect_newlinePyrexScanner.expectedPyrexScanner.indentation_actionPyrexScanner.newline_actionPyrexScanner.nextPyrexScanner.normalize_identPyrexScanner.open_brace_actionPyrexScanner.open_bracket_actionPyrexScanner.open_ft_string_brace_actionPyrexScanner.peekPyrexScanner.put_backPyrexScanner.strip_underscoresPyrexScanner.unclosed_string_action__Pyx_PyDict_NextRefRSQ_STRINGScannerSourceDescriptorSourceDescriptor.__copy__SourceDescriptor.__deepcopy__SourceDescriptor.__gt__SourceDescriptor.__le__SourceDescriptor.__lt__SourceDescriptor.__str__SourceDescriptor.get_escaped_descriptionSourceDescriptor.is_cython_fileSourceDescriptor.is_python_fileSourceDescriptor.set_file_type_from_nameStringSourceDescriptorStringSourceDescriptor.__eq__StringSourceDescriptor.__hash__StringSourceDescriptor.__init__StringSourceDescriptor.__repr__StringSourceDescriptor.get_descriptionStringSourceDescriptor.get_filenametable_entryStringSourceDescriptor.get_linesStringSourceDescriptor.get_relative_pathTDQ_STRINGTSQ_STRINGTrueUNAME_MACHINEUNAME_NODENAMEUNAME_RELEASEUNAME_SYSNAMEUNAME_VERSIONUnrecognizedInputUtils_absabspathalland__annotations__anyany_string_prefixasciiassertasyncasync_enabledas""yncio.coroutinesawaitbegin_ft_string_actionbegin_string_actionbinboolbracket_nesting_levelbreakbuiltinsbytearraybytesccdefchrcimportclass__class_getitem__cline_in_tracebackcloseclose_brace_actionclose_bracket_actionclose_ft_string_brace_action_cmp_namecodecodelinescolon_actioncommentlinecompile_time_envcompile_time_evalcompile_time_exprcomplexcontextcontextlibcontextmanagercontinue__copy__cpdefctypedefcurrent_levelcwddebug_scannerdeclaredecodedecode_filename__deepcopy__defdeldictdivmod__doc__double_braceselifelseencodeencodingend_ft_string_actionend_string_action__enter__enter_asyncenumerateeof_action__eq__errerrorerror_handlingerrors_escaped_descriptionexceptexec__exit__exit_asyncexpectexpect_dedentexpect_indentexpect_keywordexpect_newlineexpectedextffatalfilefile_path_file_typefilenamefilterfinallyfloatforformatfoundfromfrozensetft_string_bracket_levelft_string_prefixesft_string_state__func__functoolsfuture_directivesgetget_descriptionget_error_descriptionget_escaped_descriptionget_file_objectget_filenametable_entryget_linesget_relative_pathgetcwdglobal__gt___handle_close_single_ft_string_brace_handle_open_single_ft_string_bracehash__hash__hexhold_errorsidifignoreignore_semicolonimportinin_format_specifierin_utility_codeincludeincluded_filesindentation_action__init__initial_posinitial_stateintintern_ustringisis_absolute_is_coroutineis_cython_fileis_python_fileis_rawisasciiitemskeylambdalanguage_level__le__lenlen_textline_lineslineslistlonglookuplookup_here__lt____main__make_lexiconmapmaxmemomessage__metaclass__min__module____mro_entries__name__name__new_levelnewline_actionnextnonlocalnormalizenormalize_identnotoctopen_brace_actionopen_bracket_actionopen_ft_string_brace_actionopen_source_fileoptionsorordosotherouterparent_scannerparse_commentspasspathpath_descriptionpathlibpeekplatformpoppop_bracket_statepospow__prepare__printprint_functionpush_bracket_stateput_backput_back_on_failurepxdpypy_reserved_wordspyx__pyx_capi__pyx_reserved_words__pyx_vtable____qualname__r""raiserangereadlinesreducerelease_errorsrelpathreplacerepr__repr__returnreversedroundrstripsavedsaved_posscannerscanner_debug_flagsscanner_dump_filescanner_statescopeselfsendsepsetset_file_type_from_nameset_in_format_specifier__set_name__setdefault_short_path_descriptionslice__slots__sortedsource_encodingsplitextsplitlinesstarted_ft_string_exprstartswithstr__str__string_statesstrip_underscoressumsysymbolsystringtentatively_scantextthrowtrace_scannertrytupleunameunclosed_string_actionunicodeunicodedataupdateuseless_trailing_semicolonvaluevalueswarningwhatwhilewithworkdirxrangeyieldzipPyObject *\000\000IDENT\000any_string_prefixPyObject *(void)\000\000get_lexicon\000initial_compile_time_env\320\004#\2401\330\010\013\2104\210t\2203\220a\330\014\020\220\005\220Q\340\014\020\220\t\230\021\230&\240\001\320\004+\2501\330\010\013\2104\210t\2203\220f\230D\240\004\240J\250c\260\021\330\014\020\220\005\220Q\340\014\020\220\t\230\021\230&\240\001\320\004#\2401\330\010\024\220D\230\001\230\024\230Q\330\010\013\2109\220L\240\001\330\014\023\2204\220q\230\004\320\034,\250A\340\014\023\2201\320\004!\240\021\330\010\023\2205\320\030(\250\001\250\021\330\010\014\210L\230\001\330\010\014\320\014 \320 1\260\023\260A\330\010\t\330\014\020\320\020+\2502\250U\260(\270!\2704\270q\330\017\020\340\014\020\320\020+\2504\250q\340\010\022\220\"\220E\230\030\240\021\240%\240r\250\022\2501\330\010\014\210M\230\030\240\021\240#\240Q\240n\260H\270K\300q\310\016\320VW\330\010\014\320\014$\240A\240Q\330\010\014\210M\230\021\330\010\014\210J\220a\320\0048\270\001\330\010\014\210O\2307\240!\320#7\260q\270\001\200A\330\010\017\320\017+\2502\250T\260\021\200A\330\010\023\2203\220a\220q\330\010!\240\021\330\010\013\2104\320\017%\240R\240r\320)=\270Q\330\014\020\320\0204\260A\260Q\330\014\030\230\001\330\014%\240Q\330\010\017\210t\2204\320\027-\250R\250r\3201E\300Q\340\010\030\230\t\240\023\240A\330\010\014\210E\220\025\220a\220q\330\014\020\220\010\230\001\230\031\240!\330\010\025\220]\240!\2401\340\010""\013\2101\330\014\023\2209\230C\230q\330\014\020\320\0204\260A\260Q\200A\330\010\023\2203\220a\220q\330\010\016\210i\220t\2304\320\0375\260R\260r\3209M\310Q\330\014\020\320\0205\260Q\330\014\030\230\001\340\010\030\230\t\240\023\240A\330\010\014\210E\220\025\220a\220q\330\014\020\220\010\230\001\230\031\240!\330\010\024\220M\240\021\240!\340\010\013\2101\330\014\020\320\0205\260Q\200A\330\010\t\330\014\023\2204\220|\2401\240A\330\017\020\330\014\024\220D\230\001\330\014\017\210q\330\020\027\220u\230G\2401\240A\340\020\021\200A\340\010\t\330\014\023\2204\220{\240\"\240E\250\021\330\017\020\330\014\023\2201\200A\330\010\013\2104\320\017%\240S\250\001\360\006\000\r\021\320\020(\250\004\320,<\270B\270h\300a\300v\310Q\330\010\017\210t\2201\200A\340\010\t\330\014\023\2204\220{\240#\240U\250!\330\017\020\330\014\023\2201\200A\330\010\013\2104\320\017&\240c\250\021\330\014\020\220\006\220a\220q\330\014\020\220\010\230\001\230\033\240A\200A\330\010\013\2104\210q\330\014\020\220\010\230\001\230\037\250\001\200A\330\010\013\2104\210t\2201\330\014\023\2201\330\010\017\210t\220?\240\"\240B\240a\200A\330\010\013\2104\210t\2208\2301\330\014\023\2209\230A\230X\240Q\330\010\014\210H\220A\220W\230A\200A\330\010\t\330\014\020\220\013\2304\230u\240A\330\017\020\330\014\020\320\020!\240\021\240!\330\014\r\330\010\013\2103\210c\220\021\330\014\017\210y\230\003\2304\230q\330\020\023\2209\230C\230x\240t\250?\270#\270T\300\030\310\021\330\024\030\230\t\240\024\240Q\240i\250q\330\025\036\230c\240\027\250\004\250D\260\010\3208H\310\003\3101\330\024\030\230\t\240\024\240Q\240h\250a\340\024\031\230\024\230Y\240a\240q\330\014\027\220t\2308\240?\260!\2601\330\010\013\2104\320\017$\240G\2501\330\014\020\320\020$\240G\2502\250T\260\032\2704\270y\310\001\330\010\014\210F\220!\330\010\014\210L\230\001\200A\330\010\"\240$\320&<\270B\270b\320@V\320VW\330\010\013\320\013#\2403\240e\2503\250d\3202I\310\022\3101\360\006\000\r\021\220\006\220a\340\020\021\330\020\024\220D\320\030-\250Q\330\020\026\220a""\330\014\020\220\010\230\001\230\025\230a\340\014\020\220\010\230\001\230\024\320\0350\260\001\260\026\260q\200A\330\010\014\210D\320\020'\240q\330\020\024\320\024*\250\"\250B\320.D\300C\300s\310$\310a\330\014\020\320\020.\250a\330\014\017\210t\320\023.\250c\260\021\330\020\024\220H\230A\230Q\330\014\020\220\006\220a\220t\320\0331\260\022\2602\260Q\330\014\020\320\020&\240b\250\002\320*B\300!\330\010\017\210q\200A\330\010\020\220\004\220E\230\024\230Q\330\010\024\220D\230\t\240\021\330\010\014\210E\220\021\330\010\017\210t\2205\230\004\230A\330\010\014\210G\2201\220D\230\005\230T\240\033\250D\260\t\270\021\330\010\014\210E\220\024\220\\\240\021\330\010\014\320\014)\250\021\330\010\017\210q\200A\330\010\014\210F\220!\320\023/\250t\3203S\320ST\330\010\014\210H\220A\220Q\200A\330\010\014\210G\2201\220D\230\005\230T\240\033\250D\260\001\330\010\014\210F\220!\330\010\014\210L\230\001\330\010\014\320\014)\250\021\200A\330\010\014\210G\2201\220J\230a\200A\330\010\014\210H\220A\220X\230Q\200A\330\010\014\210H\220A\220X\230T\240\030\250\021\250%\250q\200A\330\010\014\210H\220A\340\010\014\210M\230\021\230$\230g\240S\250\004\250H\260D\270\013\3001\330\010\014\210M\230\021\200A\330\010\014\210H\220G\2301\230A\200A\330\010\014\210O\2302\230R\320\0376\260a\200A\330\010\014\210O\2304\230q\200A\330\010\017\320\017-\250R\250t\2601\200A\330\010\021\220\024\220S\230\005\230S\240\004\240C\240q\330\010\016\210e\2205\230\004\230A\230S\240\003\320#5\260S\270\004\270A\270S\300\003\3001\330\014\023\2204\220q\230\001\330\010\032\230\"\230A\230T\240\036\250q\260\t\270\021\270'\300\034\310Q\330\010\014\320\014\"\240'\250\021\330\014\031\230\021\230!\340\010\014\210F\220!\2201\330\010\014\210H\220A\220Q\200A\330\010\014\320\014\036\230a\330\010\013\2104\210\177\230c\240\021\330\014\020\220\t\230\021\230+\240Q\330\014\020\220\t\230\021\230+\240Q\200A\330\010\014\320\014&\240a\330\010\013\2104\210q\330\014\020\320\020&\240b\250\002\320*=\270Q\270d\300!\330\014\020\220\006\220a\220q\330\014\020""\320\020.\250a\330\010\014\210H\220A\220Q\200A\330\010\014\320\014\"\240$\240a\330\010\014\210F\220!\320\023/\250t\3203S\320ST\330\010\014\210H\220A\220Q\200A\330\010\014\320\014&\240a\330\010\017\210q\200A\330\010\014\320\014\036\230a\230q\330\010\014\320\014\035\230Q\230a\200A\330\010\016\210c\220\021\220$\320\026*\250\"\250A\330\014\020\220\010\230\001\230\032\2401\330\014\020\320\020\"\240$\240a\330\010\014\210H\220A\220W\230A\200A\330\010\016\210f\220B\220e\2309\240A\240Q\330\010\014\210N\230$\230d\240(\250(\260'\270\024\270S\300\001\300\024\300S\310\001\200A\330\010\017\210q\200A\330\010\017\210r\220\021\220!\200A\330\010\017\210t\2201\200A\330\010\017\210t\2201\220D\230\001\200A\330\010\017\210t\2201\220D\320\030(\250\001\200A\330\010\017\210t\2201\330\010\016\210e\320\023#\2401\240B\240g\250S\260\002\260\"\260E\270\021\330\010\013\2104\210{\230!\2301\330\014\023\2204\220q\230\003\2301\230A\330\010\017\210q\200A\330\010\017\210t\2208\2301\230A\200A\330\010\017\210t\220?\240\"\240A\330\010\014\320\014\036\230a\330\010\013\2104\210t\2201\330\014\020\220\004\220I\230Q\230a\330\014\020\220\004\220I\230Q\230a\330\014\017\210t\2204\220t\2309\240A\330\020\024\220E\230\024\230\\\250\027\260\004\260H\270O\3101\310D\320PQ\200A\330\010\017\210t\320\023'\240q\250\001\200A\330\010\017\210t\220<\230s\240!\200A\330\010\017\210t\220<\230t\2407\250!\200A\330\010\017\210u\220C\220q\330\010\014\210D\320\020'\240q\330\020\024\320\024*\250\"\250B\320.D\300C\300s\310$\310a\330\014\017\210t\2204\320\027-\250R\250r\3201E\300Q\330\020\024\320\0242\260!\330\020\023\2204\320\0272\260#\260Q\330\024\030\230\010\240\001\240\021\330\014\020\220\006\220a\220t\320\0331\260\022\2602\260Q\330\014\020\320\020&\240b\250\002\320*<\270A\330\010\014\320\014&\240a\330\010\017\210q\200A\330\010\017\210z\230\021\230'\320!7\260t\2704\270z\310\023\310E\320QR\200A\330\010\017\210z\230\021\230'\320!9\270\024\270T\300\026\300s\310%\310q\320\004%\320%M\310^\320[\\\340\010%\240Q\330\010\013\320\013\034\230D""\240\004\240D\250\003\2501\330\014)\250\024\250Y\260a\330\014\020\220\005\220Q\330\010\013\2104\210t\2203\220a\330\014\020\220\007\220q\230\013\2401\330\010\013\320\013&\240g\250Q\330\014\023\2201\320\0240\260\001\320\004%\240Q\330\010\013\2101\330\014\020\220\006\220a\220q\340\014\017\210t\2204\220s\230!\330\020\030\230\004\230A\340\020\030\230\004\230A\330\014\020\220\006\220a\320\0276\260f\270A\320\004!\240\034\250Q\330\010\013\2104\210s\220!\330\014\022\220$\220i\230q\330\010\013\2104\210t\2203\220a\330\014\021\220\021\220%\220q\330\010\016\210e\2201\220E\230\021\330\010\013\2107\220&\230\001\200\001\330\036\037\320\004.\250a\330\010\014\320\014%\240Q\330\010\014\320\014#\2401\320\004(\250\001\330\010\016\210e\2204\220t\2301\230C\230s\240!\330\014\023\2204\220q\230\001\330\010\014\210F\220!\2204\220~\240Q\240a\330\010\014\210H\220A\220Q\320\004\036\230o\250Q\330\010\017\210u\320\024%\240Q\240d\250+\260Z\270q\320\004\030\230\017\240q\330\010\013\2104\210q\330\014\023\2204\220q\340\014\023\2201\220D\230\007\230q\240\n\250/\270\027\300\001\300\021\330\024\030\230\010\240\004\240A\320\004'\240q\330\010\014\210F\220!\2201\360\n\000\t\014\2101\330\014\020\220\004\220A\220Q\340\014\017\210t\320\023%\240S\250\001\330\020\024\320\024(\250\001\360\006\000\021\024\2204\320\027)\250\023\250A\330\024\030\320\030)\250\021\250!\330\014\017\210t\2208\2301\230C\230t\2403\240a\330\020\024\320\024%\240Q\240a\340\010+\2504\250~\270Q\330\010'\240s\250!\2501\340\010\013\210:\220S\230\001\330\014\r\330\r\027\220r\230\021\340\014\020\320\020\"\240'\250\021\250!\330\014\020\220\010\230\001\230\032\2401\340\014\022\220*\230B\230d\240.\260\001\340\020\024\320\024&\240d\250!\330\020\024\220H\230A\230Z\240q\340\014\017\210z\230\023\230D\240\016\250a\330\020\024\320\024%\240Q\240a\320\004\030\230\017\240q\360\006\000\t\020\210z\230\021\330\010\020\220\004\220G\2304\230q\240\001\330\010\013\2106\220\027\230\001\330\014\023\2201\340\r\021\320\021!\240\021\240)\250:\260_\320DW\320WX\330\014""\024\220A\220T\230\027\240\003\2404\240x\250q\260\n\270!\360\006\000\t\r\210G\2201\220G\2309\240D\250\003\2504\250}\270A\330\010\017\210q";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 457; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 48) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 457; i < 521; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 521; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 457;
      for (Py_ssize_t i=0; i<64; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1,3};
    for (int i = 0; i < 3; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<3; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 3;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 654};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_scanner, __pyx_mstate->__pyx_n_u_errors, __pyx_mstate->__pyx_n_u_put_back_on_failure, __pyx_mstate->__pyx_n_u_initial_state, __pyx_mstate->__pyx_n_u_put_back};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_tentatively_scan, __pyx_mstate->__pyx_kp_b_iso88591__14, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 66};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_declare, __pyx_mstate->__pyx_kp_b_iso88591_A_HAXQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 69};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_update, __pyx_mstate->__pyx_kp_b_iso88591_A_HG1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 72};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_lookup_here, __pyx_mstate->__pyx_kp_b_iso88591_A_t81A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 78};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_outer};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_lookup, __pyx_mstate->__pyx_kp_b_iso88591_A_4_1A_D_q_uG1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 135};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_str_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 138};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_filename, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_ext};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_set_file_type_from_name, __pyx_mstate->__pyx_kp_b_iso88591_A_fBe9AQ_N_d_S_S, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 142};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_is_cython_file, __pyx_mstate->__pyx_kp_b_iso88591_A_t_t7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 145};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_is_python_file, __pyx_mstate->__pyx_kp_b_iso88591_A_t_s, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 148};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_escaped_description, __pyx_mstate->__pyx_kp_b_iso88591_A_4_S_BhavQ_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 155};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_gt, __pyx_mstate->__pyx_kp_b_iso88591_A_4_E_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 162};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_lt, __pyx_mstate->__pyx_kp_b_iso88591_A_4_E_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 169};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_le, __pyx_mstate->__pyx_kp_b_iso88591_A_4_U_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 176};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_copy, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 179};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_memo};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_deepcopy, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 191};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_filename, __pyx_mstate->__pyx_n_u_path_description, __pyx_mstate->__pyx_n_u_workdir};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_5_L_1_A_2U_4q_4q_E_r_1_M_QnHKq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 207};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_encoding, __pyx_mstate->__pyx_n_u_error_handling, __pyx_mstate->__pyx_n_u_key, __pyx_mstate->__pyx_n_u_lines_2, __pyx_mstate->__pyx_n_u_f, __pyx_mstate->__pyx_n_u_line};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_lines, __pyx_mstate->__pyx_kp_b_iso88591_q_z_G4q_6_1__DWWX_AT_4xq_G1G9D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 222};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_encoding, __pyx_mstate->__pyx_n_u_error_handling};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_file_object, __pyx_mstate->__pyx_kp_b_iso88591_oQ_u_Qd_Zq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 225};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_description, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 228};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_file_path};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_relative_path, __pyx_mstate->__pyx_kp_b_iso88591_1_D_Q_9L_4q_A_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 235};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_cwd};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_error_description, __pyx_mstate->__pyx_kp_b_iso88591_A_t1_e_1BgS_E_4_1_4q_1A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 242};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_filenametable_entry, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 245};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_eq, __pyx_mstate->__pyx_kp_b_iso88591_A_z_7t4z_EQR, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 248};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_hash_2, __pyx_mstate->__pyx_kp_b_iso88591_A_t1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 251};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_2T, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 260};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_line};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_HA_M_gS_HD_1_M, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 266};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_encoding, __pyx_mstate->__pyx_n_u_error_handling, __pyx_mstate->__pyx_n_u_line};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_lines, __pyx_mstate->__pyx_kp_b_iso88591_q_4q_4q_1D_q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 273};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_description, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 276};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_relative_path, __pyx_mstate->__pyx_kp_b_iso88591_A_t1D_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 281};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_get_filenametable_entry, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 284};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_hash_2, __pyx_mstate->__pyx_kp_b_iso88591_A_r, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 290};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_eq, __pyx_mstate->__pyx_kp_b_iso88591_A_z_9_T_s_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 293};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_Rt1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 355};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_normalize_ident, __pyx_mstate->__pyx_kp_b_iso88591_A_4t81_9AXQ_HAWA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 360};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_commentline, __pyx_mstate->__pyx_kp_b_iso88591_A_4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 364};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_symbol};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_strip_underscores, __pyx_mstate->__pyx_kp_b_iso88591_A_HAXT_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 370};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_open_bracket_action, __pyx_mstate->__pyx_kp_b_iso88591_A_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 374};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_close_bracket_action, __pyx_mstate->__pyx_kp_b_iso88591_A_a_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 378};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_open_brace_action, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 381};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_close_brace_action, __pyx_mstate->__pyx_kp_b_iso88591_A_uCq_D_q_B_DCs_a_t4_Rr1EQ_2_4_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 394};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_colon_action, __pyx_mstate->__pyx_kp_b_iso88591_A_D_q_B_DCs_a_a_t_c_HAQ_at_1_2Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 404};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_newline_action, __pyx_mstate->__pyx_kp_b_iso88591_A_4_c_aq_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 416};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_begin_string_action, __pyx_mstate->__pyx_kp_b_iso88591_e4t1Cs_4q_F_4_Qa_HAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 422};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_end_string_action, __pyx_mstate->__pyx_kp_b_iso88591_A_F_t3SST_HAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 426};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_is_raw, __pyx_mstate->__pyx_n_u_ft_string_state};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_begin_ft_string_action, __pyx_mstate->__pyx_kp_b_iso88591_A_S_S_Cq_e5_AS_5S_AS_1_4q_AT_q_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 437};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_end_ft_string_action, __pyx_mstate->__pyx_kp_b_iso88591_A_a_F_t3SST_HAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 442};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_started_ft_string_expr};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_handle_open_single_ft_string_br, __pyx_mstate->__pyx_kp_b_iso88591_A_a_4q_b_Qd_aq_a_HAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 450};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_len_text, __pyx_mstate->__pyx_n_u_started_ft_string_expr, __pyx_mstate->__pyx_n_u_double_braces, __pyx_mstate->__pyx_n_u__5};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_open_ft_string_brace_action, __pyx_mstate->__pyx_kp_b_iso88591_A_3aq_4_Rr_Q_4AQ_Q_t4_Rr1EQ_A_E, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 468};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_ft_string_bracket_level};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_handle_close_single_ft_string_b, __pyx_mstate->__pyx_kp_b_iso88591_A_Bb_VVW_3e3d2I_1_a_D_Q_a_a_0_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 482};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_len_text, __pyx_mstate->__pyx_n_u_double_braces, __pyx_mstate->__pyx_n_u__5};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_close_ft_string_brace_action, __pyx_mstate->__pyx_kp_b_iso88591_A_3aq_it4_5Rr9MQ_5Q_A_E_aq_M_1_5, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 496};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_unclosed_string_action, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_Qa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 500};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_c, __pyx_mstate->__pyx_n_u_current_level, __pyx_mstate->__pyx_n_u_new_level};
    __pyx_mstate_global->__pyx_codeobj_tab[51] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_indentation_action, __pyx_mstate->__pyx_kp_b_iso88591_q_F_1_1_AQ_t_S_4_A_t81Ct3a_Qa_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[51])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 536};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_text};
    __pyx_mstate_global->__pyx_codeobj_tab[52] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_eof_action, __pyx_mstate->__pyx_kp_b_iso88591_A_c_A_1_a_HAWA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[52])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 542};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_sy, __pyx_mstate->__pyx_n_u_systring};
    __pyx_mstate_global->__pyx_codeobj_tab[53] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_next, __pyx_mstate->__pyx_kp_b_iso88591_A_4uA_3c_y_4q_9Cxt_T_Qiq_c_D_8H, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[53])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 569};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_saved, __pyx_mstate->__pyx_n_u_saved_pos, __pyx_mstate->__pyx_n_u_next};
    __pyx_mstate_global->__pyx_codeobj_tab[54] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_peek, __pyx_mstate->__pyx_kp_b_iso88591_A_E_Q_D_E_t5_A_G1D_T_D_E_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[54])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 579};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_sy, __pyx_mstate->__pyx_n_u_systring, __pyx_mstate->__pyx_n_u_pos};
    __pyx_mstate_global->__pyx_codeobj_tab[55] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_put_back, __pyx_mstate->__pyx_kp_b_iso88591_A_G1D_T_D_F_L, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[55])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 586};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_fatal, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[56] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_error, __pyx_mstate->__pyx_kp_b_iso88591_Q_4s_iq_4t3a_q_e1E_7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[56])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 600};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_what, __pyx_mstate->__pyx_n_u_message};
    __pyx_mstate_global->__pyx_codeobj_tab[57] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expect, __pyx_mstate->__pyx_kp_b_iso88591_1_4t3a_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[57])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 606};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_what, __pyx_mstate->__pyx_n_u_message};
    __pyx_mstate_global->__pyx_codeobj_tab[58] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expect_keyword, __pyx_mstate->__pyx_kp_b_iso88591_1_4t3fD_Jc_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[58])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 612};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_what, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_found_2};
    __pyx_mstate_global->__pyx_codeobj_tab[59] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expected, __pyx_mstate->__pyx_kp_b_iso88591_Q_1_aq_t4s_A_A_a_6fA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[59])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 622};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[60] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expect_indent, __pyx_mstate->__pyx_kp_b_iso88591_A_G1Ja, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[60])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 625};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[61] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expect_dedent, __pyx_mstate->__pyx_kp_b_iso88591_A_G1Ja, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[61])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 628};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_ignore_semicolon, __pyx_mstate->__pyx_n_u_useless_trailing_semicolon_2};
    __pyx_mstate_global->__pyx_codeobj_tab[62] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_expect_newline, __pyx_mstate->__pyx_kp_b_iso88591_M_Q_D_D_1_Ya_Q_4t3a_q_1_gQ_1_0, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[62])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 639};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[63] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_enter_async, __pyx_mstate->__pyx_kp_b_iso88591_A_a_4_c_Q_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[63])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 645};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[64] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_exit_async, __pyx_mstate->__pyx_kp_b_iso88591_A_t_A_a_4t1_IQa_IQa_t4t9A_E_HO1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[64])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 686};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[65] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_bracket_nesting_level, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_1_t_Ba, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[65])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 691};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[66] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_in_format_specifier, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_1_t_Ba, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[66])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 696};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[67] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_set_in_format_specifier, __pyx_mstate->__pyx_kp_b_iso88591_A_O2R_6a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[67])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 699};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_bracket_nesting_level};
    __pyx_mstate_global->__pyx_codeobj_tab[68] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_push_bracket_state, __pyx_mstate->__pyx_kp_b_iso88591_8_O7_7q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[68])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 702};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[69] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_pop_bracket_state, __pyx_mstate->__pyx_kp_b_iso88591_A_O4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[69])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 712};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_bracket_nesting_level};
    __pyx_mstate_global->__pyx_codeobj_tab[70] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Scanning_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_a_Q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[70])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* Generator.init */
  if (likely(__pyx_Generator_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u_);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyLong_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyLong_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* SetStringIndexingError (used by GetItemIntUnicode) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil) {
    if (!has_gil) {
        PyGILState_STATE gil_state = PyGILState_Ensure();
        PyErr_SetString(PyExc_IndexError, message);
        PyGILState_Release(gil_state);
    } else
        PyErr_SetString(PyExc_IndexError, message);
}

/* GetItemIntUnicode */
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck, int has_gil) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return (Py_UCS4)-1;
        #endif
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely(__Pyx_is_valid_index(i, length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            __Pyx_SetStringIndexingError("string index out of range", has_gil);
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    #if !CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    #endif
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(length < 0)) return NULL;
    #endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    if (start == 0 && stop == length)
        return __Pyx_NewRef(text);
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyUnicode_Substring(text, start, stop);
#else
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#endif
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (__Pyx_IS_TYPE(L, &PySet_Type)) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_mstate_global->__pyx_n_u_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* DivInt[Py_ssize_t] */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b, int b_is_constant) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    Py_ssize_t adapt_python = (b_is_constant ?
        ((r != 0) & ((r < 0) ^ (b < 0))) :
        ((r != 0) & ((r ^ b) < 0))
    );
    return q - adapt_python;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* py_dict_pop_ignore */
static CYTHON_INLINE int __Pyx_PyDict_Pop_ignore(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop)
    int result = PyDict_Pop(d, key, NULL);
    CYTHON_UNUSED_VAR(default_value);
    return (unlikely(result == -1)) ? -1 : 0;
#else
    PyObject *value;
    CYTHON_UNUSED_VAR(default_value);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    value = _PyDict_Pop(d, key, Py_None);
    #else
    value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key, Py_None);
    #endif
    if (unlikely(value == NULL))
        return -1;
    Py_DECREF(value);
    return 0;
#endif
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice_locked(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(src);
    result = __Pyx_PyList_GetSlice_locked(src, start, stop);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
#endif // CYTHON_COMPILING_IN_CPYTHON

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc, *new_exc;
    __Pyx_PyThreadState_declare
    int is_async_stopiteration = 0;
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    __Pyx_PyThreadState_assign
    cur_exc = __Pyx_PyErr_CurrentExceptionType();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else {
            return;
        }
    }
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(tb);
    new_exc = PyObject_CallFunction(PyExc_RuntimeError, "s",
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        "generator raised StopIteration");
    if (!new_exc) {
        Py_XDECREF(val);
        return;
    }
    PyException_SetCause(new_exc, val); // steals ref to val
    PyErr_SetObject(PyExc_RuntimeError, new_exc);
}

/* pybuiltin_invalid (used by pyint_simplify) */
static void __Pyx_PyBuiltin_Invalid(PyObject *obj, const char *type_name, const char *argname) {
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    if (argname) {
        PyErr_Format(PyExc_TypeError,
            "Argument '%.200s' has incorrect type (expected %.200s, got " __Pyx_FMT_TYPENAME ")",
            argname, type_name, obj_type_name
        );
    } else {
        PyErr_Format(PyExc_TypeError,
            "Expected %.200s, got " __Pyx_FMT_TYPENAME,
            type_name, obj_type_name
        );
    }
    __Pyx_DECREF_TypeName(obj_type_name);
}

/* pyint_simplify */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none) {
    PyObject *number = *number_var;
    if (likely((accept_none && number == Py_None) || PyLong_CheckExact(number))) {
        return 0;
    }
    PyObject *int_object;
    if (likely(PyNumber_Check(number))) {
        int_object = PyNumber_Long(number);
        if (unlikely(!int_object)) goto bad;
    } else {
        __Pyx_PyBuiltin_Invalid(number, "int", argname);
        goto bad;
    }
    *number_var = int_object;
    Py_DECREF(number);
    return 0;
bad:
    *number_var = NULL;
    Py_DECREF(number);
    return -1;
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig) {
    PyObject *cobj;
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CalculateMetaclass (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectCall2Args (used by Py3ClassCreate) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* PyUCS4InUnicode */
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character) {
    Py_ssize_t idx = PyUnicode_FindChar(unicode, character, 0, PY_SSIZE_T_MAX, 1);
    if (unlikely(idx == -2)) return -1;
    return idx >= 0;
}

/* UnicodeAsUCS4 */
static void __Pyx_PyUnicode_AsPy_UCS4_error(Py_ssize_t length) {
    if (likely(length >= 0)) {
        PyErr_Format(PyExc_ValueError,
                     "only single character unicode strings can be converted to Py_UCS4, "
                     "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
    }
}
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
    Py_ssize_t length = __Pyx_PyUnicode_GET_LENGTH(x);
    if (unlikely(length != 1)) {
        __Pyx_PyUnicode_AsPy_UCS4_error(length);
        return (Py_UCS4)-1;
    }
    return __Pyx_PyUnicode_READ_CHAR(x, 0);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* ObjectAsUCS4 */
static void __Pyx__PyObject_AsPy_UCS4_raise_error(long ival) {
   if (ival < 0) {
       if (!PyErr_Occurred())
           PyErr_SetString(PyExc_OverflowError,
                           "cannot convert negative value to Py_UCS4");
   } else {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to Py_UCS4");
   }
}
static Py_UCS4 __Pyx__PyObject_AsPy_UCS4(PyObject* x) {
   long ival;
   ival = __Pyx_PyLong_As_long(x);
   if (unlikely(!__Pyx_is_valid_index(ival, 1114111 + 1))) {
       __Pyx__PyObject_AsPy_UCS4_raise_error(ival);
       return (Py_UCS4)-1;
   }
   return (Py_UCS4)ival;
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__13);
    }
    goto done;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* IterNextPlain (used by CoroutineBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void) {
    if (unlikely(!__pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache))
        __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_next);
    return __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator) {
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    PyObject *result;
    PyObject *next = __Pyx_GetBuiltinNext_LimitedAPI();
    if (unlikely(!next)) return NULL;
    result = PyObject_CallFunctionObjArgs(next, iterator, NULL);
    return result;
#else
    (void)__Pyx_GetBuiltinName; // only for early limited API
    iternextfunc iternext = __Pyx_PyObject_GetIterNextFunc(iterator);
    assert(iternext);
    return iternext(iterator);
#endif
}

/* PyObjectCallMethod1 (used by CoroutineBase) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* ReturnWithStopIteration (used by CoroutineBase) */
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async);
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext) {
    if (value == Py_None) {
        if (async || !iternext)
            PyErr_SetNone(async ? PyExc_StopAsyncIteration : PyExc_StopIteration);
        return;
    }
    __Pyx__ReturnWithStopIteration(value, async);
}
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async) {
#if CYTHON_COMPILING_IN_CPYTHON
    __Pyx_PyThreadState_declare
#endif
    PyObject *exc;
    PyObject *exc_type = async ? PyExc_StopAsyncIteration : PyExc_StopIteration;
#if CYTHON_COMPILING_IN_CPYTHON
    if ((PY_VERSION_HEX >= (0x030C00A6)) || unlikely(PyTuple_Check(value) || PyExceptionInstance_Check(value))) {
        if (PY_VERSION_HEX >= (0x030e00A1)) {
            exc = __Pyx_PyObject_CallOneArg(exc_type, value);
        } else {
            PyObject *args_tuple = PyTuple_New(1);
            if (unlikely(!args_tuple)) return;
            Py_INCREF(value);
            PyTuple_SET_ITEM(args_tuple, 0, value);
            exc = PyObject_Call(exc_type, args_tuple, NULL);
            Py_DECREF(args_tuple);
        }
        if (unlikely(!exc)) return;
    } else {
        Py_INCREF(value);
        exc = value;
    }
    #if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    #if CYTHON_USE_EXC_INFO_STACK
    if (!__pyx_tstate->exc_info->exc_value)
    #else
    if (!__pyx_tstate->exc_type)
    #endif
    {
        Py_INCREF(exc_type);
        __Pyx_ErrRestore(exc_type, exc, NULL);
        return;
    }
    #endif
#else
    exc = __Pyx_PyObject_CallOneArg(exc_type, value);
    if (unlikely(!exc)) return;
#endif
    PyErr_SetObject(exc_type, exc);
    Py_DECREF(exc);
}

/* CoroutineBase (used by Generator) */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6 && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#endif // CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void
__Pyx_Coroutine_Undelegate(__pyx_CoroutineObject *gen) {
#if CYTHON_USE_AM_SEND
    gen->yieldfrom_am_send = NULL;
#endif
    Py_CLEAR(gen->yieldfrom);
}
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
            value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
            if (unlikely(!value)) goto limited_api_failure;
            #else
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            #endif
            Py_DECREF(ev);
        }
        else if (unlikely(PyTuple_Check(ev))) {
            Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(ev);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(tuple_size < 0)) {
                Py_XDECREF(tb);
                Py_DECREF(ev);
                Py_DECREF(et);
                return -1;
            }
            #endif
            if (tuple_size >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#elif CYTHON_ASSUME_SAFE_MACROS
                value = PySequence_ITEM(ev, 0);
#else
                value = PySequence_GetItem(ev, 0);
                if (!value) goto limited_api_failure;
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
#else
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
#endif
    Py_DECREF(ev);
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!value)) return -1;
#endif
    *pvalue = value;
    return 0;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL || !CYTHON_ASSUME_SAFE_MACROS
  limited_api_failure:
    Py_XDECREF(et);
    Py_XDECREF(tb);
    Py_XDECREF(ev);
    return -1;
#endif
}
static CYTHON_INLINE
__Pyx_PySendResult __Pyx_Coroutine_status_from_result(PyObject **retval) {
    if (*retval) {
        return PYGEN_NEXT;
    } else if (likely(__Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, retval) == 0)) {
        return PYGEN_RETURN;
    } else {
        return PYGEN_ERROR;
    }
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
static void __Pyx_Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
__Pyx_PySendResult __Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, PyObject **result, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(__Pyx_Coroutine_get_is_running(self));  // Callers should ensure is_running
    if (unlikely(self->resume_label == -1)) {
        __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
        return PYGEN_ERROR;
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    retval = self->body(self, tstate, value);
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    *result = retval;
    if (self->resume_label == -1) {
        return likely(retval) ? PYGEN_RETURN : PYGEN_ERROR;
    }
    return PYGEN_NEXT;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
#define __Pyx_Coroutine_MethodReturnFromResult(gen, result, retval, iternext)\
    ((result) == PYGEN_NEXT ? (retval) : __Pyx__Coroutine_MethodReturnFromResult(gen, result, retval, iternext))
static PyObject *
__Pyx__Coroutine_MethodReturnFromResult(PyObject* gen, __Pyx_PySendResult result, PyObject *retval, int iternext) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (likely(result == PYGEN_RETURN)) {
        int is_async = 0;
        #ifdef __Pyx_AsyncGen_USED
        is_async = __Pyx_AsyncGen_CheckExact(gen);
        #endif
        __Pyx_ReturnWithStopIteration(retval, is_async, iternext);
        Py_XDECREF(retval);
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE __Pyx_PySendResult
__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen, PyObject** retval) {
    __Pyx_PySendResult result;
    PyObject *val = NULL;
    assert(__Pyx_Coroutine_get_is_running(gen));
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    result = __Pyx_Coroutine_SendEx(gen, val, retval, 0);
    Py_XDECREF(val);
    return result;
}
#if CYTHON_USE_AM_SEND
static __Pyx_PySendResult
__Pyx_Coroutine_SendToDelegate(__pyx_CoroutineObject *gen, __Pyx_pyiter_sendfunc gen_am_send, PyObject *value, PyObject **retval) {
    PyObject *ret = NULL;
    __Pyx_PySendResult delegate_result, result;
    assert(__Pyx_Coroutine_get_is_running(gen));
    delegate_result = gen_am_send(gen->yieldfrom, value, &ret);
    if (delegate_result == PYGEN_NEXT) {
        assert (ret != NULL);
        *retval = ret;
        return PYGEN_NEXT;
    }
    assert (delegate_result != PYGEN_ERROR || ret == NULL);
    __Pyx_Coroutine_Undelegate(gen);
    result = __Pyx_Coroutine_SendEx(gen, ret, retval, 0);
    Py_XDECREF(ret);
    return result;
}
#endif
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result = __Pyx_Coroutine_AmSend(self, value, &retval);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
}
static __Pyx_PySendResult
__Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval) {
    __Pyx_PySendResult result;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, value, retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
      #if !CYTHON_USE_AM_SEND
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
      #endif
        {
            #if !CYTHON_COMPILING_IN_LIMITED_API || __PYX_LIMITED_VERSION_HEX >= 0x03080000
            if (value == Py_None && PyIter_Check(yf))
                ret = __Pyx_PyIter_Next_Plain(yf);
            else
            #endif
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_mstate_global->__pyx_n_u_send, value);
        }
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            *retval = ret;
            return PYGEN_NEXT;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, value, retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return result;
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    CYTHON_UNUSED_VAR(gen);
    assert(__Pyx_Coroutine_get_is_running(gen));
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        result = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf);
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    #endif
    {
        PyObject *meth;
        result = PYGEN_RETURN;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval)) {
                result = PYGEN_ERROR;
            }
        }
    }
    Py_XDECREF(retval);
    return result == PYGEN_ERROR ? -1 : 0;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, Py_None, &retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && (PY_VERSION_HEX < 0x030A00A3 || !CYTHON_USE_AM_SEND)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
            ret = __Pyx_PyIter_Next_Plain(yf);
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 1);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result;
    CYTHON_UNUSED_VAR(arg);
    result = __Pyx_Coroutine_Close(self, &retval);
    if (unlikely(result == PYGEN_ERROR))
        return NULL;
    Py_XDECREF(retval);
    Py_RETURN_NONE;
}
static __Pyx_PySendResult
__Pyx_Coroutine_Close(PyObject *self, PyObject **retval) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PySendResult result;
    PyObject *yf;
    int err = 0;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    yf = gen->yieldfrom;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    result = __Pyx_Coroutine_SendEx(gen, NULL, retval, 1);
    if (result == PYGEN_ERROR) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_Coroutine_unset_is_running(gen);
        if (!__Pyx_PyErr_Occurred()) {
            return PYGEN_RETURN;
        } else if (likely(__Pyx_PyErr_ExceptionMatches2(PyExc_GeneratorExit, PyExc_StopIteration))) {
            __Pyx_PyErr_Clear();
            return PYGEN_RETURN;
        }
        return PYGEN_ERROR;
    } else if (likely(result == PYGEN_RETURN && *retval == Py_None)) {
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_RETURN;
    } else {
        const char *msg;
        Py_DECREF(*retval);
        *retval = NULL;
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
            msg = "async generator ignored GeneratorExit";
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_ERROR;
    }
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen)))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    yf = gen->yieldfrom;
    if (yf) {
        __Pyx_PySendResult result;
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                goto propagate_exception;
            goto throw_here;
        }
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    __Pyx_Coroutine_unset_is_running(gen);
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        Py_DECREF(yf);
        if (ret) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &ret);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, ret, 0);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
propagate_exception:
    {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, NULL, &retval, 0);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
    }
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, "throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    {
        int e = __Pyx_call_type_traverse((PyObject*)gen, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    #if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    if (gen->gi_weakreflist != NULL)
    #endif
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        {
            destructor del = __Pyx_PyObject_GetSlot(gen, tp_del, destructor);
            if (del) del(self);
        }
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
#if CYTHON_USE_TP_FINALIZE
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_Close(self, &retval);
        if (result == PYGEN_ERROR) {
            PyErr_WriteUnraisable(self);
        } else {
            Py_XDECREF(retval);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
}
#endif
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx__Coroutine_get_frame(__pyx_CoroutineObject *self)
{
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyObject *frame;
    #if PY_VERSION_HEX >= 0x030d0000
    Py_BEGIN_CRITICAL_SECTION(self);
    #endif
    frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        PyObject *globals = PyDict_New();
        if (unlikely(!globals)) return NULL;
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            globals,                        /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        Py_DECREF(globals);
        if (unlikely(!frame))
            return NULL;
        if (unlikely(self->gi_frame)) {
            Py_DECREF(frame);
            frame = self->gi_frame;
        } else {
            self->gi_frame = frame;
        }
    }
    Py_INCREF(frame);
    #if PY_VERSION_HEX >= 0x030d0000
    Py_END_CRITICAL_SECTION();
    #endif
    return frame;
#else
    CYTHON_UNUSED_VAR(self);
    Py_RETURN_NONE;
#endif
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context) {
    CYTHON_UNUSED_VAR(context);
    PyObject *frame = self->gi_frame;
    if (frame)
        return __Pyx_NewRef(frame);
    return __Pyx__Coroutine_get_frame(self);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->yieldfrom_am_send = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_weakreflist = NULL;
#endif
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    gen->is_running = 1;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen) {
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    assert(gen->is_running);
    gen->is_running = 0;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
}
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure) {
    CYTHON_UNUSED_VAR(closure);
    char result = __Pyx_Coroutine_get_is_running((__pyx_CoroutineObject*)gen);
    if (result) Py_RETURN_TRUE;
    else Py_RETURN_FALSE;
}
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send) {
    Py_ssize_t ptr_offset = (char*)(type->tp_as_async) - (char*)type;
    if (ptr_offset < 0 || ptr_offset > type->tp_basicsize) {
        return;
    }
    memcpy((void*)static_amsend_methods, (void*)(type->tp_as_async), sizeof(*type->tp_as_async));
    static_amsend_methods->am_send = am_send;
    type->tp_as_async = __Pyx_SlotTpAsAsync(static_amsend_methods);
}
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    __Pyx_TypeName self_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE((PyObject*)self));
    PyErr_Format(PyExc_TypeError, "cannot pickle '" __Pyx_FMT_TYPENAME "' object",
                         self_type_name);
    __Pyx_DECREF_TypeName(self_type_name);
    return NULL;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {"__reduce_ex__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_O, 0},
    {"__reduce__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {"gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     PyDoc_STR("object being iterated by 'yield from', or None")},
    {"gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {"__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {"__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     PyDoc_STR("name of the generator"), 0},
    {"__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     PyDoc_STR("qualified name of the generator"), 0},
    {"gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     PyDoc_STR("Frame of the generator"), 0},
    {"gi_running", __Pyx_Coroutine_get_is_running_getter, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) PyObject_GenericGetAttr},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    {Py_am_send, (void *)__Pyx_Coroutine_AmSend},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_WEAKREF |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | __Pyx_TPFLAGS_HAVE_AM_SEND,
    __pyx_GeneratorType_slots
};
#if __PYX_HAS_PY_AM_SEND == 2
static __Pyx_PyAsyncMethodsStruct __pyx_Generator_as_async;
#endif
static int __pyx_Generator_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_GeneratorType_spec, NULL);
    if (unlikely(!mstate->__pyx_GeneratorType)) {
        return -1;
    }
#if __PYX_HAS_PY_AM_SEND == 2
    __Pyx_SetBackportTypeAmSend(mstate->__pyx_GeneratorType, &__pyx_Generator_as_async, &__Pyx_Coroutine_AmSend);
#endif
    return 0;
}
static PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *retval = NULL;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    __Pyx_Coroutine_unset_is_running(gen);
    (void) result;
    assert (result == PYGEN_RETURN || result == PYGEN_ERROR);
    assert ((result == PYGEN_RETURN && retval != NULL) || (result == PYGEN_ERROR && retval == NULL));
    return retval;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
