/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "Cython.Tempita._tempita",
        "sources": [
            "/build/cython/src/cython/Cython/Tempita/_tempita.py"
        ]
    },
    "module_name": "Cython.Tempita._tempita"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Cython__Tempita___tempita
#define __PYX_HAVE_API__Cython__Tempita___tempita
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "Cython/Tempita/_tempita.py",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_defaults;
struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature;

/* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/
struct __pyx_defaults {
  PyObject_HEAD
  PyObject *arg0;
};


/* "Cython/Tempita/_tempita.py":938
 * 
 * 
 * def parse_signature(sig_text, name, pos):             # <<<<<<<<<<<<<<
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
*/
struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature {
  PyObject_HEAD
  PyObject *__pyx_v_tokens;
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* PyDeprecationWarning_Check.proto */
#define __Pyx_PyExc_DeprecationWarning_Check(obj)  __Pyx_TypeCheck(obj, PyExc_DeprecationWarning)

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyNumber_Hex.proto */
#define __Pyx_PyNumber_Hex(obj) PyNumber_ToBase((obj), 16)

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* py_dict_pop.proto */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value);

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* ListAppend.proto (used by append) */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* PySyntaxError_Check.proto */
#define __Pyx_PyExc_SyntaxError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_SyntaxError)

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyExec.proto */
static PyObject* __Pyx_PyExec3(PyObject*, PyObject*, PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyExec2(PyObject*, PyObject*);

/* PyUnicodeDecodeError_Check.proto */
#define __Pyx_PyExc_UnicodeDecodeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_UnicodeDecodeError)

/* PyUnicodeEncodeError_Check.proto */
#define __Pyx_PyExc_UnicodeEncodeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_UnicodeEncodeError)

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* pop_index.proto */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix);
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix);
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (likely(PyList_CheckExact(L) && __Pyx_fits_Py_ssize_t(ix, type, is_signed))) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    __Pyx_fits_Py_ssize_t(ix, type, is_signed) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#else
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)\
    __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
        __Pyx__PyObject_PopIndex(L, py_ix))
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyLongCompare.proto */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* IterNextPlain.proto (used by IterNext) */
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator);
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void);
#endif

/* IterNext.proto */
#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *);

/* RaiseClosureNameError.proto */
static void __Pyx_RaiseClosureNameError(const char *varname);

/* PyStopIteration_Check.proto */
#define __Pyx_PyExc_StopIteration_Check(obj)  __Pyx_TypeCheck(obj, PyExc_StopIteration)

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* ClassMethod.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include "descrobject.h"
#endif
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."


/* Module declarations from "Cython.Tempita._tempita" */
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "Cython.Tempita._tempita"
extern int __pyx_module_is_main_Cython__Tempita___tempita;
int __pyx_module_is_main_Cython__Tempita___tempita = 0;

/* Implementation of "Cython.Tempita._tempita" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_eval;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_print;
/* #### Code section: string_decls ### */
static const char __pyx_k_A_small_templating_language_Thi[] = "\nA small templating language\n\nThis implements a small templating language.  This language implements\nif/elif/else, for/continue/break, expressions, and blocks of Python\ncode.  The syntax is::\n\n  {{any expression (function calls etc)}}\n  {{any expression | filter}}\n  {{for x in y}}...{{endfor}}\n  {{if x}}x{{elif y}}y{{else}}z{{endif}}\n  {{py:x=1}}\n  {{py:\n  def foo(bar):\n      return 'baz'\n  }}\n  {{default var = default_value}}\n  {{# comment}}\n\nYou use this with the ``Template`` class or the ``sub`` shortcut.\nThe ``Template`` class takes the template string and the name of\nthe template (for errors) and a default namespace.  Then (like\n``string.Template``) you can call the ``tmpl.substitute(**kw)``\nmethod to make a substitution (or ``tmpl.substitute(a_dict)``).\n\n``sub(content, **kw)`` substitutes the template immediately.  You\ncan use ``__name='tmpl.html'`` to set the name of the template.\n\nIf there are syntax errors ``TemplateError`` will be raised.\n";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_coerce_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_v); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_message, PyObject *__pyx_v_position, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_2get_file_template(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_from_template); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_content, PyObject *__pyx_v_name, PyObject *__pyx_v_namespace, PyObject *__pyx_v_stacklevel, PyObject *__pyx_v_get_template, PyObject *__pyx_v_default_inherit, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters, PyObject *__pyx_v_delimeters); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_36__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_2from_filename(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_filename, PyObject *__pyx_v_namespace, PyObject *__pyx_v_encoding, PyObject *__pyx_v_default_inherit, PyObject *__pyx_v_get_template); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_6substitute(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_8_interpret(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ns); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_10_interpret_inherit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_body, PyObject *__pyx_v_defs, PyObject *__pyx_v_inherit_template, PyObject *__pyx_v_ns); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_12_interpret_codes(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_codes, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_14_interpret_code(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_16_interpret_for(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_vars, PyObject *__pyx_v_expr, PyObject *__pyx_v_content, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_18_interpret_if(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parts, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_20_eval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_22_exec(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_24_repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_26_add_line_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_msg, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_4sub(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_content, PyObject *__pyx_v_delimiters, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6paste_script_template_renderer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_content, PyObject *__pyx_v_vars, PyObject *__pyx_v_filename); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_2__setattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_6__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_template, PyObject *__pyx_v_func_name, PyObject *__pyx_v_func_signature, PyObject *__pyx_v_body, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos, PyObject *__pyx_v_bound_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_6__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_8__get__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_type); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_10_parse_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_template_obj); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_2__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_attr); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty___call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_6__unicode__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_8__iter__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_10__bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8lex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_name, PyObject *__pyx_v_trim_whitespace, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_10trim_lex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_12find_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_string, PyObject *__pyx_v_index, PyObject *__pyx_v_last_index, PyObject *__pyx_v_last_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_name, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_16parse_expr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_18parse_cond(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20parse_one_cond(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_22parse_for(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_24parse_default(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_26parse_inherit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_28parse_def(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_15parse_signature_get_token(PyObject *__pyx_self, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_30parse_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sig_text, PyObject *__pyx_v_name, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_32isolate_expression(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_string, PyObject *__pyx_v_start_pos, PyObject *__pyx_v_end_pos); /* proto */
static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_34fill_command(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_defaults(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyObject *__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults;
  PyObject *__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature;
  PyTypeObject *__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults;
  PyTypeObject *__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type__update;
  PyObject *__pyx_slice[6];
  PyObject *__pyx_tuple[16];
  PyObject *__pyx_codeobj_tab[57];
  PyObject *__pyx_string_tab[503];
  PyObject *__pyx_number_tab[6];
/* #### Code section: module_state_contents ### */
/* IterNextPlain.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
PyObject *__Pyx_GetBuiltinNext_LimitedAPI_cache;
#endif

/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *__pyx_freelist_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature[8];
int __pyx_freecount_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Bad_argument_r __pyx_string_tab[1]
#define __pyx_kp_u_Bad_for_no_in_in_r __pyx_string_tab[2]
#define __pyx_kp_u_Cannot_decode_bytes_value_r_into __pyx_string_tab[3]
#define __pyx_kp_u_Cannot_encode_unicode_value_r_in __pyx_string_tab[4]
#define __pyx_kp_u_Cython_Tempita__looper __pyx_string_tab[5]
#define __pyx_kp_u_Cython_Tempita__tempita_py __pyx_string_tab[6]
#define __pyx_kp_u_Exception_raised_while_parsing_a __pyx_string_tab[7]
#define __pyx_kp_u_Expression_must_be_default_var_v __pyx_string_tab[8]
#define __pyx_kp_u_Extra_position_arguments_s __pyx_string_tab[9]
#define __pyx_kp_u_File_to_write_output_to_default __pyx_string_tab[10]
#define __pyx_kp_u_Function_definition_doesn_t_end __pyx_string_tab[11]
#define __pyx_kp_u_If_you_pass_in_a_single_argument __pyx_string_tab[12]
#define __pyx_kp_u_Invalid_signature_s __pyx_string_tab[13]
#define __pyx_kp_u_Missing_argument_s __pyx_string_tab[14]
#define __pyx_kp_u_Missing_enddef __pyx_string_tab[15]
#define __pyx_kp_u_Missing_endif __pyx_string_tab[16]
#define __pyx_kp_u_Multi_line_py_blocks_must_start __pyx_string_tab[17]
#define __pyx_kp_u_Need_i_items_to_unpack_got_i_ite __pyx_string_tab[18]
#define __pyx_kp_u_No_endfor __pyx_string_tab[19]
#define __pyx_kp_u_No_endif __pyx_string_tab[20]
#define __pyx_kp_u_No_s_to_finish_last_expression __pyx_string_tab[21]
#define __pyx_kp_u_None __pyx_string_tab[22]
#define __pyx_kp_u_Not_a_valid_variable_name_for_de __pyx_string_tab[23]
#define __pyx_kp_u_Put_the_environment_in_as_top_le __pyx_string_tab[24]
#define __pyx_kp_u_Unexpected_argument_s __pyx_string_tab[25]
#define __pyx_kp_u_Unexpected_s __pyx_string_tab[26]
#define __pyx_kp_u_Unexpected_token __pyx_string_tab[27]
#define __pyx_kp_u_Unknown_code_r __pyx_string_tab[28]
#define __pyx_kp_u_You_can_only_give_one_positional __pyx_string_tab[29]
#define __pyx_kp_u_You_can_only_give_positional_or __pyx_string_tab[30]
#define __pyx_kp_u_You_cannot_have_in_the_variable __pyx_string_tab[31]
#define __pyx_kp_u_You_cannot_use_inheritance_witho __pyx_string_tab[32]
#define __pyx_kp_u_You_must_give_a_template_filenam __pyx_string_tab[33]
#define __pyx_kp_u__10 __pyx_string_tab[34]
#define __pyx_kp_u__11 __pyx_string_tab[35]
#define __pyx_kp_u__12 __pyx_string_tab[36]
#define __pyx_kp_u__13 __pyx_string_tab[37]
#define __pyx_kp_u__14 __pyx_string_tab[38]
#define __pyx_kp_u__15 __pyx_string_tab[39]
#define __pyx_kp_u__16 __pyx_string_tab[40]
#define __pyx_kp_u__17 __pyx_string_tab[41]
#define __pyx_kp_u__18 __pyx_string_tab[42]
#define __pyx_kp_u__19 __pyx_string_tab[43]
#define __pyx_kp_u__2 __pyx_string_tab[44]
#define __pyx_kp_u__20 __pyx_string_tab[45]
#define __pyx_kp_u__21 __pyx_string_tab[46]
#define __pyx_kp_u__22 __pyx_string_tab[47]
#define __pyx_kp_u__23 __pyx_string_tab[48]
#define __pyx_kp_u__24 __pyx_string_tab[49]
#define __pyx_kp_u__25 __pyx_string_tab[50]
#define __pyx_kp_u__26 __pyx_string_tab[51]
#define __pyx_kp_u__27 __pyx_string_tab[52]
#define __pyx_kp_u__3 __pyx_string_tab[53]
#define __pyx_kp_u__4 __pyx_string_tab[54]
#define __pyx_kp_u__5 __pyx_string_tab[55]
#define __pyx_kp_u__6 __pyx_string_tab[56]
#define __pyx_kp_u__7 __pyx_string_tab[57]
#define __pyx_kp_u__8 __pyx_string_tab[58]
#define __pyx_kp_u__9 __pyx_string_tab[59]
#define __pyx_kp_u_a_z__a_z0_9 __pyx_string_tab[60]
#define __pyx_kp_u_around __pyx_string_tab[61]
#define __pyx_kp_u_at __pyx_string_tab[62]
#define __pyx_kp_u_at_2 __pyx_string_tab[63]
#define __pyx_kp_u_at_line __pyx_string_tab[64]
#define __pyx_kp_u_column __pyx_string_tab[65]
#define __pyx_kp_u_continue_outside_of_for_loop __pyx_string_tab[66]
#define __pyx_kp_u_def_2 __pyx_string_tab[67]
#define __pyx_kp_u_default_2 __pyx_string_tab[68]
#define __pyx_kp_u_default_x_y_is_not_supported __pyx_string_tab[69]
#define __pyx_kp_u_delimeters_kwarg_is_being_depre __pyx_string_tab[70]
#define __pyx_kp_u_disable __pyx_string_tab[71]
#define __pyx_kp_u_elif __pyx_string_tab[72]
#define __pyx_kp_u_enable __pyx_string_tab[73]
#define __pyx_kp_u_env __pyx_string_tab[74]
#define __pyx_kp_u_for_2 __pyx_string_tab[75]
#define __pyx_kp_u_gc __pyx_string_tab[76]
#define __pyx_kp_u_if __pyx_string_tab[77]
#define __pyx_kp_u_if_elif_for_def_inherit_default __pyx_string_tab[78]
#define __pyx_kp_u_in_file_s __pyx_string_tab[79]
#define __pyx_kp_u_in_s __pyx_string_tab[80]
#define __pyx_kp_u_in_string_r __pyx_string_tab[81]
#define __pyx_kp_u_inherit_3 __pyx_string_tab[82]
#define __pyx_kp_u_invalid_syntax_in_expression_s __pyx_string_tab[83]
#define __pyx_kp_u_isenabled __pyx_string_tab[84]
#define __pyx_kp_u_n_r_t __pyx_string_tab[85]
#define __pyx_kp_u_name_3 __pyx_string_tab[86]
#define __pyx_kp_u_o __pyx_string_tab[87]
#define __pyx_kp_u_output __pyx_string_tab[88]
#define __pyx_kp_u_prog_OPTIONS_TEMPLATE_arg_value __pyx_string_tab[89]
#define __pyx_kp_u_py_2 __pyx_string_tab[90]
#define __pyx_kp_u_pyc __pyx_string_tab[91]
#define __pyx_kp_u_pyo __pyx_string_tab[92]
#define __pyx_kp_u_s __pyx_string_tab[93]
#define __pyx_kp_u_s_in_s __pyx_string_tab[94]
#define __pyx_kp_u_s_inside_expression __pyx_string_tab[95]
#define __pyx_kp_u_s_outside_expression __pyx_string_tab[96]
#define __pyx_kp_u_s_outside_of_an_if_block __pyx_string_tab[97]
#define __pyx_kp_u_s_with_no_expression __pyx_string_tab[98]
#define __pyx_kp_u_stdin_2 __pyx_string_tab[99]
#define __pyx_kp_u_string __pyx_string_tab[100]
#define __pyx_kp_u_t_n __pyx_string_tab[101]
#define __pyx_kp_u_tempita_function __pyx_string_tab[102]
#define __pyx_n_u_Cython_Tempita__tempita __pyx_string_tab[103]
#define __pyx_n_u_ENDMARKER __pyx_string_tab[104]
#define __pyx_n_u_Empty __pyx_string_tab[105]
#define __pyx_n_u_Empty_2 __pyx_string_tab[106]
#define __pyx_n_u_Empty___bool __pyx_string_tab[107]
#define __pyx_n_u_Empty___call __pyx_string_tab[108]
#define __pyx_n_u_Empty___iter __pyx_string_tab[109]
#define __pyx_n_u_Empty___repr __pyx_string_tab[110]
#define __pyx_n_u_Empty___str __pyx_string_tab[111]
#define __pyx_n_u_Empty___unicode __pyx_string_tab[112]
#define __pyx_n_u_FILENAME __pyx_string_tab[113]
#define __pyx_n_u_I __pyx_string_tab[114]
#define __pyx_n_u_NAME __pyx_string_tab[115]
#define __pyx_n_u_OP __pyx_string_tab[116]
#define __pyx_n_u_OptionParser __pyx_string_tab[117]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[118]
#define __pyx_n_u_StringIO __pyx_string_tab[119]
#define __pyx_n_u_Template __pyx_string_tab[120]
#define __pyx_n_u_TemplateBreak __pyx_string_tab[121]
#define __pyx_n_u_TemplateContinue __pyx_string_tab[122]
#define __pyx_n_u_TemplateDef __pyx_string_tab[123]
#define __pyx_n_u_TemplateDef___call __pyx_string_tab[124]
#define __pyx_n_u_TemplateDef___get __pyx_string_tab[125]
#define __pyx_n_u_TemplateDef___init __pyx_string_tab[126]
#define __pyx_n_u_TemplateDef___repr __pyx_string_tab[127]
#define __pyx_n_u_TemplateDef___str __pyx_string_tab[128]
#define __pyx_n_u_TemplateDef__parse_signature __pyx_string_tab[129]
#define __pyx_n_u_TemplateError __pyx_string_tab[130]
#define __pyx_n_u_TemplateError___init __pyx_string_tab[131]
#define __pyx_n_u_TemplateError___str __pyx_string_tab[132]
#define __pyx_n_u_TemplateObject __pyx_string_tab[133]
#define __pyx_n_u_TemplateObjectGetter __pyx_string_tab[134]
#define __pyx_n_u_TemplateObjectGetter___getattr __pyx_string_tab[135]
#define __pyx_n_u_TemplateObjectGetter___init __pyx_string_tab[136]
#define __pyx_n_u_TemplateObjectGetter___repr __pyx_string_tab[137]
#define __pyx_n_u_TemplateObjectGetter__template __pyx_string_tab[138]
#define __pyx_n_u_TemplateObject___init __pyx_string_tab[139]
#define __pyx_n_u_TemplateObject___repr __pyx_string_tab[140]
#define __pyx_n_u_TemplateObject__name __pyx_string_tab[141]
#define __pyx_n_u_Template___init __pyx_string_tab[142]
#define __pyx_n_u_Template___repr __pyx_string_tab[143]
#define __pyx_n_u_Template__add_line_info __pyx_string_tab[144]
#define __pyx_n_u_Template__eval __pyx_string_tab[145]
#define __pyx_n_u_Template__exec __pyx_string_tab[146]
#define __pyx_n_u_Template__interpret __pyx_string_tab[147]
#define __pyx_n_u_Template__interpret_code __pyx_string_tab[148]
#define __pyx_n_u_Template__interpret_codes __pyx_string_tab[149]
#define __pyx_n_u_Template__interpret_for __pyx_string_tab[150]
#define __pyx_n_u_Template__interpret_if __pyx_string_tab[151]
#define __pyx_n_u_Template__interpret_inherit __pyx_string_tab[152]
#define __pyx_n_u_Template__repr __pyx_string_tab[153]
#define __pyx_n_u_Template_from_filename __pyx_string_tab[154]
#define __pyx_n_u_Template_substitute __pyx_string_tab[155]
#define __pyx_n_u_action __pyx_string_tab[156]
#define __pyx_n_u_add_line_info __pyx_string_tab[157]
#define __pyx_n_u_add_option __pyx_string_tab[158]
#define __pyx_n_u_all __pyx_string_tab[159]
#define __pyx_n_u_append __pyx_string_tab[160]
#define __pyx_n_u_arg0 __pyx_string_tab[161]
#define __pyx_n_u_args __pyx_string_tab[162]
#define __pyx_n_u_argv __pyx_string_tab[163]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[164]
#define __pyx_n_u_attr __pyx_string_tab[165]
#define __pyx_n_u_base __pyx_string_tab[166]
#define __pyx_n_u_body __pyx_string_tab[167]
#define __pyx_n_u_body_2 __pyx_string_tab[168]
#define __pyx_n_u_bool __pyx_string_tab[169]
#define __pyx_n_u_bound_self __pyx_string_tab[170]
#define __pyx_n_u_bound_self_2 __pyx_string_tab[171]
#define __pyx_n_u_break __pyx_string_tab[172]
#define __pyx_n_u_builtins __pyx_string_tab[173]
#define __pyx_n_u_bunch __pyx_string_tab[174]
#define __pyx_n_u_bunch___getattr __pyx_string_tab[175]
#define __pyx_n_u_bunch___getitem __pyx_string_tab[176]
#define __pyx_n_u_bunch___init __pyx_string_tab[177]
#define __pyx_n_u_bunch___repr __pyx_string_tab[178]
#define __pyx_n_u_bunch___setattr __pyx_string_tab[179]
#define __pyx_n_u_c __pyx_string_tab[180]
#define __pyx_n_u_call __pyx_string_tab[181]
#define __pyx_n_u_caller __pyx_string_tab[182]
#define __pyx_n_u_chunks __pyx_string_tab[183]
#define __pyx_n_u_class __pyx_string_tab[184]
#define __pyx_n_u_class_getitem __pyx_string_tab[185]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[186]
#define __pyx_n_u_cls __pyx_string_tab[187]
#define __pyx_n_u_code __pyx_string_tab[188]
#define __pyx_n_u_codes __pyx_string_tab[189]
#define __pyx_n_u_coerce_text __pyx_string_tab[190]
#define __pyx_n_u_column_2 __pyx_string_tab[191]
#define __pyx_n_u_comment __pyx_string_tab[192]
#define __pyx_n_u_compile __pyx_string_tab[193]
#define __pyx_n_u_cond __pyx_string_tab[194]
#define __pyx_n_u_content __pyx_string_tab[195]
#define __pyx_n_u_context __pyx_string_tab[196]
#define __pyx_n_u_continue __pyx_string_tab[197]
#define __pyx_n_u_copy __pyx_string_tab[198]
#define __pyx_n_u_count __pyx_string_tab[199]
#define __pyx_n_u_current __pyx_string_tab[200]
#define __pyx_n_u_decode __pyx_string_tab[201]
#define __pyx_n_u_def __pyx_string_tab[202]
#define __pyx_n_u_default __pyx_string_tab[203]
#define __pyx_n_u_default_encoding __pyx_string_tab[204]
#define __pyx_n_u_default_expr __pyx_string_tab[205]
#define __pyx_n_u_default_inherit __pyx_string_tab[206]
#define __pyx_n_u_default_namespace __pyx_string_tab[207]
#define __pyx_n_u_defaults __pyx_string_tab[208]
#define __pyx_n_u_defs __pyx_string_tab[209]
#define __pyx_n_u_delimeters __pyx_string_tab[210]
#define __pyx_n_u_delimiters __pyx_string_tab[211]
#define __pyx_n_u_dest __pyx_string_tab[212]
#define __pyx_n_u_dirname __pyx_string_tab[213]
#define __pyx_n_u_doc __pyx_string_tab[214]
#define __pyx_n_u_e __pyx_string_tab[215]
#define __pyx_n_u_ecol __pyx_string_tab[216]
#define __pyx_n_u_elif_2 __pyx_string_tab[217]
#define __pyx_n_u_else __pyx_string_tab[218]
#define __pyx_n_u_encode __pyx_string_tab[219]
#define __pyx_n_u_encoding __pyx_string_tab[220]
#define __pyx_n_u_end __pyx_string_tab[221]
#define __pyx_n_u_end_braces __pyx_string_tab[222]
#define __pyx_n_u_end_pos __pyx_string_tab[223]
#define __pyx_n_u_enddef __pyx_string_tab[224]
#define __pyx_n_u_endfor __pyx_string_tab[225]
#define __pyx_n_u_endif __pyx_string_tab[226]
#define __pyx_n_u_endswith __pyx_string_tab[227]
#define __pyx_n_u_enter __pyx_string_tab[228]
#define __pyx_n_u_enumerate __pyx_string_tab[229]
#define __pyx_n_u_environ __pyx_string_tab[230]
#define __pyx_n_u_erow __pyx_string_tab[231]
#define __pyx_n_u_escape __pyx_string_tab[232]
#define __pyx_n_u_eval __pyx_string_tab[233]
#define __pyx_n_u_eval_2 __pyx_string_tab[234]
#define __pyx_n_u_exec __pyx_string_tab[235]
#define __pyx_n_u_exit __pyx_string_tab[236]
#define __pyx_n_u_exit_2 __pyx_string_tab[237]
#define __pyx_n_u_expr __pyx_string_tab[238]
#define __pyx_n_u_extra_kw __pyx_string_tab[239]
#define __pyx_n_u_f __pyx_string_tab[240]
#define __pyx_n_u_f_globals __pyx_string_tab[241]
#define __pyx_n_u_f_lineno __pyx_string_tab[242]
#define __pyx_n_u_file __pyx_string_tab[243]
#define __pyx_n_u_filename __pyx_string_tab[244]
#define __pyx_n_u_fill_command __pyx_string_tab[245]
#define __pyx_n_u_fill_command_usage __pyx_string_tab[246]
#define __pyx_n_u_find_position __pyx_string_tab[247]
#define __pyx_n_u_finditer __pyx_string_tab[248]
#define __pyx_n_u_first __pyx_string_tab[249]
#define __pyx_n_u_for __pyx_string_tab[250]
#define __pyx_n_u_from_filename __pyx_string_tab[251]
#define __pyx_n_u_from_template __pyx_string_tab[252]
#define __pyx_n_u_func __pyx_string_tab[253]
#define __pyx_n_u_func_2 __pyx_string_tab[254]
#define __pyx_n_u_func_name __pyx_string_tab[255]
#define __pyx_n_u_func_name_2 __pyx_string_tab[256]
#define __pyx_n_u_func_signature __pyx_string_tab[257]
#define __pyx_n_u_func_signature_2 __pyx_string_tab[258]
#define __pyx_n_u_generate_tokens __pyx_string_tab[259]
#define __pyx_n_u_get __pyx_string_tab[260]
#define __pyx_n_u_get_2 __pyx_string_tab[261]
#define __pyx_n_u_get_file_template __pyx_string_tab[262]
#define __pyx_n_u_get_template __pyx_string_tab[263]
#define __pyx_n_u_get_token __pyx_string_tab[264]
#define __pyx_n_u_getattr __pyx_string_tab[265]
#define __pyx_n_u_getframe __pyx_string_tab[266]
#define __pyx_n_u_getitem __pyx_string_tab[267]
#define __pyx_n_u_globals __pyx_string_tab[268]
#define __pyx_n_u_group __pyx_string_tab[269]
#define __pyx_n_u_help __pyx_string_tab[270]
#define __pyx_n_u_i __pyx_string_tab[271]
#define __pyx_n_u_id __pyx_string_tab[272]
#define __pyx_n_u_if_2 __pyx_string_tab[273]
#define __pyx_n_u_in_expr __pyx_string_tab[274]
#define __pyx_n_u_in_re __pyx_string_tab[275]
#define __pyx_n_u_index __pyx_string_tab[276]
#define __pyx_n_u_inherit __pyx_string_tab[277]
#define __pyx_n_u_inherit_2 __pyx_string_tab[278]
#define __pyx_n_u_inherit_template __pyx_string_tab[279]
#define __pyx_n_u_init __pyx_string_tab[280]
#define __pyx_n_u_interpret __pyx_string_tab[281]
#define __pyx_n_u_interpret_code __pyx_string_tab[282]
#define __pyx_n_u_interpret_codes __pyx_string_tab[283]
#define __pyx_n_u_interpret_for __pyx_string_tab[284]
#define __pyx_n_u_interpret_if __pyx_string_tab[285]
#define __pyx_n_u_interpret_inherit __pyx_string_tab[286]
#define __pyx_n_u_io __pyx_string_tab[287]
#define __pyx_n_u_is_coroutine __pyx_string_tab[288]
#define __pyx_n_u_isolate_expression __pyx_string_tab[289]
#define __pyx_n_u_item __pyx_string_tab[290]
#define __pyx_n_u_items __pyx_string_tab[291]
#define __pyx_n_u_iter __pyx_string_tab[292]
#define __pyx_n_u_join __pyx_string_tab[293]
#define __pyx_n_u_k __pyx_string_tab[294]
#define __pyx_n_u_key __pyx_string_tab[295]
#define __pyx_n_u_kw __pyx_string_tab[296]
#define __pyx_n_u_last __pyx_string_tab[297]
#define __pyx_n_u_last_index __pyx_string_tab[298]
#define __pyx_n_u_last_pos __pyx_string_tab[299]
#define __pyx_n_u_last_trim __pyx_string_tab[300]
#define __pyx_n_u_lead_whitespace_re __pyx_string_tab[301]
#define __pyx_n_u_lex __pyx_string_tab[302]
#define __pyx_n_u_line __pyx_string_tab[303]
#define __pyx_n_u_line_offset __pyx_string_tab[304]
#define __pyx_n_u_lineno __pyx_string_tab[305]
#define __pyx_n_u_lines __pyx_string_tab[306]
#define __pyx_n_u_looper __pyx_string_tab[307]
#define __pyx_n_u_looper_2 __pyx_string_tab[308]
#define __pyx_n_u_lstrip __pyx_string_tab[309]
#define __pyx_n_u_m __pyx_string_tab[310]
#define __pyx_n_u_main __pyx_string_tab[311]
#define __pyx_n_u_match __pyx_string_tab[312]
#define __pyx_n_u_message __pyx_string_tab[313]
#define __pyx_n_u_metaclass __pyx_string_tab[314]
#define __pyx_n_u_metavar __pyx_string_tab[315]
#define __pyx_n_u_module __pyx_string_tab[316]
#define __pyx_n_u_mro_entries __pyx_string_tab[317]
#define __pyx_n_u_msg __pyx_string_tab[318]
#define __pyx_n_u_name __pyx_string_tab[319]
#define __pyx_n_u_name_2 __pyx_string_tab[320]
#define __pyx_n_u_name_4 __pyx_string_tab[321]
#define __pyx_n_u_namespace __pyx_string_tab[322]
#define __pyx_n_u_nest_count __pyx_string_tab[323]
#define __pyx_n_u_nest_type __pyx_string_tab[324]
#define __pyx_n_u_next __pyx_string_tab[325]
#define __pyx_n_u_next_chunk __pyx_string_tab[326]
#define __pyx_n_u_ns __pyx_string_tab[327]
#define __pyx_n_u_ns_2 __pyx_string_tab[328]
#define __pyx_n_u_obj __pyx_string_tab[329]
#define __pyx_n_u_object __pyx_string_tab[330]
#define __pyx_n_u_open __pyx_string_tab[331]
#define __pyx_n_u_options __pyx_string_tab[332]
#define __pyx_n_u_optparse __pyx_string_tab[333]
#define __pyx_n_u_os __pyx_string_tab[334]
#define __pyx_n_u_out __pyx_string_tab[335]
#define __pyx_n_u_output_2 __pyx_string_tab[336]
#define __pyx_n_u_parse __pyx_string_tab[337]
#define __pyx_n_u_parse_args __pyx_string_tab[338]
#define __pyx_n_u_parse_cond __pyx_string_tab[339]
#define __pyx_n_u_parse_def __pyx_string_tab[340]
#define __pyx_n_u_parse_default __pyx_string_tab[341]
#define __pyx_n_u_parse_expr __pyx_string_tab[342]
#define __pyx_n_u_parse_for __pyx_string_tab[343]
#define __pyx_n_u_parse_inherit __pyx_string_tab[344]
#define __pyx_n_u_parse_one_cond __pyx_string_tab[345]
#define __pyx_n_u_parse_signature __pyx_string_tab[346]
#define __pyx_n_u_parse_signature_2 __pyx_string_tab[347]
#define __pyx_n_u_parse_signature_locals_get_token __pyx_string_tab[348]
#define __pyx_n_u_parsed __pyx_string_tab[349]
#define __pyx_n_u_parser __pyx_string_tab[350]
#define __pyx_n_u_part __pyx_string_tab[351]
#define __pyx_n_u_parts __pyx_string_tab[352]
#define __pyx_n_u_paste_script_template_renderer __pyx_string_tab[353]
#define __pyx_n_u_path __pyx_string_tab[354]
#define __pyx_n_u_pieces __pyx_string_tab[355]
#define __pyx_n_u_pop __pyx_string_tab[356]
#define __pyx_n_u_pos __pyx_string_tab[357]
#define __pyx_n_u_pos_2 __pyx_string_tab[358]
#define __pyx_n_u_position __pyx_string_tab[359]
#define __pyx_n_u_prepare __pyx_string_tab[360]
#define __pyx_n_u_prev __pyx_string_tab[361]
#define __pyx_n_u_prev_ok __pyx_string_tab[362]
#define __pyx_n_u_print __pyx_string_tab[363]
#define __pyx_n_u_py __pyx_string_tab[364]
#define __pyx_n_u_qualname __pyx_string_tab[365]
#define __pyx_n_u_rb __pyx_string_tab[366]
#define __pyx_n_u_re __pyx_string_tab[367]
#define __pyx_n_u_read __pyx_string_tab[368]
#define __pyx_n_u_readline __pyx_string_tab[369]
#define __pyx_n_u_reason __pyx_string_tab[370]
#define __pyx_n_u_replace __pyx_string_tab[371]
#define __pyx_n_u_repr __pyx_string_tab[372]
#define __pyx_n_u_repr_2 __pyx_string_tab[373]
#define __pyx_n_u_result __pyx_string_tab[374]
#define __pyx_n_u_rfind __pyx_string_tab[375]
#define __pyx_n_u_s_2 __pyx_string_tab[376]
#define __pyx_n_u_scol __pyx_string_tab[377]
#define __pyx_n_u_search __pyx_string_tab[378]
#define __pyx_n_u_self __pyx_string_tab[379]
#define __pyx_n_u_self_2 __pyx_string_tab[380]
#define __pyx_n_u_set_name __pyx_string_tab[381]
#define __pyx_n_u_setattr __pyx_string_tab[382]
#define __pyx_n_u_setdefault __pyx_string_tab[383]
#define __pyx_n_u_sig __pyx_string_tab[384]
#define __pyx_n_u_sig_args __pyx_string_tab[385]
#define __pyx_n_u_sig_text __pyx_string_tab[386]
#define __pyx_n_u_signature __pyx_string_tab[387]
#define __pyx_n_u_single_statements __pyx_string_tab[388]
#define __pyx_n_u_split __pyx_string_tab[389]
#define __pyx_n_u_splitlines __pyx_string_tab[390]
#define __pyx_n_u_srow __pyx_string_tab[391]
#define __pyx_n_u_stacklevel __pyx_string_tab[392]
#define __pyx_n_u_start __pyx_string_tab[393]
#define __pyx_n_u_start_braces __pyx_string_tab[394]
#define __pyx_n_u_start_pos __pyx_string_tab[395]
#define __pyx_n_u_startswith __pyx_string_tab[396]
#define __pyx_n_u_statement_re __pyx_string_tab[397]
#define __pyx_n_u_stdin __pyx_string_tab[398]
#define __pyx_n_u_stdout __pyx_string_tab[399]
#define __pyx_n_u_store_true __pyx_string_tab[400]
#define __pyx_n_u_str __pyx_string_tab[401]
#define __pyx_n_u_string_2 __pyx_string_tab[402]
#define __pyx_n_u_strip __pyx_string_tab[403]
#define __pyx_n_u_sub __pyx_string_tab[404]
#define __pyx_n_u_subdefs __pyx_string_tab[405]
#define __pyx_n_u_substitute __pyx_string_tab[406]
#define __pyx_n_u_sys __pyx_string_tab[407]
#define __pyx_n_u_templ __pyx_string_tab[408]
#define __pyx_n_u_template __pyx_string_tab[409]
#define __pyx_n_u_template_2 __pyx_string_tab[410]
#define __pyx_n_u_template_content __pyx_string_tab[411]
#define __pyx_n_u_template_name __pyx_string_tab[412]
#define __pyx_n_u_template_name_2 __pyx_string_tab[413]
#define __pyx_n_u_template_obj __pyx_string_tab[414]
#define __pyx_n_u_tmpl __pyx_string_tab[415]
#define __pyx_n_u_tok_string __pyx_string_tab[416]
#define __pyx_n_u_tok_type __pyx_string_tab[417]
#define __pyx_n_u_token_re __pyx_string_tab[418]
#define __pyx_n_u_tokenize __pyx_string_tab[419]
#define __pyx_n_u_tokens __pyx_string_tab[420]
#define __pyx_n_u_traceback_hide __pyx_string_tab[421]
#define __pyx_n_u_trail_whitespace_re __pyx_string_tab[422]
#define __pyx_n_u_trim_lex __pyx_string_tab[423]
#define __pyx_n_u_trim_whitespace __pyx_string_tab[424]
#define __pyx_n_u_type __pyx_string_tab[425]
#define __pyx_n_u_unicode __pyx_string_tab[426]
#define __pyx_n_u_unicode_2 __pyx_string_tab[427]
#define __pyx_n_u_unnest_type __pyx_string_tab[428]
#define __pyx_n_u_update __pyx_string_tab[429]
#define __pyx_n_u_usage __pyx_string_tab[430]
#define __pyx_n_u_use_env __pyx_string_tab[431]
#define __pyx_n_u_utf8 __pyx_string_tab[432]
#define __pyx_n_u_v __pyx_string_tab[433]
#define __pyx_n_u_value __pyx_string_tab[434]
#define __pyx_n_u_value_expr __pyx_string_tab[435]
#define __pyx_n_u_values __pyx_string_tab[436]
#define __pyx_n_u_var __pyx_string_tab[437]
#define __pyx_n_u_var_arg __pyx_string_tab[438]
#define __pyx_n_u_var_arg_type __pyx_string_tab[439]
#define __pyx_n_u_var_args __pyx_string_tab[440]
#define __pyx_n_u_var_kw __pyx_string_tab[441]
#define __pyx_n_u_var_name __pyx_string_tab[442]
#define __pyx_n_u_var_re __pyx_string_tab[443]
#define __pyx_n_u_vars __pyx_string_tab[444]
#define __pyx_n_u_warn __pyx_string_tab[445]
#define __pyx_n_u_warnings __pyx_string_tab[446]
#define __pyx_n_u_wb __pyx_string_tab[447]
#define __pyx_n_u_write __pyx_string_tab[448]
#define __pyx_n_u_zip __pyx_string_tab[449]
#define __pyx_kp_b_iso88591_1_4s_1_t_Q_D_T_F_g __pyx_string_tab[450]
#define __pyx_kp_b_iso88591_1_Kq_1_E_Q_Q_c_0_0_T_3EU_5Zq_3 __pyx_string_tab[451]
#define __pyx_kp_b_iso88591_2T_4q_c_81IU_4_1 __pyx_string_tab[452]
#define __pyx_kp_b_iso88591_2U_q_xq_XQ_j_Q __pyx_string_tab[453]
#define __pyx_kp_b_iso88591_2_81IU_4_1 __pyx_string_tab[454]
#define __pyx_kp_b_iso88591_5Q_9_IQ_a_1_s_83e_Zq_4M __pyx_string_tab[455]
#define __pyx_kp_b_iso88591_6_L_HA __pyx_string_tab[456]
#define __pyx_kp_b_iso88591_6_q_5_1A_5_avRq_1KuG6 __pyx_string_tab[457]
#define __pyx_kp_b_iso88591_6_q_5_1A_E_q_b_E_q_Q_s_7_Q_m1_I __pyx_string_tab[458]
#define __pyx_kp_b_iso88591_6_q_V1A_xr_a_5_1IQ_uIQa_S_E_V1 __pyx_string_tab[459]
#define __pyx_kp_b_iso88591_86_V1A_5_1A_E_q_b_uIQa_S_t7_A_t __pyx_string_tab[460]
#define __pyx_kp_b_iso88591_A_1_q_iq_s_6_1_iq_t7_4q_A_iq_1A __pyx_string_tab[461]
#define __pyx_kp_b_iso88591_A_4q __pyx_string_tab[462]
#define __pyx_kp_b_iso88591_A_4z_D __pyx_string_tab[463]
#define __pyx_kp_b_iso88591_A_AT_AQ_4q_4q_q __pyx_string_tab[464]
#define __pyx_kp_b_iso88591_A_AXQ __pyx_string_tab[465]
#define __pyx_kp_b_iso88591_A_A_F_Qa_uCq_uAU_5_AU_5_at1Ba_u __pyx_string_tab[466]
#define __pyx_kp_b_iso88591_A_D_T __pyx_string_tab[467]
#define __pyx_kp_b_iso88591_A_F_2V1_1F __pyx_string_tab[468]
#define __pyx_kp_b_iso88591_A_HKt1_1_F_2V1_t7_e7_iq_Rq_uCq_a __pyx_string_tab[469]
#define __pyx_kp_b_iso88591_A_Ja_G_q __pyx_string_tab[470]
#define __pyx_kp_b_iso88591_A_M_N_q_IQ_G1_HA_O1 __pyx_string_tab[471]
#define __pyx_kp_b_iso88591_A_Q_4t1_q_uD_M_4A_at1_F_4vQ_1G6 __pyx_string_tab[472]
#define __pyx_kp_b_iso88591_A_Q_AV4_1_k_7r_1_A_was_q_Qa_1_Yd __pyx_string_tab[473]
#define __pyx_kp_b_iso88591_A_Q_HA_4z_AT_Qa_uCq_V1D_T_q_Qd_4 __pyx_string_tab[474]
#define __pyx_kp_b_iso88591_A_Q_HA_s_6_A_4q_a_3avS_1A_A_3awc __pyx_string_tab[475]
#define __pyx_kp_b_iso88591_A_Q_HA_z_7_1_AV4uA __pyx_string_tab[476]
#define __pyx_kp_b_iso88591_A_Q_fD_T_5_1_at1D_A_Q_1_Q_Q_at4q __pyx_string_tab[477]
#define __pyx_kp_b_iso88591_A_Q_q_Qd_D_G5_A_d_aq_a_r_axvQ __pyx_string_tab[478]
#define __pyx_kp_b_iso88591_A_Q_t_q_A_q_oQauAT_oQfA __pyx_string_tab[479]
#define __pyx_kp_b_iso88591_A_Q_vS_q_t1_Cq_E_4z_Kq_Jawa_D_E __pyx_string_tab[480]
#define __pyx_kp_b_iso88591_A_S_t_q_a_t_q_a_4_1F __pyx_string_tab[481]
#define __pyx_kp_b_iso88591_A_a __pyx_string_tab[482]
#define __pyx_kp_b_iso88591_A_avQ_T_U_4_G1_az_Q_a_J_q_HD_Q_r __pyx_string_tab[483]
#define __pyx_kp_b_iso88591_A_c_at1_4q_A_T_4t9AQ_4q_9Bd_q __pyx_string_tab[484]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[485]
#define __pyx_kp_b_iso88591_A_q_T_Q __pyx_string_tab[486]
#define __pyx_kp_b_iso88591_A_q_q_6_t1 __pyx_string_tab[487]
#define __pyx_kp_b_iso88591_A_q_uAQk_Ct3e6_fA __pyx_string_tab[488]
#define __pyx_kp_b_iso88591_A_t1 __pyx_string_tab[489]
#define __pyx_kp_b_iso88591_A_t1A __pyx_string_tab[490]
#define __pyx_kp_b_iso88591_A_wat_F __pyx_string_tab[491]
#define __pyx_kp_b_iso88591_F_1_vRq_r_vQfL_S_b_HAS __pyx_string_tab[492]
#define __pyx_kp_b_iso88591_F_2Qa_Q_hc_4q_q_Q_JavQd_F_2Qc_A __pyx_string_tab[493]
#define __pyx_kp_b_iso88591_F_6_fAQ_a_uIQa_S_uKq_e5_G4q_k_U __pyx_string_tab[494]
#define __pyx_kp_b_iso88591_N_m6_wgT_8_q_1_a_Q __pyx_string_tab[495]
#define __pyx_kp_b_iso88591_O1_Q_x_1_1_a_Q_1_Bc_r_b_q_1_q_1 __pyx_string_tab[496]
#define __pyx_kp_b_iso88591_Q_z_Q_vQd_aq_4vQ_t_aq_t1Cwaq_4 __pyx_string_tab[497]
#define __pyx_kp_b_iso88591_X_Qhay_q_a_Q_q_q_y_9Cxq_9Cxt5_3 __pyx_string_tab[498]
#define __pyx_kp_b_iso88591_iq_Qiq_waq_4_7_6_U_4q_1_6_Ba_2R __pyx_string_tab[499]
#define __pyx_kp_b_iso88591_qd_Q_x_1_1_S_E_1_Q_IZq_gQa_1 __pyx_string_tab[500]
#define __pyx_kp_b_iso88591_t_Qc_7_3a_3aq_5_1 __pyx_string_tab[501]
#define __pyx_kp_b_iso88591_uCq_s_q_X_a_Q_a_Q_Q_Q_Q_q_Q_WF __pyx_string_tab[502]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_neg_1 __pyx_number_tab[1]
#define __pyx_int_1 __pyx_number_tab[2]
#define __pyx_int_2 __pyx_number_tab[3]
#define __pyx_int_3 __pyx_number_tab[4]
#define __pyx_int_5 __pyx_number_tab[5]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature);
  for (int i=0; i<6; ++i) { Py_CLEAR(clear_module_state->__pyx_slice[i]); }
  for (int i=0; i<16; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<57; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<503; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<6; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature);
  for (int i=0; i<6; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_slice[i]); }
  for (int i=0; i<16; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<57; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<503; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<6; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "Cython/Tempita/_tempita.py":46
 * var_re = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)
 * 
 * def coerce_text(v):             # <<<<<<<<<<<<<<
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_1coerce_text(PyObject *__pyx_self, PyObject *__pyx_v_v); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_1coerce_text = {"coerce_text", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_1coerce_text, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_1coerce_text(PyObject *__pyx_self, PyObject *__pyx_v_v) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coerce_text (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_coerce_text(__pyx_self, ((PyObject *)__pyx_v_v));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_coerce_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_v) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coerce_text", 0);

  /* "Cython/Tempita/_tempita.py":47
 * 
 * def coerce_text(v):
 *     if not isinstance(v, str):             # <<<<<<<<<<<<<<
 *         if hasattr(v, '__str__'):
 *             return str(v)
*/
  __pyx_t_1 = PyUnicode_Check(__pyx_v_v); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Tempita/_tempita.py":48
 * def coerce_text(v):
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):             # <<<<<<<<<<<<<<
 *             return str(v)
 *         else:
*/
    __pyx_t_2 = __Pyx_HasAttr(__pyx_v_v, __pyx_mstate_global->__pyx_n_u_str); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 48, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Tempita/_tempita.py":49
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):
 *             return str(v)             # <<<<<<<<<<<<<<
 *         else:
 *             return bytes(v)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_Unicode(__pyx_v_v); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":48
 * def coerce_text(v):
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):             # <<<<<<<<<<<<<<
 *             return str(v)
 *         else:
*/
    }

    /* "Cython/Tempita/_tempita.py":51
 *             return str(v)
 *         else:
 *             return bytes(v)             # <<<<<<<<<<<<<<
 *     return v
 * 
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_v};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 51, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }

    /* "Cython/Tempita/_tempita.py":47
 * 
 * def coerce_text(v):
 *     if not isinstance(v, str):             # <<<<<<<<<<<<<<
 *         if hasattr(v, '__str__'):
 *             return str(v)
*/
  }

  /* "Cython/Tempita/_tempita.py":52
 *         else:
 *             return bytes(v)
 *     return v             # <<<<<<<<<<<<<<
 * 
 * class TemplateError(Exception):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_v);
  __pyx_r = __pyx_v_v;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":46
 * var_re = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)
 * 
 * def coerce_text(v):             # <<<<<<<<<<<<<<
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Tempita._tempita.coerce_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":58
 *     """
 * 
 *     def __init__(self, message, position, name=None):             # <<<<<<<<<<<<<<
 *         Exception.__init__(self, message)
 *         self.position = position
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_13TemplateError_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_v_position = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_message,&__pyx_mstate_global->__pyx_n_u_position,&__pyx_mstate_global->__pyx_n_u_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 58, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 58, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, i); __PYX_ERR(0, 58, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 58, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 58, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 58, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_message = values[1];
    __pyx_v_position = values[2];
    __pyx_v_name = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 58, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateError.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError___init__(__pyx_self, __pyx_v_self, __pyx_v_message, __pyx_v_position, __pyx_v_name);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_message, PyObject *__pyx_v_position, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Tempita/_tempita.py":59
 * 
 *     def __init__(self, message, position, name=None):
 *         Exception.__init__(self, message)             # <<<<<<<<<<<<<<
 *         self.position = position
 *         self.name = name
*/
  __pyx_t_2 = ((PyObject *)(((PyTypeObject*)PyExc_Exception)));
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_self, __pyx_v_message};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":60
 *     def __init__(self, message, position, name=None):
 *         Exception.__init__(self, message)
 *         self.position = position             # <<<<<<<<<<<<<<
 *         self.name = name
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_position, __pyx_v_position) < (0)) __PYX_ERR(0, 60, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":61
 *         Exception.__init__(self, message)
 *         self.position = position
 *         self.name = name             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name, __pyx_v_name) < (0)) __PYX_ERR(0, 61, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":58
 *     """
 * 
 *     def __init__(self, message, position, name=None):             # <<<<<<<<<<<<<<
 *         Exception.__init__(self, message)
 *         self.position = position
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateError.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":63
 *         self.name = name
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         msg = ' '.join(self.args)
 *         if self.position:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_13TemplateError_3__str__ = {"__str__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_3__str__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13TemplateError_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError_2__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_13TemplateError_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "Cython/Tempita/_tempita.py":64
 * 
 *     def __str__(self):
 *         msg = ' '.join(self.args)             # <<<<<<<<<<<<<<
 *         if self.position:
 *             msg = '%s at line %s column %s' % (
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u_, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_msg = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":65
 *     def __str__(self):
 *         msg = ' '.join(self.args)
 *         if self.position:             # <<<<<<<<<<<<<<
 *             msg = '%s at line %s column %s' % (
 *                 msg, self.position[0], self.position[1])
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_position); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":67
 *         if self.position:
 *             msg = '%s at line %s column %s' % (
 *                 msg, self.position[0], self.position[1])             # <<<<<<<<<<<<<<
 *         if self.name:
 *             msg += ' in %s' % self.name
*/
    __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_msg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_4), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_position); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_4, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_5), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6[0] = __pyx_t_2;
    __pyx_t_6[1] = __pyx_mstate_global->__pyx_kp_u_at_line;
    __pyx_t_6[2] = __pyx_t_1;
    __pyx_t_6[3] = __pyx_mstate_global->__pyx_kp_u_column;
    __pyx_t_6[4] = __pyx_t_4;

    /* "Cython/Tempita/_tempita.py":66
 *         msg = ' '.join(self.args)
 *         if self.position:
 *             msg = '%s at line %s column %s' % (             # <<<<<<<<<<<<<<
 *                 msg, self.position[0], self.position[1])
 *         if self.name:
*/
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_6, 5, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_msg, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Tempita/_tempita.py":65
 *     def __str__(self):
 *         msg = ' '.join(self.args)
 *         if self.position:             # <<<<<<<<<<<<<<
 *             msg = '%s at line %s column %s' % (
 *                 msg, self.position[0], self.position[1])
*/
  }

  /* "Cython/Tempita/_tempita.py":68
 *             msg = '%s at line %s column %s' % (
 *                 msg, self.position[0], self.position[1])
 *         if self.name:             # <<<<<<<<<<<<<<
 *             msg += ' in %s' % self.name
 *         return msg
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":69
 *                 msg, self.position[0], self.position[1])
 *         if self.name:
 *             msg += ' in %s' % self.name             # <<<<<<<<<<<<<<
 *         return msg
 * 
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_in_s, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(__pyx_v_msg, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_msg, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "Cython/Tempita/_tempita.py":68
 *             msg = '%s at line %s column %s' % (
 *                 msg, self.position[0], self.position[1])
 *         if self.name:             # <<<<<<<<<<<<<<
 *             msg += ' in %s' % self.name
 *         return msg
*/
  }

  /* "Cython/Tempita/_tempita.py":70
 *         if self.name:
 *             msg += ' in %s' % self.name
 *         return msg             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_msg);
  __pyx_r = __pyx_v_msg;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":63
 *         self.name = name
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         msg = ' '.join(self.args)
 *         if self.position:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateError.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":81
 * 
 * 
 * def get_file_template(name, from_template):             # <<<<<<<<<<<<<<
 *     path = os.path.join(os.path.dirname(from_template.name), name)
 *     return from_template.__class__.from_filename(
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_3get_file_template(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_3get_file_template = {"get_file_template", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_3get_file_template, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_3get_file_template(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_from_template = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_file_template (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_from_template,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 81, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 81, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 81, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_file_template", 0) < (0)) __PYX_ERR(0, 81, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_file_template", 1, 2, 2, i); __PYX_ERR(0, 81, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 81, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 81, __pyx_L3_error)
    }
    __pyx_v_name = values[0];
    __pyx_v_from_template = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_file_template", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 81, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.get_file_template", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_2get_file_template(__pyx_self, __pyx_v_name, __pyx_v_from_template);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_2get_file_template(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name, PyObject *__pyx_v_from_template) {
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_file_template", 0);

  /* "Cython/Tempita/_tempita.py":82
 * 
 * def get_file_template(name, from_template):
 *     path = os.path.join(os.path.dirname(from_template.name), name)             # <<<<<<<<<<<<<<
 *     return from_template.__class__.from_filename(
 *         path, namespace=from_template.namespace,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = __pyx_t_7;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_from_template, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_dirname, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_v_name};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_join, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":83
 * def get_file_template(name, from_template):
 *     path = os.path.join(os.path.dirname(from_template.name), name)
 *     return from_template.__class__.from_filename(             # <<<<<<<<<<<<<<
 *         path, namespace=from_template.namespace,
 *         get_template=from_template.get_template)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_from_template, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_4);

  /* "Cython/Tempita/_tempita.py":84
 *     path = os.path.join(os.path.dirname(from_template.name), name)
 *     return from_template.__class__.from_filename(
 *         path, namespace=from_template.namespace,             # <<<<<<<<<<<<<<
 *         get_template=from_template.get_template)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_from_template, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Tempita/_tempita.py":85
 *     return from_template.__class__.from_filename(
 *         path, namespace=from_template.namespace,
 *         get_template=from_template.get_template)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_from_template, __pyx_mstate_global->__pyx_n_u_get_template); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_path};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_namespace, __pyx_t_2, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 83, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_get_template, __pyx_t_7, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 83, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_from_filename, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":81
 * 
 * 
 * def get_file_template(name, from_template):             # <<<<<<<<<<<<<<
 *     path = os.path.join(os.path.dirname(from_template.name), name)
 *     return from_template.__class__.from_filename(
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Tempita._tempita.get_file_template", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_namespace = 0;
  PyObject *__pyx_v_stacklevel = 0;
  PyObject *__pyx_v_get_template = 0;
  PyObject *__pyx_v_default_inherit = 0;
  PyObject *__pyx_v_line_offset = 0;
  PyObject *__pyx_v_delimiters = 0;
  PyObject *__pyx_v_delimeters = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_content,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_namespace,&__pyx_mstate_global->__pyx_n_u_stacklevel,&__pyx_mstate_global->__pyx_n_u_get_template,&__pyx_mstate_global->__pyx_n_u_default_inherit,&__pyx_mstate_global->__pyx_n_u_line_offset,&__pyx_mstate_global->__pyx_n_u_delimiters,&__pyx_mstate_global->__pyx_n_u_delimeters,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 99, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case 10:
        values[9] = __Pyx_ArgRef_FASTCALL(__pyx_args, 9);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[9])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  9:
        values[8] = __Pyx_ArgRef_FASTCALL(__pyx_args, 8);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[8])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 99, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Tempita/_tempita.py":100
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,
 *                  get_template=None, default_inherit=None, line_offset=0,             # <<<<<<<<<<<<<<
 *                  delimiters=None, delimeters=None):
 *         self.content = content
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));

      /* "Cython/Tempita/_tempita.py":101
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):             # <<<<<<<<<<<<<<
 *         self.content = content
 * 
*/
      if (!values[8]) values[8] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[9]) values[9] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 10, i); __PYX_ERR(0, 99, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case 10:
        values[9] = __Pyx_ArgRef_FASTCALL(__pyx_args, 9);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[9])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  9:
        values[8] = __Pyx_ArgRef_FASTCALL(__pyx_args, 8);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[8])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 99, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 99, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 99, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Tempita/_tempita.py":100
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,
 *                  get_template=None, default_inherit=None, line_offset=0,             # <<<<<<<<<<<<<<
 *                  delimiters=None, delimeters=None):
 *         self.content = content
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));

      /* "Cython/Tempita/_tempita.py":101
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):             # <<<<<<<<<<<<<<
 *         self.content = content
 * 
*/
      if (!values[8]) values[8] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[9]) values[9] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_content = values[1];
    __pyx_v_name = values[2];
    __pyx_v_namespace = values[3];
    __pyx_v_stacklevel = values[4];
    __pyx_v_get_template = values[5];
    __pyx_v_default_inherit = values[6];
    __pyx_v_line_offset = values[7];
    __pyx_v_delimiters = values[8];
    __pyx_v_delimeters = values[9];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 10, __pyx_nargs); __PYX_ERR(0, 99, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template___init__(__pyx_self, __pyx_v_self, __pyx_v_content, __pyx_v_name, __pyx_v_namespace, __pyx_v_stacklevel, __pyx_v_get_template, __pyx_v_default_inherit, __pyx_v_line_offset, __pyx_v_delimiters, __pyx_v_delimeters);

  /* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_content, PyObject *__pyx_v_name, PyObject *__pyx_v_namespace, PyObject *__pyx_v_stacklevel, PyObject *__pyx_v_get_template, PyObject *__pyx_v_default_inherit, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters, PyObject *__pyx_v_delimeters) {
  PyObject *__pyx_v_warnings = NULL;
  PyObject *__pyx_v_caller = NULL;
  PyObject *__pyx_v_globals = NULL;
  PyObject *__pyx_v_lineno = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_INCREF(__pyx_v_namespace);
  __Pyx_INCREF(__pyx_v_delimiters);

  /* "Cython/Tempita/_tempita.py":102
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
 *         self.content = content             # <<<<<<<<<<<<<<
 * 
 *         # set delimiters
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_content, __pyx_v_content) < (0)) __PYX_ERR(0, 102, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":105
 * 
 *         # set delimiters
 *         if delimeters:             # <<<<<<<<<<<<<<
 *             import warnings
 *             warnings.warn(
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_delimeters); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 105, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":106
 *         # set delimiters
 *         if delimeters:
 *             import warnings             # <<<<<<<<<<<<<<
 *             warnings.warn(
 *                 "'delimeters' kwarg is being deprecated in favor of correctly"
*/
    __pyx_t_3 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_warnings, 0, 0, NULL, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 106, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_warnings = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":107
 *         if delimeters:
 *             import warnings
 *             warnings.warn(             # <<<<<<<<<<<<<<
 *                 "'delimeters' kwarg is being deprecated in favor of correctly"
 *                 " spelled 'delimiters'. Please adjust your code.",
*/
    __pyx_t_4 = __pyx_v_warnings;
    __Pyx_INCREF(__pyx_t_4);

    /* "Cython/Tempita/_tempita.py":110
 *                 "'delimeters' kwarg is being deprecated in favor of correctly"
 *                 " spelled 'delimiters'. Please adjust your code.",
 *                 DeprecationWarning             # <<<<<<<<<<<<<<
 *             )
 *             if delimiters is None:
*/
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_delimeters_kwarg_is_being_depre, ((PyObject *)(((PyTypeObject*)PyExc_DeprecationWarning)))};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_warn, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":112
 *                 DeprecationWarning
 *             )
 *             if delimiters is None:             # <<<<<<<<<<<<<<
 *                 delimiters = delimeters
 *         if delimiters is None:
*/
    __pyx_t_1 = (__pyx_v_delimiters == Py_None);
    if (__pyx_t_1) {

      /* "Cython/Tempita/_tempita.py":113
 *             )
 *             if delimiters is None:
 *                 delimiters = delimeters             # <<<<<<<<<<<<<<
 *         if delimiters is None:
 *             delimiters = (self.default_namespace['start_braces'],
*/
      __Pyx_INCREF(__pyx_v_delimeters);
      __Pyx_DECREF_SET(__pyx_v_delimiters, __pyx_v_delimeters);

      /* "Cython/Tempita/_tempita.py":112
 *                 DeprecationWarning
 *             )
 *             if delimiters is None:             # <<<<<<<<<<<<<<
 *                 delimiters = delimeters
 *         if delimiters is None:
*/
    }

    /* "Cython/Tempita/_tempita.py":105
 * 
 *         # set delimiters
 *         if delimeters:             # <<<<<<<<<<<<<<
 *             import warnings
 *             warnings.warn(
*/
  }

  /* "Cython/Tempita/_tempita.py":114
 *             if delimiters is None:
 *                 delimiters = delimeters
 *         if delimiters is None:             # <<<<<<<<<<<<<<
 *             delimiters = (self.default_namespace['start_braces'],
 *                           self.default_namespace['end_braces'])
*/
  __pyx_t_1 = (__pyx_v_delimiters == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":115
 *                 delimiters = delimeters
 *         if delimiters is None:
 *             delimiters = (self.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                           self.default_namespace['end_braces'])
 *         else:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_start_braces); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":116
 *         if delimiters is None:
 *             delimiters = (self.default_namespace['start_braces'],
 *                           self.default_namespace['end_braces'])             # <<<<<<<<<<<<<<
 *         else:
 *             #assert len(delimiters) == 2 and all([isinstance(delimiter, str)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_end_braces); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":115
 *                 delimiters = delimeters
 *         if delimiters is None:
 *             delimiters = (self.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                           self.default_namespace['end_braces'])
 *         else:
*/
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 115, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_6) != (0)) __PYX_ERR(0, 115, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_delimiters, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":114
 *             if delimiters is None:
 *                 delimiters = delimeters
 *         if delimiters is None:             # <<<<<<<<<<<<<<
 *             delimiters = (self.default_namespace['start_braces'],
 *                           self.default_namespace['end_braces'])
*/
    goto __pyx_L5;
  }

  /* "Cython/Tempita/_tempita.py":120
 *             #assert len(delimiters) == 2 and all([isinstance(delimiter, str)
 *             #                                     for delimiter in delimiters])
 *             self.default_namespace = self.__class__.default_namespace.copy()             # <<<<<<<<<<<<<<
 *             self.default_namespace['start_braces'] = delimiters[0]
 *             self.default_namespace['end_braces'] = delimiters[1]
*/
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __pyx_t_7;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_copy, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace, __pyx_t_2) < (0)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":121
 *             #                                     for delimiter in delimiters])
 *             self.default_namespace = self.__class__.default_namespace.copy()
 *             self.default_namespace['start_braces'] = delimiters[0]             # <<<<<<<<<<<<<<
 *             self.default_namespace['end_braces'] = delimiters[1]
 *         self.delimiters = self.delimeters = delimiters  # Keep a legacy read-only copy, but don't use it.
*/
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_delimiters, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely((PyObject_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_start_braces, __pyx_t_2) < 0))) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":122
 *             self.default_namespace = self.__class__.default_namespace.copy()
 *             self.default_namespace['start_braces'] = delimiters[0]
 *             self.default_namespace['end_braces'] = delimiters[1]             # <<<<<<<<<<<<<<
 *         self.delimiters = self.delimeters = delimiters  # Keep a legacy read-only copy, but don't use it.
 * 
*/
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_delimiters, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely((PyObject_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_end_braces, __pyx_t_2) < 0))) __PYX_ERR(0, 122, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "Cython/Tempita/_tempita.py":123
 *             self.default_namespace['start_braces'] = delimiters[0]
 *             self.default_namespace['end_braces'] = delimiters[1]
 *         self.delimiters = self.delimeters = delimiters  # Keep a legacy read-only copy, but don't use it.             # <<<<<<<<<<<<<<
 * 
 *         self._unicode = isinstance(content, str)
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_delimiters, __pyx_v_delimiters) < (0)) __PYX_ERR(0, 123, __pyx_L1_error)
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_delimeters, __pyx_v_delimiters) < (0)) __PYX_ERR(0, 123, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":125
 *         self.delimiters = self.delimeters = delimiters  # Keep a legacy read-only copy, but don't use it.
 * 
 *         self._unicode = isinstance(content, str)             # <<<<<<<<<<<<<<
 *         if name is None and stacklevel is not None:
 *             try:
*/
  __pyx_t_1 = PyUnicode_Check(__pyx_v_content); 
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_unicode, __pyx_t_2) < (0)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":126
 * 
 *         self._unicode = isinstance(content, str)
 *         if name is None and stacklevel is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 caller = sys._getframe(stacklevel)
*/
  __pyx_t_8 = (__pyx_v_name == Py_None);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_8 = (__pyx_v_stacklevel != Py_None);
  __pyx_t_1 = __pyx_t_8;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":127
 *         self._unicode = isinstance(content, str)
 *         if name is None and stacklevel is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 caller = sys._getframe(stacklevel)
 *             except ValueError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":128
 *         if name is None and stacklevel is not None:
 *             try:
 *                 caller = sys._getframe(stacklevel)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 pass
*/
        __pyx_t_7 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 128, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_getframe); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 128, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_stacklevel};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 128, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_v_caller = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":127
 *         self._unicode = isinstance(content, str)
 *         if name is None and stacklevel is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 caller = sys._getframe(stacklevel)
 *             except ValueError:
*/
      }

      /* "Cython/Tempita/_tempita.py":132
 *                 pass
 *             else:
 *                 globals = caller.f_globals             # <<<<<<<<<<<<<<
 *                 lineno = caller.f_lineno
 *                 if '__file__' in globals:
*/
      /*else:*/ {
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_caller, __pyx_mstate_global->__pyx_n_u_f_globals); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 132, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_globals = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":133
 *             else:
 *                 globals = caller.f_globals
 *                 lineno = caller.f_lineno             # <<<<<<<<<<<<<<
 *                 if '__file__' in globals:
 *                     name = globals['__file__']
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_caller, __pyx_mstate_global->__pyx_n_u_f_lineno); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_lineno = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":134
 *                 globals = caller.f_globals
 *                 lineno = caller.f_lineno
 *                 if '__file__' in globals:             # <<<<<<<<<<<<<<
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
*/
        __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_file, __pyx_v_globals, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 134, __pyx_L11_except_error)
        if (__pyx_t_1) {

          /* "Cython/Tempita/_tempita.py":135
 *                 lineno = caller.f_lineno
 *                 if '__file__' in globals:
 *                     name = globals['__file__']             # <<<<<<<<<<<<<<
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
 *                         name = name[:-1]
*/
          __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_globals, __pyx_mstate_global->__pyx_n_u_file); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "Cython/Tempita/_tempita.py":136
 *                 if '__file__' in globals:
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):             # <<<<<<<<<<<<<<
 *                         name = name[:-1]
 *                 elif '__name__' in globals:
*/
          __pyx_t_4 = __pyx_v_name;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_pyc};
            __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 136, __pyx_L11_except_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (!__pyx_t_8) {
          } else {
            __pyx_t_1 = __pyx_t_8;
            goto __pyx_L17_bool_binop_done;
          }
          __pyx_t_4 = __pyx_v_name;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_pyo};
            __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 136, __pyx_L11_except_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_1 = __pyx_t_8;
          __pyx_L17_bool_binop_done:;
          if (__pyx_t_1) {

            /* "Cython/Tempita/_tempita.py":137
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
 *                         name = name[:-1]             # <<<<<<<<<<<<<<
 *                 elif '__name__' in globals:
 *                     name = globals['__name__']
*/
            __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_name, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "Cython/Tempita/_tempita.py":136
 *                 if '__file__' in globals:
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):             # <<<<<<<<<<<<<<
 *                         name = name[:-1]
 *                 elif '__name__' in globals:
*/
          }

          /* "Cython/Tempita/_tempita.py":134
 *                 globals = caller.f_globals
 *                 lineno = caller.f_lineno
 *                 if '__file__' in globals:             # <<<<<<<<<<<<<<
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
*/
          goto __pyx_L15;
        }

        /* "Cython/Tempita/_tempita.py":138
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
 *                         name = name[:-1]
 *                 elif '__name__' in globals:             # <<<<<<<<<<<<<<
 *                     name = globals['__name__']
 *                 else:
*/
        __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_name_2, __pyx_v_globals, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 138, __pyx_L11_except_error)
        if (__pyx_t_1) {

          /* "Cython/Tempita/_tempita.py":139
 *                         name = name[:-1]
 *                 elif '__name__' in globals:
 *                     name = globals['__name__']             # <<<<<<<<<<<<<<
 *                 else:
 *                     name = '<string>'
*/
          __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_globals, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "Cython/Tempita/_tempita.py":138
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
 *                         name = name[:-1]
 *                 elif '__name__' in globals:             # <<<<<<<<<<<<<<
 *                     name = globals['__name__']
 *                 else:
*/
          goto __pyx_L15;
        }

        /* "Cython/Tempita/_tempita.py":141
 *                     name = globals['__name__']
 *                 else:
 *                     name = '<string>'             # <<<<<<<<<<<<<<
 *                 if lineno:
 *                     name += ':%s' % lineno
*/
        /*else*/ {
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_string);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_mstate_global->__pyx_kp_u_string);
        }
        __pyx_L15:;

        /* "Cython/Tempita/_tempita.py":142
 *                 else:
 *                     name = '<string>'
 *                 if lineno:             # <<<<<<<<<<<<<<
 *                     name += ':%s' % lineno
 *         self.name = name
*/
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_lineno); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 142, __pyx_L11_except_error)
        if (__pyx_t_1) {

          /* "Cython/Tempita/_tempita.py":143
 *                     name = '<string>'
 *                 if lineno:
 *                     name += ':%s' % lineno             # <<<<<<<<<<<<<<
 *         self.name = name
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)
*/
          __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s, __pyx_v_lineno); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_name, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 143, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Tempita/_tempita.py":142
 *                 else:
 *                     name = '<string>'
 *                 if lineno:             # <<<<<<<<<<<<<<
 *                     name += ':%s' % lineno
 *         self.name = name
*/
        }
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L14_try_end;
      __pyx_L9_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":129
 *             try:
 *                 caller = sys._getframe(stacklevel)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
*/
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
      if (__pyx_t_11) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L10_exception_handled;
      }
      goto __pyx_L11_except_error;

      /* "Cython/Tempita/_tempita.py":127
 *         self._unicode = isinstance(content, str)
 *         if name is None and stacklevel is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 caller = sys._getframe(stacklevel)
 *             except ValueError:
*/
      __pyx_L11_except_error:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L10_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_9, __pyx_t_10);
      __pyx_L14_try_end:;
    }

    /* "Cython/Tempita/_tempita.py":126
 * 
 *         self._unicode = isinstance(content, str)
 *         if name is None and stacklevel is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 caller = sys._getframe(stacklevel)
*/
  }

  /* "Cython/Tempita/_tempita.py":144
 *                 if lineno:
 *                     name += ':%s' % lineno
 *         self.name = name             # <<<<<<<<<<<<<<
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)
 *         if namespace is None:
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name, __pyx_v_name) < (0)) __PYX_ERR(0, 144, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":145
 *                     name += ':%s' % lineno
 *         self.name = name
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)             # <<<<<<<<<<<<<<
 *         if namespace is None:
 *             namespace = {}
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_parse); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_delimiters); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_content};
    __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_line_offset, __pyx_v_line_offset, __pyx_t_12, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_delimiters, __pyx_t_6, __pyx_t_12, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_parsed, __pyx_t_4) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Tempita/_tempita.py":146
 *         self.name = name
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)
 *         if namespace is None:             # <<<<<<<<<<<<<<
 *             namespace = {}
 *         self.namespace = namespace
*/
  __pyx_t_1 = (__pyx_v_namespace == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":147
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)
 *         if namespace is None:
 *             namespace = {}             # <<<<<<<<<<<<<<
 *         self.namespace = namespace
 *         self.get_template = get_template
*/
    __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_namespace, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":146
 *         self.name = name
 *         self._parsed = parse(content, name=name, line_offset=line_offset, delimiters=self.delimiters)
 *         if namespace is None:             # <<<<<<<<<<<<<<
 *             namespace = {}
 *         self.namespace = namespace
*/
  }

  /* "Cython/Tempita/_tempita.py":148
 *         if namespace is None:
 *             namespace = {}
 *         self.namespace = namespace             # <<<<<<<<<<<<<<
 *         self.get_template = get_template
 *         if default_inherit is not None:
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_namespace, __pyx_v_namespace) < (0)) __PYX_ERR(0, 148, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":149
 *             namespace = {}
 *         self.namespace = namespace
 *         self.get_template = get_template             # <<<<<<<<<<<<<<
 *         if default_inherit is not None:
 *             self.default_inherit = default_inherit
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_get_template, __pyx_v_get_template) < (0)) __PYX_ERR(0, 149, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":150
 *         self.namespace = namespace
 *         self.get_template = get_template
 *         if default_inherit is not None:             # <<<<<<<<<<<<<<
 *             self.default_inherit = default_inherit
 * 
*/
  __pyx_t_1 = (__pyx_v_default_inherit != Py_None);
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":151
 *         self.get_template = get_template
 *         if default_inherit is not None:
 *             self.default_inherit = default_inherit             # <<<<<<<<<<<<<<
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_inherit, __pyx_v_default_inherit) < (0)) __PYX_ERR(0, 151, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":150
 *         self.namespace = namespace
 *         self.get_template = get_template
 *         if default_inherit is not None:             # <<<<<<<<<<<<<<
 *             self.default_inherit = default_inherit
 * 
*/
  }

  /* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_warnings);
  __Pyx_XDECREF(__pyx_v_caller);
  __Pyx_XDECREF(__pyx_v_globals);
  __Pyx_XDECREF(__pyx_v_lineno);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_namespace);
  __Pyx_XDECREF(__pyx_v_delimiters);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_36__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);

  /* "Cython/Tempita/_tempita.py":154
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):             # <<<<<<<<<<<<<<
 *         with open(filename, 'rb') as f:
 *             c = f.read()
*/
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_None) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);

  /* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None) != (0)) __PYX_ERR(0, 153, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Tempita._tempita.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_3from_filename(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_3from_filename = {"from_filename", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_3from_filename, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_3from_filename(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_namespace = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_default_inherit = 0;
  PyObject *__pyx_v_get_template = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_filename (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_filename,&__pyx_mstate_global->__pyx_n_u_namespace,&__pyx_mstate_global->__pyx_n_u_encoding,&__pyx_mstate_global->__pyx_n_u_default_inherit,&__pyx_mstate_global->__pyx_n_u_get_template,0};
    struct __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self);
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 153, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_filename", 0) < (0)) __PYX_ERR(0, 153, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Tempita/_tempita.py":154
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):             # <<<<<<<<<<<<<<
 *         with open(filename, 'rb') as f:
 *             c = f.read()
*/
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[5]) values[5] = __Pyx_NewRef(__pyx_dynamic_args->arg0);
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_filename", 0, 2, 6, i); __PYX_ERR(0, 153, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 153, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 153, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 153, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "Cython/Tempita/_tempita.py":154
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):             # <<<<<<<<<<<<<<
 *         with open(filename, 'rb') as f:
 *             c = f.read()
*/
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[5]) values[5] = __Pyx_NewRef(__pyx_dynamic_args->arg0);
    }
    __pyx_v_cls = values[0];
    __pyx_v_filename = values[1];
    __pyx_v_namespace = values[2];
    __pyx_v_encoding = values[3];
    __pyx_v_default_inherit = values[4];
    __pyx_v_get_template = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_filename", 0, 2, 6, __pyx_nargs); __PYX_ERR(0, 153, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.from_filename", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_2from_filename(__pyx_self, __pyx_v_cls, __pyx_v_filename, __pyx_v_namespace, __pyx_v_encoding, __pyx_v_default_inherit, __pyx_v_get_template);

  /* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_2from_filename(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_filename, PyObject *__pyx_v_namespace, PyObject *__pyx_v_encoding, PyObject *__pyx_v_default_inherit, PyObject *__pyx_v_get_template) {
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_filename", 0);

  /* "Cython/Tempita/_tempita.py":155
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:             # <<<<<<<<<<<<<<
 *             c = f.read()
 *         if encoding:
*/
  /*with:*/ {
    __pyx_t_2 = NULL;
    __pyx_t_3 = 1;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_filename, __pyx_mstate_global->__pyx_n_u_rb};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_open, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 155, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_6 = __pyx_t_2;
    __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {
          __pyx_v_f = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "Cython/Tempita/_tempita.py":156
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
 *             c = f.read()             # <<<<<<<<<<<<<<
 *         if encoding:
 *             c = c.decode(encoding)
*/
          __pyx_t_1 = __pyx_v_f;
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
            __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_read, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 156, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_6);
          }
          __pyx_v_c = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "Cython/Tempita/_tempita.py":155
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:             # <<<<<<<<<<<<<<
 *             c = f.read()
 *         if encoding:
*/
        }
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L12_try_end;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Tempita._tempita.Template.from_filename", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 155, __pyx_L9_except_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_5 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 155, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 155, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (__pyx_t_11 < (0)) __PYX_ERR(0, 155, __pyx_L9_except_error)
          __pyx_t_12 = (!__pyx_t_11);
          if (unlikely(__pyx_t_12)) {
            __Pyx_GIVEREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_XGIVEREF(__pyx_t_2);
            __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_1, __pyx_t_2);
            __pyx_t_6 = 0;  __pyx_t_1 = 0;  __pyx_t_2 = 0; 
            __PYX_ERR(0, 155, __pyx_L9_except_error)
          }
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        __pyx_L12_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_4) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[0], NULL);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 155, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L6:;
    }
    goto __pyx_L16;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L1_error;
    __pyx_L16:;
  }

  /* "Cython/Tempita/_tempita.py":157
 *         with open(filename, 'rb') as f:
 *             c = f.read()
 *         if encoding:             # <<<<<<<<<<<<<<
 *             c = c.decode(encoding)
 *         return cls(content=c, name=filename, namespace=namespace,
*/
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_encoding); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 157, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "Cython/Tempita/_tempita.py":158
 *             c = f.read()
 *         if encoding:
 *             c = c.decode(encoding)             # <<<<<<<<<<<<<<
 *         return cls(content=c, name=filename, namespace=namespace,
 *                    default_inherit=default_inherit, get_template=get_template)
*/
    if (unlikely(!__pyx_v_c)) { __Pyx_RaiseUnboundLocalError("c"); __PYX_ERR(0, 158, __pyx_L1_error) }
    __pyx_t_1 = __pyx_v_c;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_encoding};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_c, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":157
 *         with open(filename, 'rb') as f:
 *             c = f.read()
 *         if encoding:             # <<<<<<<<<<<<<<
 *             c = c.decode(encoding)
 *         return cls(content=c, name=filename, namespace=namespace,
*/
  }

  /* "Cython/Tempita/_tempita.py":159
 *         if encoding:
 *             c = c.decode(encoding)
 *         return cls(content=c, name=filename, namespace=namespace,             # <<<<<<<<<<<<<<
 *                    default_inherit=default_inherit, get_template=get_template)
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = NULL;
  __Pyx_INCREF(__pyx_v_cls);
  __pyx_t_6 = __pyx_v_cls; 
  if (unlikely(!__pyx_v_c)) { __Pyx_RaiseUnboundLocalError("c"); __PYX_ERR(0, 159, __pyx_L1_error) }

  /* "Cython/Tempita/_tempita.py":160
 *             c = c.decode(encoding)
 *         return cls(content=c, name=filename, namespace=namespace,
 *                    default_inherit=default_inherit, get_template=get_template)             # <<<<<<<<<<<<<<
 * 
 *     from_filename = classmethod(from_filename)
*/
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_1, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_content, __pyx_v_c, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 159, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_filename, __pyx_t_5, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 159, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_namespace, __pyx_v_namespace, __pyx_t_5, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 159, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_default_inherit, __pyx_v_default_inherit, __pyx_t_5, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 159, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_get_template, __pyx_v_get_template, __pyx_t_5, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 159, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.from_filename", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":164
 *     from_filename = classmethod(from_filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s name=%r>' % (
 *             self.__class__.__name__,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_5__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_5__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_4__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5[7];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":165
 * 
 *     def __repr__(self):
 *         return '<%s %s name=%r>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             hex(id(self))[2:], self.name)
*/
  __Pyx_XDECREF(__pyx_r);

  /* "Cython/Tempita/_tempita.py":166
 *     def __repr__(self):
 *         return '<%s %s name=%r>' % (
 *             self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             hex(id(self))[2:], self.name)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":167
 *         return '<%s %s name=%r>' % (
 *             self.__class__.__name__,
 *             hex(id(self))[2:], self.name)             # <<<<<<<<<<<<<<
 * 
 *     def substitute(self, *args, **kw):
*/
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Hex(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 167, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyUnicode_Substring(__pyx_t_3, 2, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_5[1] = __pyx_t_1;
  __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u_;
  __pyx_t_5[3] = __pyx_t_2;
  __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u_name_3;
  __pyx_t_5[5] = __pyx_t_4;
  __pyx_t_5[6] = __pyx_mstate_global->__pyx_kp_u__3;

  /* "Cython/Tempita/_tempita.py":165
 * 
 *     def __repr__(self):
 *         return '<%s %s name=%r>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             hex(id(self))[2:], self.name)
*/
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 7, 1 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":164
 *     from_filename = classmethod(from_filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s name=%r>' % (
 *             self.__class__.__name__,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":169
 *             hex(id(self))[2:], self.name)
 * 
 *     def substitute(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         if args:
 *             if kw:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_7substitute(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_7substitute = {"substitute", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_7substitute, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_7substitute(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("substitute (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kw = PyDict_New(); if (unlikely(!__pyx_v_kw)) return NULL;
  __Pyx_GOTREF(__pyx_v_kw);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 169, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 169, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, used_pos_args, __pyx_kwds_len, "substitute", 1) < (0)) __PYX_ERR(0, 169, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("substitute", 0, 1, 1, i); __PYX_ERR(0, 169, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 169, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("substitute", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 169, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.substitute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_6substitute(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_6substitute(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_ns = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_defs = NULL;
  PyObject *__pyx_v_inherit = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("substitute", 0);
  __Pyx_INCREF(__pyx_v_kw);

  /* "Cython/Tempita/_tempita.py":170
 * 
 *     def substitute(self, *args, **kw):
 *         if args:             # <<<<<<<<<<<<<<
 *             if kw:
 *                 raise TypeError(
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_args);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 170, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":171
 *     def substitute(self, *args, **kw):
 *         if args:
 *             if kw:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "You can only give positional *or* keyword arguments")
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_kw); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 171, __pyx_L1_error)
    if (unlikely(__pyx_t_1)) {

      /* "Cython/Tempita/_tempita.py":172
 *         if args:
 *             if kw:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     "You can only give positional *or* keyword arguments")
 *             if len(args) > 1:
*/
      __pyx_t_3 = NULL;
      __pyx_t_4 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_You_can_only_give_positional_or};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 172, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":171
 *     def substitute(self, *args, **kw):
 *         if args:
 *             if kw:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "You can only give positional *or* keyword arguments")
*/
    }

    /* "Cython/Tempita/_tempita.py":174
 *                 raise TypeError(
 *                     "You can only give positional *or* keyword arguments")
 *             if len(args) > 1:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "You can only give one positional argument")
*/
    __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 174, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_5 > 1);
    if (unlikely(__pyx_t_1)) {

      /* "Cython/Tempita/_tempita.py":175
 *                     "You can only give positional *or* keyword arguments")
 *             if len(args) > 1:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     "You can only give one positional argument")
 *             if not hasattr(args[0], 'items'):
*/
      __pyx_t_3 = NULL;
      __pyx_t_4 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_You_can_only_give_one_positional};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 175, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":174
 *                 raise TypeError(
 *                     "You can only give positional *or* keyword arguments")
 *             if len(args) > 1:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "You can only give one positional argument")
*/
    }

    /* "Cython/Tempita/_tempita.py":177
 *                 raise TypeError(
 *                     "You can only give one positional argument")
 *             if not hasattr(args[0], 'items'):             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"
*/
    __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_HasAttr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_items); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 177, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = (!__pyx_t_1);
    if (unlikely(__pyx_t_6)) {

      /* "Cython/Tempita/_tempita.py":178
 *                     "You can only give one positional argument")
 *             if not hasattr(args[0], 'items'):
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"
 *                     % (args[0],))
*/
      __pyx_t_3 = NULL;

      /* "Cython/Tempita/_tempita.py":180
 *                 raise TypeError(
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"
 *                     % (args[0],))             # <<<<<<<<<<<<<<
 *             kw = args[0]
 *         ns = kw
*/
      __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":179
 *             if not hasattr(args[0], 'items'):
 *                 raise TypeError(
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"             # <<<<<<<<<<<<<<
 *                     % (args[0],))
 *             kw = args[0]
*/
      __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_If_you_pass_in_a_single_argument, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_4 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 178, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":177
 *                 raise TypeError(
 *                     "You can only give one positional argument")
 *             if not hasattr(args[0], 'items'):             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"
*/
    }

    /* "Cython/Tempita/_tempita.py":181
 *                     "If you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave %r"
 *                     % (args[0],))
 *             kw = args[0]             # <<<<<<<<<<<<<<
 *         ns = kw
 *         ns['__template_name__'] = self.name
*/
    __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_kw, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":170
 * 
 *     def substitute(self, *args, **kw):
 *         if args:             # <<<<<<<<<<<<<<
 *             if kw:
 *                 raise TypeError(
*/
  }

  /* "Cython/Tempita/_tempita.py":182
 *                     % (args[0],))
 *             kw = args[0]
 *         ns = kw             # <<<<<<<<<<<<<<
 *         ns['__template_name__'] = self.name
 *         if self.namespace:
*/
  __Pyx_INCREF(__pyx_v_kw);
  __pyx_v_ns = __pyx_v_kw;

  /* "Cython/Tempita/_tempita.py":183
 *             kw = args[0]
 *         ns = kw
 *         ns['__template_name__'] = self.name             # <<<<<<<<<<<<<<
 *         if self.namespace:
 *             ns.update(self.namespace)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_mstate_global->__pyx_n_u_template_name, __pyx_t_2) < 0))) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":184
 *         ns = kw
 *         ns['__template_name__'] = self.name
 *         if self.namespace:             # <<<<<<<<<<<<<<
 *             ns.update(self.namespace)
 *         result, defs, inherit = self._interpret(ns)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Tempita/_tempita.py":185
 *         ns['__template_name__'] = self.name
 *         if self.namespace:
 *             ns.update(self.namespace)             # <<<<<<<<<<<<<<
 *         result, defs, inherit = self._interpret(ns)
 *         if not inherit:
*/
    __pyx_t_7 = __pyx_v_ns;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":184
 *         ns = kw
 *         ns['__template_name__'] = self.name
 *         if self.namespace:             # <<<<<<<<<<<<<<
 *             ns.update(self.namespace)
 *         result, defs, inherit = self._interpret(ns)
*/
  }

  /* "Cython/Tempita/_tempita.py":186
 *         if self.namespace:
 *             ns.update(self.namespace)
 *         result, defs, inherit = self._interpret(ns)             # <<<<<<<<<<<<<<
 *         if not inherit:
 *             inherit = self.default_inherit
*/
  __pyx_t_3 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_ns};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 186, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_8);
    } else {
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_8);
    }
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_9 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
    index = 0; __pyx_t_3 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_3)) goto __pyx_L8_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L8_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    index = 2; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L8_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 3) < (0)) __PYX_ERR(0, 186, __pyx_L1_error)
    __pyx_t_10 = NULL;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L9_unpacking_done;
    __pyx_L8_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_10 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 186, __pyx_L1_error)
    __pyx_L9_unpacking_done:;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_defs = __pyx_t_7;
  __pyx_t_7 = 0;
  __pyx_v_inherit = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "Cython/Tempita/_tempita.py":187
 *             ns.update(self.namespace)
 *         result, defs, inherit = self._interpret(ns)
 *         if not inherit:             # <<<<<<<<<<<<<<
 *             inherit = self.default_inherit
 *         if inherit:
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_inherit); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 187, __pyx_L1_error)
  __pyx_t_1 = (!__pyx_t_6);
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":188
 *         result, defs, inherit = self._interpret(ns)
 *         if not inherit:
 *             inherit = self.default_inherit             # <<<<<<<<<<<<<<
 *         if inherit:
 *             result = self._interpret_inherit(result, defs, inherit, ns)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_inherit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_inherit, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":187
 *             ns.update(self.namespace)
 *         result, defs, inherit = self._interpret(ns)
 *         if not inherit:             # <<<<<<<<<<<<<<
 *             inherit = self.default_inherit
 *         if inherit:
*/
  }

  /* "Cython/Tempita/_tempita.py":189
 *         if not inherit:
 *             inherit = self.default_inherit
 *         if inherit:             # <<<<<<<<<<<<<<
 *             result = self._interpret_inherit(result, defs, inherit, ns)
 *         return result
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_inherit); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 189, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":190
 *             inherit = self.default_inherit
 *         if inherit:
 *             result = self._interpret_inherit(result, defs, inherit, ns)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    __pyx_t_8 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_v_result, __pyx_v_defs, __pyx_v_inherit, __pyx_v_ns};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_inherit, __pyx_callargs+__pyx_t_4, (5-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":189
 *         if not inherit:
 *             inherit = self.default_inherit
 *         if inherit:             # <<<<<<<<<<<<<<
 *             result = self._interpret_inherit(result, defs, inherit, ns)
 *         return result
*/
  }

  /* "Cython/Tempita/_tempita.py":191
 *         if inherit:
 *             result = self._interpret_inherit(result, defs, inherit, ns)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def _interpret(self, ns):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":169
 *             hex(id(self))[2:], self.name)
 * 
 *     def substitute(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         if args:
 *             if kw:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template.substitute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XDECREF(__pyx_v_ns);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_defs);
  __Pyx_XDECREF(__pyx_v_inherit);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":193
 *         return result
 * 
 *     def _interpret(self, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         parts = []
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_9_interpret(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_9_interpret = {"_interpret", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_9_interpret, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_9_interpret(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_ns = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_ns,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 193, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 193, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 193, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret", 0) < (0)) __PYX_ERR(0, 193, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret", 1, 2, 2, i); __PYX_ERR(0, 193, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 193, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 193, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_ns = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 193, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_8_interpret(__pyx_self, __pyx_v_self, __pyx_v_ns);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_8_interpret(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ns) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_parts = NULL;
  PyObject *__pyx_v_defs = NULL;
  PyObject *__pyx_v_inherit = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret", 0);

  /* "Cython/Tempita/_tempita.py":194
 * 
 *     def _interpret(self, ns):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         parts = []
 *         defs = {}
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":195
 *     def _interpret(self, ns):
 *         __traceback_hide__ = True
 *         parts = []             # <<<<<<<<<<<<<<
 *         defs = {}
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_parts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":196
 *         __traceback_hide__ = True
 *         parts = []
 *         defs = {}             # <<<<<<<<<<<<<<
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)
 *         if '__inherit__' in defs:
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_defs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":197
 *         parts = []
 *         defs = {}
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)             # <<<<<<<<<<<<<<
 *         if '__inherit__' in defs:
 *             inherit = defs.pop('__inherit__')
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_parsed); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_t_3, __pyx_v_ns};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_out, __pyx_v_parts, __pyx_t_5, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_defs, __pyx_v_defs, __pyx_t_5, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_codes, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":198
 *         defs = {}
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)
 *         if '__inherit__' in defs:             # <<<<<<<<<<<<<<
 *             inherit = defs.pop('__inherit__')
 *         else:
*/
  __pyx_t_6 = (__Pyx_PyDict_ContainsTF(__pyx_mstate_global->__pyx_n_u_inherit, __pyx_v_defs, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 198, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Tempita/_tempita.py":199
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)
 *         if '__inherit__' in defs:
 *             inherit = defs.pop('__inherit__')             # <<<<<<<<<<<<<<
 *         else:
 *             inherit = None
*/
    __pyx_t_1 = __Pyx_PyDict_Pop(__pyx_v_defs, __pyx_mstate_global->__pyx_n_u_inherit, ((PyObject *)NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_inherit = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":198
 *         defs = {}
 *         self._interpret_codes(self._parsed, ns, out=parts, defs=defs)
 *         if '__inherit__' in defs:             # <<<<<<<<<<<<<<
 *             inherit = defs.pop('__inherit__')
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":201
 *             inherit = defs.pop('__inherit__')
 *         else:
 *             inherit = None             # <<<<<<<<<<<<<<
 *         return ''.join(parts), defs, inherit
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_inherit = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Tempita/_tempita.py":202
 *         else:
 *             inherit = None
 *         return ''.join(parts), defs, inherit             # <<<<<<<<<<<<<<
 * 
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__4, __pyx_v_parts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 202, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_defs);
  __Pyx_GIVEREF(__pyx_v_defs);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_defs) != (0)) __PYX_ERR(0, 202, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_inherit);
  __Pyx_GIVEREF(__pyx_v_inherit);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_inherit) != (0)) __PYX_ERR(0, 202, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":193
 *         return result
 * 
 *     def _interpret(self, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         parts = []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_defs);
  __Pyx_XDECREF(__pyx_v_inherit);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":204
 *         return ''.join(parts), defs, inherit
 * 
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         if not self.get_template:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_11_interpret_inherit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_11_interpret_inherit = {"_interpret_inherit", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_11_interpret_inherit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_11_interpret_inherit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_body = 0;
  PyObject *__pyx_v_defs = 0;
  PyObject *__pyx_v_inherit_template = 0;
  PyObject *__pyx_v_ns = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret_inherit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_body,&__pyx_mstate_global->__pyx_n_u_defs,&__pyx_mstate_global->__pyx_n_u_inherit_template,&__pyx_mstate_global->__pyx_n_u_ns,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 204, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 204, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 204, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 204, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 204, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 204, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret_inherit", 0) < (0)) __PYX_ERR(0, 204, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret_inherit", 1, 5, 5, i); __PYX_ERR(0, 204, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 204, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 204, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 204, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 204, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 204, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_body = values[1];
    __pyx_v_defs = values[2];
    __pyx_v_inherit_template = values[3];
    __pyx_v_ns = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret_inherit", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 204, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_inherit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_10_interpret_inherit(__pyx_self, __pyx_v_self, __pyx_v_body, __pyx_v_defs, __pyx_v_inherit_template, __pyx_v_ns);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_10_interpret_inherit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_body, PyObject *__pyx_v_defs, PyObject *__pyx_v_inherit_template, PyObject *__pyx_v_ns) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_templ = NULL;
  PyObject *__pyx_v_self_ = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret_inherit", 0);
  __Pyx_INCREF(__pyx_v_ns);

  /* "Cython/Tempita/_tempita.py":205
 * 
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         if not self.get_template:
 *             raise TemplateError(
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":206
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):
 *         __traceback_hide__ = True
 *         if not self.get_template:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'You cannot use inheritance without passing in get_template',
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_get_template); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_2);
  if (unlikely(__pyx_t_3)) {

    /* "Cython/Tempita/_tempita.py":207
 *         __traceback_hide__ = True
 *         if not self.get_template:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'You cannot use inheritance without passing in get_template',
 *                 position=None, name=self.name)
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "Cython/Tempita/_tempita.py":209
 *             raise TemplateError(
 *                 'You cannot use inheritance without passing in get_template',
 *                 position=None, name=self.name)             # <<<<<<<<<<<<<<
 *         templ = self.get_template(inherit_template, self)
 *         self_ = TemplateObject(self.name)
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_You_cannot_use_inheritance_witho};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, Py_None, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 207, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_6, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 207, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 207, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":206
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):
 *         __traceback_hide__ = True
 *         if not self.get_template:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'You cannot use inheritance without passing in get_template',
*/
  }

  /* "Cython/Tempita/_tempita.py":210
 *                 'You cannot use inheritance without passing in get_template',
 *                 position=None, name=self.name)
 *         templ = self.get_template(inherit_template, self)             # <<<<<<<<<<<<<<
 *         self_ = TemplateObject(self.name)
 *         for name, value in defs.items():
*/
  __pyx_t_5 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_inherit_template, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_template, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_templ = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":211
 *                 position=None, name=self.name)
 *         templ = self.get_template(inherit_template, self)
 *         self_ = TemplateObject(self.name)             # <<<<<<<<<<<<<<
 *         for name, value in defs.items():
 *             setattr(self_, name, value)
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateObject); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_self_ = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":212
 *         templ = self.get_template(inherit_template, self)
 *         self_ = TemplateObject(self.name)
 *         for name, value in defs.items():             # <<<<<<<<<<<<<<
 *             setattr(self_, name, value)
 *         self_.body = body
*/
  __pyx_t_9 = 0;
  if (unlikely(__pyx_v_defs == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 212, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_defs, 0, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_10), (&__pyx_t_11)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_8;
  __pyx_t_8 = 0;
  while (1) {
    __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_10, &__pyx_t_9, &__pyx_t_8, &__pyx_t_6, NULL, __pyx_t_11);
    if (unlikely(__pyx_t_12 == 0)) break;
    if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Tempita/_tempita.py":213
 *         self_ = TemplateObject(self.name)
 *         for name, value in defs.items():
 *             setattr(self_, name, value)             # <<<<<<<<<<<<<<
 *         self_.body = body
 *         ns = ns.copy()
*/
    __pyx_t_13 = PyObject_SetAttr(__pyx_v_self_, __pyx_v_name, __pyx_v_value); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 213, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":214
 *         for name, value in defs.items():
 *             setattr(self_, name, value)
 *         self_.body = body             # <<<<<<<<<<<<<<
 *         ns = ns.copy()
 *         ns['self'] = self_
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self_, __pyx_mstate_global->__pyx_n_u_body, __pyx_v_body) < (0)) __PYX_ERR(0, 214, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":215
 *             setattr(self_, name, value)
 *         self_.body = body
 *         ns = ns.copy()             # <<<<<<<<<<<<<<
 *         ns['self'] = self_
 *         return templ.substitute(ns)
*/
  __pyx_t_6 = __pyx_v_ns;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_copy, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF_SET(__pyx_v_ns, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":216
 *         self_.body = body
 *         ns = ns.copy()
 *         ns['self'] = self_             # <<<<<<<<<<<<<<
 *         return templ.substitute(ns)
 * 
*/
  if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_mstate_global->__pyx_n_u_self, __pyx_v_self_) < 0))) __PYX_ERR(0, 216, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":217
 *         ns = ns.copy()
 *         ns['self'] = self_
 *         return templ.substitute(ns)             # <<<<<<<<<<<<<<
 * 
 *     def _interpret_codes(self, codes, ns, out, defs):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_templ;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_ns};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_substitute, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":204
 *         return ''.join(parts), defs, inherit
 * 
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         if not self.get_template:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_inherit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_templ);
  __Pyx_XDECREF(__pyx_v_self_);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_ns);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":219
 *         return templ.substitute(ns)
 * 
 *     def _interpret_codes(self, codes, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in codes:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_13_interpret_codes(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_13_interpret_codes = {"_interpret_codes", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_13_interpret_codes, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_13_interpret_codes(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_codes = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_out = 0;
  PyObject *__pyx_v_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret_codes (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_codes,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_out,&__pyx_mstate_global->__pyx_n_u_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 219, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 219, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 219, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 219, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 219, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 219, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret_codes", 0) < (0)) __PYX_ERR(0, 219, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret_codes", 1, 5, 5, i); __PYX_ERR(0, 219, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 219, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 219, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 219, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 219, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 219, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_codes = values[1];
    __pyx_v_ns = values[2];
    __pyx_v_out = values[3];
    __pyx_v_defs = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret_codes", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 219, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_codes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_12_interpret_codes(__pyx_self, __pyx_v_self, __pyx_v_codes, __pyx_v_ns, __pyx_v_out, __pyx_v_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_12_interpret_codes(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_codes, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret_codes", 0);

  /* "Cython/Tempita/_tempita.py":220
 * 
 *     def _interpret_codes(self, codes, ns, out, defs):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         for item in codes:
 *             if isinstance(item, str):
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":221
 *     def _interpret_codes(self, codes, ns, out, defs):
 *         __traceback_hide__ = True
 *         for item in codes:             # <<<<<<<<<<<<<<
 *             if isinstance(item, str):
 *                 out.append(item)
*/
  if (likely(PyList_CheckExact(__pyx_v_codes)) || PyTuple_CheckExact(__pyx_v_codes)) {
    __pyx_t_1 = __pyx_v_codes; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_codes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 221, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 221, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 221, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 221, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 221, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":222
 *         __traceback_hide__ = True
 *         for item in codes:
 *             if isinstance(item, str):             # <<<<<<<<<<<<<<
 *                 out.append(item)
 *             else:
*/
    __pyx_t_5 = PyUnicode_Check(__pyx_v_item); 
    if (__pyx_t_5) {

      /* "Cython/Tempita/_tempita.py":223
 *         for item in codes:
 *             if isinstance(item, str):
 *                 out.append(item)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._interpret_code(item, ns, out, defs)
*/
      __pyx_t_6 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_v_item); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 223, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":222
 *         __traceback_hide__ = True
 *         for item in codes:
 *             if isinstance(item, str):             # <<<<<<<<<<<<<<
 *                 out.append(item)
 *             else:
*/
      goto __pyx_L5;
    }

    /* "Cython/Tempita/_tempita.py":225
 *                 out.append(item)
 *             else:
 *                 self._interpret_code(item, ns, out, defs)             # <<<<<<<<<<<<<<
 * 
 *     def _interpret_code(self, code, ns, out, defs):
*/
    /*else*/ {
      __pyx_t_7 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = 0;
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_item, __pyx_v_ns, __pyx_v_out, __pyx_v_defs};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_code, __pyx_callargs+__pyx_t_8, (5-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;

    /* "Cython/Tempita/_tempita.py":221
 *     def _interpret_codes(self, codes, ns, out, defs):
 *         __traceback_hide__ = True
 *         for item in codes:             # <<<<<<<<<<<<<<
 *             if isinstance(item, str):
 *                 out.append(item)
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":219
 *         return templ.substitute(ns)
 * 
 *     def _interpret_codes(self, codes, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in codes:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_codes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":227
 *                 self._interpret_code(item, ns, out, defs)
 * 
 *     def _interpret_code(self, code, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_15_interpret_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_15_interpret_code = {"_interpret_code", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_15_interpret_code, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_15_interpret_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_out = 0;
  PyObject *__pyx_v_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret_code (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_out,&__pyx_mstate_global->__pyx_n_u_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 227, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 227, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 227, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 227, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 227, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 227, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret_code", 0) < (0)) __PYX_ERR(0, 227, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret_code", 1, 5, 5, i); __PYX_ERR(0, 227, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 227, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 227, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 227, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 227, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 227, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_code = values[1];
    __pyx_v_ns = values[2];
    __pyx_v_out = values[3];
    __pyx_v_defs = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret_code", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 227, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_14_interpret_code(__pyx_self, __pyx_v_self, __pyx_v_code, __pyx_v_ns, __pyx_v_out, __pyx_v_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_14_interpret_code(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_vars = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_content = NULL;
  PyObject *__pyx_v_parts = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_var = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_signature = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret_code", 0);

  /* "Cython/Tempita/_tempita.py":228
 * 
 *     def _interpret_code(self, code, ns, out, defs):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         name, pos = code[0], code[1]
 *         if name == 'py':
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":229
 *     def _interpret_code(self, code, ns, out, defs):
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]             # <<<<<<<<<<<<<<
 *         if name == 'py':
 *             self._exec(code[2], ns, pos)
*/
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_code, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_pos = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":230
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]
 *         if name == 'py':             # <<<<<<<<<<<<<<
 *             self._exec(code[2], ns, pos)
 *         elif name == 'continue':
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_py, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 230, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":231
 *         name, pos = code[0], code[1]
 *         if name == 'py':
 *             self._exec(code[2], ns, pos)             # <<<<<<<<<<<<<<
 *         elif name == 'continue':
 *             raise _TemplateContinue()
*/
    __pyx_t_1 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_t_4, __pyx_v_ns, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exec, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":230
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]
 *         if name == 'py':             # <<<<<<<<<<<<<<
 *             self._exec(code[2], ns, pos)
 *         elif name == 'continue':
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":232
 *         if name == 'py':
 *             self._exec(code[2], ns, pos)
 *         elif name == 'continue':             # <<<<<<<<<<<<<<
 *             raise _TemplateContinue()
 *         elif name == 'break':
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_continue, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
  if (unlikely(__pyx_t_3)) {

    /* "Cython/Tempita/_tempita.py":233
 *             self._exec(code[2], ns, pos)
 *         elif name == 'continue':
 *             raise _TemplateContinue()             # <<<<<<<<<<<<<<
 *         elif name == 'break':
 *             raise _TemplateBreak()
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_TemplateContinue); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 233, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":232
 *         if name == 'py':
 *             self._exec(code[2], ns, pos)
 *         elif name == 'continue':             # <<<<<<<<<<<<<<
 *             raise _TemplateContinue()
 *         elif name == 'break':
*/
  }

  /* "Cython/Tempita/_tempita.py":234
 *         elif name == 'continue':
 *             raise _TemplateContinue()
 *         elif name == 'break':             # <<<<<<<<<<<<<<
 *             raise _TemplateBreak()
 *         elif name == 'for':
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_break, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 234, __pyx_L1_error)
  if (unlikely(__pyx_t_3)) {

    /* "Cython/Tempita/_tempita.py":235
 *             raise _TemplateContinue()
 *         elif name == 'break':
 *             raise _TemplateBreak()             # <<<<<<<<<<<<<<
 *         elif name == 'for':
 *             vars, expr, content = code[2], code[3], code[4]
*/
    __pyx_t_1 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_TemplateBreak); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 235, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":234
 *         elif name == 'continue':
 *             raise _TemplateContinue()
 *         elif name == 'break':             # <<<<<<<<<<<<<<
 *             raise _TemplateBreak()
 *         elif name == 'for':
*/
  }

  /* "Cython/Tempita/_tempita.py":236
 *         elif name == 'break':
 *             raise _TemplateBreak()
 *         elif name == 'for':             # <<<<<<<<<<<<<<
 *             vars, expr, content = code[2], code[3], code[4]
 *             expr = self._eval(expr, ns, pos)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 236, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":237
 *             raise _TemplateBreak()
 *         elif name == 'for':
 *             vars, expr, content = code[2], code[3], code[4]             # <<<<<<<<<<<<<<
 *             expr = self._eval(expr, ns, pos)
 *             self._interpret_for(vars, expr, content, ns, out, defs)
*/
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_code, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_vars = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_v_expr = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_content = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":238
 *         elif name == 'for':
 *             vars, expr, content = code[2], code[3], code[4]
 *             expr = self._eval(expr, ns, pos)             # <<<<<<<<<<<<<<
 *             self._interpret_for(vars, expr, content, ns, out, defs)
 *         elif name == 'cond':
*/
    __pyx_t_4 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_expr, __pyx_v_ns, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":239
 *             vars, expr, content = code[2], code[3], code[4]
 *             expr = self._eval(expr, ns, pos)
 *             self._interpret_for(vars, expr, content, ns, out, defs)             # <<<<<<<<<<<<<<
 *         elif name == 'cond':
 *             parts = code[2:]
*/
    __pyx_t_4 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[7] = {__pyx_t_4, __pyx_v_vars, __pyx_v_expr, __pyx_v_content, __pyx_v_ns, __pyx_v_out, __pyx_v_defs};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_for, __pyx_callargs+__pyx_t_5, (7-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":236
 *         elif name == 'break':
 *             raise _TemplateBreak()
 *         elif name == 'for':             # <<<<<<<<<<<<<<
 *             vars, expr, content = code[2], code[3], code[4]
 *             expr = self._eval(expr, ns, pos)
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":240
 *             expr = self._eval(expr, ns, pos)
 *             self._interpret_for(vars, expr, content, ns, out, defs)
 *         elif name == 'cond':             # <<<<<<<<<<<<<<
 *             parts = code[2:]
 *             self._interpret_if(parts, ns, out, defs)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_cond, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":241
 *             self._interpret_for(vars, expr, content, ns, out, defs)
 *         elif name == 'cond':
 *             parts = code[2:]             # <<<<<<<<<<<<<<
 *             self._interpret_if(parts, ns, out, defs)
 *         elif name == 'expr':
*/
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_code, 2, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[1], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_parts = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":242
 *         elif name == 'cond':
 *             parts = code[2:]
 *             self._interpret_if(parts, ns, out, defs)             # <<<<<<<<<<<<<<
 *         elif name == 'expr':
 *             parts = code[2].split('|')
*/
    __pyx_t_4 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_parts, __pyx_v_ns, __pyx_v_out, __pyx_v_defs};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_if, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":240
 *             expr = self._eval(expr, ns, pos)
 *             self._interpret_for(vars, expr, content, ns, out, defs)
 *         elif name == 'cond':             # <<<<<<<<<<<<<<
 *             parts = code[2:]
 *             self._interpret_if(parts, ns, out, defs)
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":243
 *             parts = code[2:]
 *             self._interpret_if(parts, ns, out, defs)
 *         elif name == 'expr':             # <<<<<<<<<<<<<<
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_expr, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 243, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":244
 *             self._interpret_if(parts, ns, out, defs)
 *         elif name == 'expr':
 *             parts = code[2].split('|')             # <<<<<<<<<<<<<<
 *             base = self._eval(parts[0], ns, pos)
 *             for part in parts[1:]:
*/
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_t_2;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__5};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_parts = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":245
 *         elif name == 'expr':
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)             # <<<<<<<<<<<<<<
 *             for part in parts[1:]:
 *                 func = self._eval(part, ns, pos)
*/
    __pyx_t_2 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_t_4, __pyx_v_ns, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_base = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":246
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)
 *             for part in parts[1:]:             # <<<<<<<<<<<<<<
 *                 func = self._eval(part, ns, pos)
 *                 base = func(base)
*/
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parts, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 246, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 246, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_6;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 246, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6);
          #endif
          ++__pyx_t_6;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_4);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 246, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":247
 *             base = self._eval(parts[0], ns, pos)
 *             for part in parts[1:]:
 *                 func = self._eval(part, ns, pos)             # <<<<<<<<<<<<<<
 *                 base = func(base)
 *             out.append(self._repr(base, pos))
*/
      __pyx_t_2 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_part, __pyx_v_ns, __pyx_v_pos};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_func, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":248
 *             for part in parts[1:]:
 *                 func = self._eval(part, ns, pos)
 *                 base = func(base)             # <<<<<<<<<<<<<<
 *             out.append(self._repr(base, pos))
 *         elif name == 'default':
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_func);
      __pyx_t_8 = __pyx_v_func; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_base};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_base, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":246
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)
 *             for part in parts[1:]:             # <<<<<<<<<<<<<<
 *                 func = self._eval(part, ns, pos)
 *                 base = func(base)
*/
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":249
 *                 func = self._eval(part, ns, pos)
 *                 base = func(base)
 *             out.append(self._repr(base, pos))             # <<<<<<<<<<<<<<
 *         elif name == 'default':
 *             var, expr = code[2], code[3]
*/
    __pyx_t_1 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_base, __pyx_v_pos};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_repr, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_9 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":243
 *             parts = code[2:]
 *             self._interpret_if(parts, ns, out, defs)
 *         elif name == 'expr':             # <<<<<<<<<<<<<<
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":250
 *                 base = func(base)
 *             out.append(self._repr(base, pos))
 *         elif name == 'default':             # <<<<<<<<<<<<<<
 *             var, expr = code[2], code[3]
 *             if var not in ns:
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_default, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 250, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":251
 *             out.append(self._repr(base, pos))
 *         elif name == 'default':
 *             var, expr = code[2], code[3]             # <<<<<<<<<<<<<<
 *             if var not in ns:
 *                 result = self._eval(expr, ns, pos)
*/
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_var = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_expr = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":252
 *         elif name == 'default':
 *             var, expr = code[2], code[3]
 *             if var not in ns:             # <<<<<<<<<<<<<<
 *                 result = self._eval(expr, ns, pos)
 *                 ns[var] = result
*/
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_var, __pyx_v_ns, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 252, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Tempita/_tempita.py":253
 *             var, expr = code[2], code[3]
 *             if var not in ns:
 *                 result = self._eval(expr, ns, pos)             # <<<<<<<<<<<<<<
 *                 ns[var] = result
 *         elif name == 'inherit':
*/
      __pyx_t_4 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_expr, __pyx_v_ns, __pyx_v_pos};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":254
 *             if var not in ns:
 *                 result = self._eval(expr, ns, pos)
 *                 ns[var] = result             # <<<<<<<<<<<<<<
 *         elif name == 'inherit':
 *             expr = code[2]
*/
      if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_v_var, __pyx_v_result) < 0))) __PYX_ERR(0, 254, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":252
 *         elif name == 'default':
 *             var, expr = code[2], code[3]
 *             if var not in ns:             # <<<<<<<<<<<<<<
 *                 result = self._eval(expr, ns, pos)
 *                 ns[var] = result
*/
    }

    /* "Cython/Tempita/_tempita.py":250
 *                 base = func(base)
 *             out.append(self._repr(base, pos))
 *         elif name == 'default':             # <<<<<<<<<<<<<<
 *             var, expr = code[2], code[3]
 *             if var not in ns:
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":255
 *                 result = self._eval(expr, ns, pos)
 *                 ns[var] = result
 *         elif name == 'inherit':             # <<<<<<<<<<<<<<
 *             expr = code[2]
 *             value = self._eval(expr, ns, pos)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_inherit_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 255, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":256
 *                 ns[var] = result
 *         elif name == 'inherit':
 *             expr = code[2]             # <<<<<<<<<<<<<<
 *             value = self._eval(expr, ns, pos)
 *             defs['__inherit__'] = value
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_expr = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":257
 *         elif name == 'inherit':
 *             expr = code[2]
 *             value = self._eval(expr, ns, pos)             # <<<<<<<<<<<<<<
 *             defs['__inherit__'] = value
 *         elif name == 'def':
*/
    __pyx_t_4 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_expr, __pyx_v_ns, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":258
 *             expr = code[2]
 *             value = self._eval(expr, ns, pos)
 *             defs['__inherit__'] = value             # <<<<<<<<<<<<<<
 *         elif name == 'def':
 *             name = code[2]
*/
    if (unlikely((PyObject_SetItem(__pyx_v_defs, __pyx_mstate_global->__pyx_n_u_inherit, __pyx_v_value) < 0))) __PYX_ERR(0, 258, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":255
 *                 result = self._eval(expr, ns, pos)
 *                 ns[var] = result
 *         elif name == 'inherit':             # <<<<<<<<<<<<<<
 *             expr = code[2]
 *             value = self._eval(expr, ns, pos)
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":259
 *             value = self._eval(expr, ns, pos)
 *             defs['__inherit__'] = value
 *         elif name == 'def':             # <<<<<<<<<<<<<<
 *             name = code[2]
 *             signature = code[3]
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_def, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 259, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":260
 *             defs['__inherit__'] = value
 *         elif name == 'def':
 *             name = code[2]             # <<<<<<<<<<<<<<
 *             signature = code[3]
 *             parts = code[4]
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":261
 *         elif name == 'def':
 *             name = code[2]
 *             signature = code[3]             # <<<<<<<<<<<<<<
 *             parts = code[4]
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_signature = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":262
 *             name = code[2]
 *             signature = code[3]
 *             parts = code[4]             # <<<<<<<<<<<<<<
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,
 *                                                 pos=pos)
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_code, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_parts = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":263
 *             signature = code[3]
 *             parts = code[4]
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,             # <<<<<<<<<<<<<<
 *                                                 pos=pos)
 *         elif name == 'comment':
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateDef); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "Cython/Tempita/_tempita.py":264
 *             parts = code[4]
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,
 *                                                 pos=pos)             # <<<<<<<<<<<<<<
 *         elif name == 'comment':
 *             return
*/
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[4 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_4, __pyx_v_self, __pyx_v_name, __pyx_v_signature};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_parts, __pyx_t_2, __pyx_callargs+4, 0) < (0)) __PYX_ERR(0, 263, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ns, __pyx_v_ns, __pyx_t_2, __pyx_callargs+4, 1) < (0)) __PYX_ERR(0, 263, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_2, __pyx_callargs+4, 2) < (0)) __PYX_ERR(0, 263, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "Cython/Tempita/_tempita.py":263
 *             signature = code[3]
 *             parts = code[4]
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,             # <<<<<<<<<<<<<<
 *                                                 pos=pos)
 *         elif name == 'comment':
*/
    if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 263, __pyx_L1_error)
    if (unlikely((PyObject_SetItem(__pyx_v_defs, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":259
 *             value = self._eval(expr, ns, pos)
 *             defs['__inherit__'] = value
 *         elif name == 'def':             # <<<<<<<<<<<<<<
 *             name = code[2]
 *             signature = code[3]
*/
    goto __pyx_L3;
  }

  /* "Cython/Tempita/_tempita.py":265
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,
 *                                                 pos=pos)
 *         elif name == 'comment':             # <<<<<<<<<<<<<<
 *             return
 *         else:
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_comment, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 265, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Tempita/_tempita.py":266
 *                                                 pos=pos)
 *         elif name == 'comment':
 *             return             # <<<<<<<<<<<<<<
 *         else:
 *             assert 0, "Unknown code: %r" % name
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Tempita/_tempita.py":265
 *             ns[name] = defs[name] = TemplateDef(self, name, signature, body=parts, ns=ns,
 *                                                 pos=pos)
 *         elif name == 'comment':             # <<<<<<<<<<<<<<
 *             return
 *         else:
*/
  }

  /* "Cython/Tempita/_tempita.py":268
 *             return
 *         else:
 *             assert 0, "Unknown code: %r" % name             # <<<<<<<<<<<<<<
 * 
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):
*/
  /*else*/ {
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      if (unlikely(!0)) {
        __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unknown_code_r, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_1, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 268, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 268, __pyx_L1_error)
    #endif
  }
  __pyx_L3:;

  /* "Cython/Tempita/_tempita.py":227
 *                 self._interpret_code(item, ns, out, defs)
 * 
 *     def _interpret_code(self, code, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_vars);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_content);
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_var);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_signature);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":270
 *             assert 0, "Unknown code: %r" % name
 * 
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in expr:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_17_interpret_for(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_17_interpret_for = {"_interpret_for", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_17_interpret_for, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_17_interpret_for(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_vars = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_out = 0;
  PyObject *__pyx_v_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret_for (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_vars,&__pyx_mstate_global->__pyx_n_u_expr,&__pyx_mstate_global->__pyx_n_u_content,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_out,&__pyx_mstate_global->__pyx_n_u_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 270, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 270, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret_for", 0) < (0)) __PYX_ERR(0, 270, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 7; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret_for", 1, 7, 7, i); __PYX_ERR(0, 270, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 7)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 270, __pyx_L3_error)
      values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 270, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_vars = values[1];
    __pyx_v_expr = values[2];
    __pyx_v_content = values[3];
    __pyx_v_ns = values[4];
    __pyx_v_out = values[5];
    __pyx_v_defs = values[6];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret_for", 1, 7, 7, __pyx_nargs); __PYX_ERR(0, 270, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_16_interpret_for(__pyx_self, __pyx_v_self, __pyx_v_vars, __pyx_v_expr, __pyx_v_content, __pyx_v_ns, __pyx_v_out, __pyx_v_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_16_interpret_for(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_vars, PyObject *__pyx_v_expr, PyObject *__pyx_v_content, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret_for", 0);

  /* "Cython/Tempita/_tempita.py":271
 * 
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         for item in expr:
 *             if len(vars) == 1:
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":272
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):
 *         __traceback_hide__ = True
 *         for item in expr:             # <<<<<<<<<<<<<<
 *             if len(vars) == 1:
 *                 ns[vars[0]] = item
*/
  if (likely(PyList_CheckExact(__pyx_v_expr)) || PyTuple_CheckExact(__pyx_v_expr)) {
    __pyx_t_1 = __pyx_v_expr; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 272, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 272, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 272, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 272, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 272, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":273
 *         __traceback_hide__ = True
 *         for item in expr:
 *             if len(vars) == 1:             # <<<<<<<<<<<<<<
 *                 ns[vars[0]] = item
 *             else:
*/
    __pyx_t_5 = PyObject_Length(__pyx_v_vars); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 273, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 == 1);
    if (__pyx_t_6) {

      /* "Cython/Tempita/_tempita.py":274
 *         for item in expr:
 *             if len(vars) == 1:
 *                 ns[vars[0]] = item             # <<<<<<<<<<<<<<
 *             else:
 *                 if len(vars) != len(item):
*/
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_vars, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_t_4, __pyx_v_item) < 0))) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":273
 *         __traceback_hide__ = True
 *         for item in expr:
 *             if len(vars) == 1:             # <<<<<<<<<<<<<<
 *                 ns[vars[0]] = item
 *             else:
*/
      goto __pyx_L5;
    }

    /* "Cython/Tempita/_tempita.py":276
 *                 ns[vars[0]] = item
 *             else:
 *                 if len(vars) != len(item):             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         'Need %i items to unpack (got %i items)'
*/
    /*else*/ {
      __pyx_t_5 = PyObject_Length(__pyx_v_vars); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 276, __pyx_L1_error)
      __pyx_t_7 = PyObject_Length(__pyx_v_item); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 276, __pyx_L1_error)
      __pyx_t_6 = (__pyx_t_5 != __pyx_t_7);
      if (unlikely(__pyx_t_6)) {

        /* "Cython/Tempita/_tempita.py":277
 *             else:
 *                 if len(vars) != len(item):
 *                     raise ValueError(             # <<<<<<<<<<<<<<
 *                         'Need %i items to unpack (got %i items)'
 *                         % (len(vars), len(item)))
*/
        __pyx_t_8 = NULL;

        /* "Cython/Tempita/_tempita.py":279
 *                     raise ValueError(
 *                         'Need %i items to unpack (got %i items)'
 *                         % (len(vars), len(item)))             # <<<<<<<<<<<<<<
 *                 for name, value in zip(vars, item):
 *                     ns[name] = value
*/
        __pyx_t_7 = PyObject_Length(__pyx_v_vars); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 279, __pyx_L1_error)
        __pyx_t_9 = PyLong_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_7 = PyObject_Length(__pyx_v_item); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 279, __pyx_L1_error)
        __pyx_t_10 = PyLong_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_9);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9) != (0)) __PYX_ERR(0, 279, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_10);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_10) != (0)) __PYX_ERR(0, 279, __pyx_L1_error);
        __pyx_t_9 = 0;
        __pyx_t_10 = 0;
        __pyx_t_10 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Need_i_items_to_unpack_got_i_ite, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_12 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_10};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 277, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 277, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":276
 *                 ns[vars[0]] = item
 *             else:
 *                 if len(vars) != len(item):             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         'Need %i items to unpack (got %i items)'
*/
      }

      /* "Cython/Tempita/_tempita.py":280
 *                         'Need %i items to unpack (got %i items)'
 *                         % (len(vars), len(item)))
 *                 for name, value in zip(vars, item):             # <<<<<<<<<<<<<<
 *                     ns[name] = value
 *             try:
*/
      __pyx_t_10 = NULL;
      __pyx_t_12 = 1;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_vars, __pyx_v_item};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_zip, __pyx_callargs+__pyx_t_12, (3-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_10 = __pyx_t_4; __Pyx_INCREF(__pyx_t_10);
        __pyx_t_7 = 0;
        __pyx_t_13 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 280, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_13 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 280, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_13)) {
          if (likely(PyList_CheckExact(__pyx_t_10))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 280, __pyx_L1_error)
              #endif
              if (__pyx_t_7 >= __pyx_temp) break;
            }
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_7;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 280, __pyx_L1_error)
              #endif
              if (__pyx_t_7 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_7));
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_7);
            #endif
            ++__pyx_t_7;
          }
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 280, __pyx_L1_error)
        } else {
          __pyx_t_4 = __pyx_t_13(__pyx_t_10);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 280, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_4);
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 280, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_8);
            __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_11);
          } else {
            __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_8);
            __pyx_t_11 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_11);
          }
          #else
          __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_11 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_9 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
          index = 0; __pyx_t_8 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          index = 1; __pyx_t_11 = __pyx_t_14(__pyx_t_9); if (unlikely(!__pyx_t_11)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_9), 2) < (0)) __PYX_ERR(0, 280, __pyx_L1_error)
          __pyx_t_14 = NULL;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L10_unpacking_done;
          __pyx_L9_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_14 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 280, __pyx_L1_error)
          __pyx_L10_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "Cython/Tempita/_tempita.py":281
 *                         % (len(vars), len(item)))
 *                 for name, value in zip(vars, item):
 *                     ns[name] = value             # <<<<<<<<<<<<<<
 *             try:
 *                 self._interpret_codes(content, ns, out, defs)
*/
        if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 281, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":280
 *                         'Need %i items to unpack (got %i items)'
 *                         % (len(vars), len(item)))
 *                 for name, value in zip(vars, item):             # <<<<<<<<<<<<<<
 *                     ns[name] = value
 *             try:
*/
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_L5:;

    /* "Cython/Tempita/_tempita.py":282
 *                 for name, value in zip(vars, item):
 *                     ns[name] = value
 *             try:             # <<<<<<<<<<<<<<
 *                 self._interpret_codes(content, ns, out, defs)
 *             except _TemplateContinue:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":283
 *                     ns[name] = value
 *             try:
 *                 self._interpret_codes(content, ns, out, defs)             # <<<<<<<<<<<<<<
 *             except _TemplateContinue:
 *                 continue
*/
        __pyx_t_4 = __pyx_v_self;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_12 = 0;
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_content, __pyx_v_ns, __pyx_v_out, __pyx_v_defs};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_codes, __pyx_callargs+__pyx_t_12, (5-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 283, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "Cython/Tempita/_tempita.py":282
 *                 for name, value in zip(vars, item):
 *                     ns[name] = value
 *             try:             # <<<<<<<<<<<<<<
 *                 self._interpret_codes(content, ns, out, defs)
 *             except _TemplateContinue:
*/
      }
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      goto __pyx_L19_try_end;
      __pyx_L12_error:;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "Cython/Tempita/_tempita.py":284
 *             try:
 *                 self._interpret_codes(content, ns, out, defs)
 *             except _TemplateContinue:             # <<<<<<<<<<<<<<
 *                 continue
 *             except _TemplateBreak:
*/
      __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_4, &__pyx_t_11);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateContinue); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 284, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_18 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_10, __pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_4, __pyx_t_11);
      __pyx_t_10 = 0; __pyx_t_4 = 0; __pyx_t_11 = 0;
      if (__pyx_t_18) {
        __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_4, &__pyx_t_10) < 0) __PYX_ERR(0, 284, __pyx_L14_except_error)
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_10);

        /* "Cython/Tempita/_tempita.py":285
 *                 self._interpret_codes(content, ns, out, defs)
 *             except _TemplateContinue:
 *                 continue             # <<<<<<<<<<<<<<
 *             except _TemplateBreak:
 *                 break
*/
        goto __pyx_L20_except_continue;
        __pyx_L20_except_continue:;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L18_try_continue;
      }

      /* "Cython/Tempita/_tempita.py":286
 *             except _TemplateContinue:
 *                 continue
 *             except _TemplateBreak:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_4, &__pyx_t_11);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateBreak); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 286, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_18 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_10, __pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_4, __pyx_t_11);
      __pyx_t_10 = 0; __pyx_t_4 = 0; __pyx_t_11 = 0;
      if (__pyx_t_18) {
        __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_4, &__pyx_t_10) < 0) __PYX_ERR(0, 286, __pyx_L14_except_error)
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_10);

        /* "Cython/Tempita/_tempita.py":287
 *                 continue
 *             except _TemplateBreak:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *     def _interpret_if(self, parts, ns, out, defs):
*/
        goto __pyx_L23_except_break;
        __pyx_L23_except_break:;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L17_try_break;
      }
      goto __pyx_L14_except_error;

      /* "Cython/Tempita/_tempita.py":282
 *                 for name, value in zip(vars, item):
 *                     ns[name] = value
 *             try:             # <<<<<<<<<<<<<<
 *                 self._interpret_codes(content, ns, out, defs)
 *             except _TemplateContinue:
*/
      __pyx_L14_except_error:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L1_error;
      __pyx_L17_try_break:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L4_break;
      __pyx_L18_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L3_continue;
      __pyx_L19_try_end:;
    }

    /* "Cython/Tempita/_tempita.py":272
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):
 *         __traceback_hide__ = True
 *         for item in expr:             # <<<<<<<<<<<<<<
 *             if len(vars) == 1:
 *                 ns[vars[0]] = item
*/
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L24_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L24_for_end;
  __pyx_L24_for_end:;

  /* "Cython/Tempita/_tempita.py":270
 *             assert 0, "Unknown code: %r" % name
 * 
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in expr:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":289
 *                 break
 * 
 *     def _interpret_if(self, parts, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         # @@: if/else/else gets through
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_19_interpret_if(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_19_interpret_if = {"_interpret_if", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_19_interpret_if, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_19_interpret_if(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parts = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_out = 0;
  PyObject *__pyx_v_defs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interpret_if (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_parts,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_out,&__pyx_mstate_global->__pyx_n_u_defs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 289, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 289, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 289, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 289, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 289, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 289, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interpret_if", 0) < (0)) __PYX_ERR(0, 289, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interpret_if", 1, 5, 5, i); __PYX_ERR(0, 289, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 289, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 289, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 289, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 289, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 289, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_parts = values[1];
    __pyx_v_ns = values[2];
    __pyx_v_out = values[3];
    __pyx_v_defs = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interpret_if", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 289, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_if", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_18_interpret_if(__pyx_self, __pyx_v_self, __pyx_v_parts, __pyx_v_ns, __pyx_v_out, __pyx_v_defs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_18_interpret_if(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parts, PyObject *__pyx_v_ns, PyObject *__pyx_v_out, PyObject *__pyx_v_defs) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interpret_if", 0);

  /* "Cython/Tempita/_tempita.py":290
 * 
 *     def _interpret_if(self, parts, ns, out, defs):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         # @@: if/else/else gets through
 *         for part in parts:
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":292
 *         __traceback_hide__ = True
 *         # @@: if/else/else gets through
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             assert not isinstance(part, str)
 *             name, pos = part[0], part[1]
*/
  if (likely(PyList_CheckExact(__pyx_v_parts)) || PyTuple_CheckExact(__pyx_v_parts)) {
    __pyx_t_1 = __pyx_v_parts; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_parts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 292, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 292, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 292, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 292, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 292, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":293
 *         # @@: if/else/else gets through
 *         for part in parts:
 *             assert not isinstance(part, str)             # <<<<<<<<<<<<<<
 *             name, pos = part[0], part[1]
 *             if name == 'else':
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_5 = PyUnicode_Check(__pyx_v_part); 
      __pyx_t_6 = (!__pyx_t_5);
      if (unlikely(!__pyx_t_6)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 293, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 293, __pyx_L1_error)
    #endif

    /* "Cython/Tempita/_tempita.py":294
 *         for part in parts:
 *             assert not isinstance(part, str)
 *             name, pos = part[0], part[1]             # <<<<<<<<<<<<<<
 *             if name == 'else':
 *                 result = True
*/
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_part, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_part, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "Cython/Tempita/_tempita.py":295
 *             assert not isinstance(part, str)
 *             name, pos = part[0], part[1]
 *             if name == 'else':             # <<<<<<<<<<<<<<
 *                 result = True
 *             else:
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 295, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Tempita/_tempita.py":296
 *             name, pos = part[0], part[1]
 *             if name == 'else':
 *                 result = True             # <<<<<<<<<<<<<<
 *             else:
 *                 result = self._eval(part[2], ns, pos)
*/
      __Pyx_INCREF(Py_True);
      __Pyx_XDECREF_SET(__pyx_v_result, Py_True);

      /* "Cython/Tempita/_tempita.py":295
 *             assert not isinstance(part, str)
 *             name, pos = part[0], part[1]
 *             if name == 'else':             # <<<<<<<<<<<<<<
 *                 result = True
 *             else:
*/
      goto __pyx_L5;
    }

    /* "Cython/Tempita/_tempita.py":298
 *                 result = True
 *             else:
 *                 result = self._eval(part[2], ns, pos)             # <<<<<<<<<<<<<<
 *             if result:
 *                 self._interpret_codes(part[3], ns, out, defs)
*/
    /*else*/ {
      __pyx_t_4 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_part, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_t_8, __pyx_v_ns, __pyx_v_pos};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_9, (4-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_7);
      __pyx_t_7 = 0;
    }
    __pyx_L5:;

    /* "Cython/Tempita/_tempita.py":299
 *             else:
 *                 result = self._eval(part[2], ns, pos)
 *             if result:             # <<<<<<<<<<<<<<
 *                 self._interpret_codes(part[3], ns, out, defs)
 *                 break
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 299, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Tempita/_tempita.py":300
 *                 result = self._eval(part[2], ns, pos)
 *             if result:
 *                 self._interpret_codes(part[3], ns, out, defs)             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      __pyx_t_8 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_part, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = 0;
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_t_4, __pyx_v_ns, __pyx_v_out, __pyx_v_defs};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_codes, __pyx_callargs+__pyx_t_9, (5-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":301
 *             if result:
 *                 self._interpret_codes(part[3], ns, out, defs)
 *                 break             # <<<<<<<<<<<<<<
 * 
 *     def _eval(self, code, ns, pos):
*/
      goto __pyx_L4_break;

      /* "Cython/Tempita/_tempita.py":299
 *             else:
 *                 result = self._eval(part[2], ns, pos)
 *             if result:             # <<<<<<<<<<<<<<
 *                 self._interpret_codes(part[3], ns, out, defs)
 *                 break
*/
    }

    /* "Cython/Tempita/_tempita.py":292
 *         __traceback_hide__ = True
 *         # @@: if/else/else gets through
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             assert not isinstance(part, str)
 *             name, pos = part[0], part[1]
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L7_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L7_for_end;
  __pyx_L7_for_end:;

  /* "Cython/Tempita/_tempita.py":289
 *                 break
 * 
 *     def _interpret_if(self, parts, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         # @@: if/else/else gets through
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._interpret_if", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":303
 *                 break
 * 
 *     def _eval(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_21_eval(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_21_eval = {"_eval", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_21_eval, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_21_eval(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_eval (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 303, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 303, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 303, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 303, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 303, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_eval", 0) < (0)) __PYX_ERR(0, 303, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_eval", 1, 4, 4, i); __PYX_ERR(0, 303, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 303, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 303, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 303, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 303, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_code = values[1];
    __pyx_v_ns = values[2];
    __pyx_v_pos = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_eval", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 303, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_20_eval(__pyx_self, __pyx_v_self, __pyx_v_code, __pyx_v_ns, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_20_eval(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_arg0 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_t_23;
  char const *__pyx_t_24;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_eval", 0);

  /* "Cython/Tempita/_tempita.py":304
 * 
 *     def _eval(self, code, ns, pos):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         try:
 *             try:
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":305
 *     def _eval(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 value = eval(code, self.default_namespace, ns)
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Tempita/_tempita.py":306
 *         __traceback_hide__ = True
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        /*try:*/ {

          /* "Cython/Tempita/_tempita.py":307
 *         try:
 *             try:
 *                 value = eval(code, self.default_namespace, ns)             # <<<<<<<<<<<<<<
 *             except SyntaxError as e:
 *                 raise SyntaxError(
*/
          __pyx_t_8 = NULL;
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 307, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = 1;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_v_code, __pyx_t_9, __pyx_v_ns};
            __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_eval, __pyx_callargs+__pyx_t_10, (4-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 307, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_v_value = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "Cython/Tempita/_tempita.py":306
 *         __traceback_hide__ = True
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:
*/
        }
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L14_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "Cython/Tempita/_tempita.py":308
 *             try:
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:             # <<<<<<<<<<<<<<
 *                 raise SyntaxError(
 *                     'invalid syntax in expression: %s' % code)
*/
        __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_SyntaxError))));
        if (__pyx_t_11) {
          __Pyx_AddTraceback("Cython.Tempita._tempita.Template._eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 308, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __pyx_v_e = __pyx_t_9;
          /*try:*/ {

            /* "Cython/Tempita/_tempita.py":309
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:
 *                 raise SyntaxError(             # <<<<<<<<<<<<<<
 *                     'invalid syntax in expression: %s' % code)
 *             return value
*/
            __pyx_t_13 = NULL;

            /* "Cython/Tempita/_tempita.py":310
 *             except SyntaxError as e:
 *                 raise SyntaxError(
 *                     'invalid syntax in expression: %s' % code)             # <<<<<<<<<<<<<<
 *             return value
 *         except Exception as e:
*/
            __pyx_t_14 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_invalid_syntax_in_expression_s, __pyx_v_code); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 310, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_10 = 1;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_14};
              __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_SyntaxError)), __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 309, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_Raise(__pyx_t_12, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __PYX_ERR(0, 309, __pyx_L20_error)
          }

          /* "Cython/Tempita/_tempita.py":308
 *             try:
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:             # <<<<<<<<<<<<<<
 *                 raise SyntaxError(
 *                     'invalid syntax in expression: %s' % code)
*/
          /*finally:*/ {
            __pyx_L20_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
               __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
              if ( unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_22);
              __pyx_t_11 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
              }
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
              __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
              __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
              goto __pyx_L11_except_error;
            }
          }
        }
        goto __pyx_L11_except_error;

        /* "Cython/Tempita/_tempita.py":306
 *         __traceback_hide__ = True
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 value = eval(code, self.default_namespace, ns)
 *             except SyntaxError as e:
*/
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        goto __pyx_L3_error;
        __pyx_L14_try_end:;
      }

      /* "Cython/Tempita/_tempita.py":311
 *                 raise SyntaxError(
 *                     'invalid syntax in expression: %s' % code)
 *             return value             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             if getattr(e, 'args', None):
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_value);
      __pyx_r = __pyx_v_value;
      goto __pyx_L7_try_return;

      /* "Cython/Tempita/_tempita.py":305
 *     def _eval(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 value = eval(code, self.default_namespace, ns)
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "Cython/Tempita/_tempita.py":312
 *                     'invalid syntax in expression: %s' % code)
 *             return value
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if getattr(e, 'args', None):
 *                 arg0 = e.args[0]
*/
    __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_15) {
      __Pyx_AddTraceback("Cython.Tempita._tempita.Template._eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_7) < 0) __PYX_ERR(0, 312, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_9);
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":313
 *             return value
 *         except Exception as e:
 *             if getattr(e, 'args', None):             # <<<<<<<<<<<<<<
 *                 arg0 = e.args[0]
 *             else:
*/
        __pyx_t_12 = __Pyx_GetAttr3(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args, Py_None); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 313, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_23 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_23 < 0))) __PYX_ERR(0, 313, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_23) {

          /* "Cython/Tempita/_tempita.py":314
 *         except Exception as e:
 *             if getattr(e, 'args', None):
 *                 arg0 = e.args[0]             # <<<<<<<<<<<<<<
 *             else:
 *                 arg0 = coerce_text(e)
*/
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 314, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_14 = __Pyx_GetItemInt(__pyx_t_12, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 314, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_v_arg0 = __pyx_t_14;
          __pyx_t_14 = 0;

          /* "Cython/Tempita/_tempita.py":313
 *             return value
 *         except Exception as e:
 *             if getattr(e, 'args', None):             # <<<<<<<<<<<<<<
 *                 arg0 = e.args[0]
 *             else:
*/
          goto __pyx_L33;
        }

        /* "Cython/Tempita/_tempita.py":316
 *                 arg0 = e.args[0]
 *             else:
 *                 arg0 = coerce_text(e)             # <<<<<<<<<<<<<<
 *             e.args = (self._add_line_info(arg0, pos),)
 *             raise
*/
        /*else*/ {
          __pyx_t_12 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_coerce_text); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 316, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_10 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
            assert(__pyx_t_12);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
            __pyx_t_10 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_e};
            __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 316, __pyx_L31_error)
            __Pyx_GOTREF(__pyx_t_14);
          }
          __pyx_v_arg0 = __pyx_t_14;
          __pyx_t_14 = 0;
        }
        __pyx_L33:;

        /* "Cython/Tempita/_tempita.py":317
 *             else:
 *                 arg0 = coerce_text(e)
 *             e.args = (self._add_line_info(arg0, pos),)             # <<<<<<<<<<<<<<
 *             raise
 * 
*/
        __pyx_t_13 = __pyx_v_self;
        __Pyx_INCREF(__pyx_t_13);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_v_arg0, __pyx_v_pos};
          __pyx_t_14 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_line_info, __pyx_callargs+__pyx_t_10, (3-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 317, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_14);
        }
        __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 317, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_14);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_14) != (0)) __PYX_ERR(0, 317, __pyx_L31_error);
        __pyx_t_14 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args, __pyx_t_13) < (0)) __PYX_ERR(0, 317, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "Cython/Tempita/_tempita.py":318
 *                 arg0 = coerce_text(e)
 *             e.args = (self._add_line_info(arg0, pos),)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *     def _exec(self, code, ns, pos):
*/
        __Pyx_GIVEREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_9, __pyx_t_7);
        __pyx_t_8 = 0;  __pyx_t_9 = 0;  __pyx_t_7 = 0; 
        __PYX_ERR(0, 318, __pyx_L31_error)
      }

      /* "Cython/Tempita/_tempita.py":312
 *                     'invalid syntax in expression: %s' % code)
 *             return value
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if getattr(e, 'args', None):
 *                 arg0 = e.args[0]
*/
      /*finally:*/ {
        __pyx_L31_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_15 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_24 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_21, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_24;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "Cython/Tempita/_tempita.py":305
 *     def _eval(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 value = eval(code, self.default_namespace, ns)
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Tempita/_tempita.py":303
 *                 break
 * 
 *     def _eval(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_arg0);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":320
 *             raise
 * 
 *     def _exec(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_23_exec(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_23_exec = {"_exec", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_23_exec, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_23_exec(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_exec (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 320, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 320, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 320, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 320, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 320, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_exec", 0) < (0)) __PYX_ERR(0, 320, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_exec", 1, 4, 4, i); __PYX_ERR(0, 320, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 320, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 320, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 320, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 320, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_code = values[1];
    __pyx_v_ns = values[2];
    __pyx_v_pos = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_exec", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 320, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_22_exec(__pyx_self, __pyx_v_self, __pyx_v_code, __pyx_v_ns, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_22_exec(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_code, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  size_t __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_exec", 0);

  /* "Cython/Tempita/_tempita.py":321
 * 
 *     def _exec(self, code, ns, pos):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         try:
 *             exec(code, self.default_namespace, ns)
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":322
 *     def _exec(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Tempita/_tempita.py":323
 *         __traceback_hide__ = True
 *         try:
 *             exec(code, self.default_namespace, ns)             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             if e.args:
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 323, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyExec3(__pyx_v_code, __pyx_t_4, __pyx_v_ns); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 323, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":322
 *     def _exec(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Tempita/_tempita.py":324
 *         try:
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if e.args:
 *                 e.args = (self._add_line_info(e.args[0], pos),)
*/
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("Cython.Tempita._tempita.Template._exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 324, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_e = __pyx_t_4;
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":325
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:
 *             if e.args:             # <<<<<<<<<<<<<<
 *                 e.args = (self._add_line_info(e.args[0], pos),)
 *             else:
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 325, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 325, __pyx_L14_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_9) {

          /* "Cython/Tempita/_tempita.py":326
 *         except Exception as e:
 *             if e.args:
 *                 e.args = (self._add_line_info(e.args[0], pos),)             # <<<<<<<<<<<<<<
 *             else:
 *                 e.args = (self._add_line_info(None, pos),)
*/
          __pyx_t_10 = __pyx_v_self;
          __Pyx_INCREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 326, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_11, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 326, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_12, __pyx_v_pos};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_line_info, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 326, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __pyx_t_12 = PyTuple_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 326, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GIVEREF(__pyx_t_8);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_8) != (0)) __PYX_ERR(0, 326, __pyx_L14_error);
          __pyx_t_8 = 0;
          if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args, __pyx_t_12) < (0)) __PYX_ERR(0, 326, __pyx_L14_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "Cython/Tempita/_tempita.py":325
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:
 *             if e.args:             # <<<<<<<<<<<<<<
 *                 e.args = (self._add_line_info(e.args[0], pos),)
 *             else:
*/
          goto __pyx_L16;
        }

        /* "Cython/Tempita/_tempita.py":328
 *                 e.args = (self._add_line_info(e.args[0], pos),)
 *             else:
 *                 e.args = (self._add_line_info(None, pos),)             # <<<<<<<<<<<<<<
 *             raise
 * 
*/
        /*else*/ {
          __pyx_t_8 = __pyx_v_self;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_13 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_8, Py_None, __pyx_v_pos};
            __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_line_info, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 328, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_12);
          }
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 328, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_12);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_12) != (0)) __PYX_ERR(0, 328, __pyx_L14_error);
          __pyx_t_12 = 0;
          if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args, __pyx_t_8) < (0)) __PYX_ERR(0, 328, __pyx_L14_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L16:;

        /* "Cython/Tempita/_tempita.py":329
 *             else:
 *                 e.args = (self._add_line_info(None, pos),)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *     def _repr(self, value, pos):
*/
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_4, __pyx_t_7);
        __pyx_t_5 = 0;  __pyx_t_4 = 0;  __pyx_t_7 = 0; 
        __PYX_ERR(0, 329, __pyx_L14_error)
      }

      /* "Cython/Tempita/_tempita.py":324
 *         try:
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if e.args:
 *                 e.args = (self._add_line_info(e.args[0], pos),)
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ( unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_6 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "Cython/Tempita/_tempita.py":322
 *     def _exec(self, code, ns, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             exec(code, self.default_namespace, ns)
 *         except Exception as e:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "Cython/Tempita/_tempita.py":320
 *             raise
 * 
 *     def _exec(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":331
 *             raise
 * 
 *     def _repr(self, value, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_25_repr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_25_repr = {"_repr", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_25_repr, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_25_repr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_value,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 331, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 331, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 331, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 331, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_repr", 0) < (0)) __PYX_ERR(0, 331, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_repr", 1, 3, 3, i); __PYX_ERR(0, 331, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 331, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 331, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 331, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_value = values[1];
    __pyx_v_pos = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_repr", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_24_repr(__pyx_self, __pyx_v_self, __pyx_v_value, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_24_repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_pos) {
  CYTHON_UNUSED int __pyx_v___traceback_hide__;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  size_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_t_23;
  char const *__pyx_t_24;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  int __pyx_t_31;
  char const *__pyx_t_32;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr", 0);
  __Pyx_INCREF(__pyx_v_value);

  /* "Cython/Tempita/_tempita.py":332
 * 
 *     def _repr(self, value, pos):
 *         __traceback_hide__ = True             # <<<<<<<<<<<<<<
 *         try:
 *             if value is None:
*/
  __pyx_v___traceback_hide__ = 1;

  /* "Cython/Tempita/_tempita.py":333
 *     def _repr(self, value, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             if value is None:
 *                 return ''
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Tempita/_tempita.py":334
 *         __traceback_hide__ = True
 *         try:
 *             if value is None:             # <<<<<<<<<<<<<<
 *                 return ''
 *             if self._unicode:
*/
      __pyx_t_4 = (__pyx_v_value == Py_None);
      if (__pyx_t_4) {

        /* "Cython/Tempita/_tempita.py":335
 *         try:
 *             if value is None:
 *                 return ''             # <<<<<<<<<<<<<<
 *             if self._unicode:
 *                 try:
*/
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
        __pyx_r = __pyx_mstate_global->__pyx_kp_u__4;
        goto __pyx_L7_try_return;

        /* "Cython/Tempita/_tempita.py":334
 *         __traceback_hide__ = True
 *         try:
 *             if value is None:             # <<<<<<<<<<<<<<
 *                 return ''
 *             if self._unicode:
*/
      }

      /* "Cython/Tempita/_tempita.py":336
 *             if value is None:
 *                 return ''
 *             if self._unicode:             # <<<<<<<<<<<<<<
 *                 try:
 *                     value = str(value)
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 336, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_4) {

        /* "Cython/Tempita/_tempita.py":337
 *                 return ''
 *             if self._unicode:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = str(value)
 *                 except UnicodeDecodeError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          /*try:*/ {

            /* "Cython/Tempita/_tempita.py":338
 *             if self._unicode:
 *                 try:
 *                     value = str(value)             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     value = bytes(value)
*/
            __pyx_t_5 = __Pyx_PyObject_Unicode(__pyx_v_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 338, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "Cython/Tempita/_tempita.py":337
 *                 return ''
 *             if self._unicode:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = str(value)
 *                 except UnicodeDecodeError:
*/
          }
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L16_try_end;
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "Cython/Tempita/_tempita.py":339
 *                 try:
 *                     value = str(value)
 *                 except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                     value = bytes(value)
 *             else:
*/
          __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_UnicodeDecodeError))));
          if (__pyx_t_9) {
            __Pyx_AddTraceback("Cython.Tempita._tempita.Template._repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_10, &__pyx_t_11) < 0) __PYX_ERR(0, 339, __pyx_L13_except_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_11);

            /* "Cython/Tempita/_tempita.py":340
 *                     value = str(value)
 *                 except UnicodeDecodeError:
 *                     value = bytes(value)             # <<<<<<<<<<<<<<
 *             else:
 *                 if not isinstance(value, str):
*/
            __pyx_t_13 = NULL;
            __pyx_t_14 = 1;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_value};
              __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 340, __pyx_L13_except_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_12);
            __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            goto __pyx_L12_exception_handled;
          }
          goto __pyx_L13_except_error;

          /* "Cython/Tempita/_tempita.py":337
 *                 return ''
 *             if self._unicode:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = str(value)
 *                 except UnicodeDecodeError:
*/
          __pyx_L13_except_error:;
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
          goto __pyx_L3_error;
          __pyx_L12_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
          __pyx_L16_try_end:;
        }

        /* "Cython/Tempita/_tempita.py":336
 *             if value is None:
 *                 return ''
 *             if self._unicode:             # <<<<<<<<<<<<<<
 *                 try:
 *                     value = str(value)
*/
        goto __pyx_L10;
      }

      /* "Cython/Tempita/_tempita.py":342
 *                     value = bytes(value)
 *             else:
 *                 if not isinstance(value, str):             # <<<<<<<<<<<<<<
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)
*/
      /*else*/ {
        __pyx_t_4 = PyUnicode_Check(__pyx_v_value); 
        __pyx_t_15 = (!__pyx_t_4);
        if (__pyx_t_15) {

          /* "Cython/Tempita/_tempita.py":343
 *             else:
 *                 if not isinstance(value, str):
 *                     value = coerce_text(value)             # <<<<<<<<<<<<<<
 *                 if (isinstance(value, str)
 *                         and self.default_encoding):
*/
          __pyx_t_10 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_coerce_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 343, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
            assert(__pyx_t_10);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
            __pyx_t_14 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_value};
            __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 343, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_11);
          __pyx_t_11 = 0;

          /* "Cython/Tempita/_tempita.py":342
 *                     value = bytes(value)
 *             else:
 *                 if not isinstance(value, str):             # <<<<<<<<<<<<<<
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)
*/
        }

        /* "Cython/Tempita/_tempita.py":344
 *                 if not isinstance(value, str):
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)             # <<<<<<<<<<<<<<
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)
*/
        __pyx_t_4 = PyUnicode_Check(__pyx_v_value); 
        if (__pyx_t_4) {
        } else {
          __pyx_t_15 = __pyx_t_4;
          goto __pyx_L21_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":345
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)
 *                         and self.default_encoding):             # <<<<<<<<<<<<<<
 *                     value = value.encode(self.default_encoding)
 *         except Exception as e:
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 345, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 345, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_15 = __pyx_t_4;
        __pyx_L21_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":344
 *                 if not isinstance(value, str):
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)             # <<<<<<<<<<<<<<
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)
*/
        if (__pyx_t_15) {

          /* "Cython/Tempita/_tempita.py":346
 *                 if (isinstance(value, str)
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             e.args = (self._add_line_info(e.args[0], pos),)
*/
          __pyx_t_5 = __pyx_v_value;
          __Pyx_INCREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 346, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_14 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_10};
            __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 346, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_11);
          __pyx_t_11 = 0;

          /* "Cython/Tempita/_tempita.py":344
 *                 if not isinstance(value, str):
 *                     value = coerce_text(value)
 *                 if (isinstance(value, str)             # <<<<<<<<<<<<<<
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)
*/
        }
      }
      __pyx_L10:;

      /* "Cython/Tempita/_tempita.py":333
 *     def _repr(self, value, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             if value is None:
 *                 return ''
*/
    }

    /* "Cython/Tempita/_tempita.py":351
 *             raise
 *         else:
 *             if self._unicode and isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *                 if not self.default_encoding:
 *                     raise UnicodeDecodeError(
*/
    /*else:*/ {
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 351, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 351, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_4) {
      } else {
        __pyx_t_15 = __pyx_t_4;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = PyBytes_Check(__pyx_v_value); 
      __pyx_t_15 = __pyx_t_4;
      __pyx_L24_bool_binop_done:;
      if (__pyx_t_15) {

        /* "Cython/Tempita/_tempita.py":352
 *         else:
 *             if self._unicode and isinstance(value, bytes):
 *                 if not self.default_encoding:             # <<<<<<<<<<<<<<
 *                     raise UnicodeDecodeError(
 *                         'Cannot decode bytes value %r into unicode '
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 352, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 352, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_4 = (!__pyx_t_15);
        if (unlikely(__pyx_t_4)) {

          /* "Cython/Tempita/_tempita.py":353
 *             if self._unicode and isinstance(value, bytes):
 *                 if not self.default_encoding:
 *                     raise UnicodeDecodeError(             # <<<<<<<<<<<<<<
 *                         'Cannot decode bytes value %r into unicode '
 *                         '(no default_encoding provided)' % value)
*/
          __pyx_t_10 = NULL;

          /* "Cython/Tempita/_tempita.py":355
 *                     raise UnicodeDecodeError(
 *                         'Cannot decode bytes value %r into unicode '
 *                         '(no default_encoding provided)' % value)             # <<<<<<<<<<<<<<
 *                 try:
 *                     value = value.decode(self.default_encoding)
*/
          __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Cannot_decode_bytes_value_r_into, __pyx_v_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 355, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_5};
            __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_UnicodeDecodeError)), __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 353, __pyx_L5_except_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_Raise(__pyx_t_11, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __PYX_ERR(0, 353, __pyx_L5_except_error)

          /* "Cython/Tempita/_tempita.py":352
 *         else:
 *             if self._unicode and isinstance(value, bytes):
 *                 if not self.default_encoding:             # <<<<<<<<<<<<<<
 *                     raise UnicodeDecodeError(
 *                         'Cannot decode bytes value %r into unicode '
*/
        }

        /* "Cython/Tempita/_tempita.py":356
 *                         'Cannot decode bytes value %r into unicode '
 *                         '(no default_encoding provided)' % value)
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_6);
          /*try:*/ {

            /* "Cython/Tempita/_tempita.py":357
 *                         '(no default_encoding provided)' % value)
 *                 try:
 *                     value = value.decode(self.default_encoding)             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError as e:
 *                     raise UnicodeDecodeError(
*/
            __pyx_t_5 = __pyx_v_value;
            __Pyx_INCREF(__pyx_t_5);
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 357, __pyx_L27_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_14 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_10};
              __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decode, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 357, __pyx_L27_error)
              __Pyx_GOTREF(__pyx_t_11);
            }
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "Cython/Tempita/_tempita.py":356
 *                         'Cannot decode bytes value %r into unicode '
 *                         '(no default_encoding provided)' % value)
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:
*/
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L32_try_end;
          __pyx_L27_error:;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "Cython/Tempita/_tempita.py":358
 *                 try:
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:             # <<<<<<<<<<<<<<
 *                     raise UnicodeDecodeError(
 *                         e.encoding,
*/
          __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_UnicodeDecodeError))));
          if (__pyx_t_9) {
            __Pyx_AddTraceback("Cython.Tempita._tempita.Template._repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_10, &__pyx_t_5) < 0) __PYX_ERR(0, 358, __pyx_L29_except_error)
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_10);
            __pyx_v_e = __pyx_t_10;
            /*try:*/ {

              /* "Cython/Tempita/_tempita.py":359
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:
 *                     raise UnicodeDecodeError(             # <<<<<<<<<<<<<<
 *                         e.encoding,
 *                         e.object,
*/
              __pyx_t_13 = NULL;

              /* "Cython/Tempita/_tempita.py":360
 *                 except UnicodeDecodeError as e:
 *                     raise UnicodeDecodeError(
 *                         e.encoding,             # <<<<<<<<<<<<<<
 *                         e.object,
 *                         e.start,
*/
              __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_encoding); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 360, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_16);

              /* "Cython/Tempita/_tempita.py":361
 *                     raise UnicodeDecodeError(
 *                         e.encoding,
 *                         e.object,             # <<<<<<<<<<<<<<
 *                         e.start,
 *                         e.end,
*/
              __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_object); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 361, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_17);

              /* "Cython/Tempita/_tempita.py":362
 *                         e.encoding,
 *                         e.object,
 *                         e.start,             # <<<<<<<<<<<<<<
 *                         e.end,
 *                         e.reason + ' in string %r' % value)
*/
              __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_start); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 362, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_18);

              /* "Cython/Tempita/_tempita.py":363
 *                         e.object,
 *                         e.start,
 *                         e.end,             # <<<<<<<<<<<<<<
 *                         e.reason + ' in string %r' % value)
 *             elif not self._unicode and isinstance(value, str):
*/
              __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_end); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 363, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_19);

              /* "Cython/Tempita/_tempita.py":364
 *                         e.start,
 *                         e.end,
 *                         e.reason + ' in string %r' % value)             # <<<<<<<<<<<<<<
 *             elif not self._unicode and isinstance(value, str):
 *                 if not self.default_encoding:
*/
              __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_reason); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 364, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_20);
              __pyx_t_21 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_in_string_r, __pyx_v_value); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 364, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_21);
              __pyx_t_22 = PyNumber_Add(__pyx_t_20, __pyx_t_21); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 364, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_22);
              __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              __pyx_t_14 = 1;
              {
                PyObject *__pyx_callargs[6] = {__pyx_t_13, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_22};
                __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_UnicodeDecodeError)), __pyx_callargs+__pyx_t_14, (6-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
                if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 359, __pyx_L38_error)
                __Pyx_GOTREF(__pyx_t_12);
              }
              __Pyx_Raise(__pyx_t_12, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __PYX_ERR(0, 359, __pyx_L38_error)
            }

            /* "Cython/Tempita/_tempita.py":358
 *                 try:
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:             # <<<<<<<<<<<<<<
 *                     raise UnicodeDecodeError(
 *                         e.encoding,
*/
            /*finally:*/ {
              __pyx_L38_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
                __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
                 __Pyx_ExceptionSwap(&__pyx_t_28, &__pyx_t_29, &__pyx_t_30);
                if ( unlikely(__Pyx_GetException(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27) < 0)) __Pyx_ErrFetch(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
                __Pyx_XGOTREF(__pyx_t_25);
                __Pyx_XGOTREF(__pyx_t_26);
                __Pyx_XGOTREF(__pyx_t_27);
                __Pyx_XGOTREF(__pyx_t_28);
                __Pyx_XGOTREF(__pyx_t_29);
                __Pyx_XGOTREF(__pyx_t_30);
                __pyx_t_9 = __pyx_lineno; __pyx_t_23 = __pyx_clineno; __pyx_t_24 = __pyx_filename;
                {
                  __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
                }
                __Pyx_XGIVEREF(__pyx_t_28);
                __Pyx_XGIVEREF(__pyx_t_29);
                __Pyx_XGIVEREF(__pyx_t_30);
                __Pyx_ExceptionReset(__pyx_t_28, __pyx_t_29, __pyx_t_30);
                __Pyx_XGIVEREF(__pyx_t_25);
                __Pyx_XGIVEREF(__pyx_t_26);
                __Pyx_XGIVEREF(__pyx_t_27);
                __Pyx_ErrRestore(__pyx_t_25, __pyx_t_26, __pyx_t_27);
                __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
                __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_23; __pyx_filename = __pyx_t_24;
                goto __pyx_L29_except_error;
              }
            }
          }
          goto __pyx_L29_except_error;

          /* "Cython/Tempita/_tempita.py":356
 *                         'Cannot decode bytes value %r into unicode '
 *                         '(no default_encoding provided)' % value)
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = value.decode(self.default_encoding)
 *                 except UnicodeDecodeError as e:
*/
          __pyx_L29_except_error:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
          goto __pyx_L5_except_error;
          __pyx_L32_try_end:;
        }

        /* "Cython/Tempita/_tempita.py":351
 *             raise
 *         else:
 *             if self._unicode and isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *                 if not self.default_encoding:
 *                     raise UnicodeDecodeError(
*/
        goto __pyx_L23;
      }

      /* "Cython/Tempita/_tempita.py":365
 *                         e.end,
 *                         e.reason + ' in string %r' % value)
 *             elif not self._unicode and isinstance(value, str):             # <<<<<<<<<<<<<<
 *                 if not self.default_encoding:
 *                     raise UnicodeEncodeError(
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 365, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 365, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_31 = (!__pyx_t_15);
      if (__pyx_t_31) {
      } else {
        __pyx_t_4 = __pyx_t_31;
        goto __pyx_L44_bool_binop_done;
      }
      __pyx_t_31 = PyUnicode_Check(__pyx_v_value); 
      __pyx_t_4 = __pyx_t_31;
      __pyx_L44_bool_binop_done:;
      if (__pyx_t_4) {

        /* "Cython/Tempita/_tempita.py":366
 *                         e.reason + ' in string %r' % value)
 *             elif not self._unicode and isinstance(value, str):
 *                 if not self.default_encoding:             # <<<<<<<<<<<<<<
 *                     raise UnicodeEncodeError(
 *                         'Cannot encode unicode value %r into bytes '
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 366, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 366, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_31 = (!__pyx_t_4);
        if (unlikely(__pyx_t_31)) {

          /* "Cython/Tempita/_tempita.py":367
 *             elif not self._unicode and isinstance(value, str):
 *                 if not self.default_encoding:
 *                     raise UnicodeEncodeError(             # <<<<<<<<<<<<<<
 *                         'Cannot encode unicode value %r into bytes '
 *                         '(no default_encoding provided)' % value)
*/
          __pyx_t_10 = NULL;

          /* "Cython/Tempita/_tempita.py":369
 *                     raise UnicodeEncodeError(
 *                         'Cannot encode unicode value %r into bytes '
 *                         '(no default_encoding provided)' % value)             # <<<<<<<<<<<<<<
 *                 value = value.encode(self.default_encoding)
 *             return value
*/
          __pyx_t_11 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Cannot_encode_unicode_value_r_in, __pyx_v_value); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 369, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_14 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_11};
            __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_UnicodeEncodeError)), __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 367, __pyx_L5_except_error)
            __Pyx_GOTREF(__pyx_t_5);
          }
          __Pyx_Raise(__pyx_t_5, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __PYX_ERR(0, 367, __pyx_L5_except_error)

          /* "Cython/Tempita/_tempita.py":366
 *                         e.reason + ' in string %r' % value)
 *             elif not self._unicode and isinstance(value, str):
 *                 if not self.default_encoding:             # <<<<<<<<<<<<<<
 *                     raise UnicodeEncodeError(
 *                         'Cannot encode unicode value %r into bytes '
*/
        }

        /* "Cython/Tempita/_tempita.py":370
 *                         'Cannot encode unicode value %r into bytes '
 *                         '(no default_encoding provided)' % value)
 *                 value = value.encode(self.default_encoding)             # <<<<<<<<<<<<<<
 *             return value
 * 
*/
        __pyx_t_11 = __pyx_v_value;
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_default_encoding); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 370, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_14 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_10};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 370, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":365
 *                         e.end,
 *                         e.reason + ' in string %r' % value)
 *             elif not self._unicode and isinstance(value, str):             # <<<<<<<<<<<<<<
 *                 if not self.default_encoding:
 *                     raise UnicodeEncodeError(
*/
      }
      __pyx_L23:;

      /* "Cython/Tempita/_tempita.py":371
 *                         '(no default_encoding provided)' % value)
 *                 value = value.encode(self.default_encoding)
 *             return value             # <<<<<<<<<<<<<<
 * 
 *     def _add_line_info(self, msg, pos):
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_value);
      __pyx_r = __pyx_v_value;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Tempita/_tempita.py":347
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             e.args = (self._add_line_info(e.args[0], pos),)
 *             raise
*/
    __pyx_t_23 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_23) {
      __Pyx_AddTraceback("Cython.Tempita._tempita.Template._repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_10, &__pyx_t_11) < 0) __PYX_ERR(0, 347, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_v_e = __pyx_t_10;
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":348
 *                     value = value.encode(self.default_encoding)
 *         except Exception as e:
 *             e.args = (self._add_line_info(e.args[0], pos),)             # <<<<<<<<<<<<<<
 *             raise
 *         else:
*/
        __pyx_t_22 = __pyx_v_self;
        __Pyx_INCREF(__pyx_t_22);
        __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 348, __pyx_L52_error)
        __Pyx_GOTREF(__pyx_t_19);
        __pyx_t_18 = __Pyx_GetItemInt(__pyx_t_19, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 348, __pyx_L52_error)
        __Pyx_GOTREF(__pyx_t_18);
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_14 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_22, __pyx_t_18, __pyx_v_pos};
          __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_line_info, __pyx_callargs+__pyx_t_14, (3-__pyx_t_14) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 348, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_12);
        }
        __pyx_t_18 = PyTuple_New(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 348, __pyx_L52_error)
        __Pyx_GOTREF(__pyx_t_18);
        __Pyx_GIVEREF(__pyx_t_12);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_12) != (0)) __PYX_ERR(0, 348, __pyx_L52_error);
        __pyx_t_12 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args, __pyx_t_18) < (0)) __PYX_ERR(0, 348, __pyx_L52_error)
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

        /* "Cython/Tempita/_tempita.py":349
 *         except Exception as e:
 *             e.args = (self._add_line_info(e.args[0], pos),)
 *             raise             # <<<<<<<<<<<<<<
 *         else:
 *             if self._unicode and isinstance(value, bytes):
*/
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_10, __pyx_t_11);
        __pyx_t_5 = 0;  __pyx_t_10 = 0;  __pyx_t_11 = 0; 
        __PYX_ERR(0, 349, __pyx_L52_error)
      }

      /* "Cython/Tempita/_tempita.py":347
 *                         and self.default_encoding):
 *                     value = value.encode(self.default_encoding)
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             e.args = (self._add_line_info(e.args[0], pos),)
 *             raise
*/
      /*finally:*/ {
        __pyx_L52_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_30, &__pyx_t_29, &__pyx_t_28);
          if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_30);
          __Pyx_XGOTREF(__pyx_t_29);
          __Pyx_XGOTREF(__pyx_t_28);
          __pyx_t_23 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_32 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_30);
          __Pyx_XGIVEREF(__pyx_t_29);
          __Pyx_XGIVEREF(__pyx_t_28);
          __Pyx_ExceptionReset(__pyx_t_30, __pyx_t_29, __pyx_t_28);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
          __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_30 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0;
          __pyx_lineno = __pyx_t_23; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_32;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "Cython/Tempita/_tempita.py":333
 *     def _repr(self, value, pos):
 *         __traceback_hide__ = True
 *         try:             # <<<<<<<<<<<<<<
 *             if value is None:
 *                 return ''
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Tempita/_tempita.py":331
 *             raise
 * 
 *     def _repr(self, value, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":373
 *             return value
 * 
 *     def _add_line_info(self, msg, pos):             # <<<<<<<<<<<<<<
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_27_add_line_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_8Template_27_add_line_info = {"_add_line_info", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_8Template_27_add_line_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_8Template_27_add_line_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_pos = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_add_line_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_pos,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 373, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 373, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 373, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 373, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_add_line_info", 0) < (0)) __PYX_ERR(0, 373, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_add_line_info", 1, 3, 3, i); __PYX_ERR(0, 373, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 373, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 373, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 373, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_msg = values[1];
    __pyx_v_pos = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_add_line_info", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 373, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._add_line_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8Template_26_add_line_info(__pyx_self, __pyx_v_self, __pyx_v_msg, __pyx_v_pos);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8Template_26_add_line_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_msg, PyObject *__pyx_v_pos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5[5];
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_add_line_info", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "Cython/Tempita/_tempita.py":375
 *     def _add_line_info(self, msg, pos):
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])             # <<<<<<<<<<<<<<
 *         if self.name:
 *             msg += " in file %s" % self.name
*/
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_msg), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5[0] = __pyx_t_1;
  __pyx_t_5[1] = __pyx_mstate_global->__pyx_kp_u_at_line;
  __pyx_t_5[2] = __pyx_t_3;
  __pyx_t_5[3] = __pyx_mstate_global->__pyx_kp_u_column;
  __pyx_t_5[4] = __pyx_t_4;

  /* "Cython/Tempita/_tempita.py":374
 * 
 *     def _add_line_info(self, msg, pos):
 *         msg = "%s at line %s column %s" % (             # <<<<<<<<<<<<<<
 *             msg, pos[0], pos[1])
 *         if self.name:
*/
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_msg, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":376
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])
 *         if self.name:             # <<<<<<<<<<<<<<
 *             msg += " in file %s" % self.name
 *         return msg
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "Cython/Tempita/_tempita.py":377
 *             msg, pos[0], pos[1])
 *         if self.name:
 *             msg += " in file %s" % self.name             # <<<<<<<<<<<<<<
 *         return msg
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_in_file_s, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_msg, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_msg, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Tempita/_tempita.py":376
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])
 *         if self.name:             # <<<<<<<<<<<<<<
 *             msg += " in file %s" % self.name
 *         return msg
*/
  }

  /* "Cython/Tempita/_tempita.py":378
 *         if self.name:
 *             msg += " in file %s" % self.name
 *         return msg             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_msg);
  __pyx_r = __pyx_v_msg;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":373
 *             return value
 * 
 *     def _add_line_info(self, msg, pos):             # <<<<<<<<<<<<<<
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Tempita._tempita.Template._add_line_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":381
 * 
 * 
 * def sub(content, delimiters=None, **kw):             # <<<<<<<<<<<<<<
 *     name = kw.get('__name')
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5sub(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5sub = {"sub", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_5sub, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5sub(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_delimiters = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sub (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kw = PyDict_New(); if (unlikely(!__pyx_v_kw)) return NULL;
  __Pyx_GOTREF(__pyx_v_kw);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_content,&__pyx_mstate_global->__pyx_n_u_delimiters,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 381, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 381, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 381, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, kwd_pos_args, __pyx_kwds_len, "sub", 1) < (0)) __PYX_ERR(0, 381, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("sub", 0, 1, 2, i); __PYX_ERR(0, 381, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 381, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 381, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_content = values[0];
    __pyx_v_delimiters = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sub", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 381, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("Cython.Tempita._tempita.sub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_4sub(__pyx_self, __pyx_v_content, __pyx_v_delimiters, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_4sub(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_content, PyObject *__pyx_v_delimiters, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_delimeters = NULL;
  PyObject *__pyx_v_tmpl = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sub", 0);

  /* "Cython/Tempita/_tempita.py":382
 * 
 * def sub(content, delimiters=None, **kw):
 *     name = kw.get('__name')             # <<<<<<<<<<<<<<
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
 *     tmpl = Template(content, name=name, delimiters=delimiters, delimeters=delimeters)
*/
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_kw, __pyx_mstate_global->__pyx_n_u_name_4, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":383
 * def sub(content, delimiters=None, **kw):
 *     name = kw.get('__name')
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code             # <<<<<<<<<<<<<<
 *     tmpl = Template(content, name=name, delimiters=delimiters, delimeters=delimeters)
 *     return tmpl.substitute(kw)
*/
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_mstate_global->__pyx_n_u_delimeters, __pyx_v_kw, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyDict_Pop(__pyx_v_kw, __pyx_mstate_global->__pyx_n_u_delimeters, ((PyObject *)NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __pyx_v_delimeters = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":384
 *     name = kw.get('__name')
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
 *     tmpl = Template(content, name=name, delimiters=delimiters, delimeters=delimeters)             # <<<<<<<<<<<<<<
 *     return tmpl.substitute(kw)
 * 
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, __pyx_v_content};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 384, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_delimiters, __pyx_v_delimiters, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 384, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_delimeters, __pyx_v_delimeters, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 384, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_tmpl = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":385
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
 *     tmpl = Template(content, name=name, delimiters=delimiters, delimeters=delimeters)
 *     return tmpl.substitute(kw)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_tmpl;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_kw};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_substitute, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":381
 * 
 * 
 * def sub(content, delimiters=None, **kw):             # <<<<<<<<<<<<<<
 *     name = kw.get('__name')
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Tempita._tempita.sub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_delimeters);
  __Pyx_XDECREF(__pyx_v_tmpl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":388
 * 
 * 
 * def paste_script_template_renderer(content, vars, filename=None):             # <<<<<<<<<<<<<<
 *     tmpl = Template(content, name=filename)
 *     return tmpl.substitute(vars)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_7paste_script_template_renderer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_7paste_script_template_renderer = {"paste_script_template_renderer", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_7paste_script_template_renderer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_7paste_script_template_renderer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_vars = 0;
  PyObject *__pyx_v_filename = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("paste_script_template_renderer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_content,&__pyx_mstate_global->__pyx_n_u_vars,&__pyx_mstate_global->__pyx_n_u_filename,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 388, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 388, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 388, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 388, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "paste_script_template_renderer", 0) < (0)) __PYX_ERR(0, 388, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("paste_script_template_renderer", 0, 2, 3, i); __PYX_ERR(0, 388, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 388, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 388, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 388, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_content = values[0];
    __pyx_v_vars = values[1];
    __pyx_v_filename = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("paste_script_template_renderer", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 388, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.paste_script_template_renderer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6paste_script_template_renderer(__pyx_self, __pyx_v_content, __pyx_v_vars, __pyx_v_filename);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6paste_script_template_renderer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_content, PyObject *__pyx_v_vars, PyObject *__pyx_v_filename) {
  PyObject *__pyx_v_tmpl = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("paste_script_template_renderer", 0);

  /* "Cython/Tempita/_tempita.py":389
 * 
 * def paste_script_template_renderer(content, vars, filename=None):
 *     tmpl = Template(content, name=filename)             # <<<<<<<<<<<<<<
 *     return tmpl.substitute(vars)
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_content};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_filename, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 389, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_tmpl = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":390
 * def paste_script_template_renderer(content, vars, filename=None):
 *     tmpl = Template(content, name=filename)
 *     return tmpl.substitute(vars)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_tmpl;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_vars};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_substitute, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":388
 * 
 * 
 * def paste_script_template_renderer(content, vars, filename=None):             # <<<<<<<<<<<<<<
 *     tmpl = Template(content, name=filename)
 *     return tmpl.substitute(vars)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Tempita._tempita.paste_script_template_renderer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmpl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":395
 * class bunch(dict):
 * 
 *     def __init__(self, **kw):             # <<<<<<<<<<<<<<
 *         for name, value in kw.items():
 *             setattr(self, name, value)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kw = PyDict_New(); if (unlikely(!__pyx_v_kw)) return NULL;
  __Pyx_GOTREF(__pyx_v_kw);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 395, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 395, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, kwd_pos_args, __pyx_kwds_len, "__init__", 1) < (0)) __PYX_ERR(0, 395, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 395, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 395, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 395, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_5bunch___init__(__pyx_self, __pyx_v_self, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Tempita/_tempita.py":396
 * 
 *     def __init__(self, **kw):
 *         for name, value in kw.items():             # <<<<<<<<<<<<<<
 *             setattr(self, name, value)
 * 
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_kw, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Tempita/_tempita.py":397
 *     def __init__(self, **kw):
 *         for name, value in kw.items():
 *             setattr(self, name, value)             # <<<<<<<<<<<<<<
 * 
 *     def __setattr__(self, name, value):
*/
    __pyx_t_8 = PyObject_SetAttr(__pyx_v_self, __pyx_v_name, __pyx_v_value); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 397, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":395
 * class bunch(dict):
 * 
 *     def __init__(self, **kw):             # <<<<<<<<<<<<<<
 *         for name, value in kw.items():
 *             setattr(self, name, value)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":399
 *             setattr(self, name, value)
 * 
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         self[name] = value
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_3__setattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_3__setattr__ = {"__setattr__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_3__setattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_3__setattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_value,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 399, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 399, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 399, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 399, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setattr__", 0) < (0)) __PYX_ERR(0, 399, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setattr__", 1, 3, 3, i); __PYX_ERR(0, 399, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 399, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 399, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 399, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setattr__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 399, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__setattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_5bunch_2__setattr__(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_value);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_2__setattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setattr__", 0);

  /* "Cython/Tempita/_tempita.py":400
 * 
 *     def __setattr__(self, name, value):
 *         self[name] = value             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, name):
*/
  if (unlikely((PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 400, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":399
 *             setattr(self, name, value)
 * 
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         self[name] = value
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__setattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":402
 *         self[name] = value
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_5__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_5__getattr__ = {"__getattr__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_5__getattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_5__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 402, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 402, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 402, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__getattr__", 0) < (0)) __PYX_ERR(0, 402, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, i); __PYX_ERR(0, 402, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 402, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 402, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 402, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_5bunch_4__getattr__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "Cython/Tempita/_tempita.py":403
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Tempita/_tempita.py":404
 *     def __getattr__(self, name):
 *         try:
 *             return self[name]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             raise AttributeError(name)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_self, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Tempita/_tempita.py":403
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":405
 *         try:
 *             return self[name]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             raise AttributeError(name)
 * 
*/
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 405, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "Cython/Tempita/_tempita.py":406
 *             return self[name]
 *         except KeyError:
 *             raise AttributeError(name)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, key):
*/
      __pyx_t_9 = NULL;
      __pyx_t_10 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_name};
        __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 406, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 406, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "Cython/Tempita/_tempita.py":403
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "Cython/Tempita/_tempita.py":402
 *         self[name] = value
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":408
 *             raise AttributeError(name)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         if 'default' in self:
 *             try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_7__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_7__getitem__ = {"__getitem__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_7__getitem__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_7__getitem__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_key,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 408, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 408, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 408, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__getitem__", 0) < (0)) __PYX_ERR(0, 408, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, i); __PYX_ERR(0, 408, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 408, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 408, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 408, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_5bunch_6__getitem__(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_6__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "Cython/Tempita/_tempita.py":409
 * 
 *     def __getitem__(self, key):
 *         if 'default' in self:             # <<<<<<<<<<<<<<
 *             try:
 *                 return dict.__getitem__(self, key)
*/
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_default, __pyx_v_self, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 409, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":410
 *     def __getitem__(self, key):
 *         if 'default' in self:
 *             try:             # <<<<<<<<<<<<<<
 *                 return dict.__getitem__(self, key)
 *             except KeyError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "Cython/Tempita/_tempita.py":411
 *         if 'default' in self:
 *             try:
 *                 return dict.__getitem__(self, key)             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 return dict.__getitem__(self, 'default')
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_6 = ((PyObject *)(&PyDict_Type));
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_self, __pyx_v_key};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getitem, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 411, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        goto __pyx_L8_try_return;

        /* "Cython/Tempita/_tempita.py":410
 *     def __getitem__(self, key):
 *         if 'default' in self:
 *             try:             # <<<<<<<<<<<<<<
 *                 return dict.__getitem__(self, key)
 *             except KeyError:
*/
      }
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Tempita/_tempita.py":412
 *             try:
 *                 return dict.__getitem__(self, key)
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 return dict.__getitem__(self, 'default')
 *         else:
*/
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
      if (__pyx_t_8) {
        __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(0, 412, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_9);

        /* "Cython/Tempita/_tempita.py":413
 *                 return dict.__getitem__(self, key)
 *             except KeyError:
 *                 return dict.__getitem__(self, 'default')             # <<<<<<<<<<<<<<
 *         else:
 *             return dict.__getitem__(self, key)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = ((PyObject *)(&PyDict_Type));
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_v_self, __pyx_mstate_global->__pyx_n_u_default};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getitem, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 413, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __pyx_r = __pyx_t_10;
        __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "Cython/Tempita/_tempita.py":410
 *     def __getitem__(self, key):
 *         if 'default' in self:
 *             try:             # <<<<<<<<<<<<<<
 *                 return dict.__getitem__(self, key)
 *             except KeyError:
*/
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L8_try_return:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L0;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L0;
    }

    /* "Cython/Tempita/_tempita.py":409
 * 
 *     def __getitem__(self, key):
 *         if 'default' in self:             # <<<<<<<<<<<<<<
 *             try:
 *                 return dict.__getitem__(self, key)
*/
  }

  /* "Cython/Tempita/_tempita.py":415
 *                 return dict.__getitem__(self, 'default')
 *         else:
 *             return dict.__getitem__(self, key)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)(&PyDict_Type));
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_self, __pyx_v_key};
      __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getitem, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    }
    __pyx_r = __pyx_t_9;
    __pyx_t_9 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Tempita/_tempita.py":408
 *             raise AttributeError(name)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         if 'default' in self:
 *             try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":417
 *             return dict.__getitem__(self, key)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (
 *             self.__class__.__name__,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_9__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_9__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_9__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_5bunch_9__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_5bunch_8__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_5bunch_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_7genexpr__pyx_v_k = NULL;
  PyObject *__pyx_7genexpr__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10[3];
  PyObject *__pyx_t_11[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":418
 * 
 *     def __repr__(self):
 *         return '<%s %s>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             ' '.join(['%s=%r' % (k, v) for k, v in sorted(self.items())]))
*/
  __Pyx_XDECREF(__pyx_r);

  /* "Cython/Tempita/_tempita.py":419
 *     def __repr__(self):
 *         return '<%s %s>' % (
 *             self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             ' '.join(['%s=%r' % (k, v) for k, v in sorted(self.items())]))
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":420
 *         return '<%s %s>' % (
 *             self.__class__.__name__,
 *             ' '.join(['%s=%r' % (k, v) for k, v in sorted(self.items())]))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 420, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_items); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 420, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PySequence_List(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely((PyList_Sort(__pyx_t_3) < 0))) __PYX_ERR(0, 420, __pyx_L5_error)
    __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 420, __pyx_L5_error)
        #endif
        if (__pyx_t_5 >= __pyx_temp) break;
      }
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_5;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
        PyObject* sequence = __pyx_t_3;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 420, __pyx_L5_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_7);
        } else {
          __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 420, __pyx_L5_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 420, __pyx_L5_error)
          __Pyx_XGOTREF(__pyx_t_7);
        }
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 420, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 420, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 420, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
        index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L8_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L8_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < (0)) __PYX_ERR(0, 420, __pyx_L5_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L9_unpacking_done;
        __pyx_L8_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 420, __pyx_L5_error)
        __pyx_L9_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_k, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_v, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_7genexpr__pyx_v_k), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_7genexpr__pyx_v_v), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 420, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10[0] = __pyx_t_3;
      __pyx_t_10[1] = __pyx_mstate_global->__pyx_kp_u__6;
      __pyx_t_10[2] = __pyx_t_7;
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_10, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 420, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 420, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_k); __pyx_7genexpr__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v); __pyx_7genexpr__pyx_v_v = 0;
    goto __pyx_L11_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_k); __pyx_7genexpr__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v); __pyx_7genexpr__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L11_exit_scope:;
  } /* exit inner scope */
  __pyx_t_4 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u_, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_11[0] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_11[1] = __pyx_t_1;
  __pyx_t_11[2] = __pyx_mstate_global->__pyx_kp_u_;
  __pyx_t_11[3] = __pyx_t_4;
  __pyx_t_11[4] = __pyx_mstate_global->__pyx_kp_u__3;

  /* "Cython/Tempita/_tempita.py":418
 * 
 *     def __repr__(self):
 *         return '<%s %s>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             ' '.join(['%s=%r' % (k, v) for k, v in sorted(self.items())]))
*/
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_11, 5, 1 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":417
 *             return dict.__getitem__(self, key)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (
 *             self.__class__.__name__,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Tempita._tempita.bunch.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_k);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":424
 * 
 * class TemplateDef:
 *     def __init__(self, template, func_name, func_signature,             # <<<<<<<<<<<<<<
 *                  body, ns, pos, bound_self=None):
 *         self._template = template
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_template = 0;
  PyObject *__pyx_v_func_name = 0;
  PyObject *__pyx_v_func_signature = 0;
  PyObject *__pyx_v_body = 0;
  PyObject *__pyx_v_ns = 0;
  PyObject *__pyx_v_pos = 0;
  PyObject *__pyx_v_bound_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_template,&__pyx_mstate_global->__pyx_n_u_func_name,&__pyx_mstate_global->__pyx_n_u_func_signature,&__pyx_mstate_global->__pyx_n_u_body,&__pyx_mstate_global->__pyx_n_u_ns,&__pyx_mstate_global->__pyx_n_u_pos,&__pyx_mstate_global->__pyx_n_u_bound_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 424, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 424, __pyx_L3_error)

      /* "Cython/Tempita/_tempita.py":425
 * class TemplateDef:
 *     def __init__(self, template, func_name, func_signature,
 *                  body, ns, pos, bound_self=None):             # <<<<<<<<<<<<<<
 *         self._template = template
 *         self._func_name = func_name
*/
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 7; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 7, 8, i); __PYX_ERR(0, 424, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 424, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 424, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 424, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_template = values[1];
    __pyx_v_func_name = values[2];
    __pyx_v_func_signature = values[3];
    __pyx_v_body = values[4];
    __pyx_v_ns = values[5];
    __pyx_v_pos = values[6];
    __pyx_v_bound_self = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 7, 8, __pyx_nargs); __PYX_ERR(0, 424, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef___init__(__pyx_self, __pyx_v_self, __pyx_v_template, __pyx_v_func_name, __pyx_v_func_signature, __pyx_v_body, __pyx_v_ns, __pyx_v_pos, __pyx_v_bound_self);

  /* "Cython/Tempita/_tempita.py":424
 * 
 * class TemplateDef:
 *     def __init__(self, template, func_name, func_signature,             # <<<<<<<<<<<<<<
 *                  body, ns, pos, bound_self=None):
 *         self._template = template
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_template, PyObject *__pyx_v_func_name, PyObject *__pyx_v_func_signature, PyObject *__pyx_v_body, PyObject *__pyx_v_ns, PyObject *__pyx_v_pos, PyObject *__pyx_v_bound_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Tempita/_tempita.py":426
 *     def __init__(self, template, func_name, func_signature,
 *                  body, ns, pos, bound_self=None):
 *         self._template = template             # <<<<<<<<<<<<<<
 *         self._func_name = func_name
 *         self._func_signature = func_signature
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_template_2, __pyx_v_template) < (0)) __PYX_ERR(0, 426, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":427
 *                  body, ns, pos, bound_self=None):
 *         self._template = template
 *         self._func_name = func_name             # <<<<<<<<<<<<<<
 *         self._func_signature = func_signature
 *         self._body = body
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_name_2, __pyx_v_func_name) < (0)) __PYX_ERR(0, 427, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":428
 *         self._template = template
 *         self._func_name = func_name
 *         self._func_signature = func_signature             # <<<<<<<<<<<<<<
 *         self._body = body
 *         self._ns = ns
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_signature_2, __pyx_v_func_signature) < (0)) __PYX_ERR(0, 428, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":429
 *         self._func_name = func_name
 *         self._func_signature = func_signature
 *         self._body = body             # <<<<<<<<<<<<<<
 *         self._ns = ns
 *         self._pos = pos
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_body_2, __pyx_v_body) < (0)) __PYX_ERR(0, 429, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":430
 *         self._func_signature = func_signature
 *         self._body = body
 *         self._ns = ns             # <<<<<<<<<<<<<<
 *         self._pos = pos
 *         self._bound_self = bound_self
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_ns_2, __pyx_v_ns) < (0)) __PYX_ERR(0, 430, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":431
 *         self._body = body
 *         self._ns = ns
 *         self._pos = pos             # <<<<<<<<<<<<<<
 *         self._bound_self = bound_self
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_pos_2, __pyx_v_pos) < (0)) __PYX_ERR(0, 431, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":432
 *         self._ns = ns
 *         self._pos = pos
 *         self._bound_self = bound_self             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_bound_self_2, __pyx_v_bound_self) < (0)) __PYX_ERR(0, 432, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":424
 * 
 * class TemplateDef:
 *     def __init__(self, template, func_name, func_signature,             # <<<<<<<<<<<<<<
 *                  body, ns, pos, bound_self=None):
 *         self._template = template
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":434
 *         self._bound_self = bound_self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<tempita function %s(%s) at %s:%s>' % (
 *             self._func_name, self._func_signature,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6[9];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":435
 * 
 *     def __repr__(self):
 *         return '<tempita function %s(%s) at %s:%s>' % (             # <<<<<<<<<<<<<<
 *             self._func_name, self._func_signature,
 *             self._template.name, self._pos)
*/
  __Pyx_XDECREF(__pyx_r);

  /* "Cython/Tempita/_tempita.py":436
 *     def __repr__(self):
 *         return '<tempita function %s(%s) at %s:%s>' % (
 *             self._func_name, self._func_signature,             # <<<<<<<<<<<<<<
 *             self._template.name, self._pos)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_1), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_signature_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_1), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":437
 *         return '<tempita function %s(%s) at %s:%s>' % (
 *             self._func_name, self._func_signature,
 *             self._template.name, self._pos)             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_template_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_4), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_pos_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_4), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6[0] = __pyx_mstate_global->__pyx_kp_u_tempita_function;
  __pyx_t_6[1] = __pyx_t_2;
  __pyx_t_6[2] = __pyx_mstate_global->__pyx_kp_u__7;
  __pyx_t_6[3] = __pyx_t_3;
  __pyx_t_6[4] = __pyx_mstate_global->__pyx_kp_u_at;
  __pyx_t_6[5] = __pyx_t_1;
  __pyx_t_6[6] = __pyx_mstate_global->__pyx_kp_u__8;
  __pyx_t_6[7] = __pyx_t_5;
  __pyx_t_6[8] = __pyx_mstate_global->__pyx_kp_u__3;

  /* "Cython/Tempita/_tempita.py":435
 * 
 *     def __repr__(self):
 *         return '<tempita function %s(%s) at %s:%s>' % (             # <<<<<<<<<<<<<<
 *             self._func_name, self._func_signature,
 *             self._template.name, self._pos)
*/
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_6, 9, 18 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 5 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":434
 *         self._bound_self = bound_self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<tempita function %s(%s) at %s:%s>' % (
 *             self._func_name, self._func_signature,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":439
 *             self._template.name, self._pos)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_5__str__ = {"__str__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_5__str__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "Cython/Tempita/_tempita.py":440
 * 
 *     def __str__(self):
 *         return self()             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, *args, **kw):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_self);
  __pyx_t_3 = __pyx_v_self; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":439
 *             self._template.name, self._pos)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":442
 *         return self()
 * 
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         values = self._parse_signature(args, kw)
 *         ns = self._ns.copy()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_7__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_7__call__ = {"__call__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_7__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_7__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kw = PyDict_New(); if (unlikely(!__pyx_v_kw)) return NULL;
  __Pyx_GOTREF(__pyx_v_kw);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 442, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 442, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, used_pos_args, __pyx_kwds_len, "__call__", 1) < (0)) __PYX_ERR(0, 442, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, i); __PYX_ERR(0, 442, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 442, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 442, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_6__call__(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_6__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_ns = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_subdefs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Tempita/_tempita.py":443
 * 
 *     def __call__(self, *args, **kw):
 *         values = self._parse_signature(args, kw)             # <<<<<<<<<<<<<<
 *         ns = self._ns.copy()
 *         ns.update(values)
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_args, __pyx_v_kw};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_parse_signature, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_values = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":444
 *     def __call__(self, *args, **kw):
 *         values = self._parse_signature(args, kw)
 *         ns = self._ns.copy()             # <<<<<<<<<<<<<<
 *         ns.update(values)
 *         if self._bound_self is not None:
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_ns_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_copy, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_ns = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":445
 *         values = self._parse_signature(args, kw)
 *         ns = self._ns.copy()
 *         ns.update(values)             # <<<<<<<<<<<<<<
 *         if self._bound_self is not None:
 *             ns['self'] = self._bound_self
*/
  __pyx_t_4 = __pyx_v_ns;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_values};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":446
 *         ns = self._ns.copy()
 *         ns.update(values)
 *         if self._bound_self is not None:             # <<<<<<<<<<<<<<
 *             ns['self'] = self._bound_self
 *         out = []
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_bound_self_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "Cython/Tempita/_tempita.py":447
 *         ns.update(values)
 *         if self._bound_self is not None:
 *             ns['self'] = self._bound_self             # <<<<<<<<<<<<<<
 *         out = []
 *         subdefs = {}
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_bound_self_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_v_ns, __pyx_mstate_global->__pyx_n_u_self, __pyx_t_1) < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Tempita/_tempita.py":446
 *         ns = self._ns.copy()
 *         ns.update(values)
 *         if self._bound_self is not None:             # <<<<<<<<<<<<<<
 *             ns['self'] = self._bound_self
 *         out = []
*/
  }

  /* "Cython/Tempita/_tempita.py":448
 *         if self._bound_self is not None:
 *             ns['self'] = self._bound_self
 *         out = []             # <<<<<<<<<<<<<<
 *         subdefs = {}
 *         self._template._interpret_codes(self._body, ns, out, subdefs)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":449
 *             ns['self'] = self._bound_self
 *         out = []
 *         subdefs = {}             # <<<<<<<<<<<<<<
 *         self._template._interpret_codes(self._body, ns, out, subdefs)
 *         return ''.join(out)
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_subdefs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":450
 *         out = []
 *         subdefs = {}
 *         self._template._interpret_codes(self._body, ns, out, subdefs)             # <<<<<<<<<<<<<<
 *         return ''.join(out)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_template_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_body_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_t_6, __pyx_v_ns, __pyx_v_out, __pyx_v_subdefs};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_interpret_codes, __pyx_callargs+__pyx_t_3, (5-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":451
 *         subdefs = {}
 *         self._template._interpret_codes(self._body, ns, out, subdefs)
 *         return ''.join(out)             # <<<<<<<<<<<<<<
 * 
 *     def __get__(self, obj, type=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__4, __pyx_v_out); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":442
 *         return self()
 * 
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         values = self._parse_signature(args, kw)
 *         ns = self._ns.copy()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_ns);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_subdefs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":453
 *         return ''.join(out)
 * 
 *     def __get__(self, obj, type=None):             # <<<<<<<<<<<<<<
 *         if obj is None:
 *             return self
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_9__get__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_9__get__ = {"__get__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_9__get__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_9__get__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_obj = 0;
  CYTHON_UNUSED PyObject *__pyx_v_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 453, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__get__", 0) < (0)) __PYX_ERR(0, 453, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__get__", 0, 2, 3, i); __PYX_ERR(0, 453, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 453, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 453, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_obj = values[1];
    __pyx_v_type = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__get__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_8__get__(__pyx_self, __pyx_v_self, __pyx_v_obj, __pyx_v_type);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_8__get__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_type) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "Cython/Tempita/_tempita.py":454
 * 
 *     def __get__(self, obj, type=None):
 *         if obj is None:             # <<<<<<<<<<<<<<
 *             return self
 *         return self.__class__(
*/
  __pyx_t_1 = (__pyx_v_obj == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Tempita/_tempita.py":455
 *     def __get__(self, obj, type=None):
 *         if obj is None:
 *             return self             # <<<<<<<<<<<<<<
 *         return self.__class__(
 *             self._template, self._func_name, self._func_signature,
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self);
    __pyx_r = __pyx_v_self;
    goto __pyx_L0;

    /* "Cython/Tempita/_tempita.py":454
 * 
 *     def __get__(self, obj, type=None):
 *         if obj is None:             # <<<<<<<<<<<<<<
 *             return self
 *         return self.__class__(
*/
  }

  /* "Cython/Tempita/_tempita.py":456
 *         if obj is None:
 *             return self
 *         return self.__class__(             # <<<<<<<<<<<<<<
 *             self._template, self._func_name, self._func_signature,
 *             self._body, self._ns, self._pos, bound_self=obj)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_3);

  /* "Cython/Tempita/_tempita.py":457
 *             return self
 *         return self.__class__(
 *             self._template, self._func_name, self._func_signature,             # <<<<<<<<<<<<<<
 *             self._body, self._ns, self._pos, bound_self=obj)
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_template_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_signature_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "Cython/Tempita/_tempita.py":458
 *         return self.__class__(
 *             self._template, self._func_name, self._func_signature,
 *             self._body, self._ns, self._pos, bound_self=obj)             # <<<<<<<<<<<<<<
 * 
 *     def _parse_signature(self, args, kw):
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_body_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_ns_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_pos_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = 0;
  {
    PyObject *__pyx_callargs[7 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8, __pyx_t_9};
    __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bound_self, __pyx_v_obj, __pyx_t_11, __pyx_callargs+7, 0) < (0)) __PYX_ERR(0, 456, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_class, __pyx_callargs+__pyx_t_10, (7-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":453
 *         return ''.join(out)
 * 
 *     def __get__(self, obj, type=None):             # <<<<<<<<<<<<<<
 *         if obj is None:
 *             return self
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":460
 *             self._body, self._ns, self._pos, bound_self=obj)
 * 
 *     def _parse_signature(self, args, kw):             # <<<<<<<<<<<<<<
 *         values = {}
 *         sig_args, var_args, var_kw, defaults = self._func_signature
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_11_parse_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_11_parse_signature = {"_parse_signature", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_11_parse_signature, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11TemplateDef_11_parse_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parse_signature (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_args,&__pyx_mstate_global->__pyx_n_u_kw,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 460, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 460, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 460, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 460, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_parse_signature", 0) < (0)) __PYX_ERR(0, 460, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_parse_signature", 1, 3, 3, i); __PYX_ERR(0, 460, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 460, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 460, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 460, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_args = values[1];
    __pyx_v_kw = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parse_signature", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 460, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef._parse_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_10_parse_signature(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_11TemplateDef_10_parse_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_sig_args = NULL;
  PyObject *__pyx_v_var_args = NULL;
  PyObject *__pyx_v_var_kw = NULL;
  PyObject *__pyx_v_defaults = NULL;
  PyObject *__pyx_v_extra_kw = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_value_expr = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  size_t __pyx_t_15;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_signature", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "Cython/Tempita/_tempita.py":461
 * 
 *     def _parse_signature(self, args, kw):
 *         values = {}             # <<<<<<<<<<<<<<
 *         sig_args, var_args, var_kw, defaults = self._func_signature
 *         extra_kw = {}
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_values = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":462
 *     def _parse_signature(self, args, kw):
 *         values = {}
 *         sig_args, var_args, var_kw, defaults = self._func_signature             # <<<<<<<<<<<<<<
 *         extra_kw = {}
 *         for name, value in kw.items():
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_func_signature_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 4)) {
      if (size > 4) __Pyx_RaiseTooManyValuesError(4);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 462, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 3);
      __Pyx_INCREF(__pyx_t_5);
    } else {
      __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 3, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_5);
    }
    #else
    {
      Py_ssize_t i;
      PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
      for (i=0; i < 4; i++) {
        PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 462, __pyx_L1_error)
        __Pyx_GOTREF(item);
        *(temps[i]) = item;
      }
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    for (index=0; index < 4; index++) {
      PyObject* item = __pyx_t_7(__pyx_t_6); if (unlikely(!item)) goto __pyx_L3_unpacking_failed;
      __Pyx_GOTREF(item);
      *(temps[index]) = item;
    }
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 4) < (0)) __PYX_ERR(0, 462, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 462, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_sig_args = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_var_args = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_var_kw = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_defaults = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":463
 *         values = {}
 *         sig_args, var_args, var_kw, defaults = self._func_signature
 *         extra_kw = {}             # <<<<<<<<<<<<<<
 *         for name, value in kw.items():
 *             if not var_kw and name not in sig_args:
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_extra_kw = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":464
 *         sig_args, var_args, var_kw, defaults = self._func_signature
 *         extra_kw = {}
 *         for name, value in kw.items():             # <<<<<<<<<<<<<<
 *             if not var_kw and name not in sig_args:
 *                 raise TypeError(
*/
  __pyx_t_8 = 0;
  if (unlikely(__pyx_v_kw == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 464, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_kw, 0, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_9), (&__pyx_t_10)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_9, &__pyx_t_8, &__pyx_t_5, &__pyx_t_4, NULL, __pyx_t_10);
    if (unlikely(__pyx_t_11 == 0)) break;
    if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":465
 *         extra_kw = {}
 *         for name, value in kw.items():
 *             if not var_kw and name not in sig_args:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'Unexpected argument %s' % name)
*/
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_v_var_kw); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 465, __pyx_L1_error)
    __pyx_t_14 = (!__pyx_t_13);
    if (__pyx_t_14) {
    } else {
      __pyx_t_12 = __pyx_t_14;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_sig_args, Py_NE)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 465, __pyx_L1_error)
    __pyx_t_12 = __pyx_t_14;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_12)) {

      /* "Cython/Tempita/_tempita.py":466
 *         for name, value in kw.items():
 *             if not var_kw and name not in sig_args:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     'Unexpected argument %s' % name)
 *             if name in sig_args:
*/
      __pyx_t_5 = NULL;

      /* "Cython/Tempita/_tempita.py":467
 *             if not var_kw and name not in sig_args:
 *                 raise TypeError(
 *                     'Unexpected argument %s' % name)             # <<<<<<<<<<<<<<
 *             if name in sig_args:
 *                 values[sig_args] = value
*/
      __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unexpected_argument_s, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_15 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 466, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 466, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":465
 *         extra_kw = {}
 *         for name, value in kw.items():
 *             if not var_kw and name not in sig_args:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'Unexpected argument %s' % name)
*/
    }

    /* "Cython/Tempita/_tempita.py":468
 *                 raise TypeError(
 *                     'Unexpected argument %s' % name)
 *             if name in sig_args:             # <<<<<<<<<<<<<<
 *                 values[sig_args] = value
 *             else:
*/
    __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_sig_args, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 468, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "Cython/Tempita/_tempita.py":469
 *                     'Unexpected argument %s' % name)
 *             if name in sig_args:
 *                 values[sig_args] = value             # <<<<<<<<<<<<<<
 *             else:
 *                 extra_kw[name] = value
*/
      if (unlikely((PyDict_SetItem(__pyx_v_values, __pyx_v_sig_args, __pyx_v_value) < 0))) __PYX_ERR(0, 469, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":468
 *                 raise TypeError(
 *                     'Unexpected argument %s' % name)
 *             if name in sig_args:             # <<<<<<<<<<<<<<
 *                 values[sig_args] = value
 *             else:
*/
      goto __pyx_L10;
    }

    /* "Cython/Tempita/_tempita.py":471
 *                 values[sig_args] = value
 *             else:
 *                 extra_kw[name] = value             # <<<<<<<<<<<<<<
 *         args = list(args)
 *         sig_args = list(sig_args)
*/
    /*else*/ {
      if (unlikely((PyDict_SetItem(__pyx_v_extra_kw, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 471, __pyx_L1_error)
    }
    __pyx_L10:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":472
 *             else:
 *                 extra_kw[name] = value
 *         args = list(args)             # <<<<<<<<<<<<<<
 *         sig_args = list(sig_args)
 *         while args:
*/
  __pyx_t_1 = PySequence_List(__pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":473
 *                 extra_kw[name] = value
 *         args = list(args)
 *         sig_args = list(sig_args)             # <<<<<<<<<<<<<<
 *         while args:
 *             while sig_args and sig_args[0] in values:
*/
  __pyx_t_1 = PySequence_List(__pyx_v_sig_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_sig_args, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":474
 *         args = list(args)
 *         sig_args = list(sig_args)
 *         while args:             # <<<<<<<<<<<<<<
 *             while sig_args and sig_args[0] in values:
 *                 sig_args.pop(0)
*/
  while (1) {
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_args); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 474, __pyx_L1_error)
    if (!__pyx_t_12) break;

    /* "Cython/Tempita/_tempita.py":475
 *         sig_args = list(sig_args)
 *         while args:
 *             while sig_args and sig_args[0] in values:             # <<<<<<<<<<<<<<
 *                 sig_args.pop(0)
 *             if sig_args:
*/
    while (1) {
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_sig_args); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
      if (__pyx_t_14) {
      } else {
        __pyx_t_12 = __pyx_t_14;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_sig_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_14 = (__Pyx_PyDict_ContainsTF(__pyx_t_1, __pyx_v_values, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_12 = __pyx_t_14;
      __pyx_L15_bool_binop_done:;
      if (!__pyx_t_12) break;

      /* "Cython/Tempita/_tempita.py":476
 *         while args:
 *             while sig_args and sig_args[0] in values:
 *                 sig_args.pop(0)             # <<<<<<<<<<<<<<
 *             if sig_args:
 *                 name = sig_args.pop(0)
*/
      __pyx_t_1 = __Pyx_PyObject_PopIndex(__pyx_v_sig_args, __pyx_mstate_global->__pyx_int_0, 0, 1, Py_ssize_t, PyLong_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "Cython/Tempita/_tempita.py":477
 *             while sig_args and sig_args[0] in values:
 *                 sig_args.pop(0)
 *             if sig_args:             # <<<<<<<<<<<<<<
 *                 name = sig_args.pop(0)
 *                 values[name] = args.pop(0)
*/
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_sig_args); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 477, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "Cython/Tempita/_tempita.py":478
 *                 sig_args.pop(0)
 *             if sig_args:
 *                 name = sig_args.pop(0)             # <<<<<<<<<<<<<<
 *                 values[name] = args.pop(0)
 *             elif var_args:
*/
      __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_sig_args, __pyx_mstate_global->__pyx_int_0, 0, 1, Py_ssize_t, PyLong_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":479
 *             if sig_args:
 *                 name = sig_args.pop(0)
 *                 values[name] = args.pop(0)             # <<<<<<<<<<<<<<
 *             elif var_args:
 *                 values[var_args] = tuple(args)
*/
      __pyx_t_1 = __Pyx_PyObject_PopIndex(__pyx_v_args, __pyx_mstate_global->__pyx_int_0, 0, 1, Py_ssize_t, PyLong_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely((PyDict_SetItem(__pyx_v_values, __pyx_v_name, __pyx_t_1) < 0))) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":477
 *             while sig_args and sig_args[0] in values:
 *                 sig_args.pop(0)
 *             if sig_args:             # <<<<<<<<<<<<<<
 *                 name = sig_args.pop(0)
 *                 values[name] = args.pop(0)
*/
      goto __pyx_L17;
    }

    /* "Cython/Tempita/_tempita.py":480
 *                 name = sig_args.pop(0)
 *                 values[name] = args.pop(0)
 *             elif var_args:             # <<<<<<<<<<<<<<
 *                 values[var_args] = tuple(args)
 *                 break
*/
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_var_args); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 480, __pyx_L1_error)
    if (likely(__pyx_t_12)) {

      /* "Cython/Tempita/_tempita.py":481
 *                 values[name] = args.pop(0)
 *             elif var_args:
 *                 values[var_args] = tuple(args)             # <<<<<<<<<<<<<<
 *                 break
 *             else:
*/
      __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 481, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely((PyDict_SetItem(__pyx_v_values, __pyx_v_var_args, __pyx_t_1) < 0))) __PYX_ERR(0, 481, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":482
 *             elif var_args:
 *                 values[var_args] = tuple(args)
 *                 break             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError(
*/
      goto __pyx_L12_break;

      /* "Cython/Tempita/_tempita.py":480
 *                 name = sig_args.pop(0)
 *                 values[name] = args.pop(0)
 *             elif var_args:             # <<<<<<<<<<<<<<
 *                 values[var_args] = tuple(args)
 *                 break
*/
    }

    /* "Cython/Tempita/_tempita.py":484
 *                 break
 *             else:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     'Extra position arguments: %s'
 *                     % ', '.join([repr(v) for v in args]))
*/
    /*else*/ {
      __pyx_t_4 = NULL;

      /* "Cython/Tempita/_tempita.py":486
 *                 raise TypeError(
 *                     'Extra position arguments: %s'
 *                     % ', '.join([repr(v) for v in args]))             # <<<<<<<<<<<<<<
 *         for name, value_expr in defaults.items():
 *             if name not in values:
*/
      { /* enter inner scope */
        __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (likely(PyList_CheckExact(__pyx_v_args)) || PyTuple_CheckExact(__pyx_v_args)) {
          __pyx_t_5 = __pyx_v_args; __Pyx_INCREF(__pyx_t_5);
          __pyx_t_9 = 0;
          __pyx_t_16 = NULL;
        } else {
          __pyx_t_9 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_16 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 486, __pyx_L20_error)
        }
        for (;;) {
          if (likely(!__pyx_t_16)) {
            if (likely(PyList_CheckExact(__pyx_t_5))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 486, __pyx_L20_error)
                #endif
                if (__pyx_t_9 >= __pyx_temp) break;
              }
              __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_9;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 486, __pyx_L20_error)
                #endif
                if (__pyx_t_9 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_9));
              #else
              __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_9);
              #endif
              ++__pyx_t_9;
            }
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L20_error)
          } else {
            __pyx_t_2 = __pyx_t_16(__pyx_t_5);
            if (unlikely(!__pyx_t_2)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 486, __pyx_L20_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_v, __pyx_t_2);
          __pyx_t_2 = 0;
          __pyx_t_2 = PyObject_Repr(__pyx_8genexpr1__pyx_v_v); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 486, __pyx_L20_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v); __pyx_8genexpr1__pyx_v_v = 0;
        goto __pyx_L24_exit_scope;
        __pyx_L20_error:;
        __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v); __pyx_8genexpr1__pyx_v_v = 0;
        goto __pyx_L1_error;
        __pyx_L24_exit_scope:;
      } /* exit inner scope */
      __pyx_t_5 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__9, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Extra_position_arguments_s, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_15 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 484, __pyx_L1_error)
    }
    __pyx_L17:;
  }
  __pyx_L12_break:;

  /* "Cython/Tempita/_tempita.py":487
 *                     'Extra position arguments: %s'
 *                     % ', '.join([repr(v) for v in args]))
 *         for name, value_expr in defaults.items():             # <<<<<<<<<<<<<<
 *             if name not in values:
 *                 values[name] = self._template._eval(
*/
  __pyx_t_9 = 0;
  if (unlikely(__pyx_v_defaults == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 487, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_defaults, 0, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_8), (&__pyx_t_10)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  while (1) {
    __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_8, &__pyx_t_9, &__pyx_t_3, &__pyx_t_4, NULL, __pyx_t_10);
    if (unlikely(__pyx_t_11 == 0)) break;
    if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value_expr, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":488
 *                     % ', '.join([repr(v) for v in args]))
 *         for name, value_expr in defaults.items():
 *             if name not in values:             # <<<<<<<<<<<<<<
 *                 values[name] = self._template._eval(
 *                     value_expr, self._ns, self._pos)
*/
    __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_values, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 488, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "Cython/Tempita/_tempita.py":489
 *         for name, value_expr in defaults.items():
 *             if name not in values:
 *                 values[name] = self._template._eval(             # <<<<<<<<<<<<<<
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_template_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __pyx_t_5;
      __Pyx_INCREF(__pyx_t_3);

      /* "Cython/Tempita/_tempita.py":490
 *             if name not in values:
 *                 values[name] = self._template._eval(
 *                     value_expr, self._ns, self._pos)             # <<<<<<<<<<<<<<
 *         for name in sig_args:
 *             if name not in values:
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_ns_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 490, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_pos_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 490, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_15 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_value_expr, __pyx_t_2, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_eval_2, __pyx_callargs+__pyx_t_15, (4-__pyx_t_15) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 489, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }

      /* "Cython/Tempita/_tempita.py":489
 *         for name, value_expr in defaults.items():
 *             if name not in values:
 *                 values[name] = self._template._eval(             # <<<<<<<<<<<<<<
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:
*/
      if (unlikely((PyDict_SetItem(__pyx_v_values, __pyx_v_name, __pyx_t_4) < 0))) __PYX_ERR(0, 489, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":488
 *                     % ', '.join([repr(v) for v in args]))
 *         for name, value_expr in defaults.items():
 *             if name not in values:             # <<<<<<<<<<<<<<
 *                 values[name] = self._template._eval(
 *                     value_expr, self._ns, self._pos)
*/
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":491
 *                 values[name] = self._template._eval(
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:             # <<<<<<<<<<<<<<
 *             if name not in values:
 *                 raise TypeError(
*/
  __pyx_t_1 = __pyx_v_sig_args; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_8 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 491, __pyx_L1_error)
      #endif
      if (__pyx_t_8 >= __pyx_temp) break;
    }
    __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_8;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Tempita/_tempita.py":492
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:
 *             if name not in values:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'Missing argument: %s' % name)
*/
    __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_values, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 492, __pyx_L1_error)
    if (unlikely(__pyx_t_12)) {

      /* "Cython/Tempita/_tempita.py":493
 *         for name in sig_args:
 *             if name not in values:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     'Missing argument: %s' % name)
 *         if var_kw:
*/
      __pyx_t_5 = NULL;

      /* "Cython/Tempita/_tempita.py":494
 *             if name not in values:
 *                 raise TypeError(
 *                     'Missing argument: %s' % name)             # <<<<<<<<<<<<<<
 *         if var_kw:
 *             values[var_kw] = extra_kw
*/
      __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Missing_argument_s, __pyx_v_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_15 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 493, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 493, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":492
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:
 *             if name not in values:             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'Missing argument: %s' % name)
*/
    }

    /* "Cython/Tempita/_tempita.py":491
 *                 values[name] = self._template._eval(
 *                     value_expr, self._ns, self._pos)
 *         for name in sig_args:             # <<<<<<<<<<<<<<
 *             if name not in values:
 *                 raise TypeError(
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":495
 *                 raise TypeError(
 *                     'Missing argument: %s' % name)
 *         if var_kw:             # <<<<<<<<<<<<<<
 *             values[var_kw] = extra_kw
 *         return values
*/
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_var_kw); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 495, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "Cython/Tempita/_tempita.py":496
 *                     'Missing argument: %s' % name)
 *         if var_kw:
 *             values[var_kw] = extra_kw             # <<<<<<<<<<<<<<
 *         return values
 * 
*/
    if (unlikely((PyDict_SetItem(__pyx_v_values, __pyx_v_var_kw, __pyx_v_extra_kw) < 0))) __PYX_ERR(0, 496, __pyx_L1_error)

    /* "Cython/Tempita/_tempita.py":495
 *                 raise TypeError(
 *                     'Missing argument: %s' % name)
 *         if var_kw:             # <<<<<<<<<<<<<<
 *             values[var_kw] = extra_kw
 *         return values
*/
  }

  /* "Cython/Tempita/_tempita.py":497
 *         if var_kw:
 *             values[var_kw] = extra_kw
 *         return values             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_values);
  __pyx_r = __pyx_v_values;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":460
 *             self._body, self._ns, self._pos, bound_self=obj)
 * 
 *     def _parse_signature(self, args, kw):             # <<<<<<<<<<<<<<
 *         values = {}
 *         sig_args, var_args, var_kw, defaults = self._func_signature
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateDef._parse_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_sig_args);
  __Pyx_XDECREF(__pyx_v_var_args);
  __Pyx_XDECREF(__pyx_v_var_kw);
  __Pyx_XDECREF(__pyx_v_defaults);
  __Pyx_XDECREF(__pyx_v_extra_kw);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_value_expr);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":502
 * class TemplateObject:
 * 
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.__name = name
 *         self.get = TemplateObjectGetter(self)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_14TemplateObject_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 502, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 502, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 502, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 502, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 502, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 502, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 502, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 502, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObject.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject___init__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Tempita/_tempita.py":503
 * 
 *     def __init__(self, name):
 *         self.__name = name             # <<<<<<<<<<<<<<
 *         self.get = TemplateObjectGetter(self)
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_TemplateObject__name, __pyx_v_name) < (0)) __PYX_ERR(0, 503, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":504
 *     def __init__(self, name):
 *         self.__name = name
 *         self.get = TemplateObjectGetter(self)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_get, __pyx_t_1) < (0)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Tempita/_tempita.py":502
 * class TemplateObject:
 * 
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.__name = name
 *         self.get = TemplateObjectGetter(self)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObject.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":506
 *         self.get = TemplateObjectGetter(self)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (self.__class__.__name__, self.__name)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_14TemplateObject_3__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_3__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_14TemplateObject_3__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject_2__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14TemplateObject_2__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":507
 * 
 *     def __repr__(self):
 *         return '<%s %s>' % (self.__class__.__name__, self.__name)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_TemplateObject__name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4[0] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_4[1] = __pyx_t_1;
  __pyx_t_4[2] = __pyx_mstate_global->__pyx_kp_u_;
  __pyx_t_4[3] = __pyx_t_3;
  __pyx_t_4[4] = __pyx_mstate_global->__pyx_kp_u__3;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, 1 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":506
 *         self.get = TemplateObjectGetter(self)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (self.__class__.__name__, self.__name)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObject.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":512
 * class TemplateObjectGetter:
 * 
 *     def __init__(self, template_obj):             # <<<<<<<<<<<<<<
 *         self.__template_obj = template_obj
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_template_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_template_obj,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 512, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 512, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 512, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 512, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 512, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 512, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 512, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_template_obj = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 512, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObjectGetter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter___init__(__pyx_self, __pyx_v_self, __pyx_v_template_obj);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_template_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Tempita/_tempita.py":513
 * 
 *     def __init__(self, template_obj):
 *         self.__template_obj = template_obj             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, attr):
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter__template, __pyx_v_template_obj) < (0)) __PYX_ERR(0, 513, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":512
 * class TemplateObjectGetter:
 * 
 *     def __init__(self, template_obj):             # <<<<<<<<<<<<<<
 *         self.__template_obj = template_obj
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObjectGetter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":515
 *         self.__template_obj = template_obj
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.__template_obj, attr, Empty)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_3__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_3__getattr__ = {"__getattr__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_3__getattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_3__getattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_attr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_attr,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 515, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 515, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 515, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__getattr__", 0) < (0)) __PYX_ERR(0, 515, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, i); __PYX_ERR(0, 515, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 515, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 515, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_attr = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 515, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObjectGetter.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_2__getattr__(__pyx_self, __pyx_v_self, __pyx_v_attr);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_2__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "Cython/Tempita/_tempita.py":516
 * 
 *     def __getattr__(self, attr):
 *         return getattr(self.__template_obj, attr, Empty)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter__template); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetAttr3(__pyx_t_1, __pyx_v_attr, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":515
 *         self.__template_obj = template_obj
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.__template_obj, attr, Empty)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObjectGetter.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":518
 *         return getattr(self.__template_obj, attr, Empty)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s around %r>' % (self.__class__.__name__, self.__template_obj)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_5__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_5__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_4__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":519
 * 
 *     def __repr__(self):
 *         return '<%s around %r>' % (self.__class__.__name__, self.__template_obj)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter__template); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4[0] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_4[1] = __pyx_t_1;
  __pyx_t_4[2] = __pyx_mstate_global->__pyx_kp_u_around;
  __pyx_t_4[3] = __pyx_t_3;
  __pyx_t_4[4] = __pyx_mstate_global->__pyx_kp_u__3;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":518
 *         return getattr(self.__template_obj, attr, Empty)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s around %r>' % (self.__class__.__name__, self.__template_obj)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Tempita._tempita.TemplateObjectGetter.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":523
 * 
 * class _Empty:
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_1__call__ = {"__call__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_1__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 523, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 523, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, used_pos_args, __pyx_kwds_len, "__call__", 1) < (0)) __PYX_ERR(0, 523, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, i); __PYX_ERR(0, 523, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 523, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 523, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_XDECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("Cython.Tempita._tempita._Empty.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty___call__(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty___call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kw) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Tempita/_tempita.py":524
 * class _Empty:
 *     def __call__(self, *args, **kw):
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":523
 * 
 * class _Empty:
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":526
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_3__str__ = {"__str__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_3__str__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_2__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "Cython/Tempita/_tempita.py":527
 * 
 *     def __str__(self):
 *         return ''             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
  __pyx_r = __pyx_mstate_global->__pyx_kp_u__4;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":526
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":529
 *         return ''
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Empty'
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_5__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_5__repr__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_4__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "Cython/Tempita/_tempita.py":530
 * 
 *     def __repr__(self):
 *         return 'Empty'             # <<<<<<<<<<<<<<
 * 
 *     def __unicode__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_Empty);
  __pyx_r = __pyx_mstate_global->__pyx_n_u_Empty;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":529
 *         return ''
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Empty'
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":532
 *         return 'Empty'
 * 
 *     def __unicode__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_7__unicode__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_7__unicode__ = {"__unicode__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_7__unicode__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_7__unicode__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__unicode__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_6__unicode__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_6__unicode__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__unicode__", 0);

  /* "Cython/Tempita/_tempita.py":533
 * 
 *     def __unicode__(self):
 *         return ''             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
  __pyx_r = __pyx_mstate_global->__pyx_kp_u__4;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":532
 *         return 'Empty'
 * 
 *     def __unicode__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":535
 *         return ''
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(())
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_9__iter__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_9__iter__ = {"__iter__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_9__iter__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_9__iter__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_8__iter__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_8__iter__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "Cython/Tempita/_tempita.py":536
 * 
 *     def __iter__(self):
 *         return iter(())             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_GetIter(__pyx_mstate_global->__pyx_empty_tuple); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":535
 *         return ''
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(())
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Tempita._tempita._Empty.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":538
 *         return iter(())
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_11__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_11__bool__ = {"__bool__", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_11__bool__, METH_O, 0};
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_6_Empty_11__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_10__bool__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_6_Empty_10__bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__", 0);

  /* "Cython/Tempita/_tempita.py":539
 * 
 *     def __bool__(self):
 *         return False             # <<<<<<<<<<<<<<
 * 
 * Empty = _Empty()
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "Cython/Tempita/_tempita.py":538
 *         return iter(())
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Tempita/_tempita.py":549
 * 
 * 
 * def lex(s, name=None, trim_whitespace=True, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     """
 *     Lex a string into chunks:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_9lex(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_7Tempita_8_tempita_8lex, "\n    Lex a string into chunks:\n\n        >>> lex('hey')\n        ['hey']\n        >>> lex('hey {{you}}')\n        ['hey ', ('you', (1, 7))]\n        >>> lex('hey {{')\n        Traceback (most recent call last):\n            ...\n        TemplateError: No }} to finish last expression at line 1 column 7\n        >>> lex('hey }}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: }} outside expression at line 1 column 7\n        >>> lex('hey {{ {{')\n        Traceback (most recent call last):\n            ...\n        TemplateError: {{ inside expression at line 1 column 10\n\n    ");
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_9lex = {"lex", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_9lex, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_7Tempita_8_tempita_8lex};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_9lex(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_s = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_trim_whitespace = 0;
      PyObject *__pyx_v_line_offset = 0;
      PyObject *__pyx_v_delimiters = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[5] = {0,0,0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("lex (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s_2,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_trim_whitespace,&__pyx_mstate_global->__pyx_n_u_line_offset,&__pyx_mstate_global->__pyx_n_u_delimiters,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 549, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  5:
            values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  4:
            values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "lex", 0) < (0)) __PYX_ERR(0, 549, __pyx_L3_error)
          if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_True)));
          if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));
          if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
          for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("lex", 0, 1, 5, i); __PYX_ERR(0, 549, __pyx_L3_error) }
          }
        } else {
          switch (__pyx_nargs) {
            case  5:
            values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  4:
            values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 549, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 549, __pyx_L3_error)
            break;
            default: goto __pyx_L5_argtuple_error;
          }
          if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_True)));
          if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));
          if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));
        }
        __pyx_v_s = values[0];
        __pyx_v_name = values[1];
        __pyx_v_trim_whitespace = values[2];
        __pyx_v_line_offset = values[3];
        __pyx_v_delimiters = values[4];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("lex", 0, 1, 5, __pyx_nargs); __PYX_ERR(0, 549, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.lex", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_8lex(__pyx_self, __pyx_v_s, __pyx_v_name, __pyx_v_trim_whitespace, __pyx_v_line_offset, __pyx_v_delimiters);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_8lex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_name, PyObject *__pyx_v_trim_whitespace, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters) {
      int __pyx_v_in_expr;
      PyObject *__pyx_v_chunks = NULL;
      PyObject *__pyx_v_last = NULL;
      PyObject *__pyx_v_last_pos = NULL;
      PyObject *__pyx_v_token_re = NULL;
      PyObject *__pyx_v_match = NULL;
      PyObject *__pyx_v_expr = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_v_part = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      int __pyx_t_1;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      PyObject *__pyx_t_6 = NULL;
      PyObject *__pyx_t_7 = NULL;
      PyObject *__pyx_t_8 = NULL;
      PyObject *__pyx_t_9[3];
      size_t __pyx_t_10;
      Py_ssize_t __pyx_t_11;
      PyObject *(*__pyx_t_12)(PyObject *);
      int __pyx_t_13;
      int __pyx_t_14;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("lex", 0);
      __Pyx_INCREF(__pyx_v_delimiters);

      /* "Cython/Tempita/_tempita.py":571
 * 
 *     """
 *     if delimiters is None:             # <<<<<<<<<<<<<<
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
*/
      __pyx_t_1 = (__pyx_v_delimiters == Py_None);
      if (__pyx_t_1) {

        /* "Cython/Tempita/_tempita.py":572
 *     """
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                        Template.default_namespace['end_braces'] )
 *     in_expr = False
*/
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_start_braces); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":573
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )             # <<<<<<<<<<<<<<
 *     in_expr = False
 *     chunks = []
*/
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_end_braces); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":572
 *     """
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                        Template.default_namespace['end_braces'] )
 *     in_expr = False
*/
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 572, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 572, __pyx_L1_error);
        __pyx_t_2 = 0;
        __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_delimiters, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":571
 * 
 *     """
 *     if delimiters is None:             # <<<<<<<<<<<<<<
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
*/
      }

      /* "Cython/Tempita/_tempita.py":574
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
 *     in_expr = False             # <<<<<<<<<<<<<<
 *     chunks = []
 *     last = 0
*/
      __pyx_v_in_expr = 0;

      /* "Cython/Tempita/_tempita.py":575
 *                        Template.default_namespace['end_braces'] )
 *     in_expr = False
 *     chunks = []             # <<<<<<<<<<<<<<
 *     last = 0
 *     last_pos = (line_offset + 1, 1)
*/
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_chunks = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":576
 *     in_expr = False
 *     chunks = []
 *     last = 0             # <<<<<<<<<<<<<<
 *     last_pos = (line_offset + 1, 1)
 * 
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
      __pyx_v_last = __pyx_mstate_global->__pyx_int_0;

      /* "Cython/Tempita/_tempita.py":577
 *     chunks = []
 *     last = 0
 *     last_pos = (line_offset + 1, 1)             # <<<<<<<<<<<<<<
 * 
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),
*/
      __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_v_line_offset, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 577, __pyx_L1_error);
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_1);
      __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_mstate_global->__pyx_int_1) != (0)) __PYX_ERR(0, 577, __pyx_L1_error);
      __pyx_t_4 = 0;
      __pyx_v_last_pos = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":579
 *     last_pos = (line_offset + 1, 1)
 * 
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),             # <<<<<<<<<<<<<<
 *                                       re.escape(delimiters[1])))
 *     for match in token_re.finditer(s):
*/
      __pyx_t_4 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_escape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_delimiters, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":580
 * 
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),
 *                                       re.escape(delimiters[1])))             # <<<<<<<<<<<<<<
 *     for match in token_re.finditer(s):
 *         expr = match.group(0)
*/
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_escape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_delimiters, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_8), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9[0] = __pyx_t_2;
      __pyx_t_9[1] = __pyx_mstate_global->__pyx_kp_u__5;
      __pyx_t_9[2] = __pyx_t_7;

      /* "Cython/Tempita/_tempita.py":579
 *     last_pos = (line_offset + 1, 1)
 * 
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),             # <<<<<<<<<<<<<<
 *                                       re.escape(delimiters[1])))
 *     for match in token_re.finditer(s):
*/
      __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_9, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 579, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_v_token_re = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":581
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),
 *                                       re.escape(delimiters[1])))
 *     for match in token_re.finditer(s):             # <<<<<<<<<<<<<<
 *         expr = match.group(0)
 *         pos = find_position(s, match.end(), last, last_pos)
*/
      __pyx_t_5 = __pyx_v_token_re;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_10 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_s};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_finditer, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_5 = __pyx_t_3; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_11 = 0;
        __pyx_t_12 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 581, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 581, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_12)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 581, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_11, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_11;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 581, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_11));
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_11);
            #endif
            ++__pyx_t_11;
          }
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
        } else {
          __pyx_t_3 = __pyx_t_12(__pyx_t_5);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 581, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_match, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":582
 *                                       re.escape(delimiters[1])))
 *     for match in token_re.finditer(s):
 *         expr = match.group(0)             # <<<<<<<<<<<<<<
 *         pos = find_position(s, match.end(), last, last_pos)
 *         if expr == delimiters[0] and in_expr:
*/
        __pyx_t_8 = __pyx_v_match;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_int_0};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_group, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 582, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_expr, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":583
 *     for match in token_re.finditer(s):
 *         expr = match.group(0)
 *         pos = find_position(s, match.end(), last, last_pos)             # <<<<<<<<<<<<<<
 *         if expr == delimiters[0] and in_expr:
 *             raise TemplateError('%s inside expression' % delimiters[0],
*/
        __pyx_t_8 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_find_position); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 583, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = __pyx_v_match;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_end, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 583, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_v_s, __pyx_t_7, __pyx_v_last, __pyx_v_last_pos};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_10, (5-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 583, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":584
 *         expr = match.group(0)
 *         pos = find_position(s, match.end(), last, last_pos)
 *         if expr == delimiters[0] and in_expr:             # <<<<<<<<<<<<<<
 *             raise TemplateError('%s inside expression' % delimiters[0],
 *                                 position=pos,
*/
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_delimiters, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 584, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyObject_RichCompare(__pyx_v_expr, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 584, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 584, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_13) {
        } else {
          __pyx_t_1 = __pyx_t_13;
          goto __pyx_L7_bool_binop_done;
        }
        __pyx_t_1 = __pyx_v_in_expr;
        __pyx_L7_bool_binop_done:;
        if (unlikely(__pyx_t_1)) {

          /* "Cython/Tempita/_tempita.py":585
 *         pos = find_position(s, match.end(), last, last_pos)
 *         if expr == delimiters[0] and in_expr:
 *             raise TemplateError('%s inside expression' % delimiters[0],             # <<<<<<<<<<<<<<
 *                                 position=pos,
 *                                 name=name)
*/
          __pyx_t_3 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_delimiters, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s_inside_expression, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "Cython/Tempita/_tempita.py":587
 *             raise TemplateError('%s inside expression' % delimiters[0],
 *                                 position=pos,
 *                                 name=name)             # <<<<<<<<<<<<<<
 *         elif expr == delimiters[1] and not in_expr:
 *             raise TemplateError('%s outside expression' % delimiters[1],
*/
          __pyx_t_10 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
            __pyx_t_10 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_t_2};
            __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 585, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 585, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 585, __pyx_L1_error)
            __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 585, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __PYX_ERR(0, 585, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":584
 *         expr = match.group(0)
 *         pos = find_position(s, match.end(), last, last_pos)
 *         if expr == delimiters[0] and in_expr:             # <<<<<<<<<<<<<<
 *             raise TemplateError('%s inside expression' % delimiters[0],
 *                                 position=pos,
*/
        }

        /* "Cython/Tempita/_tempita.py":588
 *                                 position=pos,
 *                                 name=name)
 *         elif expr == delimiters[1] and not in_expr:             # <<<<<<<<<<<<<<
 *             raise TemplateError('%s outside expression' % delimiters[1],
 *                                 position=pos,
*/
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_delimiters, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 588, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = PyObject_RichCompare(__pyx_v_expr, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 588, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 588, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_13) {
        } else {
          __pyx_t_1 = __pyx_t_13;
          goto __pyx_L9_bool_binop_done;
        }
        __pyx_t_13 = (!__pyx_v_in_expr);
        __pyx_t_1 = __pyx_t_13;
        __pyx_L9_bool_binop_done:;
        if (unlikely(__pyx_t_1)) {

          /* "Cython/Tempita/_tempita.py":589
 *                                 name=name)
 *         elif expr == delimiters[1] and not in_expr:
 *             raise TemplateError('%s outside expression' % delimiters[1],             # <<<<<<<<<<<<<<
 *                                 position=pos,
 *                                 name=name)
*/
          __pyx_t_4 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_delimiters, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s_outside_expression, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "Cython/Tempita/_tempita.py":591
 *             raise TemplateError('%s outside expression' % delimiters[1],
 *                                 position=pos,
 *                                 name=name)             # <<<<<<<<<<<<<<
 *         if expr == delimiters[0]:
 *             part = s[last:match.start()]
*/
          __pyx_t_10 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
            assert(__pyx_t_4);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
            __pyx_t_10 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_t_3};
            __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 589, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 589, __pyx_L1_error)
            __pyx_t_7 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 589, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __Pyx_Raise(__pyx_t_7, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __PYX_ERR(0, 589, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":588
 *                                 position=pos,
 *                                 name=name)
 *         elif expr == delimiters[1] and not in_expr:             # <<<<<<<<<<<<<<
 *             raise TemplateError('%s outside expression' % delimiters[1],
 *                                 position=pos,
*/
        }

        /* "Cython/Tempita/_tempita.py":592
 *                                 position=pos,
 *                                 name=name)
 *         if expr == delimiters[0]:             # <<<<<<<<<<<<<<
 *             part = s[last:match.start()]
 *             if part:
*/
        __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_delimiters, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyObject_RichCompare(__pyx_v_expr, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_1) {

          /* "Cython/Tempita/_tempita.py":593
 *                                 name=name)
 *         if expr == delimiters[0]:
 *             part = s[last:match.start()]             # <<<<<<<<<<<<<<
 *             if part:
 *                 chunks.append(part)
*/
          __pyx_t_7 = __pyx_v_match;
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_10 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 593, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_v_last, &__pyx_t_8, NULL, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 593, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "Cython/Tempita/_tempita.py":594
 *         if expr == delimiters[0]:
 *             part = s[last:match.start()]
 *             if part:             # <<<<<<<<<<<<<<
 *                 chunks.append(part)
 *             in_expr = True
*/
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_part); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 594, __pyx_L1_error)
          if (__pyx_t_1) {

            /* "Cython/Tempita/_tempita.py":595
 *             part = s[last:match.start()]
 *             if part:
 *                 chunks.append(part)             # <<<<<<<<<<<<<<
 *             in_expr = True
 *         else:
*/
            __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_chunks, __pyx_v_part); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 595, __pyx_L1_error)

            /* "Cython/Tempita/_tempita.py":594
 *         if expr == delimiters[0]:
 *             part = s[last:match.start()]
 *             if part:             # <<<<<<<<<<<<<<
 *                 chunks.append(part)
 *             in_expr = True
*/
          }

          /* "Cython/Tempita/_tempita.py":596
 *             if part:
 *                 chunks.append(part)
 *             in_expr = True             # <<<<<<<<<<<<<<
 *         else:
 *             chunks.append((s[last:match.start()], last_pos))
*/
          __pyx_v_in_expr = 1;

          /* "Cython/Tempita/_tempita.py":592
 *                                 position=pos,
 *                                 name=name)
 *         if expr == delimiters[0]:             # <<<<<<<<<<<<<<
 *             part = s[last:match.start()]
 *             if part:
*/
          goto __pyx_L11;
        }

        /* "Cython/Tempita/_tempita.py":598
 *             in_expr = True
 *         else:
 *             chunks.append((s[last:match.start()], last_pos))             # <<<<<<<<<<<<<<
 *             in_expr = False
 *         last = match.end()
*/
        /*else*/ {
          __pyx_t_8 = __pyx_v_match;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_10 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 598, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_v_last, &__pyx_t_7, NULL, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 598, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 598, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_8);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8) != (0)) __PYX_ERR(0, 598, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_last_pos);
          __Pyx_GIVEREF(__pyx_v_last_pos);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_last_pos) != (0)) __PYX_ERR(0, 598, __pyx_L1_error);
          __pyx_t_8 = 0;
          __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_chunks, __pyx_t_7); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 598, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "Cython/Tempita/_tempita.py":599
 *         else:
 *             chunks.append((s[last:match.start()], last_pos))
 *             in_expr = False             # <<<<<<<<<<<<<<
 *         last = match.end()
 *         last_pos = pos
*/
          __pyx_v_in_expr = 0;
        }
        __pyx_L11:;

        /* "Cython/Tempita/_tempita.py":600
 *             chunks.append((s[last:match.start()], last_pos))
 *             in_expr = False
 *         last = match.end()             # <<<<<<<<<<<<<<
 *         last_pos = pos
 *     if in_expr:
*/
        __pyx_t_8 = __pyx_v_match;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_end, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF_SET(__pyx_v_last, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "Cython/Tempita/_tempita.py":601
 *             in_expr = False
 *         last = match.end()
 *         last_pos = pos             # <<<<<<<<<<<<<<
 *     if in_expr:
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],
*/
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_DECREF_SET(__pyx_v_last_pos, __pyx_v_pos);

        /* "Cython/Tempita/_tempita.py":581
 *     token_re = re.compile(r'%s|%s' % (re.escape(delimiters[0]),
 *                                       re.escape(delimiters[1])))
 *     for match in token_re.finditer(s):             # <<<<<<<<<<<<<<
 *         expr = match.group(0)
 *         pos = find_position(s, match.end(), last, last_pos)
*/
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":602
 *         last = match.end()
 *         last_pos = pos
 *     if in_expr:             # <<<<<<<<<<<<<<
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],
 *                             name=name, position=last_pos)
*/
      if (unlikely(__pyx_v_in_expr)) {

        /* "Cython/Tempita/_tempita.py":603
 *         last_pos = pos
 *     if in_expr:
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],             # <<<<<<<<<<<<<<
 *                             name=name, position=last_pos)
 *     part = s[last:]
*/
        __pyx_t_7 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 603, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_delimiters, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 603, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_No_s_to_finish_last_expression, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 603, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":604
 *     if in_expr:
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],
 *                             name=name, position=last_pos)             # <<<<<<<<<<<<<<
 *     part = s[last:]
 *     if part:
*/
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_7, __pyx_t_3};
          __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 603, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 603, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_last_pos, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 603, __pyx_L1_error)
          __pyx_t_5 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 603, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 603, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":602
 *         last = match.end()
 *         last_pos = pos
 *     if in_expr:             # <<<<<<<<<<<<<<
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],
 *                             name=name, position=last_pos)
*/
      }

      /* "Cython/Tempita/_tempita.py":605
 *         raise TemplateError('No %s to finish last expression' % delimiters[1],
 *                             name=name, position=last_pos)
 *     part = s[last:]             # <<<<<<<<<<<<<<
 *     if part:
 *         chunks.append(part)
*/
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_v_last, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":606
 *                             name=name, position=last_pos)
 *     part = s[last:]
 *     if part:             # <<<<<<<<<<<<<<
 *         chunks.append(part)
 *     if trim_whitespace:
*/
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_part); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 606, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "Cython/Tempita/_tempita.py":607
 *     part = s[last:]
 *     if part:
 *         chunks.append(part)             # <<<<<<<<<<<<<<
 *     if trim_whitespace:
 *         chunks = trim_lex(chunks)
*/
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_chunks, __pyx_v_part); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 607, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":606
 *                             name=name, position=last_pos)
 *     part = s[last:]
 *     if part:             # <<<<<<<<<<<<<<
 *         chunks.append(part)
 *     if trim_whitespace:
*/
      }

      /* "Cython/Tempita/_tempita.py":608
 *     if part:
 *         chunks.append(part)
 *     if trim_whitespace:             # <<<<<<<<<<<<<<
 *         chunks = trim_lex(chunks)
 *     return chunks
*/
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_trim_whitespace); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 608, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "Cython/Tempita/_tempita.py":609
 *         chunks.append(part)
 *     if trim_whitespace:
 *         chunks = trim_lex(chunks)             # <<<<<<<<<<<<<<
 *     return chunks
 * 
*/
        __pyx_t_8 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_trim_lex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 609, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_chunks};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 609, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF_SET(__pyx_v_chunks, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":608
 *     if part:
 *         chunks.append(part)
 *     if trim_whitespace:             # <<<<<<<<<<<<<<
 *         chunks = trim_lex(chunks)
 *     return chunks
*/
      }

      /* "Cython/Tempita/_tempita.py":610
 *     if trim_whitespace:
 *         chunks = trim_lex(chunks)
 *     return chunks             # <<<<<<<<<<<<<<
 * 
 * statement_re = re.compile(r'^(?:if |elif |for |def |inherit |default |py:)')
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_chunks);
      __pyx_r = __pyx_v_chunks;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":549
 * 
 * 
 * def lex(s, name=None, trim_whitespace=True, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     """
 *     Lex a string into chunks:
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8);
      __Pyx_AddTraceback("Cython.Tempita._tempita.lex", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_chunks);
      __Pyx_XDECREF(__pyx_v_last);
      __Pyx_XDECREF(__pyx_v_last_pos);
      __Pyx_XDECREF(__pyx_v_token_re);
      __Pyx_XDECREF(__pyx_v_match);
      __Pyx_XDECREF(__pyx_v_expr);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XDECREF(__pyx_v_part);
      __Pyx_XDECREF(__pyx_v_delimiters);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":618
 * 
 * 
 * def trim_lex(tokens):             # <<<<<<<<<<<<<<
 *     r"""
 *     Takes a lexed set of tokens, and removes whitespace when there is
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11trim_lex(PyObject *__pyx_self, PyObject *__pyx_v_tokens); /*proto*/
    PyDoc_STRVAR(__pyx_doc_6Cython_7Tempita_8_tempita_10trim_lex, "\n    Takes a lexed set of tokens, and removes whitespace when there is\n    a directive on a line by itself:\n\n       >>> tokens = lex('{{if x}}\\nx\\n{{endif}}\\ny', trim_whitespace=False)\n       >>> tokens\n       [('if x', (1, 3)), '\\nx\\n', ('endif', (3, 3)), '\\ny']\n       >>> trim_lex(tokens)\n       [('if x', (1, 3)), 'x\\n', ('endif', (3, 3)), 'y']\n    ");
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_11trim_lex = {"trim_lex", (PyCFunction)__pyx_pw_6Cython_7Tempita_8_tempita_11trim_lex, METH_O, __pyx_doc_6Cython_7Tempita_8_tempita_10trim_lex};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_11trim_lex(PyObject *__pyx_self, PyObject *__pyx_v_tokens) {
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("trim_lex (wrapper)", 0);
      __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_10trim_lex(__pyx_self, ((PyObject *)__pyx_v_tokens));

      /* function exit code */
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_10trim_lex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens) {
      PyObject *__pyx_v_last_trim = NULL;
      PyObject *__pyx_v_i = NULL;
      PyObject *__pyx_v_current = NULL;
      PyObject *__pyx_v_item = NULL;
      PyObject *__pyx_v_prev = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_v_prev_ok = NULL;
      PyObject *__pyx_v_m = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      Py_ssize_t __pyx_t_3;
      PyObject *(*__pyx_t_4)(PyObject *);
      PyObject *__pyx_t_5 = NULL;
      int __pyx_t_6;
      PyObject *__pyx_t_7 = NULL;
      PyObject *__pyx_t_8 = NULL;
      PyObject *__pyx_t_9 = NULL;
      size_t __pyx_t_10;
      int __pyx_t_11;
      int __pyx_t_12;
      Py_ssize_t __pyx_t_13;
      PyObject *__pyx_t_14 = NULL;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("trim_lex", 0);

      /* "Cython/Tempita/_tempita.py":629
 *        [('if x', (1, 3)), 'x\n', ('endif', (3, 3)), 'y']
 *     """
 *     last_trim = None             # <<<<<<<<<<<<<<
 *     for i, current in enumerate(tokens):
 *         if isinstance(current, str):
*/
      __Pyx_INCREF(Py_None);
      __pyx_v_last_trim = Py_None;

      /* "Cython/Tempita/_tempita.py":630
 *     """
 *     last_trim = None
 *     for i, current in enumerate(tokens):             # <<<<<<<<<<<<<<
 *         if isinstance(current, str):
 *             # we don't trim this
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
      __pyx_t_1 = __pyx_mstate_global->__pyx_int_0;
      if (likely(PyList_CheckExact(__pyx_v_tokens)) || PyTuple_CheckExact(__pyx_v_tokens)) {
        __pyx_t_2 = __pyx_v_tokens; __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        __pyx_t_4 = NULL;
      } else {
        __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_tokens); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 630, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 630, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_4)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 630, __pyx_L1_error)
              #endif
              if (__pyx_t_3 >= __pyx_temp) break;
            }
            __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_3;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 630, __pyx_L1_error)
              #endif
              if (__pyx_t_3 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
            #endif
            ++__pyx_t_3;
          }
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 630, __pyx_L1_error)
        } else {
          __pyx_t_5 = __pyx_t_4(__pyx_t_2);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 630, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_current, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
        __pyx_t_5 = __Pyx_PyLong_AddObjC(__pyx_t_1, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 630, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1);
        __pyx_t_1 = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":631
 *     last_trim = None
 *     for i, current in enumerate(tokens):
 *         if isinstance(current, str):             # <<<<<<<<<<<<<<
 *             # we don't trim this
 *             continue
*/
        __pyx_t_6 = PyUnicode_Check(__pyx_v_current); 
        if (__pyx_t_6) {

          /* "Cython/Tempita/_tempita.py":633
 *         if isinstance(current, str):
 *             # we don't trim this
 *             continue             # <<<<<<<<<<<<<<
 *         item = current[0]
 *         if not statement_re.search(item) and item not in single_statements:
*/
          goto __pyx_L3_continue;

          /* "Cython/Tempita/_tempita.py":631
 *     last_trim = None
 *     for i, current in enumerate(tokens):
 *         if isinstance(current, str):             # <<<<<<<<<<<<<<
 *             # we don't trim this
 *             continue
*/
        }

        /* "Cython/Tempita/_tempita.py":634
 *             # we don't trim this
 *             continue
 *         item = current[0]             # <<<<<<<<<<<<<<
 *         if not statement_re.search(item) and item not in single_statements:
 *             continue
*/
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_current, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 634, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":635
 *             continue
 *         item = current[0]
 *         if not statement_re.search(item) and item not in single_statements:             # <<<<<<<<<<<<<<
 *             continue
 *         if not i:
*/
        __pyx_t_7 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_statement_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_item};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 635, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_12 = (!__pyx_t_11);
        if (__pyx_t_12) {
        } else {
          __pyx_t_6 = __pyx_t_12;
          goto __pyx_L7_bool_binop_done;
        }
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_single_statements); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_v_item, __pyx_t_5, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_6 = __pyx_t_12;
        __pyx_L7_bool_binop_done:;
        if (__pyx_t_6) {

          /* "Cython/Tempita/_tempita.py":636
 *         item = current[0]
 *         if not statement_re.search(item) and item not in single_statements:
 *             continue             # <<<<<<<<<<<<<<
 *         if not i:
 *             prev = ''
*/
          goto __pyx_L3_continue;

          /* "Cython/Tempita/_tempita.py":635
 *             continue
 *         item = current[0]
 *         if not statement_re.search(item) and item not in single_statements:             # <<<<<<<<<<<<<<
 *             continue
 *         if not i:
*/
        }

        /* "Cython/Tempita/_tempita.py":637
 *         if not statement_re.search(item) and item not in single_statements:
 *             continue
 *         if not i:             # <<<<<<<<<<<<<<
 *             prev = ''
 *         else:
*/
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_i); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 637, __pyx_L1_error)
        __pyx_t_12 = (!__pyx_t_6);
        if (__pyx_t_12) {

          /* "Cython/Tempita/_tempita.py":638
 *             continue
 *         if not i:
 *             prev = ''             # <<<<<<<<<<<<<<
 *         else:
 *             prev = tokens[i - 1]
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
          __Pyx_XDECREF_SET(__pyx_v_prev, __pyx_mstate_global->__pyx_kp_u__4);

          /* "Cython/Tempita/_tempita.py":637
 *         if not statement_re.search(item) and item not in single_statements:
 *             continue
 *         if not i:             # <<<<<<<<<<<<<<
 *             prev = ''
 *         else:
*/
          goto __pyx_L9;
        }

        /* "Cython/Tempita/_tempita.py":640
 *             prev = ''
 *         else:
 *             prev = tokens[i - 1]             # <<<<<<<<<<<<<<
 *         if i + 1 >= len(tokens):
 *             next_chunk = ''
*/
        /*else*/ {
          __pyx_t_5 = __Pyx_PyLong_SubtractObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_prev, __pyx_t_9);
          __pyx_t_9 = 0;
        }
        __pyx_L9:;

        /* "Cython/Tempita/_tempita.py":641
 *         else:
 *             prev = tokens[i - 1]
 *         if i + 1 >= len(tokens):             # <<<<<<<<<<<<<<
 *             next_chunk = ''
 *         else:
*/
        __pyx_t_9 = __Pyx_PyLong_AddObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 641, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_13 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 641, __pyx_L1_error)
        __pyx_t_5 = PyLong_FromSsize_t(__pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 641, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_9, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 641, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 641, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_12) {

          /* "Cython/Tempita/_tempita.py":642
 *             prev = tokens[i - 1]
 *         if i + 1 >= len(tokens):
 *             next_chunk = ''             # <<<<<<<<<<<<<<
 *         else:
 *             next_chunk = tokens[i + 1]
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
          __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_mstate_global->__pyx_kp_u__4);

          /* "Cython/Tempita/_tempita.py":641
 *         else:
 *             prev = tokens[i - 1]
 *         if i + 1 >= len(tokens):             # <<<<<<<<<<<<<<
 *             next_chunk = ''
 *         else:
*/
          goto __pyx_L10;
        }

        /* "Cython/Tempita/_tempita.py":644
 *             next_chunk = ''
 *         else:
 *             next_chunk = tokens[i + 1]             # <<<<<<<<<<<<<<
 *         if (not isinstance(next_chunk, str)
 *                 or not isinstance(prev, str)):
*/
        /*else*/ {
          __pyx_t_7 = __Pyx_PyLong_AddObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 644, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 644, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_5);
          __pyx_t_5 = 0;
        }
        __pyx_L10:;

        /* "Cython/Tempita/_tempita.py":645
 *         else:
 *             next_chunk = tokens[i + 1]
 *         if (not isinstance(next_chunk, str)             # <<<<<<<<<<<<<<
 *                 or not isinstance(prev, str)):
 *             continue
*/
        __pyx_t_6 = PyUnicode_Check(__pyx_v_next_chunk); 
        __pyx_t_11 = (!__pyx_t_6);
        if (!__pyx_t_11) {
        } else {
          __pyx_t_12 = __pyx_t_11;
          goto __pyx_L12_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":646
 *             next_chunk = tokens[i + 1]
 *         if (not isinstance(next_chunk, str)
 *                 or not isinstance(prev, str)):             # <<<<<<<<<<<<<<
 *             continue
 *         prev_ok = not prev or trail_whitespace_re.search(prev)
*/
        __pyx_t_11 = PyUnicode_Check(__pyx_v_prev); 
        __pyx_t_6 = (!__pyx_t_11);
        __pyx_t_12 = __pyx_t_6;
        __pyx_L12_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":645
 *         else:
 *             next_chunk = tokens[i + 1]
 *         if (not isinstance(next_chunk, str)             # <<<<<<<<<<<<<<
 *                 or not isinstance(prev, str)):
 *             continue
*/
        if (__pyx_t_12) {

          /* "Cython/Tempita/_tempita.py":647
 *         if (not isinstance(next_chunk, str)
 *                 or not isinstance(prev, str)):
 *             continue             # <<<<<<<<<<<<<<
 *         prev_ok = not prev or trail_whitespace_re.search(prev)
 *         if i == 1 and not prev.strip():
*/
          goto __pyx_L3_continue;

          /* "Cython/Tempita/_tempita.py":645
 *         else:
 *             next_chunk = tokens[i + 1]
 *         if (not isinstance(next_chunk, str)             # <<<<<<<<<<<<<<
 *                 or not isinstance(prev, str)):
 *             continue
*/
        }

        /* "Cython/Tempita/_tempita.py":648
 *                 or not isinstance(prev, str)):
 *             continue
 *         prev_ok = not prev or trail_whitespace_re.search(prev)             # <<<<<<<<<<<<<<
 *         if i == 1 and not prev.strip():
 *             prev_ok = True
*/
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_prev); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 648, __pyx_L1_error)
        __pyx_t_6 = (!__pyx_t_12);
        if (!__pyx_t_6) {
        } else {
          __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 648, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_5 = __pyx_t_7;
          __pyx_t_7 = 0;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_trail_whitespace_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_14);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_prev};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 648, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_5 = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_L14_bool_binop_done:;
        __Pyx_XDECREF_SET(__pyx_v_prev_ok, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":649
 *             continue
 *         prev_ok = not prev or trail_whitespace_re.search(prev)
 *         if i == 1 and not prev.strip():             # <<<<<<<<<<<<<<
 *             prev_ok = True
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
*/
        __pyx_t_12 = (__Pyx_PyLong_BoolEqObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 649, __pyx_L1_error)
        if (__pyx_t_12) {
        } else {
          __pyx_t_6 = __pyx_t_12;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_7 = __pyx_v_prev;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 649, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 649, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = (!__pyx_t_12);
        __pyx_t_6 = __pyx_t_11;
        __pyx_L17_bool_binop_done:;
        if (__pyx_t_6) {

          /* "Cython/Tempita/_tempita.py":650
 *         prev_ok = not prev or trail_whitespace_re.search(prev)
 *         if i == 1 and not prev.strip():
 *             prev_ok = True             # <<<<<<<<<<<<<<
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
 *             prev_ok = 'last'
*/
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_prev_ok, Py_True);

          /* "Cython/Tempita/_tempita.py":649
 *             continue
 *         prev_ok = not prev or trail_whitespace_re.search(prev)
 *         if i == 1 and not prev.strip():             # <<<<<<<<<<<<<<
 *             prev_ok = True
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
*/
        }

        /* "Cython/Tempita/_tempita.py":651
 *         if i == 1 and not prev.strip():
 *             prev_ok = True
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():             # <<<<<<<<<<<<<<
 *             prev_ok = 'last'
 *         if (prev_ok
*/
        __pyx_t_11 = (__pyx_v_last_trim != Py_None);
        if (__pyx_t_11) {
        } else {
          __pyx_t_6 = __pyx_t_11;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_5 = __Pyx_PyLong_AddObjC(__pyx_v_last_trim, __pyx_mstate_global->__pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_v_i, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_11) {
        } else {
          __pyx_t_6 = __pyx_t_11;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_5 = __pyx_v_prev;
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 651, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_12 = (!__pyx_t_11);
        __pyx_t_6 = __pyx_t_12;
        __pyx_L20_bool_binop_done:;
        if (__pyx_t_6) {

          /* "Cython/Tempita/_tempita.py":652
 *             prev_ok = True
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
 *             prev_ok = 'last'             # <<<<<<<<<<<<<<
 *         if (prev_ok
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_last);
          __Pyx_DECREF_SET(__pyx_v_prev_ok, __pyx_mstate_global->__pyx_n_u_last);

          /* "Cython/Tempita/_tempita.py":651
 *         if i == 1 and not prev.strip():
 *             prev_ok = True
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():             # <<<<<<<<<<<<<<
 *             prev_ok = 'last'
 *         if (prev_ok
*/
        }

        /* "Cython/Tempita/_tempita.py":653
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
 *             prev_ok = 'last'
 *         if (prev_ok             # <<<<<<<<<<<<<<
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
*/
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_prev_ok); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 653, __pyx_L1_error)
        if (__pyx_t_12) {
        } else {
          __pyx_t_6 = __pyx_t_12;
          goto __pyx_L24_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":654
 *             prev_ok = 'last'
 *         if (prev_ok
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)             # <<<<<<<<<<<<<<
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:
*/
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_next_chunk); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 654, __pyx_L1_error)
        __pyx_t_11 = (!__pyx_t_12);
        if (!__pyx_t_11) {
        } else {
          __pyx_t_6 = __pyx_t_11;
          goto __pyx_L24_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":655
 *         if (prev_ok
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):             # <<<<<<<<<<<<<<
 *             if prev:
 *                 if ((i == 1 and not prev.strip())
*/
        __pyx_t_5 = NULL;

        /* "Cython/Tempita/_tempita.py":654
 *             prev_ok = 'last'
 *         if (prev_ok
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)             # <<<<<<<<<<<<<<
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:
*/
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_lead_whitespace_re); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 654, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 654, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_next_chunk};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 654, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 654, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (!__pyx_t_11) {
        } else {
          __pyx_t_6 = __pyx_t_11;
          goto __pyx_L24_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":655
 *         if (prev_ok
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):             # <<<<<<<<<<<<<<
 *             if prev:
 *                 if ((i == 1 and not prev.strip())
*/
        __pyx_t_13 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 655, __pyx_L1_error)
        __pyx_t_7 = PyLong_FromSsize_t((__pyx_t_13 - 2)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = PyObject_RichCompare(__pyx_v_i, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 655, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (__pyx_t_11) {
        } else {
          __pyx_t_6 = __pyx_t_11;
          goto __pyx_L24_bool_binop_done;
        }
        __pyx_t_7 = __pyx_v_next_chunk;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 655, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_12 = (!__pyx_t_11);
        __pyx_t_6 = __pyx_t_12;
        __pyx_L24_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":653
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
 *             prev_ok = 'last'
 *         if (prev_ok             # <<<<<<<<<<<<<<
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
*/
        if (__pyx_t_6) {

          /* "Cython/Tempita/_tempita.py":656
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:             # <<<<<<<<<<<<<<
 *                 if ((i == 1 and not prev.strip())
 *                         or prev_ok == 'last'):
*/
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_prev); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 656, __pyx_L1_error)
          if (__pyx_t_6) {

            /* "Cython/Tempita/_tempita.py":657
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:
 *                 if ((i == 1 and not prev.strip())             # <<<<<<<<<<<<<<
 *                         or prev_ok == 'last'):
 *                     tokens[i - 1] = ''
*/
            __pyx_t_12 = (__Pyx_PyLong_BoolEqObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 657, __pyx_L1_error)
            if (!__pyx_t_12) {
              goto __pyx_L32_next_or;
            } else {
            }
            __pyx_t_7 = __pyx_v_prev;
            __Pyx_INCREF(__pyx_t_7);
            __pyx_t_10 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
              __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 657, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
            }
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 657, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_11 = (!__pyx_t_12);
            if (!__pyx_t_11) {
            } else {
              __pyx_t_6 = __pyx_t_11;
              goto __pyx_L31_bool_binop_done;
            }
            __pyx_L32_next_or:;

            /* "Cython/Tempita/_tempita.py":658
 *             if prev:
 *                 if ((i == 1 and not prev.strip())
 *                         or prev_ok == 'last'):             # <<<<<<<<<<<<<<
 *                     tokens[i - 1] = ''
 *                 else:
*/
            __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_v_prev_ok, __pyx_mstate_global->__pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 658, __pyx_L1_error)
            __pyx_t_6 = __pyx_t_11;
            __pyx_L31_bool_binop_done:;

            /* "Cython/Tempita/_tempita.py":657
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:
 *                 if ((i == 1 and not prev.strip())             # <<<<<<<<<<<<<<
 *                         or prev_ok == 'last'):
 *                     tokens[i - 1] = ''
*/
            if (__pyx_t_6) {

              /* "Cython/Tempita/_tempita.py":659
 *                 if ((i == 1 and not prev.strip())
 *                         or prev_ok == 'last'):
 *                     tokens[i - 1] = ''             # <<<<<<<<<<<<<<
 *                 else:
 *                     m = trail_whitespace_re.search(prev)
*/
              __pyx_t_9 = __Pyx_PyLong_SubtractObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 659, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (unlikely((PyObject_SetItem(__pyx_v_tokens, __pyx_t_9, __pyx_mstate_global->__pyx_kp_u__4) < 0))) __PYX_ERR(0, 659, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

              /* "Cython/Tempita/_tempita.py":657
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:
 *                 if ((i == 1 and not prev.strip())             # <<<<<<<<<<<<<<
 *                         or prev_ok == 'last'):
 *                     tokens[i - 1] = ''
*/
              goto __pyx_L30;
            }

            /* "Cython/Tempita/_tempita.py":661
 *                     tokens[i - 1] = ''
 *                 else:
 *                     m = trail_whitespace_re.search(prev)             # <<<<<<<<<<<<<<
 *                     # +1 to leave the leading \n on:
 *                     prev = prev[:m.start() + 1]
*/
            /*else*/ {
              __pyx_t_7 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_trail_whitespace_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 661, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 661, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __pyx_t_10 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_14))) {
                __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_14);
                assert(__pyx_t_7);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
                __pyx_t_10 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_prev};
                __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 661, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_9);
              }
              __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_9);
              __pyx_t_9 = 0;

              /* "Cython/Tempita/_tempita.py":663
 *                     m = trail_whitespace_re.search(prev)
 *                     # +1 to leave the leading \n on:
 *                     prev = prev[:m.start() + 1]             # <<<<<<<<<<<<<<
 *                     tokens[i - 1] = prev
 *             if next_chunk:
*/
              __pyx_t_14 = __pyx_v_m;
              __Pyx_INCREF(__pyx_t_14);
              __pyx_t_10 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_14, NULL};
                __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_9);
              }
              __pyx_t_14 = __Pyx_PyLong_AddObjC(__pyx_t_9, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 663, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_v_prev, 0, 0, NULL, &__pyx_t_14, NULL, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF_SET(__pyx_v_prev, __pyx_t_9);
              __pyx_t_9 = 0;

              /* "Cython/Tempita/_tempita.py":664
 *                     # +1 to leave the leading \n on:
 *                     prev = prev[:m.start() + 1]
 *                     tokens[i - 1] = prev             # <<<<<<<<<<<<<<
 *             if next_chunk:
 *                 last_trim = i
*/
              __pyx_t_9 = __Pyx_PyLong_SubtractObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 664, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (unlikely((PyObject_SetItem(__pyx_v_tokens, __pyx_t_9, __pyx_v_prev) < 0))) __PYX_ERR(0, 664, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __pyx_L30:;

            /* "Cython/Tempita/_tempita.py":656
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
 *             if prev:             # <<<<<<<<<<<<<<
 *                 if ((i == 1 and not prev.strip())
 *                         or prev_ok == 'last'):
*/
          }

          /* "Cython/Tempita/_tempita.py":665
 *                     prev = prev[:m.start() + 1]
 *                     tokens[i - 1] = prev
 *             if next_chunk:             # <<<<<<<<<<<<<<
 *                 last_trim = i
 *                 if i == len(tokens) - 2 and not next_chunk.strip():
*/
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_next_chunk); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 665, __pyx_L1_error)
          if (__pyx_t_6) {

            /* "Cython/Tempita/_tempita.py":666
 *                     tokens[i - 1] = prev
 *             if next_chunk:
 *                 last_trim = i             # <<<<<<<<<<<<<<
 *                 if i == len(tokens) - 2 and not next_chunk.strip():
 *                     tokens[i + 1] = ''
*/
            __Pyx_INCREF(__pyx_v_i);
            __Pyx_DECREF_SET(__pyx_v_last_trim, __pyx_v_i);

            /* "Cython/Tempita/_tempita.py":667
 *             if next_chunk:
 *                 last_trim = i
 *                 if i == len(tokens) - 2 and not next_chunk.strip():             # <<<<<<<<<<<<<<
 *                     tokens[i + 1] = ''
 *                 else:
*/
            __pyx_t_13 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 667, __pyx_L1_error)
            __pyx_t_9 = PyLong_FromSsize_t((__pyx_t_13 - 2)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 667, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_14 = PyObject_RichCompare(__pyx_v_i, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 667, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 667, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_6 = __pyx_t_11;
              goto __pyx_L36_bool_binop_done;
            }
            __pyx_t_9 = __pyx_v_next_chunk;
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_10 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
              __pyx_t_14 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 667, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
            }
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 667, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_12 = (!__pyx_t_11);
            __pyx_t_6 = __pyx_t_12;
            __pyx_L36_bool_binop_done:;
            if (__pyx_t_6) {

              /* "Cython/Tempita/_tempita.py":668
 *                 last_trim = i
 *                 if i == len(tokens) - 2 and not next_chunk.strip():
 *                     tokens[i + 1] = ''             # <<<<<<<<<<<<<<
 *                 else:
 *                     m = lead_whitespace_re.search(next_chunk)
*/
              __pyx_t_14 = __Pyx_PyLong_AddObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 668, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              if (unlikely((PyObject_SetItem(__pyx_v_tokens, __pyx_t_14, __pyx_mstate_global->__pyx_kp_u__4) < 0))) __PYX_ERR(0, 668, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

              /* "Cython/Tempita/_tempita.py":667
 *             if next_chunk:
 *                 last_trim = i
 *                 if i == len(tokens) - 2 and not next_chunk.strip():             # <<<<<<<<<<<<<<
 *                     tokens[i + 1] = ''
 *                 else:
*/
              goto __pyx_L35;
            }

            /* "Cython/Tempita/_tempita.py":670
 *                     tokens[i + 1] = ''
 *                 else:
 *                     m = lead_whitespace_re.search(next_chunk)             # <<<<<<<<<<<<<<
 *                     next_chunk = next_chunk[m.end():]
 *                     tokens[i + 1] = next_chunk
*/
            /*else*/ {
              __pyx_t_9 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_lead_whitespace_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 670, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 670, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __pyx_t_10 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_5))) {
                __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
                assert(__pyx_t_9);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
                __pyx_t_10 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_next_chunk};
                __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 670, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
              }
              __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_14);
              __pyx_t_14 = 0;

              /* "Cython/Tempita/_tempita.py":671
 *                 else:
 *                     m = lead_whitespace_re.search(next_chunk)
 *                     next_chunk = next_chunk[m.end():]             # <<<<<<<<<<<<<<
 *                     tokens[i + 1] = next_chunk
 *     return tokens
*/
              __pyx_t_5 = __pyx_v_m;
              __Pyx_INCREF(__pyx_t_5);
              __pyx_t_10 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
                __pyx_t_14 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_end, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 671, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
              }
              __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_next_chunk, 0, 0, &__pyx_t_14, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 671, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF_SET(__pyx_v_next_chunk, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "Cython/Tempita/_tempita.py":672
 *                     m = lead_whitespace_re.search(next_chunk)
 *                     next_chunk = next_chunk[m.end():]
 *                     tokens[i + 1] = next_chunk             # <<<<<<<<<<<<<<
 *     return tokens
 * 
*/
              __pyx_t_5 = __Pyx_PyLong_AddObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 672, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              if (unlikely((PyObject_SetItem(__pyx_v_tokens, __pyx_t_5, __pyx_v_next_chunk) < 0))) __PYX_ERR(0, 672, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
            __pyx_L35:;

            /* "Cython/Tempita/_tempita.py":665
 *                     prev = prev[:m.start() + 1]
 *                     tokens[i - 1] = prev
 *             if next_chunk:             # <<<<<<<<<<<<<<
 *                 last_trim = i
 *                 if i == len(tokens) - 2 and not next_chunk.strip():
*/
          }

          /* "Cython/Tempita/_tempita.py":653
 *         if last_trim is not None and last_trim + 2 == i and not prev.strip():
 *             prev_ok = 'last'
 *         if (prev_ok             # <<<<<<<<<<<<<<
 *             and (not next_chunk or lead_whitespace_re.search(next_chunk)
 *                  or (i == len(tokens) - 2 and not next_chunk.strip()))):
*/
        }

        /* "Cython/Tempita/_tempita.py":630
 *     """
 *     last_trim = None
 *     for i, current in enumerate(tokens):             # <<<<<<<<<<<<<<
 *         if isinstance(current, str):
 *             # we don't trim this
*/
        __pyx_L3_continue:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":673
 *                     next_chunk = next_chunk[m.end():]
 *                     tokens[i + 1] = next_chunk
 *     return tokens             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_tokens);
      __pyx_r = __pyx_v_tokens;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":618
 * 
 * 
 * def trim_lex(tokens):             # <<<<<<<<<<<<<<
 *     r"""
 *     Takes a lexed set of tokens, and removes whitespace when there is
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_14);
      __Pyx_AddTraceback("Cython.Tempita._tempita.trim_lex", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_last_trim);
      __Pyx_XDECREF(__pyx_v_i);
      __Pyx_XDECREF(__pyx_v_current);
      __Pyx_XDECREF(__pyx_v_item);
      __Pyx_XDECREF(__pyx_v_prev);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_v_prev_ok);
      __Pyx_XDECREF(__pyx_v_m);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":676
 * 
 * 
 * def find_position(string, index, last_index, last_pos):             # <<<<<<<<<<<<<<
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13find_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    PyDoc_STRVAR(__pyx_doc_6Cython_7Tempita_8_tempita_12find_position, "Given a string and index, return (line, column)");
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_13find_position = {"find_position", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_13find_position, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_7Tempita_8_tempita_12find_position};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_13find_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_string = 0;
      PyObject *__pyx_v_index = 0;
      PyObject *__pyx_v_last_index = 0;
      PyObject *__pyx_v_last_pos = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[4] = {0,0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("find_position (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_string_2,&__pyx_mstate_global->__pyx_n_u_index,&__pyx_mstate_global->__pyx_n_u_last_index,&__pyx_mstate_global->__pyx_n_u_last_pos,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 676, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  4:
            values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 676, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 676, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 676, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 676, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "find_position", 0) < (0)) __PYX_ERR(0, 676, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("find_position", 1, 4, 4, i); __PYX_ERR(0, 676, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 4)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 676, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 676, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 676, __pyx_L3_error)
          values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 676, __pyx_L3_error)
        }
        __pyx_v_string = values[0];
        __pyx_v_index = values[1];
        __pyx_v_last_index = values[2];
        __pyx_v_last_pos = values[3];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("find_position", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 676, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.find_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_12find_position(__pyx_self, __pyx_v_string, __pyx_v_index, __pyx_v_last_index, __pyx_v_last_pos);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_12find_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_string, PyObject *__pyx_v_index, PyObject *__pyx_v_last_index, PyObject *__pyx_v_last_pos) {
      PyObject *__pyx_v_lines = NULL;
      PyObject *__pyx_v_column = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      size_t __pyx_t_3;
      int __pyx_t_4;
      PyObject *__pyx_t_5 = NULL;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("find_position", 0);

      /* "Cython/Tempita/_tempita.py":678
 * def find_position(string, index, last_index, last_pos):
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)             # <<<<<<<<<<<<<<
 *     if lines > 0:
 *         column = index - string.rfind('\n', last_index, index)
*/
      __pyx_t_2 = __pyx_v_string;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__10, __pyx_v_last_index, __pyx_v_index};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_count, __pyx_callargs+__pyx_t_3, (4-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 678, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_lines = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":679
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)
 *     if lines > 0:             # <<<<<<<<<<<<<<
 *         column = index - string.rfind('\n', last_index, index)
 *     else:
*/
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_lines, __pyx_mstate_global->__pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 679, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_4) {

        /* "Cython/Tempita/_tempita.py":680
 *     lines = string.count('\n', last_index, index)
 *     if lines > 0:
 *         column = index - string.rfind('\n', last_index, index)             # <<<<<<<<<<<<<<
 *     else:
 *         column = last_pos[1] + (index - last_index)
*/
        __pyx_t_2 = __pyx_v_string;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__10, __pyx_v_last_index, __pyx_v_index};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rfind, __pyx_callargs+__pyx_t_3, (4-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_2 = PyNumber_Subtract(__pyx_v_index, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_column = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":679
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)
 *     if lines > 0:             # <<<<<<<<<<<<<<
 *         column = index - string.rfind('\n', last_index, index)
 *     else:
*/
        goto __pyx_L3;
      }

      /* "Cython/Tempita/_tempita.py":682
 *         column = index - string.rfind('\n', last_index, index)
 *     else:
 *         column = last_pos[1] + (index - last_index)             # <<<<<<<<<<<<<<
 *     return (last_pos[0] + lines, column)
 * 
*/
      /*else*/ {
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_last_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyNumber_Subtract(__pyx_v_index, __pyx_v_last_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_column = __pyx_t_5;
        __pyx_t_5 = 0;
      }
      __pyx_L3:;

      /* "Cython/Tempita/_tempita.py":683
 *     else:
 *         column = last_pos[1] + (index - last_index)
 *     return (last_pos[0] + lines, column)             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_last_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_v_lines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 683, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_column);
      __Pyx_GIVEREF(__pyx_v_column);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_column) != (0)) __PYX_ERR(0, 683, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":676
 * 
 * 
 * def find_position(string, index, last_index, last_pos):             # <<<<<<<<<<<<<<
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_AddTraceback("Cython.Tempita._tempita.find_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_lines);
      __Pyx_XDECREF(__pyx_v_column);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":686
 * 
 * 
 * def parse(s, name=None, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     r"""
 *     Parses a string into a kind of AST
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_15parse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    PyDoc_STRVAR(__pyx_doc_6Cython_7Tempita_8_tempita_14parse, "\n    Parses a string into a kind of AST\n\n        >>> parse('{{x}}')\n        [('expr', (1, 3), 'x')]\n        >>> parse('foo')\n        ['foo']\n        >>> parse('{{if x}}test{{endif}}')\n        [('cond', (1, 3), ('if', (1, 3), 'x', ['test']))]\n        >>> parse('series->{{for x in y}}x={{x}}{{endfor}}')\n        ['series->', ('for', (1, 11), ('x',), 'y', ['x=', ('expr', (1, 27), 'x')])]\n        >>> parse('{{for x, y in z:}}{{continue}}{{endfor}}')\n        [('for', (1, 3), ('x', 'y'), 'z', [('continue', (1, 21))])]\n        >>> parse('{{py:x=1}}')\n        [('py', (1, 3), 'x=1')]\n        >>> parse('{{if x}}a{{elif y}}b{{else}}c{{endif}}')\n        [('cond', (1, 3), ('if', (1, 3), 'x', ['a']), ('elif', (1, 12), 'y', ['b']), ('else', (1, 23), None, ['c']))]\n\n    Some exceptions::\n\n        >>> parse('{{continue}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: continue outside of for loop at line 1 column 3\n        >>> parse('{{if x}}foo')\n        Traceback (most recent call last):\n            ...\n        TemplateError: No {{endif}} at line 1 column 3\n        >>> parse('{{else}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: else outside of an if block at line 1 column 3\n        >>> parse('{{if x}}{{for x in y}}{{endif}}{{endfor}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: Unexpected endif at line 1 column 25\n        >>> parse('{{if}}{{endif}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: if with no expression at line 1 column 3\n        >>> parse('{{for x y}}{{endfor}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: Bad for (no \"in\") in 'x y' at line 1 column 3\n        >>> parse('{{py:x=1\\ny=2}}')\n        Traceback (most recent call last):\n            ...\n        TemplateError: Multi-line py blocks must start with a newline at line 1 column 3""\n    ");
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_15parse = {"parse", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_15parse, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_7Tempita_8_tempita_14parse};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_15parse(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_s = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_line_offset = 0;
      PyObject *__pyx_v_delimiters = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[4] = {0,0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s_2,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_line_offset,&__pyx_mstate_global->__pyx_n_u_delimiters,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 686, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  4:
            values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse", 0) < (0)) __PYX_ERR(0, 686, __pyx_L3_error)
          if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));
          if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
          for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse", 0, 1, 4, i); __PYX_ERR(0, 686, __pyx_L3_error) }
          }
        } else {
          switch (__pyx_nargs) {
            case  4:
            values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 686, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 686, __pyx_L3_error)
            break;
            default: goto __pyx_L5_argtuple_error;
          }
          if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_int_0)));
          if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
        }
        __pyx_v_s = values[0];
        __pyx_v_name = values[1];
        __pyx_v_line_offset = values[2];
        __pyx_v_delimiters = values[3];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 686, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_14parse(__pyx_self, __pyx_v_s, __pyx_v_name, __pyx_v_line_offset, __pyx_v_delimiters);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_14parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_name, PyObject *__pyx_v_line_offset, PyObject *__pyx_v_delimiters) {
      PyObject *__pyx_v_tokens = NULL;
      PyObject *__pyx_v_result = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      int __pyx_t_1;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      size_t __pyx_t_5;
      PyObject *__pyx_t_6 = NULL;
      PyObject *(*__pyx_t_7)(PyObject *);
      int __pyx_t_8;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse", 0);
      __Pyx_INCREF(__pyx_v_delimiters);

      /* "Cython/Tempita/_tempita.py":736
 *         TemplateError: Multi-line py blocks must start with a newline at line 1 column 3
 *     """
 *     if delimiters is None:             # <<<<<<<<<<<<<<
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
*/
      __pyx_t_1 = (__pyx_v_delimiters == Py_None);
      if (__pyx_t_1) {

        /* "Cython/Tempita/_tempita.py":737
 *     """
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                        Template.default_namespace['end_braces'] )
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)
*/
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 737, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 737, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_start_braces); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 737, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":738
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )             # <<<<<<<<<<<<<<
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)
 *     result = []
*/
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_default_namespace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 738, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_end_braces); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":737
 *     """
 *     if delimiters is None:
 *         delimiters = ( Template.default_namespace['start_braces'],             # <<<<<<<<<<<<<<
 *                        Template.default_namespace['end_braces'] )
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)
*/
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 737, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 737, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 737, __pyx_L1_error);
        __pyx_t_2 = 0;
        __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_delimiters, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":736
 *         TemplateError: Multi-line py blocks must start with a newline at line 1 column 3
 *     """
 *     if delimiters is None:             # <<<<<<<<<<<<<<
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
*/
      }

      /* "Cython/Tempita/_tempita.py":739
 *         delimiters = ( Template.default_namespace['start_braces'],
 *                        Template.default_namespace['end_braces'] )
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)             # <<<<<<<<<<<<<<
 *     result = []
 *     while tokens:
*/
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_lex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 739, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, __pyx_v_s};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 739, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 739, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_line_offset, __pyx_v_line_offset, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 739, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_delimiters, __pyx_v_delimiters, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 739, __pyx_L1_error)
        __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_tokens = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":740
 *                        Template.default_namespace['end_braces'] )
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)
 *     result = []             # <<<<<<<<<<<<<<
 *     while tokens:
 *         next_chunk, tokens = parse_expr(tokens, name)
*/
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_result = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":741
 *     tokens = lex(s, name=name, line_offset=line_offset, delimiters=delimiters)
 *     result = []
 *     while tokens:             # <<<<<<<<<<<<<<
 *         next_chunk, tokens = parse_expr(tokens, name)
 *         result.append(next_chunk)
*/
      while (1) {
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_tokens); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 741, __pyx_L1_error)
        if (!__pyx_t_1) break;

        /* "Cython/Tempita/_tempita.py":742
 *     result = []
 *     while tokens:
 *         next_chunk, tokens = parse_expr(tokens, name)             # <<<<<<<<<<<<<<
 *         result.append(next_chunk)
 *     return result
*/
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_parse_expr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 742, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_tokens, __pyx_v_name};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 742, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 742, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_6);
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_2);
          } else {
            __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 742, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_6);
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 742, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
          }
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 742, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 742, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 742, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
          index = 0; __pyx_t_6 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L6_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 742, __pyx_L1_error)
          __pyx_t_7 = NULL;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L7_unpacking_done;
          __pyx_L6_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_7 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 742, __pyx_L1_error)
          __pyx_L7_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":743
 *     while tokens:
 *         next_chunk, tokens = parse_expr(tokens, name)
 *         result.append(next_chunk)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_result, __pyx_v_next_chunk); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 743, __pyx_L1_error)
      }

      /* "Cython/Tempita/_tempita.py":744
 *         next_chunk, tokens = parse_expr(tokens, name)
 *         result.append(next_chunk)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_result);
      __pyx_r = __pyx_v_result;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":686
 * 
 * 
 * def parse(s, name=None, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     r"""
 *     Parses a string into a kind of AST
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_tokens);
      __Pyx_XDECREF(__pyx_v_result);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_v_delimiters);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":747
 * 
 * 
 * def parse_expr(tokens, name, context=()):             # <<<<<<<<<<<<<<
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_17parse_expr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_17parse_expr = {"parse_expr", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_17parse_expr, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_17parse_expr(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_expr (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 747, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 747, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 747, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 747, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_expr", 0) < (0)) __PYX_ERR(0, 747, __pyx_L3_error)
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_empty_tuple)));
          for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_expr", 0, 2, 3, i); __PYX_ERR(0, 747, __pyx_L3_error) }
          }
        } else {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 747, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 747, __pyx_L3_error)
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 747, __pyx_L3_error)
            break;
            default: goto __pyx_L5_argtuple_error;
          }
          if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_empty_tuple)));
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_expr", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 747, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_16parse_expr(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_16parse_expr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context) {
      PyObject *__pyx_v_expr = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      int __pyx_t_2;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      PyObject *(*__pyx_t_6)(PyObject *);
      size_t __pyx_t_7;
      int __pyx_t_8;
      PyObject *__pyx_t_9 = NULL;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_expr", 0);

      /* "Cython/Tempita/_tempita.py":748
 * 
 * def parse_expr(tokens, name, context=()):
 *     if isinstance(tokens[0], str):             # <<<<<<<<<<<<<<
 *         return tokens[0], tokens[1:]
 *     expr, pos = tokens[0]
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyUnicode_Check(__pyx_t_1); 
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "Cython/Tempita/_tempita.py":749
 * def parse_expr(tokens, name, context=()):
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]             # <<<<<<<<<<<<<<
 *     expr, pos = tokens[0]
 *     expr = expr.strip()
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 749, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 749, __pyx_L1_error);
        __pyx_t_1 = 0;
        __pyx_t_3 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":748
 * 
 * def parse_expr(tokens, name, context=()):
 *     if isinstance(tokens[0], str):             # <<<<<<<<<<<<<<
 *         return tokens[0], tokens[1:]
 *     expr, pos = tokens[0]
*/
      }

      /* "Cython/Tempita/_tempita.py":750
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]
 *     expr, pos = tokens[0]             # <<<<<<<<<<<<<<
 *     expr = expr.strip()
 *     if expr.startswith('py:'):
*/
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 750, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_1);
        } else {
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 750, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_1);
        }
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_5 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
        index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        index = 1; __pyx_t_1 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < (0)) __PYX_ERR(0, 750, __pyx_L1_error)
        __pyx_t_6 = NULL;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L5_unpacking_done;
        __pyx_L4_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 750, __pyx_L1_error)
        __pyx_L5_unpacking_done:;
      }
      __pyx_v_expr = __pyx_t_3;
      __pyx_t_3 = 0;
      __pyx_v_pos = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":751
 *         return tokens[0], tokens[1:]
 *     expr, pos = tokens[0]
 *     expr = expr.strip()             # <<<<<<<<<<<<<<
 *     if expr.startswith('py:'):
 *         expr = expr[3:].lstrip(' \t')
*/
      __pyx_t_1 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 751, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":752
 *     expr, pos = tokens[0]
 *     expr = expr.strip()
 *     if expr.startswith('py:'):             # <<<<<<<<<<<<<<
 *         expr = expr[3:].lstrip(' \t')
 *         if expr.startswith('\n') or expr.startswith('\r'):
*/
      __pyx_t_1 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_py_2};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 752, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 752, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "Cython/Tempita/_tempita.py":753
 *     expr = expr.strip()
 *     if expr.startswith('py:'):
 *         expr = expr[3:].lstrip(' \t')             # <<<<<<<<<<<<<<
 *         if expr.startswith('\n') or expr.startswith('\r'):
 *             expr = expr.lstrip('\r\n')
*/
        __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_expr, 3, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[3], 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 753, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __pyx_t_3;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__11};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 753, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":754
 *     if expr.startswith('py:'):
 *         expr = expr[3:].lstrip(' \t')
 *         if expr.startswith('\n') or expr.startswith('\r'):             # <<<<<<<<<<<<<<
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:
*/
        __pyx_t_3 = __pyx_v_expr;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__10};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 754, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 754, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!__pyx_t_8) {
        } else {
          __pyx_t_2 = __pyx_t_8;
          goto __pyx_L8_bool_binop_done;
        }
        __pyx_t_3 = __pyx_v_expr;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__12};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 754, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 754, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __pyx_t_8;
        __pyx_L8_bool_binop_done:;
        if (__pyx_t_2) {

          /* "Cython/Tempita/_tempita.py":755
 *         expr = expr[3:].lstrip(' \t')
 *         if expr.startswith('\n') or expr.startswith('\r'):
 *             expr = expr.lstrip('\r\n')             # <<<<<<<<<<<<<<
 *             if '\r' in expr:
 *                 expr = expr.replace('\r\n', '\n')
*/
          __pyx_t_3 = __pyx_v_expr;
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_7 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__13};
            __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 755, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Tempita/_tempita.py":756
 *         if expr.startswith('\n') or expr.startswith('\r'):
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:             # <<<<<<<<<<<<<<
 *                 expr = expr.replace('\r\n', '\n')
 *                 expr = expr.replace('\r', '')
*/
          __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__12, __pyx_v_expr, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 756, __pyx_L1_error)
          if (__pyx_t_2) {

            /* "Cython/Tempita/_tempita.py":757
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:
 *                 expr = expr.replace('\r\n', '\n')             # <<<<<<<<<<<<<<
 *                 expr = expr.replace('\r', '')
 *             expr += '\n'
*/
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 757, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[1], NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 757, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_3);
            __pyx_t_3 = 0;

            /* "Cython/Tempita/_tempita.py":758
 *             if '\r' in expr:
 *                 expr = expr.replace('\r\n', '\n')
 *                 expr = expr.replace('\r', '')             # <<<<<<<<<<<<<<
 *             expr += '\n'
 *         else:
*/
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 758, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_mstate_global->__pyx_tuple[2], NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 758, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "Cython/Tempita/_tempita.py":756
 *         if expr.startswith('\n') or expr.startswith('\r'):
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:             # <<<<<<<<<<<<<<
 *                 expr = expr.replace('\r\n', '\n')
 *                 expr = expr.replace('\r', '')
*/
          }

          /* "Cython/Tempita/_tempita.py":759
 *                 expr = expr.replace('\r\n', '\n')
 *                 expr = expr.replace('\r', '')
 *             expr += '\n'             # <<<<<<<<<<<<<<
 *         else:
 *             if '\n' in expr:
*/
          __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_expr, __pyx_mstate_global->__pyx_kp_u__10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 759, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Tempita/_tempita.py":754
 *     if expr.startswith('py:'):
 *         expr = expr[3:].lstrip(' \t')
 *         if expr.startswith('\n') or expr.startswith('\r'):             # <<<<<<<<<<<<<<
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:
*/
          goto __pyx_L7;
        }

        /* "Cython/Tempita/_tempita.py":761
 *             expr += '\n'
 *         else:
 *             if '\n' in expr:             # <<<<<<<<<<<<<<
 *                 raise TemplateError(
 *                     'Multi-line py blocks must start with a newline',
*/
        /*else*/ {
          __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__10, __pyx_v_expr, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 761, __pyx_L1_error)
          if (unlikely(__pyx_t_2)) {

            /* "Cython/Tempita/_tempita.py":762
 *         else:
 *             if '\n' in expr:
 *                 raise TemplateError(             # <<<<<<<<<<<<<<
 *                     'Multi-line py blocks must start with a newline',
 *                     position=pos, name=name)
*/
            __pyx_t_3 = NULL;
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 762, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);

            /* "Cython/Tempita/_tempita.py":764
 *                 raise TemplateError(
 *                     'Multi-line py blocks must start with a newline',
 *                     position=pos, name=name)             # <<<<<<<<<<<<<<
 *         return ('py', pos, expr), tokens[1:]
 *     elif expr in ('continue', 'break'):
*/
            __pyx_t_7 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
              assert(__pyx_t_3);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
              __pyx_t_7 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Multi_line_py_blocks_must_start};
              __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 762, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 762, __pyx_L1_error)
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 762, __pyx_L1_error)
              __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 762, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
            }
            __Pyx_Raise(__pyx_t_4, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __PYX_ERR(0, 762, __pyx_L1_error)

            /* "Cython/Tempita/_tempita.py":761
 *             expr += '\n'
 *         else:
 *             if '\n' in expr:             # <<<<<<<<<<<<<<
 *                 raise TemplateError(
 *                     'Multi-line py blocks must start with a newline',
*/
          }
        }
        __pyx_L7:;

        /* "Cython/Tempita/_tempita.py":765
 *                     'Multi-line py blocks must start with a newline',
 *                     position=pos, name=name)
 *         return ('py', pos, expr), tokens[1:]             # <<<<<<<<<<<<<<
 *     elif expr in ('continue', 'break'):
 *         if 'for' not in context:
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 765, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_py);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_py);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_mstate_global->__pyx_n_u_py) != (0)) __PYX_ERR(0, 765, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 765, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_expr);
        __Pyx_GIVEREF(__pyx_v_expr);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_expr) != (0)) __PYX_ERR(0, 765, __pyx_L1_error);
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 765, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 765, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 765, __pyx_L1_error);
        __pyx_t_4 = 0;
        __pyx_t_1 = 0;
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":752
 *     expr, pos = tokens[0]
 *     expr = expr.strip()
 *     if expr.startswith('py:'):             # <<<<<<<<<<<<<<
 *         expr = expr[3:].lstrip(' \t')
 *         if expr.startswith('\n') or expr.startswith('\r'):
*/
      }

      /* "Cython/Tempita/_tempita.py":766
 *                     position=pos, name=name)
 *         return ('py', pos, expr), tokens[1:]
 *     elif expr in ('continue', 'break'):             # <<<<<<<<<<<<<<
 *         if 'for' not in context:
 *             raise TemplateError(
*/
      __Pyx_INCREF(__pyx_v_expr);
      __pyx_t_5 = __pyx_v_expr;
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_continue, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 766, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_break, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 766, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L12_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_8 = __pyx_t_2;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":767
 *         return ('py', pos, expr), tokens[1:]
 *     elif expr in ('continue', 'break'):
 *         if 'for' not in context:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'continue outside of for loop',
*/
        __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_for, __pyx_v_context, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 767, __pyx_L1_error)
        if (unlikely(__pyx_t_8)) {

          /* "Cython/Tempita/_tempita.py":768
 *     elif expr in ('continue', 'break'):
 *         if 'for' not in context:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'continue outside of for loop',
 *                 position=pos, name=name)
*/
          __pyx_t_1 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 768, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);

          /* "Cython/Tempita/_tempita.py":770
 *             raise TemplateError(
 *                 'continue outside of for loop',
 *                 position=pos, name=name)             # <<<<<<<<<<<<<<
 *         return (expr, pos), tokens[1:]
 *     elif expr.startswith('if '):
*/
          __pyx_t_7 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
            __pyx_t_7 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_continue_outside_of_for_loop};
            __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 768, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 768, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 768, __pyx_L1_error)
            __pyx_t_5 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 768, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
          }
          __Pyx_Raise(__pyx_t_5, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __PYX_ERR(0, 768, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":767
 *         return ('py', pos, expr), tokens[1:]
 *     elif expr in ('continue', 'break'):
 *         if 'for' not in context:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'continue outside of for loop',
*/
        }

        /* "Cython/Tempita/_tempita.py":771
 *                 'continue outside of for loop',
 *                 position=pos, name=name)
 *         return (expr, pos), tokens[1:]             # <<<<<<<<<<<<<<
 *     elif expr.startswith('if '):
 *         return parse_cond(tokens, name, context)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 771, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_expr);
        __Pyx_GIVEREF(__pyx_v_expr);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 771, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 771, __pyx_L1_error);
        __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 771, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 771, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5) != (0)) __PYX_ERR(0, 771, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 771, __pyx_L1_error);
        __pyx_t_5 = 0;
        __pyx_t_4 = 0;
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":766
 *                     position=pos, name=name)
 *         return ('py', pos, expr), tokens[1:]
 *     elif expr in ('continue', 'break'):             # <<<<<<<<<<<<<<
 *         if 'for' not in context:
 *             raise TemplateError(
*/
      }

      /* "Cython/Tempita/_tempita.py":772
 *                 position=pos, name=name)
 *         return (expr, pos), tokens[1:]
 *     elif expr.startswith('if '):             # <<<<<<<<<<<<<<
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')
*/
      __pyx_t_4 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_if};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 772, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 772, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":773
 *         return (expr, pos), tokens[1:]
 *     elif expr.startswith('if '):
 *         return parse_cond(tokens, name, context)             # <<<<<<<<<<<<<<
 *     elif (expr.startswith('elif ')
 *           or expr == 'else'):
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_parse_cond); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 773, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 773, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":772
 *                 position=pos, name=name)
 *         return (expr, pos), tokens[1:]
 *     elif expr.startswith('if '):             # <<<<<<<<<<<<<<
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')
*/
      }

      /* "Cython/Tempita/_tempita.py":774
 *     elif expr.startswith('if '):
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')             # <<<<<<<<<<<<<<
 *           or expr == 'else'):
 *         raise TemplateError(
*/
      __pyx_t_5 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_elif};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 774, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 774, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_2) {
      } else {
        __pyx_t_8 = __pyx_t_2;
        goto __pyx_L15_bool_binop_done;
      }

      /* "Cython/Tempita/_tempita.py":775
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')
 *           or expr == 'else'):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             '%s outside of an if block' % expr.split()[0],
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 775, __pyx_L1_error)
      __pyx_t_8 = __pyx_t_2;
      __pyx_L15_bool_binop_done:;

      /* "Cython/Tempita/_tempita.py":774
 *     elif expr.startswith('if '):
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')             # <<<<<<<<<<<<<<
 *           or expr == 'else'):
 *         raise TemplateError(
*/
      if (unlikely(__pyx_t_8)) {

        /* "Cython/Tempita/_tempita.py":776
 *     elif (expr.startswith('elif ')
 *           or expr == 'else'):
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             '%s outside of an if block' % expr.split()[0],
 *             position=pos, name=name)
*/
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 776, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "Cython/Tempita/_tempita.py":777
 *           or expr == 'else'):
 *         raise TemplateError(
 *             '%s outside of an if block' % expr.split()[0],             # <<<<<<<<<<<<<<
 *             position=pos, name=name)
 *     elif expr in ('if', 'elif', 'for'):
*/
        __pyx_t_9 = __pyx_v_expr;
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 777, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s_outside_of_an_if_block, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "Cython/Tempita/_tempita.py":778
 *         raise TemplateError(
 *             '%s outside of an if block' % expr.split()[0],
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     elif expr in ('if', 'elif', 'for'):
 *         raise TemplateError(
*/
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_t_1};
          __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 776, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 776, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 776, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 776, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 776, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":774
 *     elif expr.startswith('if '):
 *         return parse_cond(tokens, name, context)
 *     elif (expr.startswith('elif ')             # <<<<<<<<<<<<<<
 *           or expr == 'else'):
 *         raise TemplateError(
*/
      }

      /* "Cython/Tempita/_tempita.py":779
 *             '%s outside of an if block' % expr.split()[0],
 *             position=pos, name=name)
 *     elif expr in ('if', 'elif', 'for'):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             '%s with no expression' % expr,
*/
      __Pyx_INCREF(__pyx_v_expr);
      __pyx_t_3 = __pyx_v_expr;
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_if_2, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 779, __pyx_L1_error)
      if (!__pyx_t_2) {
      } else {
        __pyx_t_8 = __pyx_t_2;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_elif_2, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 779, __pyx_L1_error)
      if (!__pyx_t_2) {
      } else {
        __pyx_t_8 = __pyx_t_2;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 779, __pyx_L1_error)
      __pyx_t_8 = __pyx_t_2;
      __pyx_L17_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_2 = __pyx_t_8;
      if (unlikely(__pyx_t_2)) {

        /* "Cython/Tempita/_tempita.py":780
 *             position=pos, name=name)
 *     elif expr in ('if', 'elif', 'for'):
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             '%s with no expression' % expr,
 *             position=pos, name=name)
*/
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "Cython/Tempita/_tempita.py":781
 *     elif expr in ('if', 'elif', 'for'):
 *         raise TemplateError(
 *             '%s with no expression' % expr,             # <<<<<<<<<<<<<<
 *             position=pos, name=name)
 *     elif expr in ('endif', 'endfor', 'enddef'):
*/
        __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s_with_no_expression, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 781, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "Cython/Tempita/_tempita.py":782
 *         raise TemplateError(
 *             '%s with no expression' % expr,
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     elif expr in ('endif', 'endfor', 'enddef'):
 *         raise TemplateError(
*/
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_t_1};
          __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 780, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 780, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 780, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 780, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 780, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":779
 *             '%s outside of an if block' % expr.split()[0],
 *             position=pos, name=name)
 *     elif expr in ('if', 'elif', 'for'):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             '%s with no expression' % expr,
*/
      }

      /* "Cython/Tempita/_tempita.py":783
 *             '%s with no expression' % expr,
 *             position=pos, name=name)
 *     elif expr in ('endif', 'endfor', 'enddef'):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'Unexpected %s' % expr,
*/
      __Pyx_INCREF(__pyx_v_expr);
      __pyx_t_3 = __pyx_v_expr;
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_endif, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 783, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_endfor, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 783, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_enddef, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 783, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L20_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = __pyx_t_2;
      if (unlikely(__pyx_t_8)) {

        /* "Cython/Tempita/_tempita.py":784
 *             position=pos, name=name)
 *     elif expr in ('endif', 'endfor', 'enddef'):
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             'Unexpected %s' % expr,
 *             position=pos, name=name)
*/
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 784, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);

        /* "Cython/Tempita/_tempita.py":785
 *     elif expr in ('endif', 'endfor', 'enddef'):
 *         raise TemplateError(
 *             'Unexpected %s' % expr,             # <<<<<<<<<<<<<<
 *             position=pos, name=name)
 *     elif expr.startswith('for '):
*/
        __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Unexpected_s, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "Cython/Tempita/_tempita.py":786
 *         raise TemplateError(
 *             'Unexpected %s' % expr,
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     elif expr.startswith('for '):
 *         return parse_for(tokens, name, context)
*/
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_t_1};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 784, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 784, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 784, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 784, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 784, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":783
 *             '%s with no expression' % expr,
 *             position=pos, name=name)
 *     elif expr in ('endif', 'endfor', 'enddef'):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'Unexpected %s' % expr,
*/
      }

      /* "Cython/Tempita/_tempita.py":787
 *             'Unexpected %s' % expr,
 *             position=pos, name=name)
 *     elif expr.startswith('for '):             # <<<<<<<<<<<<<<
 *         return parse_for(tokens, name, context)
 *     elif expr.startswith('default '):
*/
      __pyx_t_5 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_for_2};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 787, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 787, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":788
 *             position=pos, name=name)
 *     elif expr.startswith('for '):
 *         return parse_for(tokens, name, context)             # <<<<<<<<<<<<<<
 *     elif expr.startswith('default '):
 *         return parse_default(tokens, name, context)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_parse_for); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 788, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 788, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":787
 *             'Unexpected %s' % expr,
 *             position=pos, name=name)
 *     elif expr.startswith('for '):             # <<<<<<<<<<<<<<
 *         return parse_for(tokens, name, context)
 *     elif expr.startswith('default '):
*/
      }

      /* "Cython/Tempita/_tempita.py":789
 *     elif expr.startswith('for '):
 *         return parse_for(tokens, name, context)
 *     elif expr.startswith('default '):             # <<<<<<<<<<<<<<
 *         return parse_default(tokens, name, context)
 *     elif expr.startswith('inherit '):
*/
      __pyx_t_4 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_default_2};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 789, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 789, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":790
 *         return parse_for(tokens, name, context)
 *     elif expr.startswith('default '):
 *         return parse_default(tokens, name, context)             # <<<<<<<<<<<<<<
 *     elif expr.startswith('inherit '):
 *         return parse_inherit(tokens, name, context)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_parse_default); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 790, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 790, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":789
 *     elif expr.startswith('for '):
 *         return parse_for(tokens, name, context)
 *     elif expr.startswith('default '):             # <<<<<<<<<<<<<<
 *         return parse_default(tokens, name, context)
 *     elif expr.startswith('inherit '):
*/
      }

      /* "Cython/Tempita/_tempita.py":791
 *     elif expr.startswith('default '):
 *         return parse_default(tokens, name, context)
 *     elif expr.startswith('inherit '):             # <<<<<<<<<<<<<<
 *         return parse_inherit(tokens, name, context)
 *     elif expr.startswith('def '):
*/
      __pyx_t_5 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_inherit_3};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 791, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 791, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":792
 *         return parse_default(tokens, name, context)
 *     elif expr.startswith('inherit '):
 *         return parse_inherit(tokens, name, context)             # <<<<<<<<<<<<<<
 *     elif expr.startswith('def '):
 *         return parse_def(tokens, name, context)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_parse_inherit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 792, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 792, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":791
 *     elif expr.startswith('default '):
 *         return parse_default(tokens, name, context)
 *     elif expr.startswith('inherit '):             # <<<<<<<<<<<<<<
 *         return parse_inherit(tokens, name, context)
 *     elif expr.startswith('def '):
*/
      }

      /* "Cython/Tempita/_tempita.py":793
 *     elif expr.startswith('inherit '):
 *         return parse_inherit(tokens, name, context)
 *     elif expr.startswith('def '):             # <<<<<<<<<<<<<<
 *         return parse_def(tokens, name, context)
 *     elif expr.startswith('#'):
*/
      __pyx_t_4 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_def_2};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":794
 *         return parse_inherit(tokens, name, context)
 *     elif expr.startswith('def '):
 *         return parse_def(tokens, name, context)             # <<<<<<<<<<<<<<
 *     elif expr.startswith('#'):
 *         return ('comment', pos, tokens[0][0]), tokens[1:]
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_parse_def); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 794, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 794, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":793
 *     elif expr.startswith('inherit '):
 *         return parse_inherit(tokens, name, context)
 *     elif expr.startswith('def '):             # <<<<<<<<<<<<<<
 *         return parse_def(tokens, name, context)
 *     elif expr.startswith('#'):
*/
      }

      /* "Cython/Tempita/_tempita.py":795
 *     elif expr.startswith('def '):
 *         return parse_def(tokens, name, context)
 *     elif expr.startswith('#'):             # <<<<<<<<<<<<<<
 *         return ('comment', pos, tokens[0][0]), tokens[1:]
 *     return ('expr', pos, tokens[0][0]), tokens[1:]
*/
      __pyx_t_5 = __pyx_v_expr;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__14};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 795, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":796
 *         return parse_def(tokens, name, context)
 *     elif expr.startswith('#'):
 *         return ('comment', pos, tokens[0][0]), tokens[1:]             # <<<<<<<<<<<<<<
 *     return ('expr', pos, tokens[0][0]), tokens[1:]
 * 
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_comment);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_comment);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_mstate_global->__pyx_n_u_comment) != (0)) __PYX_ERR(0, 796, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 796, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 796, __pyx_L1_error);
        __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 796, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5) != (0)) __PYX_ERR(0, 796, __pyx_L1_error);
        __pyx_t_3 = 0;
        __pyx_t_5 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":795
 *     elif expr.startswith('def '):
 *         return parse_def(tokens, name, context)
 *     elif expr.startswith('#'):             # <<<<<<<<<<<<<<
 *         return ('comment', pos, tokens[0][0]), tokens[1:]
 *     return ('expr', pos, tokens[0][0]), tokens[1:]
*/
      }

      /* "Cython/Tempita/_tempita.py":797
 *     elif expr.startswith('#'):
 *         return ('comment', pos, tokens[0][0]), tokens[1:]
 *     return ('expr', pos, tokens[0][0]), tokens[1:]             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_expr);
      __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_expr);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_mstate_global->__pyx_n_u_expr) != (0)) __PYX_ERR(0, 797, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 797, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 797, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 797, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5) != (0)) __PYX_ERR(0, 797, __pyx_L1_error);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":747
 * 
 * 
 * def parse_expr(tokens, name, context=()):             # <<<<<<<<<<<<<<
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_expr);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":800
 * 
 * 
 * def parse_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     start = tokens[0][1]
 *     pieces = []
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_19parse_cond(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_19parse_cond = {"parse_cond", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_19parse_cond, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_19parse_cond(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_cond (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 800, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 800, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 800, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 800, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_cond", 0) < (0)) __PYX_ERR(0, 800, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_cond", 1, 3, 3, i); __PYX_ERR(0, 800, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 800, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 800, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 800, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_cond", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 800, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_cond", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_18parse_cond(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_18parse_cond(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context) {
      PyObject *__pyx_v_start = NULL;
      PyObject *__pyx_v_pieces = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      int __pyx_t_3;
      int __pyx_t_4;
      PyObject *__pyx_t_5 = NULL;
      size_t __pyx_t_6;
      PyObject *__pyx_t_7 = NULL;
      PyObject *(*__pyx_t_8)(PyObject *);
      int __pyx_t_9;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_cond", 0);
      __Pyx_INCREF(__pyx_v_tokens);
      __Pyx_INCREF(__pyx_v_context);

      /* "Cython/Tempita/_tempita.py":801
 * 
 * def parse_cond(tokens, name, context):
 *     start = tokens[0][1]             # <<<<<<<<<<<<<<
 *     pieces = []
 *     context = context + ('if',)
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_start = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":802
 * def parse_cond(tokens, name, context):
 *     start = tokens[0][1]
 *     pieces = []             # <<<<<<<<<<<<<<
 *     context = context + ('if',)
 *     while 1:
*/
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_pieces = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":803
 *     start = tokens[0][1]
 *     pieces = []
 *     context = context + ('if',)             # <<<<<<<<<<<<<<
 *     while 1:
 *         if not tokens:
*/
      __pyx_t_2 = PyNumber_Add(__pyx_v_context, __pyx_mstate_global->__pyx_tuple[3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":804
 *     pieces = []
 *     context = context + ('if',)
 *     while 1:             # <<<<<<<<<<<<<<
 *         if not tokens:
 *             raise TemplateError(
*/
      while (1) {

        /* "Cython/Tempita/_tempita.py":805
 *     context = context + ('if',)
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'Missing {{endif}}',
*/
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_tokens); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 805, __pyx_L1_error)
        __pyx_t_4 = (!__pyx_t_3);
        if (unlikely(__pyx_t_4)) {

          /* "Cython/Tempita/_tempita.py":806
 *     while 1:
 *         if not tokens:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'Missing {{endif}}',
 *                 position=start, name=name)
*/
          __pyx_t_1 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 806, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Tempita/_tempita.py":808
 *             raise TemplateError(
 *                 'Missing {{endif}}',
 *                 position=start, name=name)             # <<<<<<<<<<<<<<
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endif'):
*/
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_Missing_endif};
            __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 806, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_start, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 806, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 806, __pyx_L1_error)
            __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 806, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 806, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":805
 *     context = context + ('if',)
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'Missing {{endif}}',
*/
        }

        /* "Cython/Tempita/_tempita.py":809
 *                 'Missing {{endif}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endif'):
 *             return ('cond', start) + tuple(pieces), tokens[1:]
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyTuple_Check(__pyx_t_2); 
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_3) {
        } else {
          __pyx_t_4 = __pyx_t_3;
          goto __pyx_L7_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":810
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endif'):             # <<<<<<<<<<<<<<
 *             return ('cond', start) + tuple(pieces), tokens[1:]
 *         next_chunk, tokens = parse_one_cond(tokens, name, context)
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_endif, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_4 = __pyx_t_3;
        __pyx_L7_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":809
 *                 'Missing {{endif}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endif'):
 *             return ('cond', start) + tuple(pieces), tokens[1:]
*/
        if (__pyx_t_4) {

          /* "Cython/Tempita/_tempita.py":811
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endif'):
 *             return ('cond', start) + tuple(pieces), tokens[1:]             # <<<<<<<<<<<<<<
 *         next_chunk, tokens = parse_one_cond(tokens, name, context)
 *         pieces.append(next_chunk)
*/
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_cond);
          __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_cond);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_mstate_global->__pyx_n_u_cond) != (0)) __PYX_ERR(0, 811, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_start);
          __Pyx_GIVEREF(__pyx_v_start);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_start) != (0)) __PYX_ERR(0, 811, __pyx_L1_error);
          __pyx_t_2 = PyList_AsTuple(__pyx_v_pieces); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_7 = PyNumber_Add(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_7);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7) != (0)) __PYX_ERR(0, 811, __pyx_L1_error);
          __Pyx_GIVEREF(__pyx_t_2);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 811, __pyx_L1_error);
          __pyx_t_7 = 0;
          __pyx_t_2 = 0;
          __pyx_r = __pyx_t_5;
          __pyx_t_5 = 0;
          goto __pyx_L0;

          /* "Cython/Tempita/_tempita.py":809
 *                 'Missing {{endif}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endif'):
 *             return ('cond', start) + tuple(pieces), tokens[1:]
*/
        }

        /* "Cython/Tempita/_tempita.py":812
 *                 and tokens[0][0] == 'endif'):
 *             return ('cond', start) + tuple(pieces), tokens[1:]
 *         next_chunk, tokens = parse_one_cond(tokens, name, context)             # <<<<<<<<<<<<<<
 *         pieces.append(next_chunk)
 * 
*/
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_parse_one_cond); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 812, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
          PyObject* sequence = __pyx_t_5;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 812, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_7);
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_2);
          } else {
            __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 812, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_7);
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 812, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
          }
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 812, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 812, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
          index = 0; __pyx_t_7 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          index = 1; __pyx_t_2 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_1), 2) < (0)) __PYX_ERR(0, 812, __pyx_L1_error)
          __pyx_t_8 = NULL;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L10_unpacking_done;
          __pyx_L9_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_8 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 812, __pyx_L1_error)
          __pyx_L10_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":813
 *             return ('cond', start) + tuple(pieces), tokens[1:]
 *         next_chunk, tokens = parse_one_cond(tokens, name, context)
 *         pieces.append(next_chunk)             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_pieces, __pyx_v_next_chunk); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 813, __pyx_L1_error)
      }

      /* "Cython/Tempita/_tempita.py":800
 * 
 * 
 * def parse_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     start = tokens[0][1]
 *     pieces = []
*/

      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_cond", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_start);
      __Pyx_XDECREF(__pyx_v_pieces);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_v_tokens);
      __Pyx_XDECREF(__pyx_v_context);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":816
 * 
 * 
 * def parse_one_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_21parse_one_cond(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_21parse_one_cond = {"parse_one_cond", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_21parse_one_cond, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_21parse_one_cond(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_one_cond (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 816, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 816, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 816, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 816, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_one_cond", 0) < (0)) __PYX_ERR(0, 816, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_one_cond", 1, 3, 3, i); __PYX_ERR(0, 816, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 816, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 816, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 816, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_one_cond", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 816, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_one_cond", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_20parse_one_cond(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_20parse_one_cond(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context) {
      PyObject *__pyx_v_first = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_v_content = NULL;
      PyObject *__pyx_v_part = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      PyObject *(*__pyx_t_6)(PyObject *);
      size_t __pyx_t_7;
      int __pyx_t_8;
      PyObject *__pyx_t_9[4];
      int __pyx_t_10;
      int __pyx_t_11;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_one_cond", 0);
      __Pyx_INCREF(__pyx_v_tokens);

      /* "Cython/Tempita/_tempita.py":817
 * 
 * def parse_one_cond(tokens, name, context):
 *     (first, pos), tokens = tokens[0], tokens[1:]             # <<<<<<<<<<<<<<
 *     content = []
 *     if first.endswith(':'):
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 817, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_4);
        } else {
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_4);
        }
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
        index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < (0)) __PYX_ERR(0, 817, __pyx_L1_error)
        __pyx_t_6 = NULL;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 817, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_first = __pyx_t_3;
      __pyx_t_3 = 0;
      __pyx_v_pos = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":818
 * def parse_one_cond(tokens, name, context):
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []             # <<<<<<<<<<<<<<
 *     if first.endswith(':'):
 *         first = first[:-1]
*/
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_content = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":819
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     if first.startswith('if '):
*/
      __pyx_t_1 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__8};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 819, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":820
 *     content = []
 *     if first.endswith(':'):
 *         first = first[:-1]             # <<<<<<<<<<<<<<
 *     if first.startswith('if '):
 *         part = ('if', pos, first[3:].lstrip(), content)
*/
        __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":819
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     if first.startswith('if '):
*/
      }

      /* "Cython/Tempita/_tempita.py":821
 *     if first.endswith(':'):
 *         first = first[:-1]
 *     if first.startswith('if '):             # <<<<<<<<<<<<<<
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):
*/
      __pyx_t_1 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_if};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 821, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":822
 *         first = first[:-1]
 *     if first.startswith('if '):
 *         part = ('if', pos, first[3:].lstrip(), content)             # <<<<<<<<<<<<<<
 *     elif first.startswith('elif '):
 *         part = ('elif', pos, first[5:].lstrip(), content)
*/
        __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_first, 3, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[3], 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 822, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_if_2);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_if_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_mstate_global->__pyx_n_u_if_2) != (0)) __PYX_ERR(0, 822, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 822, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2) != (0)) __PYX_ERR(0, 822, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_content);
        __Pyx_GIVEREF(__pyx_v_content);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_content) != (0)) __PYX_ERR(0, 822, __pyx_L1_error);
        __pyx_t_2 = 0;
        __pyx_v_part = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":821
 *     if first.endswith(':'):
 *         first = first[:-1]
 *     if first.startswith('if '):             # <<<<<<<<<<<<<<
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):
*/
        goto __pyx_L6;
      }

      /* "Cython/Tempita/_tempita.py":823
 *     if first.startswith('if '):
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):             # <<<<<<<<<<<<<<
 *         part = ('elif', pos, first[5:].lstrip(), content)
 *     elif first == 'else':
*/
      __pyx_t_2 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_elif};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 823, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 823, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":824
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):
 *         part = ('elif', pos, first[5:].lstrip(), content)             # <<<<<<<<<<<<<<
 *     elif first == 'else':
 *         part = ('else', pos, None, content)
*/
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_first, 5, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[4], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __pyx_t_1;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 824, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_elif_2);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_elif_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_mstate_global->__pyx_n_u_elif_2) != (0)) __PYX_ERR(0, 824, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 824, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_4);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4) != (0)) __PYX_ERR(0, 824, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_content);
        __Pyx_GIVEREF(__pyx_v_content);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_content) != (0)) __PYX_ERR(0, 824, __pyx_L1_error);
        __pyx_t_4 = 0;
        __pyx_v_part = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":823
 *     if first.startswith('if '):
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):             # <<<<<<<<<<<<<<
 *         part = ('elif', pos, first[5:].lstrip(), content)
 *     elif first == 'else':
*/
        goto __pyx_L6;
      }

      /* "Cython/Tempita/_tempita.py":825
 *     elif first.startswith('elif '):
 *         part = ('elif', pos, first[5:].lstrip(), content)
 *     elif first == 'else':             # <<<<<<<<<<<<<<
 *         part = ('else', pos, None, content)
 *     else:
*/
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 825, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "Cython/Tempita/_tempita.py":826
 *         part = ('elif', pos, first[5:].lstrip(), content)
 *     elif first == 'else':
 *         part = ('else', pos, None, content)             # <<<<<<<<<<<<<<
 *     else:
 *         assert 0, "Unexpected token %r at %s" % (first, pos)
*/
        __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_else);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_else);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_mstate_global->__pyx_n_u_else) != (0)) __PYX_ERR(0, 826, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_pos);
        __Pyx_GIVEREF(__pyx_v_pos);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 826, __pyx_L1_error);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(0, 826, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_content);
        __Pyx_GIVEREF(__pyx_v_content);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_content) != (0)) __PYX_ERR(0, 826, __pyx_L1_error);
        __pyx_v_part = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":825
 *     elif first.startswith('elif '):
 *         part = ('elif', pos, first[5:].lstrip(), content)
 *     elif first == 'else':             # <<<<<<<<<<<<<<
 *         part = ('else', pos, None, content)
 *     else:
*/
        goto __pyx_L6;
      }

      /* "Cython/Tempita/_tempita.py":828
 *         part = ('else', pos, None, content)
 *     else:
 *         assert 0, "Unexpected token %r at %s" % (first, pos)             # <<<<<<<<<<<<<<
 *     while 1:
 *         if not tokens:
*/
      /*else*/ {
        #ifndef CYTHON_WITHOUT_ASSERTIONS
        if (unlikely(__pyx_assertions_enabled())) {
          if (unlikely(!0)) {
            __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_first), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_pos), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 828, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Unexpected_token;
            __pyx_t_9[1] = __pyx_t_1;
            __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_at_2;
            __pyx_t_9[3] = __pyx_t_4;
            __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_9, 4, 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 4 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 828, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_2, 0, 0);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __PYX_ERR(0, 828, __pyx_L1_error)
          }
        }
        #else
        if ((1)); else __PYX_ERR(0, 828, __pyx_L1_error)
        #endif
      }
      __pyx_L6:;

      /* "Cython/Tempita/_tempita.py":829
 *     else:
 *         assert 0, "Unexpected token %r at %s" % (first, pos)
 *     while 1:             # <<<<<<<<<<<<<<
 *         if not tokens:
 *             raise TemplateError(
*/
      while (1) {

        /* "Cython/Tempita/_tempita.py":830
 *         assert 0, "Unexpected token %r at %s" % (first, pos)
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'No {{endif}}',
*/
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_tokens); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 830, __pyx_L1_error)
        __pyx_t_10 = (!__pyx_t_8);
        if (unlikely(__pyx_t_10)) {

          /* "Cython/Tempita/_tempita.py":831
 *     while 1:
 *         if not tokens:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'No {{endif}}',
 *                 position=pos, name=name)
*/
          __pyx_t_4 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 831, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "Cython/Tempita/_tempita.py":833
 *             raise TemplateError(
 *                 'No {{endif}}',
 *                 position=pos, name=name)             # <<<<<<<<<<<<<<
 *         if (isinstance(tokens[0], tuple)
 *             and (tokens[0][0] == 'endif'
*/
          __pyx_t_7 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
            assert(__pyx_t_4);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
            __pyx_t_7 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_No_endif};
            __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 831, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 831, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 831, __pyx_L1_error)
            __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 831, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":830
 *         assert 0, "Unexpected token %r at %s" % (first, pos)
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'No {{endif}}',
*/
        }

        /* "Cython/Tempita/_tempita.py":834
 *                 'No {{endif}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *             and (tokens[0][0] == 'endif'
 *                  or tokens[0][0].startswith('elif ')
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 834, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyTuple_Check(__pyx_t_2); 
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_10 = __pyx_t_8;
          goto __pyx_L11_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":835
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)
 *             and (tokens[0][0] == 'endif'             # <<<<<<<<<<<<<<
 *                  or tokens[0][0].startswith('elif ')
 *                  or tokens[0][0] == 'else')):
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_endif, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 835, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (!__pyx_t_8) {
        } else {
          __pyx_t_10 = __pyx_t_8;
          goto __pyx_L11_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":836
 *         if (isinstance(tokens[0], tuple)
 *             and (tokens[0][0] == 'endif'
 *                  or tokens[0][0].startswith('elif ')             # <<<<<<<<<<<<<<
 *                  or tokens[0][0] == 'else')):
 *             return part, tokens
*/
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 836, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 836, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_2 = __pyx_t_4;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_elif};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 836, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 836, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (!__pyx_t_8) {
        } else {
          __pyx_t_10 = __pyx_t_8;
          goto __pyx_L11_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":837
 *             and (tokens[0][0] == 'endif'
 *                  or tokens[0][0].startswith('elif ')
 *                  or tokens[0][0] == 'else')):             # <<<<<<<<<<<<<<
 *             return part, tokens
 *         next_chunk, tokens = parse_expr(tokens, name, context)
*/
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 837, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 837, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 837, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_10 = __pyx_t_8;
        __pyx_L11_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":834
 *                 'No {{endif}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *             and (tokens[0][0] == 'endif'
 *                  or tokens[0][0].startswith('elif ')
*/
        if (__pyx_t_10) {

          /* "Cython/Tempita/_tempita.py":838
 *                  or tokens[0][0].startswith('elif ')
 *                  or tokens[0][0] == 'else')):
 *             return part, tokens             # <<<<<<<<<<<<<<
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)
*/
          __Pyx_XDECREF(__pyx_r);
          if (unlikely(!__pyx_v_part)) { __Pyx_RaiseUnboundLocalError("part"); __PYX_ERR(0, 838, __pyx_L1_error) }
          __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 838, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_v_part);
          __Pyx_GIVEREF(__pyx_v_part);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_part) != (0)) __PYX_ERR(0, 838, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_tokens);
          __Pyx_GIVEREF(__pyx_v_tokens);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_tokens) != (0)) __PYX_ERR(0, 838, __pyx_L1_error);
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L0;

          /* "Cython/Tempita/_tempita.py":834
 *                 'No {{endif}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *             and (tokens[0][0] == 'endif'
 *                  or tokens[0][0].startswith('elif ')
*/
        }

        /* "Cython/Tempita/_tempita.py":839
 *                  or tokens[0][0] == 'else')):
 *             return part, tokens
 *         next_chunk, tokens = parse_expr(tokens, name, context)             # <<<<<<<<<<<<<<
 *         content.append(next_chunk)
 * 
*/
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_parse_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 839, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_1);
          } else {
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 839, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
            __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_1);
          }
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 839, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
          index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          index = 1; __pyx_t_1 = __pyx_t_6(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 839, __pyx_L1_error)
          __pyx_t_6 = NULL;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L16_unpacking_done;
          __pyx_L15_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_6 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 839, __pyx_L1_error)
          __pyx_L16_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":840
 *             return part, tokens
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_content, __pyx_v_next_chunk); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 840, __pyx_L1_error)
      }

      /* "Cython/Tempita/_tempita.py":816
 * 
 * 
 * def parse_one_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []
*/

      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_one_cond", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_first);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XDECREF(__pyx_v_content);
      __Pyx_XDECREF(__pyx_v_part);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_v_tokens);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":843
 * 
 * 
 * def parse_for(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_23parse_for(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_23parse_for = {"parse_for", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_23parse_for, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_23parse_for(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_for (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 843, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 843, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 843, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 843, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_for", 0) < (0)) __PYX_ERR(0, 843, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_for", 1, 3, 3, i); __PYX_ERR(0, 843, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 843, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 843, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 843, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_for", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 843, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_22parse_for(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_22parse_for(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context) {
      PyObject *__pyx_v_first = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_v_content = NULL;
      PyObject *__pyx_v_match = NULL;
      PyObject *__pyx_v_vars = NULL;
      PyObject *__pyx_v_expr = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_8genexpr2__pyx_v_v = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *(*__pyx_t_5)(PyObject *);
      size_t __pyx_t_6;
      int __pyx_t_7;
      int __pyx_t_8;
      PyObject *__pyx_t_9 = NULL;
      Py_ssize_t __pyx_t_10;
      PyObject *(*__pyx_t_11)(PyObject *);
      int __pyx_t_12;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_for", 0);
      __Pyx_INCREF(__pyx_v_tokens);
      __Pyx_INCREF(__pyx_v_context);

      /* "Cython/Tempita/_tempita.py":844
 * 
 * def parse_for(tokens, name, context):
 *     first, pos = tokens[0]             # <<<<<<<<<<<<<<
 *     tokens = tokens[1:]
 *     context = ('for',) + context
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 844, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_3);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 844, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 844, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_first = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_pos = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":845
 * def parse_for(tokens, name, context):
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]             # <<<<<<<<<<<<<<
 *     context = ('for',) + context
 *     content = []
*/
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":846
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]
 *     context = ('for',) + context             # <<<<<<<<<<<<<<
 *     content = []
 *     assert first.startswith('for '), first
*/
      __pyx_t_1 = PyNumber_Add(__pyx_mstate_global->__pyx_tuple[4], __pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":847
 *     tokens = tokens[1:]
 *     context = ('for',) + context
 *     content = []             # <<<<<<<<<<<<<<
 *     assert first.startswith('for '), first
 *     if first.endswith(':'):
*/
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 847, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_content = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":848
 *     context = ('for',) + context
 *     content = []
 *     assert first.startswith('for '), first             # <<<<<<<<<<<<<<
 *     if first.endswith(':'):
 *         first = first[:-1]
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        __pyx_t_3 = __pyx_v_first;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_for_2};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 848, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) {
          __pyx_t_1 = PyTuple_Pack(1, __pyx_v_first); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_1, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 848, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 848, __pyx_L1_error)
      #endif

      /* "Cython/Tempita/_tempita.py":849
 *     content = []
 *     assert first.startswith('for '), first
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     first = first[3:].strip()
*/
      __pyx_t_3 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__8};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 849, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 849, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_7) {

        /* "Cython/Tempita/_tempita.py":850
 *     assert first.startswith('for '), first
 *     if first.endswith(':'):
 *         first = first[:-1]             # <<<<<<<<<<<<<<
 *     first = first[3:].strip()
 *     match = in_re.search(first)
*/
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":849
 *     content = []
 *     assert first.startswith('for '), first
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     first = first[3:].strip()
*/
      }

      /* "Cython/Tempita/_tempita.py":851
 *     if first.endswith(':'):
 *         first = first[:-1]
 *     first = first[3:].strip()             # <<<<<<<<<<<<<<
 *     match = in_re.search(first)
 *     if not match:
*/
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_first, 3, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[3], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 851, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":852
 *         first = first[:-1]
 *     first = first[3:].strip()
 *     match = in_re.search(first)             # <<<<<<<<<<<<<<
 *     if not match:
 *         raise TemplateError(
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_in_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 852, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 852, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_first};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_match = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":853
 *     first = first[3:].strip()
 *     match = in_re.search(first)
 *     if not match:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'Bad for (no "in") in %r' % first,
*/
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_match); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 853, __pyx_L1_error)
      __pyx_t_8 = (!__pyx_t_7);
      if (unlikely(__pyx_t_8)) {

        /* "Cython/Tempita/_tempita.py":854
 *     match = in_re.search(first)
 *     if not match:
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             'Bad for (no "in") in %r' % first,
 *             position=pos, name=name)
*/
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "Cython/Tempita/_tempita.py":855
 *     if not match:
 *         raise TemplateError(
 *             'Bad for (no "in") in %r' % first,             # <<<<<<<<<<<<<<
 *             position=pos, name=name)
 *     vars = first[:match.start()]
*/
        __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Bad_for_no_in_in_r, __pyx_v_first); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 855, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);

        /* "Cython/Tempita/_tempita.py":856
 *         raise TemplateError(
 *             'Bad for (no "in") in %r' % first,
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     vars = first[:match.start()]
 *     if '(' in vars:
*/
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_t_3};
          __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 854, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 854, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 854, __pyx_L1_error)
          __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 854, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":853
 *     first = first[3:].strip()
 *     match = in_re.search(first)
 *     if not match:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'Bad for (no "in") in %r' % first,
*/
      }

      /* "Cython/Tempita/_tempita.py":857
 *             'Bad for (no "in") in %r' % first,
 *             position=pos, name=name)
 *     vars = first[:match.start()]             # <<<<<<<<<<<<<<
 *     if '(' in vars:
 *         raise TemplateError(
*/
      __pyx_t_2 = __pyx_v_match;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, 0, NULL, &__pyx_t_1, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_vars = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":858
 *             position=pos, name=name)
 *     vars = first[:match.start()]
 *     if '(' in vars:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'You cannot have () in the variable section of a for loop (%r)'
*/
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__7, __pyx_v_vars, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 858, __pyx_L1_error)
      if (unlikely(__pyx_t_8)) {

        /* "Cython/Tempita/_tempita.py":859
 *     vars = first[:match.start()]
 *     if '(' in vars:
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             'You cannot have () in the variable section of a for loop (%r)'
 *             % vars, position=pos, name=name)
*/
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "Cython/Tempita/_tempita.py":861
 *         raise TemplateError(
 *             'You cannot have () in the variable section of a for loop (%r)'
 *             % vars, position=pos, name=name)             # <<<<<<<<<<<<<<
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')
*/
        __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_You_cannot_have_in_the_variable, __pyx_v_vars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 861, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_t_3};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 859, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 859, __pyx_L1_error)
          __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 859, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":858
 *             position=pos, name=name)
 *     vars = first[:match.start()]
 *     if '(' in vars:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             'You cannot have () in the variable section of a for loop (%r)'
*/
      }

      /* "Cython/Tempita/_tempita.py":862
 *             'You cannot have () in the variable section of a for loop (%r)'
 *             % vars, position=pos, name=name)
 *     vars = tuple([             # <<<<<<<<<<<<<<
 *         v.strip() for v in first[:match.start()].split(',')
 *         if v.strip()])
*/
      { /* enter inner scope */
        __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 862, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "Cython/Tempita/_tempita.py":863
 *             % vars, position=pos, name=name)
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')             # <<<<<<<<<<<<<<
 *         if v.strip()])
 *     expr = first[match.end():]
*/
        __pyx_t_1 = __pyx_v_match;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 863, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, 0, NULL, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = __pyx_t_1;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__15};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 863, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        if (likely(PyList_CheckExact(__pyx_t_9)) || PyTuple_CheckExact(__pyx_t_9)) {
          __pyx_t_1 = __pyx_t_9; __Pyx_INCREF(__pyx_t_1);
          __pyx_t_10 = 0;
          __pyx_t_11 = NULL;
        } else {
          __pyx_t_10 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 863, __pyx_L10_error)
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        for (;;) {
          if (likely(!__pyx_t_11)) {
            if (likely(PyList_CheckExact(__pyx_t_1))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 863, __pyx_L10_error)
                #endif
                if (__pyx_t_10 >= __pyx_temp) break;
              }
              __pyx_t_9 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_10;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 863, __pyx_L10_error)
                #endif
                if (__pyx_t_10 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_9 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_10));
              #else
              __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_10);
              #endif
              ++__pyx_t_10;
            }
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 863, __pyx_L10_error)
          } else {
            __pyx_t_9 = __pyx_t_11(__pyx_t_1);
            if (unlikely(!__pyx_t_9)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 863, __pyx_L10_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_v, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "Cython/Tempita/_tempita.py":864
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')
 *         if v.strip()])             # <<<<<<<<<<<<<<
 *     expr = first[match.end():]
 *     while 1:
*/
          __pyx_t_4 = __pyx_8genexpr2__pyx_v_v;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
            __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 864, __pyx_L10_error)
            __Pyx_GOTREF(__pyx_t_9);
          }
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 864, __pyx_L10_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_8) {

            /* "Cython/Tempita/_tempita.py":863
 *             % vars, position=pos, name=name)
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')             # <<<<<<<<<<<<<<
 *         if v.strip()])
 *     expr = first[match.end():]
*/
            __pyx_t_4 = __pyx_8genexpr2__pyx_v_v;
            __Pyx_INCREF(__pyx_t_4);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
              __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 863, __pyx_L10_error)
              __Pyx_GOTREF(__pyx_t_9);
            }
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_9))) __PYX_ERR(0, 862, __pyx_L10_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

            /* "Cython/Tempita/_tempita.py":864
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')
 *         if v.strip()])             # <<<<<<<<<<<<<<
 *     expr = first[match.end():]
 *     while 1:
*/
          }

          /* "Cython/Tempita/_tempita.py":863
 *             % vars, position=pos, name=name)
 *     vars = tuple([
 *         v.strip() for v in first[:match.start()].split(',')             # <<<<<<<<<<<<<<
 *         if v.strip()])
 *     expr = first[match.end():]
*/
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v); __pyx_8genexpr2__pyx_v_v = 0;
        goto __pyx_L15_exit_scope;
        __pyx_L10_error:;
        __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v); __pyx_8genexpr2__pyx_v_v = 0;
        goto __pyx_L1_error;
        __pyx_L15_exit_scope:;
      } /* exit inner scope */

      /* "Cython/Tempita/_tempita.py":862
 *             'You cannot have () in the variable section of a for loop (%r)'
 *             % vars, position=pos, name=name)
 *     vars = tuple([             # <<<<<<<<<<<<<<
 *         v.strip() for v in first[:match.start()].split(',')
 *         if v.strip()])
*/
      __pyx_t_1 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 862, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_vars, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":865
 *         v.strip() for v in first[:match.start()].split(',')
 *         if v.strip()])
 *     expr = first[match.end():]             # <<<<<<<<<<<<<<
 *     while 1:
 *         if not tokens:
*/
      __pyx_t_2 = __pyx_v_match;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_end, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, 0, &__pyx_t_1, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_expr = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":866
 *         if v.strip()])
 *     expr = first[match.end():]
 *     while 1:             # <<<<<<<<<<<<<<
 *         if not tokens:
 *             raise TemplateError(
*/
      while (1) {

        /* "Cython/Tempita/_tempita.py":867
 *     expr = first[match.end():]
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'No {{endfor}}',
*/
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_tokens); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 867, __pyx_L1_error)
        __pyx_t_7 = (!__pyx_t_8);
        if (unlikely(__pyx_t_7)) {

          /* "Cython/Tempita/_tempita.py":868
 *     while 1:
 *         if not tokens:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'No {{endfor}}',
 *                 position=pos, name=name)
*/
          __pyx_t_1 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 868, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);

          /* "Cython/Tempita/_tempita.py":870
 *             raise TemplateError(
 *                 'No {{endfor}}',
 *                 position=pos, name=name)             # <<<<<<<<<<<<<<
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endfor'):
*/
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_No_endfor};
            __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 868, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 868, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 868, __pyx_L1_error)
            __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 868, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 868, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":867
 *     expr = first[match.end():]
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'No {{endfor}}',
*/
        }

        /* "Cython/Tempita/_tempita.py":871
 *                 'No {{endfor}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endfor'):
 *             return ('for', pos, vars, expr, content), tokens[1:]
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 871, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyTuple_Check(__pyx_t_2); 
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L20_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":872
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endfor'):             # <<<<<<<<<<<<<<
 *             return ('for', pos, vars, expr, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 872, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 872, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_endfor, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 872, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_7 = __pyx_t_8;
        __pyx_L20_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":871
 *                 'No {{endfor}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endfor'):
 *             return ('for', pos, vars, expr, content), tokens[1:]
*/
        if (__pyx_t_7) {

          /* "Cython/Tempita/_tempita.py":873
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'endfor'):
 *             return ('for', pos, vars, expr, content), tokens[1:]             # <<<<<<<<<<<<<<
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)
*/
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 873, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_for);
          __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_for);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_mstate_global->__pyx_n_u_for) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_pos);
          __Pyx_GIVEREF(__pyx_v_pos);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_vars);
          __Pyx_GIVEREF(__pyx_v_vars);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_v_vars) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_expr);
          __Pyx_GIVEREF(__pyx_v_expr);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_v_expr) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_content);
          __Pyx_GIVEREF(__pyx_v_content);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_v_content) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 873, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 873, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_9);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_9) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __Pyx_GIVEREF(__pyx_t_2);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 873, __pyx_L1_error);
          __pyx_t_9 = 0;
          __pyx_t_2 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L0;

          /* "Cython/Tempita/_tempita.py":871
 *                 'No {{endfor}}',
 *                 position=pos, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'endfor'):
 *             return ('for', pos, vars, expr, content), tokens[1:]
*/
        }

        /* "Cython/Tempita/_tempita.py":874
 *                 and tokens[0][0] == 'endfor'):
 *             return ('for', pos, vars, expr, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)             # <<<<<<<<<<<<<<
 *         content.append(next_chunk)
 * 
*/
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_parse_expr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 874, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 874, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 874, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_2);
          } else {
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 874, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 874, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
          }
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 874, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 874, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
          index = 0; __pyx_t_9 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_9)) goto __pyx_L22_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L22_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < (0)) __PYX_ERR(0, 874, __pyx_L1_error)
          __pyx_t_5 = NULL;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L23_unpacking_done;
          __pyx_L22_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_5 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 874, __pyx_L1_error)
          __pyx_L23_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":875
 *             return ('for', pos, vars, expr, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_content, __pyx_v_next_chunk); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 875, __pyx_L1_error)
      }

      /* "Cython/Tempita/_tempita.py":843
 * 
 * 
 * def parse_for(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]
*/

      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_first);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XDECREF(__pyx_v_content);
      __Pyx_XDECREF(__pyx_v_match);
      __Pyx_XDECREF(__pyx_v_vars);
      __Pyx_XDECREF(__pyx_v_expr);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v);
      __Pyx_XDECREF(__pyx_v_tokens);
      __Pyx_XDECREF(__pyx_v_context);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":878
 * 
 * 
 * def parse_default(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_25parse_default(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_25parse_default = {"parse_default", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_25parse_default, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_25parse_default(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      CYTHON_UNUSED PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_default (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 878, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 878, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 878, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 878, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_default", 0) < (0)) __PYX_ERR(0, 878, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_default", 1, 3, 3, i); __PYX_ERR(0, 878, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 878, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 878, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 878, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_default", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 878, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_24parse_default(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_24parse_default(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_context) {
      PyObject *__pyx_v_first = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_v_parts = NULL;
      PyObject *__pyx_v_var = NULL;
      PyObject *__pyx_v_expr = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *(*__pyx_t_5)(PyObject *);
      size_t __pyx_t_6;
      int __pyx_t_7;
      Py_ssize_t __pyx_t_8;
      PyObject *__pyx_t_9 = NULL;
      int __pyx_t_10;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_default", 0);

      /* "Cython/Tempita/_tempita.py":879
 * 
 * def parse_default(tokens, name, context):
 *     first, pos = tokens[0]             # <<<<<<<<<<<<<<
 *     assert first.startswith('default ')
 *     first = first.split(None, 1)[1]
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 879, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_3);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 879, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 879, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 879, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 879, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 879, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 879, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 879, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_first = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_pos = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":880
 * def parse_default(tokens, name, context):
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')             # <<<<<<<<<<<<<<
 *     first = first.split(None, 1)[1]
 *     parts = first.split('=', 1)
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        __pyx_t_3 = __pyx_v_first;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_default_2};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 880, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) {
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
          __PYX_ERR(0, 880, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 880, __pyx_L1_error)
      #endif

      /* "Cython/Tempita/_tempita.py":881
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')
 *     first = first.split(None, 1)[1]             # <<<<<<<<<<<<<<
 *     parts = first.split('=', 1)
 *     if len(parts) == 1:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[5], NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":882
 *     assert first.startswith('default ')
 *     first = first.split(None, 1)[1]
 *     parts = first.split('=', 1)             # <<<<<<<<<<<<<<
 *     if len(parts) == 1:
 *         raise TemplateError(
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[6], NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_parts = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":883
 *     first = first.split(None, 1)[1]
 *     parts = first.split('=', 1)
 *     if len(parts) == 1:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "Expression must be {{default var=value}}; no = found in %r" % first,
*/
      __pyx_t_8 = PyObject_Length(__pyx_v_parts); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 883, __pyx_L1_error)
      __pyx_t_7 = (__pyx_t_8 == 1);
      if (unlikely(__pyx_t_7)) {

        /* "Cython/Tempita/_tempita.py":884
 *     parts = first.split('=', 1)
 *     if len(parts) == 1:
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             "Expression must be {{default var=value}}; no = found in %r" % first,
 *             position=pos, name=name)
*/
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 884, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "Cython/Tempita/_tempita.py":885
 *     if len(parts) == 1:
 *         raise TemplateError(
 *             "Expression must be {{default var=value}}; no = found in %r" % first,             # <<<<<<<<<<<<<<
 *             position=pos, name=name)
 *     var = parts[0].strip()
*/
        __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Expression_must_be_default_var_v, __pyx_v_first); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 885, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "Cython/Tempita/_tempita.py":886
 *         raise TemplateError(
 *             "Expression must be {{default var=value}}; no = found in %r" % first,
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     var = parts[0].strip()
 *     if ',' in var:
*/
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_t_4};
          __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 884, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 884, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 884, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 884, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 884, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":883
 *     first = first.split(None, 1)[1]
 *     parts = first.split('=', 1)
 *     if len(parts) == 1:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "Expression must be {{default var=value}}; no = found in %r" % first,
*/
      }

      /* "Cython/Tempita/_tempita.py":887
 *             "Expression must be {{default var=value}}; no = found in %r" % first,
 *             position=pos, name=name)
 *     var = parts[0].strip()             # <<<<<<<<<<<<<<
 *     if ',' in var:
 *         raise TemplateError(
*/
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_2 = __pyx_t_9;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 887, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_v_var = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":888
 *             position=pos, name=name)
 *     var = parts[0].strip()
 *     if ',' in var:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "{{default x, y = ...}} is not supported",
*/
      __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__15, __pyx_v_var, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 888, __pyx_L1_error)
      if (unlikely(__pyx_t_7)) {

        /* "Cython/Tempita/_tempita.py":889
 *     var = parts[0].strip()
 *     if ',' in var:
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             "{{default x, y = ...}} is not supported",
 *             position=pos, name=name)
*/
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 889, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "Cython/Tempita/_tempita.py":891
 *         raise TemplateError(
 *             "{{default x, y = ...}} is not supported",
 *             position=pos, name=name)             # <<<<<<<<<<<<<<
 *     if not var_re.search(var):
 *         raise TemplateError(
*/
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_mstate_global->__pyx_kp_u_default_x_y_is_not_supported};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 889, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 889, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 889, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 889, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 889, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":888
 *             position=pos, name=name)
 *     var = parts[0].strip()
 *     if ',' in var:             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "{{default x, y = ...}} is not supported",
*/
      }

      /* "Cython/Tempita/_tempita.py":892
 *             "{{default x, y = ...}} is not supported",
 *             position=pos, name=name)
 *     if not var_re.search(var):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "Not a valid variable name for {{default}}: %r"
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_var_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_var};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 892, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_10 = (!__pyx_t_7);
      if (unlikely(__pyx_t_10)) {

        /* "Cython/Tempita/_tempita.py":893
 *             position=pos, name=name)
 *     if not var_re.search(var):
 *         raise TemplateError(             # <<<<<<<<<<<<<<
 *             "Not a valid variable name for {{default}}: %r"
 *             % var, position=pos, name=name)
*/
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 893, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "Cython/Tempita/_tempita.py":895
 *         raise TemplateError(
 *             "Not a valid variable name for {{default}}: %r"
 *             % var, position=pos, name=name)             # <<<<<<<<<<<<<<
 *     expr = parts[1].strip()
 *     return ('default', pos, var, expr), tokens[1:]
*/
        __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Not_a_valid_variable_name_for_de, __pyx_v_var); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 895, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_t_4};
          __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 893, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 893, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 893, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":892
 *             "{{default x, y = ...}} is not supported",
 *             position=pos, name=name)
 *     if not var_re.search(var):             # <<<<<<<<<<<<<<
 *         raise TemplateError(
 *             "Not a valid variable name for {{default}}: %r"
*/
      }

      /* "Cython/Tempita/_tempita.py":896
 *             "Not a valid variable name for {{default}}: %r"
 *             % var, position=pos, name=name)
 *     expr = parts[1].strip()             # <<<<<<<<<<<<<<
 *     return ('default', pos, var, expr), tokens[1:]
 * 
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_parts, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 896, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_v_expr = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":897
 *             % var, position=pos, name=name)
 *     expr = parts[1].strip()
 *     return ('default', pos, var, expr), tokens[1:]             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_default);
      __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_default);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_mstate_global->__pyx_n_u_default) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_var);
      __Pyx_GIVEREF(__pyx_v_var);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_var) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_expr) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 897, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_1 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":878
 * 
 * 
 * def parse_default(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_first);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XDECREF(__pyx_v_parts);
      __Pyx_XDECREF(__pyx_v_var);
      __Pyx_XDECREF(__pyx_v_expr);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":900
 * 
 * 
 * def parse_inherit(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('inherit ')
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_27parse_inherit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_27parse_inherit = {"parse_inherit", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_27parse_inherit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_27parse_inherit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      CYTHON_UNUSED PyObject *__pyx_v_name = 0;
      CYTHON_UNUSED PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_inherit (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 900, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 900, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 900, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 900, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_inherit", 0) < (0)) __PYX_ERR(0, 900, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_inherit", 1, 3, 3, i); __PYX_ERR(0, 900, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 900, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 900, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 900, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_inherit", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 900, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_inherit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_26parse_inherit(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_26parse_inherit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_context) {
      PyObject *__pyx_v_first = NULL;
      PyObject *__pyx_v_pos = NULL;
      PyObject *__pyx_v_expr = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *(*__pyx_t_5)(PyObject *);
      size_t __pyx_t_6;
      int __pyx_t_7;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_inherit", 0);

      /* "Cython/Tempita/_tempita.py":901
 * 
 * def parse_inherit(tokens, name, context):
 *     first, pos = tokens[0]             # <<<<<<<<<<<<<<
 *     assert first.startswith('inherit ')
 *     expr = first.split(None, 1)[1]
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 901, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 901, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_3);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 901, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 901, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 901, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 901, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_first = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_pos = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":902
 * def parse_inherit(tokens, name, context):
 *     first, pos = tokens[0]
 *     assert first.startswith('inherit ')             # <<<<<<<<<<<<<<
 *     expr = first.split(None, 1)[1]
 *     return ('inherit', pos, expr), tokens[1:]
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        __pyx_t_3 = __pyx_v_first;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_inherit_3};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 902, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 902, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) {
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
          __PYX_ERR(0, 902, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 902, __pyx_L1_error)
      #endif

      /* "Cython/Tempita/_tempita.py":903
 *     first, pos = tokens[0]
 *     assert first.startswith('inherit ')
 *     expr = first.split(None, 1)[1]             # <<<<<<<<<<<<<<
 *     return ('inherit', pos, expr), tokens[1:]
 * 
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[5], NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_expr = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":904
 *     assert first.startswith('inherit ')
 *     expr = first.split(None, 1)[1]
 *     return ('inherit', pos, expr), tokens[1:]             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 904, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_inherit_2);
      __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_inherit_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_mstate_global->__pyx_n_u_inherit_2) != (0)) __PYX_ERR(0, 904, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 904, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_expr) != (0)) __PYX_ERR(0, 904, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 904, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 904, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 904, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 904, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":900
 * 
 * 
 * def parse_inherit(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('inherit ')
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_inherit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_first);
      __Pyx_XDECREF(__pyx_v_pos);
      __Pyx_XDECREF(__pyx_v_expr);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":907
 * 
 * 
 * def parse_def(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, start = tokens[0]
 *     tokens = tokens[1:]
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_29parse_def(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_29parse_def = {"parse_def", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_29parse_def, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_29parse_def(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_tokens = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_context = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_def (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tokens,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_context,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 907, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 907, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 907, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 907, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_def", 0) < (0)) __PYX_ERR(0, 907, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_def", 1, 3, 3, i); __PYX_ERR(0, 907, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 907, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 907, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 907, __pyx_L3_error)
        }
        __pyx_v_tokens = values[0];
        __pyx_v_name = values[1];
        __pyx_v_context = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_def", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 907, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_def", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_28parse_def(__pyx_self, __pyx_v_tokens, __pyx_v_name, __pyx_v_context);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_28parse_def(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tokens, PyObject *__pyx_v_name, PyObject *__pyx_v_context) {
      PyObject *__pyx_v_first = NULL;
      PyObject *__pyx_v_start = NULL;
      PyObject *__pyx_v_func_name = NULL;
      PyObject *__pyx_v_sig = NULL;
      PyObject *__pyx_v_sig_text = NULL;
      PyObject *__pyx_v_content = NULL;
      PyObject *__pyx_v_next_chunk = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *(*__pyx_t_5)(PyObject *);
      size_t __pyx_t_6;
      int __pyx_t_7;
      int __pyx_t_8;
      PyObject *__pyx_t_9 = NULL;
      int __pyx_t_10;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_def", 0);
      __Pyx_INCREF(__pyx_v_tokens);
      __Pyx_INCREF(__pyx_v_context);

      /* "Cython/Tempita/_tempita.py":908
 * 
 * def parse_def(tokens, name, context):
 *     first, start = tokens[0]             # <<<<<<<<<<<<<<
 *     tokens = tokens[1:]
 *     assert first.startswith('def ')
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 908, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 908, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_3);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_3);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 908, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 908, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_first = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_start = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Tempita/_tempita.py":909
 * def parse_def(tokens, name, context):
 *     first, start = tokens[0]
 *     tokens = tokens[1:]             # <<<<<<<<<<<<<<
 *     assert first.startswith('def ')
 *     first = first.split(None, 1)[1]
*/
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":910
 *     first, start = tokens[0]
 *     tokens = tokens[1:]
 *     assert first.startswith('def ')             # <<<<<<<<<<<<<<
 *     first = first.split(None, 1)[1]
 *     if first.endswith(':'):
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        __pyx_t_3 = __pyx_v_first;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_def_2};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 910, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) {
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
          __PYX_ERR(0, 910, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 910, __pyx_L1_error)
      #endif

      /* "Cython/Tempita/_tempita.py":911
 *     tokens = tokens[1:]
 *     assert first.startswith('def ')
 *     first = first.split(None, 1)[1]             # <<<<<<<<<<<<<<
 *     if first.endswith(':'):
 *         first = first[:-1]
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[5], NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":912
 *     assert first.startswith('def ')
 *     first = first.split(None, 1)[1]
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     if '(' not in first:
*/
      __pyx_t_3 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__8};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 912, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 912, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_7) {

        /* "Cython/Tempita/_tempita.py":913
 *     first = first.split(None, 1)[1]
 *     if first.endswith(':'):
 *         first = first[:-1]             # <<<<<<<<<<<<<<
 *     if '(' not in first:
 *         func_name = first
*/
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":912
 *     assert first.startswith('def ')
 *     first = first.split(None, 1)[1]
 *     if first.endswith(':'):             # <<<<<<<<<<<<<<
 *         first = first[:-1]
 *     if '(' not in first:
*/
      }

      /* "Cython/Tempita/_tempita.py":914
 *     if first.endswith(':'):
 *         first = first[:-1]
 *     if '(' not in first:             # <<<<<<<<<<<<<<
 *         func_name = first
 *         sig = ((), None, None, {})
*/
      __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__7, __pyx_v_first, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 914, __pyx_L1_error)
      if (__pyx_t_7) {

        /* "Cython/Tempita/_tempita.py":915
 *         first = first[:-1]
 *     if '(' not in first:
 *         func_name = first             # <<<<<<<<<<<<<<
 *         sig = ((), None, None, {})
 *     elif not first.endswith(')'):
*/
        __Pyx_INCREF(__pyx_v_first);
        __pyx_v_func_name = __pyx_v_first;

        /* "Cython/Tempita/_tempita.py":916
 *     if '(' not in first:
 *         func_name = first
 *         sig = ((), None, None, {})             # <<<<<<<<<<<<<<
 *     elif not first.endswith(')'):
 *         raise TemplateError("Function definition doesn't end with ): %s" % first,
*/
        __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
        __Pyx_GIVEREF(__pyx_mstate_global->__pyx_empty_tuple);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_mstate_global->__pyx_empty_tuple) != (0)) __PYX_ERR(0, 916, __pyx_L1_error);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, Py_None) != (0)) __PYX_ERR(0, 916, __pyx_L1_error);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None) != (0)) __PYX_ERR(0, 916, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_1) != (0)) __PYX_ERR(0, 916, __pyx_L1_error);
        __pyx_t_1 = 0;
        __pyx_v_sig = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":914
 *     if first.endswith(':'):
 *         first = first[:-1]
 *     if '(' not in first:             # <<<<<<<<<<<<<<
 *         func_name = first
 *         sig = ((), None, None, {})
*/
        goto __pyx_L6;
      }

      /* "Cython/Tempita/_tempita.py":917
 *         func_name = first
 *         sig = ((), None, None, {})
 *     elif not first.endswith(')'):             # <<<<<<<<<<<<<<
 *         raise TemplateError("Function definition doesn't end with ): %s" % first,
 *                             position=start, name=name)
*/
      __pyx_t_1 = __pyx_v_first;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__16};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 917, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 917, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = (!__pyx_t_7);
      if (unlikely(__pyx_t_8)) {

        /* "Cython/Tempita/_tempita.py":918
 *         sig = ((), None, None, {})
 *     elif not first.endswith(')'):
 *         raise TemplateError("Function definition doesn't end with ): %s" % first,             # <<<<<<<<<<<<<<
 *                             position=start, name=name)
 *     else:
*/
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 918, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Function_definition_doesn_t_end, __pyx_v_first); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 918, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "Cython/Tempita/_tempita.py":919
 *     elif not first.endswith(')'):
 *         raise TemplateError("Function definition doesn't end with ): %s" % first,
 *                             position=start, name=name)             # <<<<<<<<<<<<<<
 *     else:
 *         first = first[:-1]
*/
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_t_4};
          __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 918, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_start, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 918, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 918, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 918, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 918, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":917
 *         func_name = first
 *         sig = ((), None, None, {})
 *     elif not first.endswith(')'):             # <<<<<<<<<<<<<<
 *         raise TemplateError("Function definition doesn't end with ): %s" % first,
 *                             position=start, name=name)
*/
      }

      /* "Cython/Tempita/_tempita.py":921
 *                             position=start, name=name)
 *     else:
 *         first = first[:-1]             # <<<<<<<<<<<<<<
 *         func_name, sig_text = first.split('(', 1)
 *         sig = parse_signature(sig_text, name, start)
*/
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_first, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 921, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF_SET(__pyx_v_first, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":922
 *     else:
 *         first = first[:-1]
 *         func_name, sig_text = first.split('(', 1)             # <<<<<<<<<<<<<<
 *         sig = parse_signature(sig_text, name, start)
 *     context = context + ('def',)
*/
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_first, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 922, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_mstate_global->__pyx_tuple[7], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 922, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
          PyObject* sequence = __pyx_t_2;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 922, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_9);
          } else {
            __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 922, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_3);
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 922, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_9);
          }
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 922, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 922, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 922, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
          index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L7_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          index = 1; __pyx_t_9 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_9)) goto __pyx_L7_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 922, __pyx_L1_error)
          __pyx_t_5 = NULL;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_unpacking_done;
          __pyx_L7_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_5 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 922, __pyx_L1_error)
          __pyx_L8_unpacking_done:;
        }
        __pyx_v_func_name = __pyx_t_3;
        __pyx_t_3 = 0;
        __pyx_v_sig_text = __pyx_t_9;
        __pyx_t_9 = 0;

        /* "Cython/Tempita/_tempita.py":923
 *         first = first[:-1]
 *         func_name, sig_text = first.split('(', 1)
 *         sig = parse_signature(sig_text, name, start)             # <<<<<<<<<<<<<<
 *     context = context + ('def',)
 *     content = []
*/
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_parse_signature_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 923, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_v_sig_text, __pyx_v_name, __pyx_v_start};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 923, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_v_sig = __pyx_t_2;
        __pyx_t_2 = 0;
      }
      __pyx_L6:;

      /* "Cython/Tempita/_tempita.py":924
 *         func_name, sig_text = first.split('(', 1)
 *         sig = parse_signature(sig_text, name, start)
 *     context = context + ('def',)             # <<<<<<<<<<<<<<
 *     content = []
 *     while 1:
*/
      __pyx_t_2 = PyNumber_Add(__pyx_v_context, __pyx_mstate_global->__pyx_tuple[8]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 924, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":925
 *         sig = parse_signature(sig_text, name, start)
 *     context = context + ('def',)
 *     content = []             # <<<<<<<<<<<<<<
 *     while 1:
 *         if not tokens:
*/
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 925, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_content = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":926
 *     context = context + ('def',)
 *     content = []
 *     while 1:             # <<<<<<<<<<<<<<
 *         if not tokens:
 *             raise TemplateError(
*/
      while (1) {

        /* "Cython/Tempita/_tempita.py":927
 *     content = []
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'Missing {{enddef}}',
*/
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_tokens); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 927, __pyx_L1_error)
        __pyx_t_7 = (!__pyx_t_8);
        if (unlikely(__pyx_t_7)) {

          /* "Cython/Tempita/_tempita.py":928
 *     while 1:
 *         if not tokens:
 *             raise TemplateError(             # <<<<<<<<<<<<<<
 *                 'Missing {{enddef}}',
 *                 position=start, name=name)
*/
          __pyx_t_3 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 928, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);

          /* "Cython/Tempita/_tempita.py":930
 *             raise TemplateError(
 *                 'Missing {{enddef}}',
 *                 position=start, name=name)             # <<<<<<<<<<<<<<
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'enddef'):
*/
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Missing_enddef};
            __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 928, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_start, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 928, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 928, __pyx_L1_error)
            __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 928, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 928, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":927
 *     content = []
 *     while 1:
 *         if not tokens:             # <<<<<<<<<<<<<<
 *             raise TemplateError(
 *                 'Missing {{enddef}}',
*/
        }

        /* "Cython/Tempita/_tempita.py":931
 *                 'Missing {{enddef}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'enddef'):
 *             return ('def', start, func_name, sig, content), tokens[1:]
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 931, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = PyTuple_Check(__pyx_t_2); 
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L13_bool_binop_done;
        }

        /* "Cython/Tempita/_tempita.py":932
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'enddef'):             # <<<<<<<<<<<<<<
 *             return ('def', start, func_name, sig, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)
*/
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 932, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 932, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_enddef, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 932, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_7 = __pyx_t_8;
        __pyx_L13_bool_binop_done:;

        /* "Cython/Tempita/_tempita.py":931
 *                 'Missing {{enddef}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'enddef'):
 *             return ('def', start, func_name, sig, content), tokens[1:]
*/
        if (__pyx_t_7) {

          /* "Cython/Tempita/_tempita.py":933
 *         if (isinstance(tokens[0], tuple)
 *                 and tokens[0][0] == 'enddef'):
 *             return ('def', start, func_name, sig, content), tokens[1:]             # <<<<<<<<<<<<<<
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)
*/
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 933, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_def);
          __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_def);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_mstate_global->__pyx_n_u_def) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_start);
          __Pyx_GIVEREF(__pyx_v_start);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_start) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_func_name);
          __Pyx_GIVEREF(__pyx_v_func_name);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_v_func_name) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_sig);
          __Pyx_GIVEREF(__pyx_v_sig);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_v_sig) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __Pyx_INCREF(__pyx_v_content);
          __Pyx_GIVEREF(__pyx_v_content);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_v_content) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 933, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 933, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_9);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_9) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __Pyx_GIVEREF(__pyx_t_2);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 933, __pyx_L1_error);
          __pyx_t_9 = 0;
          __pyx_t_2 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L0;

          /* "Cython/Tempita/_tempita.py":931
 *                 'Missing {{enddef}}',
 *                 position=start, name=name)
 *         if (isinstance(tokens[0], tuple)             # <<<<<<<<<<<<<<
 *                 and tokens[0][0] == 'enddef'):
 *             return ('def', start, func_name, sig, content), tokens[1:]
*/
        }

        /* "Cython/Tempita/_tempita.py":934
 *                 and tokens[0][0] == 'enddef'):
 *             return ('def', start, func_name, sig, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)             # <<<<<<<<<<<<<<
 *         content.append(next_chunk)
 * 
*/
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_parse_expr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 934, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_tokens, __pyx_v_name, __pyx_v_context};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 934, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_2);
          } else {
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 934, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
          }
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 934, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
          index = 0; __pyx_t_9 = __pyx_t_5(__pyx_t_3); if (unlikely(!__pyx_t_9)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 934, __pyx_L1_error)
          __pyx_t_5 = NULL;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L16_unpacking_done;
          __pyx_L15_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_5 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 934, __pyx_L1_error)
          __pyx_L16_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_next_chunk, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Tempita/_tempita.py":935
 *             return ('def', start, func_name, sig, content), tokens[1:]
 *         next_chunk, tokens = parse_expr(tokens, name, context)
 *         content.append(next_chunk)             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_content, __pyx_v_next_chunk); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 935, __pyx_L1_error)
      }

      /* "Cython/Tempita/_tempita.py":907
 * 
 * 
 * def parse_def(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, start = tokens[0]
 *     tokens = tokens[1:]
*/

      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_def", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_first);
      __Pyx_XDECREF(__pyx_v_start);
      __Pyx_XDECREF(__pyx_v_func_name);
      __Pyx_XDECREF(__pyx_v_sig);
      __Pyx_XDECREF(__pyx_v_sig_text);
      __Pyx_XDECREF(__pyx_v_content);
      __Pyx_XDECREF(__pyx_v_next_chunk);
      __Pyx_XDECREF(__pyx_v_tokens);
      __Pyx_XDECREF(__pyx_v_context);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":938
 * 
 * 
 * def parse_signature(sig_text, name, pos):             # <<<<<<<<<<<<<<
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_31parse_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_31parse_signature = {"parse_signature", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_31parse_signature, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_31parse_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_sig_text = 0;
      PyObject *__pyx_v_name = 0;
      PyObject *__pyx_v_pos = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("parse_signature (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_sig_text,&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_pos,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 938, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 938, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 938, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 938, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_signature", 0) < (0)) __PYX_ERR(0, 938, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_signature", 1, 3, 3, i); __PYX_ERR(0, 938, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 938, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 938, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 938, __pyx_L3_error)
        }
        __pyx_v_sig_text = values[0];
        __pyx_v_name = values[1];
        __pyx_v_pos = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("parse_signature", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 938, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_30parse_signature(__pyx_self, __pyx_v_sig_text, __pyx_v_name, __pyx_v_pos);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":945
 *     defaults = {}
 * 
 *     def get_token(pos=False):             # <<<<<<<<<<<<<<
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_15parse_signature_1get_token(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_15parse_signature_1get_token = {"get_token", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_15parse_signature_1get_token, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_15parse_signature_1get_token(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_pos = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[1] = {0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("get_token (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pos,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 945, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 945, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_token", 0) < (0)) __PYX_ERR(0, 945, __pyx_L3_error)
          if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
        } else {
          switch (__pyx_nargs) {
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 945, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_False)));
        }
        __pyx_v_pos = values[0];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("get_token", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 945, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_signature.get_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_15parse_signature_get_token(__pyx_self, __pyx_v_pos);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_15parse_signature_get_token(PyObject *__pyx_self, PyObject *__pyx_v_pos) {
      struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *__pyx_cur_scope;
      struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *__pyx_outer_scope;
      PyObject *__pyx_v_tok_type = NULL;
      PyObject *__pyx_v_tok_string = NULL;
      PyObject *__pyx_v_srow = NULL;
      PyObject *__pyx_v_scol = NULL;
      PyObject *__pyx_v_erow = NULL;
      PyObject *__pyx_v_ecol = NULL;
      CYTHON_UNUSED PyObject *__pyx_v_line = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      PyObject *__pyx_t_6 = NULL;
      PyObject *__pyx_t_7 = NULL;
      PyObject *__pyx_t_8 = NULL;
      PyObject *__pyx_t_9 = NULL;
      PyObject *__pyx_t_10 = NULL;
      PyObject *(*__pyx_t_11)(PyObject *);
      PyObject *__pyx_t_12 = NULL;
      PyObject *__pyx_t_13 = NULL;
      int __pyx_t_14;
      int __pyx_t_15;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("get_token", 0);
      __pyx_outer_scope = (struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *) __Pyx_CyFunction_GetClosure(__pyx_self);
      __pyx_cur_scope = __pyx_outer_scope;

      /* "Cython/Tempita/_tempita.py":946
 * 
 *     def get_token(pos=False):
 *         try:             # <<<<<<<<<<<<<<
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
 *         except StopIteration:
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        /*try:*/ {

          /* "Cython/Tempita/_tempita.py":947
 *     def get_token(pos=False):
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)             # <<<<<<<<<<<<<<
 *         except StopIteration:
 *             return tokenize.ENDMARKER, ''
*/
          if (unlikely(!__pyx_cur_scope->__pyx_v_tokens)) { __Pyx_RaiseClosureNameError("tokens"); __PYX_ERR(0, 947, __pyx_L3_error) }
          __pyx_t_4 = __pyx_cur_scope->__pyx_v_tokens;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyIter_Next(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 947, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
            PyObject* sequence = __pyx_t_5;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 5)) {
              if (size > 5) __Pyx_RaiseTooManyValuesError(5);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 947, __pyx_L3_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
              __Pyx_INCREF(__pyx_t_4);
              __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
              __Pyx_INCREF(__pyx_t_6);
              __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2);
              __Pyx_INCREF(__pyx_t_7);
              __pyx_t_8 = PyTuple_GET_ITEM(sequence, 3);
              __Pyx_INCREF(__pyx_t_8);
              __pyx_t_9 = PyTuple_GET_ITEM(sequence, 4);
              __Pyx_INCREF(__pyx_t_9);
            } else {
              __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_4);
              __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_7);
              __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 3, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_8);
              __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 4, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_9);
            }
            #else
            {
              Py_ssize_t i;
              PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_6,&__pyx_t_7,&__pyx_t_8,&__pyx_t_9};
              for (i=0; i < 5; i++) {
                PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 947, __pyx_L3_error)
                __Pyx_GOTREF(item);
                *(temps[i]) = item;
              }
            }
            #endif
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else {
            Py_ssize_t index = -1;
            PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_6,&__pyx_t_7,&__pyx_t_8,&__pyx_t_9};
            __pyx_t_10 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
            for (index=0; index < 5; index++) {
              PyObject* item = __pyx_t_11(__pyx_t_10); if (unlikely(!item)) goto __pyx_L9_unpacking_failed;
              __Pyx_GOTREF(item);
              *(temps[index]) = item;
            }
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 5) < (0)) __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_t_11 = NULL;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            goto __pyx_L10_unpacking_done;
            __pyx_L9_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_11 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_L10_unpacking_done:;
          }
          __pyx_v_tok_type = __pyx_t_4;
          __pyx_t_4 = 0;
          __pyx_v_tok_string = __pyx_t_6;
          __pyx_t_6 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
            PyObject* sequence = __pyx_t_7;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 947, __pyx_L3_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0);
              __Pyx_INCREF(__pyx_t_10);
              __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1);
              __Pyx_INCREF(__pyx_t_12);
            } else {
              __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_10);
              __pyx_t_12 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_12);
            }
            #else
            __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_12 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_12);
            #endif
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_13 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
            index = 0; __pyx_t_10 = __pyx_t_11(__pyx_t_13); if (unlikely(!__pyx_t_10)) goto __pyx_L11_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_10);
            index = 1; __pyx_t_12 = __pyx_t_11(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L11_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_12);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_13), 2) < (0)) __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_t_11 = NULL;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L12_unpacking_done;
            __pyx_L11_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_11 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_L12_unpacking_done:;
          }
          __pyx_v_srow = __pyx_t_10;
          __pyx_t_10 = 0;
          __pyx_v_scol = __pyx_t_12;
          __pyx_t_12 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
            PyObject* sequence = __pyx_t_8;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 947, __pyx_L3_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0);
              __Pyx_INCREF(__pyx_t_12);
              __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
              __Pyx_INCREF(__pyx_t_10);
            } else {
              __pyx_t_12 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_12);
              __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 947, __pyx_L3_error)
              __Pyx_XGOTREF(__pyx_t_10);
            }
            #else
            __pyx_t_12 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            #endif
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_13 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 947, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
            index = 0; __pyx_t_12 = __pyx_t_11(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L13_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_12);
            index = 1; __pyx_t_10 = __pyx_t_11(__pyx_t_13); if (unlikely(!__pyx_t_10)) goto __pyx_L13_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_10);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_13), 2) < (0)) __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_t_11 = NULL;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L14_unpacking_done;
            __pyx_L13_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_11 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 947, __pyx_L3_error)
            __pyx_L14_unpacking_done:;
          }
          __pyx_v_erow = __pyx_t_12;
          __pyx_t_12 = 0;
          __pyx_v_ecol = __pyx_t_10;
          __pyx_t_10 = 0;
          __pyx_v_line = __pyx_t_9;
          __pyx_t_9 = 0;

          /* "Cython/Tempita/_tempita.py":946
 * 
 *     def get_token(pos=False):
 *         try:             # <<<<<<<<<<<<<<
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
 *         except StopIteration:
*/
        }
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L8_try_end;
        __pyx_L3_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "Cython/Tempita/_tempita.py":948
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
 *         except StopIteration:             # <<<<<<<<<<<<<<
 *             return tokenize.ENDMARKER, ''
 *         if pos:
*/
        __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_StopIteration))));
        if (__pyx_t_14) {
          __Pyx_AddTraceback("Cython.Tempita._tempita.parse_signature.get_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 948, __pyx_L5_except_error)
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);

          /* "Cython/Tempita/_tempita.py":949
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
 *         except StopIteration:
 *             return tokenize.ENDMARKER, ''             # <<<<<<<<<<<<<<
 *         if pos:
 *             return tok_type, tok_string, (srow, scol), (erow, ecol)
*/
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 949, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 949, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 949, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6) != (0)) __PYX_ERR(0, 949, __pyx_L5_except_error);
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__4);
          __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_u__4);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_mstate_global->__pyx_kp_u__4) != (0)) __PYX_ERR(0, 949, __pyx_L5_except_error);
          __pyx_t_6 = 0;
          __pyx_r = __pyx_t_7;
          __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L6_except_return;
        }
        goto __pyx_L5_except_error;

        /* "Cython/Tempita/_tempita.py":946
 * 
 *     def get_token(pos=False):
 *         try:             # <<<<<<<<<<<<<<
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
 *         except StopIteration:
*/
        __pyx_L5_except_error:;
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
        goto __pyx_L1_error;
        __pyx_L6_except_return:;
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
        goto __pyx_L0;
        __pyx_L8_try_end:;
      }

      /* "Cython/Tempita/_tempita.py":950
 *         except StopIteration:
 *             return tokenize.ENDMARKER, ''
 *         if pos:             # <<<<<<<<<<<<<<
 *             return tok_type, tok_string, (srow, scol), (erow, ecol)
 *         else:
*/
      __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_pos); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 950, __pyx_L1_error)
      if (__pyx_t_15) {

        /* "Cython/Tempita/_tempita.py":951
 *             return tokenize.ENDMARKER, ''
 *         if pos:
 *             return tok_type, tok_string, (srow, scol), (erow, ecol)             # <<<<<<<<<<<<<<
 *         else:
 *             return tok_type, tok_string
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 951, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_srow);
        __Pyx_GIVEREF(__pyx_v_srow);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_srow) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_scol);
        __Pyx_GIVEREF(__pyx_v_scol);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_scol) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 951, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_erow);
        __Pyx_GIVEREF(__pyx_v_erow);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_erow) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_ecol);
        __Pyx_GIVEREF(__pyx_v_ecol);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_ecol) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 951, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_tok_type);
        __Pyx_GIVEREF(__pyx_v_tok_type);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tok_type) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_tok_string);
        __Pyx_GIVEREF(__pyx_v_tok_string);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_tok_string) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_8);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_8) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_9);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_9) != (0)) __PYX_ERR(0, 951, __pyx_L1_error);
        __pyx_t_8 = 0;
        __pyx_t_9 = 0;
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":950
 *         except StopIteration:
 *             return tokenize.ENDMARKER, ''
 *         if pos:             # <<<<<<<<<<<<<<
 *             return tok_type, tok_string, (srow, scol), (erow, ecol)
 *         else:
*/
      }

      /* "Cython/Tempita/_tempita.py":953
 *             return tok_type, tok_string, (srow, scol), (erow, ecol)
 *         else:
 *             return tok_type, tok_string             # <<<<<<<<<<<<<<
 *     while 1:
 *         var_arg_type = None
*/
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 953, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_tok_type);
        __Pyx_GIVEREF(__pyx_v_tok_type);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_tok_type) != (0)) __PYX_ERR(0, 953, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_tok_string);
        __Pyx_GIVEREF(__pyx_v_tok_string);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_tok_string) != (0)) __PYX_ERR(0, 953, __pyx_L1_error);
        __pyx_r = __pyx_t_5;
        __pyx_t_5 = 0;
        goto __pyx_L0;
      }

      /* "Cython/Tempita/_tempita.py":945
 *     defaults = {}
 * 
 *     def get_token(pos=False):             # <<<<<<<<<<<<<<
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_13);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_signature.get_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_tok_type);
      __Pyx_XDECREF(__pyx_v_tok_string);
      __Pyx_XDECREF(__pyx_v_srow);
      __Pyx_XDECREF(__pyx_v_scol);
      __Pyx_XDECREF(__pyx_v_erow);
      __Pyx_XDECREF(__pyx_v_ecol);
      __Pyx_XDECREF(__pyx_v_line);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":938
 * 
 * 
 * def parse_signature(sig_text, name, pos):             # <<<<<<<<<<<<<<
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
*/

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_30parse_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sig_text, PyObject *__pyx_v_name, PyObject *__pyx_v_pos) {
      struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *__pyx_cur_scope;
      PyObject *__pyx_v_sig_args = NULL;
      PyObject *__pyx_v_var_arg = NULL;
      PyObject *__pyx_v_var_kw = NULL;
      PyObject *__pyx_v_defaults = NULL;
      PyObject *__pyx_v_get_token = 0;
      PyObject *__pyx_v_var_arg_type = NULL;
      PyObject *__pyx_v_tok_type = NULL;
      PyObject *__pyx_v_tok_string = NULL;
      PyObject *__pyx_v_var_name = NULL;
      PyObject *__pyx_v_nest_type = NULL;
      PyObject *__pyx_v_unnest_type = NULL;
      PyObject *__pyx_v_nest_count = NULL;
      PyObject *__pyx_v_start_pos = NULL;
      PyObject *__pyx_v_end_pos = NULL;
      PyObject *__pyx_v_parts = NULL;
      PyObject *__pyx_v_s = NULL;
      PyObject *__pyx_v_e = NULL;
      PyObject *__pyx_v_default_expr = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      PyObject *__pyx_t_6 = NULL;
      size_t __pyx_t_7;
      PyObject *(*__pyx_t_8)(PyObject *);
      int __pyx_t_9;
      int __pyx_t_10;
      int __pyx_t_11;
      int __pyx_t_12;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("parse_signature", 0);
      __pyx_cur_scope = (struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(__pyx_mstate_global->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, __pyx_mstate_global->__pyx_empty_tuple, NULL);
      if (unlikely(!__pyx_cur_scope)) {
        __pyx_cur_scope = ((struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)Py_None);
        __Pyx_INCREF(Py_None);
        __PYX_ERR(0, 938, __pyx_L1_error)
      } else {
        __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
      }

      /* "Cython/Tempita/_tempita.py":939
 * 
 * def parse_signature(sig_text, name, pos):
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)             # <<<<<<<<<<<<<<
 *     sig_args = []
 *     var_arg = None
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_generate_tokens); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_StringIO); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_sig_text};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_readline); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 939, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_v_tokens = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":940
 * def parse_signature(sig_text, name, pos):
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []             # <<<<<<<<<<<<<<
 *     var_arg = None
 *     var_kw = None
*/
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 940, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_sig_args = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":941
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
 *     var_arg = None             # <<<<<<<<<<<<<<
 *     var_kw = None
 *     defaults = {}
*/
      __Pyx_INCREF(Py_None);
      __pyx_v_var_arg = Py_None;

      /* "Cython/Tempita/_tempita.py":942
 *     sig_args = []
 *     var_arg = None
 *     var_kw = None             # <<<<<<<<<<<<<<
 *     defaults = {}
 * 
*/
      __Pyx_INCREF(Py_None);
      __pyx_v_var_kw = Py_None;

      /* "Cython/Tempita/_tempita.py":943
 *     var_arg = None
 *     var_kw = None
 *     defaults = {}             # <<<<<<<<<<<<<<
 * 
 *     def get_token(pos=False):
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 943, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_defaults = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":945
 *     defaults = {}
 * 
 *     def get_token(pos=False):             # <<<<<<<<<<<<<<
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
*/
      __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_15parse_signature_1get_token, 0, __pyx_mstate_global->__pyx_n_u_parse_signature_locals_get_token, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[9]);
      __pyx_v_get_token = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":954
 *         else:
 *             return tok_type, tok_string
 *     while 1:             # <<<<<<<<<<<<<<
 *         var_arg_type = None
 *         tok_type, tok_string = get_token()
*/
      while (1) {

        /* "Cython/Tempita/_tempita.py":955
 *             return tok_type, tok_string
 *     while 1:
 *         var_arg_type = None             # <<<<<<<<<<<<<<
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER:
*/
        __Pyx_INCREF(Py_None);
        __Pyx_XDECREF_SET(__pyx_v_var_arg_type, Py_None);

        /* "Cython/Tempita/_tempita.py":956
 *     while 1:
 *         var_arg_type = None
 *         tok_type, tok_string = get_token()             # <<<<<<<<<<<<<<
 *         if tok_type == tokenize.ENDMARKER:
 *             break
*/
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_v_get_token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 956, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 956, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_4);
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_6);
          } else {
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 956, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_4);
            __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 956, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_6);
          }
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 956, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 956, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 956, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_4);
          index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_2), 2) < (0)) __PYX_ERR(0, 956, __pyx_L1_error)
          __pyx_t_8 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L6_unpacking_done;
          __pyx_L5_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_8 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 956, __pyx_L1_error)
          __pyx_L6_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_tok_type, __pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tok_string, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Tempita/_tempita.py":957
 *         var_arg_type = None
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER:             # <<<<<<<<<<<<<<
 *             break
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 957, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 957, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 957, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 957, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_9) {

          /* "Cython/Tempita/_tempita.py":958
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER:
 *             break             # <<<<<<<<<<<<<<
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):
 *             var_arg_type = tok_string
*/
          goto __pyx_L4_break;

          /* "Cython/Tempita/_tempita.py":957
 *         var_arg_type = None
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER:             # <<<<<<<<<<<<<<
 *             break
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):
*/
        }

        /* "Cython/Tempita/_tempita.py":959
 *         if tok_type == tokenize.ENDMARKER:
 *             break
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):             # <<<<<<<<<<<<<<
 *             var_arg_type = tok_string
 *             tok_type, tok_string = get_token()
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 959, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L9_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_tok_string, __pyx_mstate_global->__pyx_kp_u__17, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 959, __pyx_L1_error)
        if (!__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L9_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_tok_string, __pyx_mstate_global->__pyx_kp_u__18, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 959, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_10;
        __pyx_L9_bool_binop_done:;
        if (__pyx_t_9) {

          /* "Cython/Tempita/_tempita.py":960
 *             break
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):
 *             var_arg_type = tok_string             # <<<<<<<<<<<<<<
 *             tok_type, tok_string = get_token()
 *         if tok_type != tokenize.NAME:
*/
          __Pyx_INCREF(__pyx_v_tok_string);
          __Pyx_DECREF_SET(__pyx_v_var_arg_type, __pyx_v_tok_string);

          /* "Cython/Tempita/_tempita.py":961
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):
 *             var_arg_type = tok_string
 *             tok_type, tok_string = get_token()             # <<<<<<<<<<<<<<
 *         if tok_type != tokenize.NAME:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
*/
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_v_get_token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 961, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
            PyObject* sequence = __pyx_t_1;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 961, __pyx_L1_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
              __Pyx_INCREF(__pyx_t_6);
              __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
              __Pyx_INCREF(__pyx_t_4);
            } else {
              __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 961, __pyx_L1_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 961, __pyx_L1_error)
              __Pyx_XGOTREF(__pyx_t_4);
            }
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 961, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 961, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 961, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
            index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_6)) goto __pyx_L12_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_6);
            index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_4)) goto __pyx_L12_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_2), 2) < (0)) __PYX_ERR(0, 961, __pyx_L1_error)
            __pyx_t_8 = NULL;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            goto __pyx_L13_unpacking_done;
            __pyx_L12_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_8 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 961, __pyx_L1_error)
            __pyx_L13_unpacking_done:;
          }
          __Pyx_DECREF_SET(__pyx_v_tok_type, __pyx_t_6);
          __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_tok_string, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Tempita/_tempita.py":959
 *         if tok_type == tokenize.ENDMARKER:
 *             break
 *         if tok_type == tokenize.OP and (tok_string == '*' or tok_string == '**'):             # <<<<<<<<<<<<<<
 *             var_arg_type = tok_string
 *             tok_type, tok_string = get_token()
*/
        }

        /* "Cython/Tempita/_tempita.py":962
 *             var_arg_type = tok_string
 *             tok_type, tok_string = get_token()
 *         if tok_type != tokenize.NAME:             # <<<<<<<<<<<<<<
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_NAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(__pyx_t_9)) {

          /* "Cython/Tempita/_tempita.py":963
 *             tok_type, tok_string = get_token()
 *         if tok_type != tokenize.NAME:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,             # <<<<<<<<<<<<<<
 *                                 position=pos, name=name)
 *         var_name = tok_string
*/
          __pyx_t_4 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 963, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Invalid_signature_s, __pyx_v_sig_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 963, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);

          /* "Cython/Tempita/_tempita.py":964
 *         if tok_type != tokenize.NAME:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)             # <<<<<<<<<<<<<<
 *         var_name = tok_string
 *         tok_type, tok_string = get_token()
*/
          __pyx_t_7 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
            assert(__pyx_t_4);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
            __pyx_t_7 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_t_2};
            __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 963, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 963, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 963, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 963, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":962
 *             var_arg_type = tok_string
 *             tok_type, tok_string = get_token()
 *         if tok_type != tokenize.NAME:             # <<<<<<<<<<<<<<
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
*/
        }

        /* "Cython/Tempita/_tempita.py":965
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
 *         var_name = tok_string             # <<<<<<<<<<<<<<
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):
*/
        __Pyx_INCREF(__pyx_v_tok_string);
        __Pyx_XDECREF_SET(__pyx_v_var_name, __pyx_v_tok_string);

        /* "Cython/Tempita/_tempita.py":966
 *                                 position=pos, name=name)
 *         var_name = tok_string
 *         tok_type, tok_string = get_token()             # <<<<<<<<<<<<<<
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):
 *             if var_arg_type == '*':
*/
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_v_get_token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 966, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_6);
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_3);
          } else {
            __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_6);
            __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 966, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_3);
          }
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 966, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 966, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_6)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_3 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_3)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_2), 2) < (0)) __PYX_ERR(0, 966, __pyx_L1_error)
          __pyx_t_8 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L16_unpacking_done;
          __pyx_L15_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_8 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 966, __pyx_L1_error)
          __pyx_L16_unpacking_done:;
        }
        __Pyx_DECREF_SET(__pyx_v_tok_type, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_tok_string, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Tempita/_tempita.py":967
 *         var_name = tok_string
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):             # <<<<<<<<<<<<<<
 *             if var_arg_type == '*':
 *                 var_arg = var_name
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (!__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L18_bool_binop_done;
        }
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L18_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_tok_string, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_10;
        __pyx_L18_bool_binop_done:;
        if (__pyx_t_9) {

          /* "Cython/Tempita/_tempita.py":968
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):
 *             if var_arg_type == '*':             # <<<<<<<<<<<<<<
 *                 var_arg = var_name
 *             elif var_arg_type == '**':
*/
          __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_var_arg_type, __pyx_mstate_global->__pyx_kp_u__17, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
          if (__pyx_t_9) {

            /* "Cython/Tempita/_tempita.py":969
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):
 *             if var_arg_type == '*':
 *                 var_arg = var_name             # <<<<<<<<<<<<<<
 *             elif var_arg_type == '**':
 *                 var_kw = var_name
*/
            __Pyx_INCREF(__pyx_v_var_name);
            __Pyx_DECREF_SET(__pyx_v_var_arg, __pyx_v_var_name);

            /* "Cython/Tempita/_tempita.py":968
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):
 *             if var_arg_type == '*':             # <<<<<<<<<<<<<<
 *                 var_arg = var_name
 *             elif var_arg_type == '**':
*/
            goto __pyx_L21;
          }

          /* "Cython/Tempita/_tempita.py":970
 *             if var_arg_type == '*':
 *                 var_arg = var_name
 *             elif var_arg_type == '**':             # <<<<<<<<<<<<<<
 *                 var_kw = var_name
 *             else:
*/
          __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_var_arg_type, __pyx_mstate_global->__pyx_kp_u__18, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 970, __pyx_L1_error)
          if (__pyx_t_9) {

            /* "Cython/Tempita/_tempita.py":971
 *                 var_arg = var_name
 *             elif var_arg_type == '**':
 *                 var_kw = var_name             # <<<<<<<<<<<<<<
 *             else:
 *                 sig_args.append(var_name)
*/
            __Pyx_INCREF(__pyx_v_var_name);
            __Pyx_DECREF_SET(__pyx_v_var_kw, __pyx_v_var_name);

            /* "Cython/Tempita/_tempita.py":970
 *             if var_arg_type == '*':
 *                 var_arg = var_name
 *             elif var_arg_type == '**':             # <<<<<<<<<<<<<<
 *                 var_kw = var_name
 *             else:
*/
            goto __pyx_L21;
          }

          /* "Cython/Tempita/_tempita.py":973
 *                 var_kw = var_name
 *             else:
 *                 sig_args.append(var_name)             # <<<<<<<<<<<<<<
 *             if tok_type == tokenize.ENDMARKER:
 *                 break
*/
          /*else*/ {
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_sig_args, __pyx_v_var_name); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 973, __pyx_L1_error)
          }
          __pyx_L21:;

          /* "Cython/Tempita/_tempita.py":974
 *             else:
 *                 sig_args.append(var_name)
 *             if tok_type == tokenize.ENDMARKER:             # <<<<<<<<<<<<<<
 *                 break
 *             continue
*/
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 974, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 974, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_9) {

            /* "Cython/Tempita/_tempita.py":975
 *                 sig_args.append(var_name)
 *             if tok_type == tokenize.ENDMARKER:
 *                 break             # <<<<<<<<<<<<<<
 *             continue
 *         if var_arg_type is not None:
*/
            goto __pyx_L4_break;

            /* "Cython/Tempita/_tempita.py":974
 *             else:
 *                 sig_args.append(var_name)
 *             if tok_type == tokenize.ENDMARKER:             # <<<<<<<<<<<<<<
 *                 break
 *             continue
*/
          }

          /* "Cython/Tempita/_tempita.py":976
 *             if tok_type == tokenize.ENDMARKER:
 *                 break
 *             continue             # <<<<<<<<<<<<<<
 *         if var_arg_type is not None:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
*/
          goto __pyx_L3_continue;

          /* "Cython/Tempita/_tempita.py":967
 *         var_name = tok_string
 *         tok_type, tok_string = get_token()
 *         if tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','):             # <<<<<<<<<<<<<<
 *             if var_arg_type == '*':
 *                 var_arg = var_name
*/
        }

        /* "Cython/Tempita/_tempita.py":977
 *                 break
 *             continue
 *         if var_arg_type is not None:             # <<<<<<<<<<<<<<
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
*/
        __pyx_t_9 = (__pyx_v_var_arg_type != Py_None);
        if (unlikely(__pyx_t_9)) {

          /* "Cython/Tempita/_tempita.py":978
 *             continue
 *         if var_arg_type is not None:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,             # <<<<<<<<<<<<<<
 *                                 position=pos, name=name)
 *         if tok_type == tokenize.OP and tok_string == '=':
*/
          __pyx_t_3 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 978, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Invalid_signature_s, __pyx_v_sig_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);

          /* "Cython/Tempita/_tempita.py":979
 *         if var_arg_type is not None:
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)             # <<<<<<<<<<<<<<
 *         if tok_type == tokenize.OP and tok_string == '=':
 *             nest_type = None
*/
          __pyx_t_7 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
            __pyx_t_7 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_t_2};
            __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 978, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 978, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 978, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 978, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 978, __pyx_L1_error)

          /* "Cython/Tempita/_tempita.py":977
 *                 break
 *             continue
 *         if var_arg_type is not None:             # <<<<<<<<<<<<<<
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
*/
        }

        /* "Cython/Tempita/_tempita.py":980
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
 *         if tok_type == tokenize.OP and tok_string == '=':             # <<<<<<<<<<<<<<
 *             nest_type = None
 *             unnest_type = None
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 980, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L25_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_tok_string, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 980, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_10;
        __pyx_L25_bool_binop_done:;
        if (__pyx_t_9) {

          /* "Cython/Tempita/_tempita.py":981
 *                                 position=pos, name=name)
 *         if tok_type == tokenize.OP and tok_string == '=':
 *             nest_type = None             # <<<<<<<<<<<<<<
 *             unnest_type = None
 *             nest_count = 0
*/
          __Pyx_INCREF(Py_None);
          __Pyx_XDECREF_SET(__pyx_v_nest_type, Py_None);

          /* "Cython/Tempita/_tempita.py":982
 *         if tok_type == tokenize.OP and tok_string == '=':
 *             nest_type = None
 *             unnest_type = None             # <<<<<<<<<<<<<<
 *             nest_count = 0
 *             start_pos = end_pos = None
*/
          __Pyx_INCREF(Py_None);
          __Pyx_XDECREF_SET(__pyx_v_unnest_type, Py_None);

          /* "Cython/Tempita/_tempita.py":983
 *             nest_type = None
 *             unnest_type = None
 *             nest_count = 0             # <<<<<<<<<<<<<<
 *             start_pos = end_pos = None
 *             parts = []
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
          __Pyx_XDECREF_SET(__pyx_v_nest_count, __pyx_mstate_global->__pyx_int_0);

          /* "Cython/Tempita/_tempita.py":984
 *             unnest_type = None
 *             nest_count = 0
 *             start_pos = end_pos = None             # <<<<<<<<<<<<<<
 *             parts = []
 *             while 1:
*/
          __Pyx_INCREF(Py_None);
          __Pyx_XDECREF_SET(__pyx_v_start_pos, Py_None);
          __Pyx_INCREF(Py_None);
          __Pyx_XDECREF_SET(__pyx_v_end_pos, Py_None);

          /* "Cython/Tempita/_tempita.py":985
 *             nest_count = 0
 *             start_pos = end_pos = None
 *             parts = []             # <<<<<<<<<<<<<<
 *             while 1:
 *                 tok_type, tok_string, s, e = get_token(True)
*/
          __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 985, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_parts, ((PyObject*)__pyx_t_1));
          __pyx_t_1 = 0;

          /* "Cython/Tempita/_tempita.py":986
 *             start_pos = end_pos = None
 *             parts = []
 *             while 1:             # <<<<<<<<<<<<<<
 *                 tok_type, tok_string, s, e = get_token(True)
 *                 if start_pos is None:
*/
          while (1) {

            /* "Cython/Tempita/_tempita.py":987
 *             parts = []
 *             while 1:
 *                 tok_type, tok_string, s, e = get_token(True)             # <<<<<<<<<<<<<<
 *                 if start_pos is None:
 *                     start_pos = s
*/
            __pyx_t_1 = __pyx_pf_6Cython_7Tempita_8_tempita_15parse_signature_get_token(__pyx_v_get_token, Py_True); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 987, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
              PyObject* sequence = __pyx_t_1;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 4)) {
                if (size > 4) __Pyx_RaiseTooManyValuesError(4);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 987, __pyx_L1_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
                __Pyx_INCREF(__pyx_t_6);
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
                __Pyx_INCREF(__pyx_t_4);
                __pyx_t_2 = PyTuple_GET_ITEM(sequence, 2);
                __Pyx_INCREF(__pyx_t_2);
                __pyx_t_3 = PyTuple_GET_ITEM(sequence, 3);
                __Pyx_INCREF(__pyx_t_3);
              } else {
                __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
                if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 987, __pyx_L1_error)
                __Pyx_XGOTREF(__pyx_t_6);
                __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 987, __pyx_L1_error)
                __Pyx_XGOTREF(__pyx_t_4);
                __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 987, __pyx_L1_error)
                __Pyx_XGOTREF(__pyx_t_2);
                __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 3, __Pyx_ReferenceSharing_SharedReference);
                if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 987, __pyx_L1_error)
                __Pyx_XGOTREF(__pyx_t_3);
              }
              #else
              {
                Py_ssize_t i;
                PyObject** temps[4] = {&__pyx_t_6,&__pyx_t_4,&__pyx_t_2,&__pyx_t_3};
                for (i=0; i < 4; i++) {
                  PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 987, __pyx_L1_error)
                  __Pyx_GOTREF(item);
                  *(temps[i]) = item;
                }
              }
              #endif
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else {
              Py_ssize_t index = -1;
              PyObject** temps[4] = {&__pyx_t_6,&__pyx_t_4,&__pyx_t_2,&__pyx_t_3};
              __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 987, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
              for (index=0; index < 4; index++) {
                PyObject* item = __pyx_t_8(__pyx_t_5); if (unlikely(!item)) goto __pyx_L29_unpacking_failed;
                __Pyx_GOTREF(item);
                *(temps[index]) = item;
              }
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_5), 4) < (0)) __PYX_ERR(0, 987, __pyx_L1_error)
              __pyx_t_8 = NULL;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              goto __pyx_L30_unpacking_done;
              __pyx_L29_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __pyx_t_8 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 987, __pyx_L1_error)
              __pyx_L30_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_tok_type, __pyx_t_6);
            __pyx_t_6 = 0;
            __Pyx_DECREF_SET(__pyx_v_tok_string, __pyx_t_4);
            __pyx_t_4 = 0;
            __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_2);
            __pyx_t_2 = 0;
            __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
            __pyx_t_3 = 0;

            /* "Cython/Tempita/_tempita.py":988
 *             while 1:
 *                 tok_type, tok_string, s, e = get_token(True)
 *                 if start_pos is None:             # <<<<<<<<<<<<<<
 *                     start_pos = s
 *                 end_pos = e
*/
            __pyx_t_9 = (__pyx_v_start_pos == Py_None);
            if (__pyx_t_9) {

              /* "Cython/Tempita/_tempita.py":989
 *                 tok_type, tok_string, s, e = get_token(True)
 *                 if start_pos is None:
 *                     start_pos = s             # <<<<<<<<<<<<<<
 *                 end_pos = e
 *                 if tok_type == tokenize.ENDMARKER and nest_count:
*/
              __Pyx_INCREF(__pyx_v_s);
              __Pyx_DECREF_SET(__pyx_v_start_pos, __pyx_v_s);

              /* "Cython/Tempita/_tempita.py":988
 *             while 1:
 *                 tok_type, tok_string, s, e = get_token(True)
 *                 if start_pos is None:             # <<<<<<<<<<<<<<
 *                     start_pos = s
 *                 end_pos = e
*/
            }

            /* "Cython/Tempita/_tempita.py":990
 *                 if start_pos is None:
 *                     start_pos = s
 *                 end_pos = e             # <<<<<<<<<<<<<<
 *                 if tok_type == tokenize.ENDMARKER and nest_count:
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
*/
            __Pyx_INCREF(__pyx_v_e);
            __Pyx_DECREF_SET(__pyx_v_end_pos, __pyx_v_e);

            /* "Cython/Tempita/_tempita.py":991
 *                     start_pos = s
 *                 end_pos = e
 *                 if tok_type == tokenize.ENDMARKER and nest_count:             # <<<<<<<<<<<<<<
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)
*/
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 991, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 991, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 991, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 991, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_10) {
            } else {
              __pyx_t_9 = __pyx_t_10;
              goto __pyx_L33_bool_binop_done;
            }
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 991, __pyx_L1_error)
            __pyx_t_9 = __pyx_t_10;
            __pyx_L33_bool_binop_done:;
            if (unlikely(__pyx_t_9)) {

              /* "Cython/Tempita/_tempita.py":992
 *                 end_pos = e
 *                 if tok_type == tokenize.ENDMARKER and nest_count:
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,             # <<<<<<<<<<<<<<
 *                                         position=pos, name=name)
 *                 if (not nest_count and
*/
              __pyx_t_3 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 992, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Invalid_signature_s, __pyx_v_sig_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 992, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);

              /* "Cython/Tempita/_tempita.py":993
 *                 if tok_type == tokenize.ENDMARKER and nest_count:
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)             # <<<<<<<<<<<<<<
 *                 if (not nest_count and
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
*/
              __pyx_t_7 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_2))) {
                __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
                assert(__pyx_t_3);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
                __pyx_t_7 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_t_4};
                __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 992, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_6);
                if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_position, __pyx_v_pos, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 992, __pyx_L1_error)
                if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 992, __pyx_L1_error)
                __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
              }
              __Pyx_Raise(__pyx_t_1, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __PYX_ERR(0, 992, __pyx_L1_error)

              /* "Cython/Tempita/_tempita.py":991
 *                     start_pos = s
 *                 end_pos = e
 *                 if tok_type == tokenize.ENDMARKER and nest_count:             # <<<<<<<<<<<<<<
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)
*/
            }

            /* "Cython/Tempita/_tempita.py":994
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)
 *                 if (not nest_count and             # <<<<<<<<<<<<<<
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
*/
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 994, __pyx_L1_error)
            __pyx_t_12 = (!__pyx_t_10);
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L36_bool_binop_done;
            }

            /* "Cython/Tempita/_tempita.py":995
 *                                         position=pos, name=name)
 *                 if (not nest_count and
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):             # <<<<<<<<<<<<<<
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
 *                     defaults[var_name] = default_expr
*/
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ENDMARKER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (!__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L36_bool_binop_done;
            }
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 995, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L36_bool_binop_done;
            }
            __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_tok_string, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 995, __pyx_L1_error)
            __pyx_t_9 = __pyx_t_12;
            __pyx_L36_bool_binop_done:;

            /* "Cython/Tempita/_tempita.py":994
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)
 *                 if (not nest_count and             # <<<<<<<<<<<<<<
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
*/
            if (__pyx_t_9) {

              /* "Cython/Tempita/_tempita.py":996
 *                 if (not nest_count and
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)             # <<<<<<<<<<<<<<
 *                     defaults[var_name] = default_expr
 *                     sig_args.append(var_name)
*/
              __pyx_t_2 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_isolate_expression); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 996, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __pyx_t_7 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_6))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
                assert(__pyx_t_2);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_2);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
                __pyx_t_7 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_sig_text, __pyx_v_start_pos, __pyx_v_end_pos};
                __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 996, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
              }
              __Pyx_XDECREF_SET(__pyx_v_default_expr, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "Cython/Tempita/_tempita.py":997
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
 *                     defaults[var_name] = default_expr             # <<<<<<<<<<<<<<
 *                     sig_args.append(var_name)
 *                     break
*/
              if (unlikely((PyDict_SetItem(__pyx_v_defaults, __pyx_v_var_name, __pyx_v_default_expr) < 0))) __PYX_ERR(0, 997, __pyx_L1_error)

              /* "Cython/Tempita/_tempita.py":998
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
 *                     defaults[var_name] = default_expr
 *                     sig_args.append(var_name)             # <<<<<<<<<<<<<<
 *                     break
 *                 parts.append((tok_type, tok_string))
*/
              __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_sig_args, __pyx_v_var_name); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 998, __pyx_L1_error)

              /* "Cython/Tempita/_tempita.py":999
 *                     defaults[var_name] = default_expr
 *                     sig_args.append(var_name)
 *                     break             # <<<<<<<<<<<<<<
 *                 parts.append((tok_type, tok_string))
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:
*/
              goto __pyx_L28_break;

              /* "Cython/Tempita/_tempita.py":994
 *                     raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                         position=pos, name=name)
 *                 if (not nest_count and             # <<<<<<<<<<<<<<
 *                         (tok_type == tokenize.ENDMARKER or (tok_type == tokenize.OP and tok_string == ','))):
 *                     default_expr = isolate_expression(sig_text, start_pos, end_pos)
*/
            }

            /* "Cython/Tempita/_tempita.py":1000
 *                     sig_args.append(var_name)
 *                     break
 *                 parts.append((tok_type, tok_string))             # <<<<<<<<<<<<<<
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:
 *                     nest_count += 1
*/
            __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_v_tok_type);
            __Pyx_GIVEREF(__pyx_v_tok_type);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tok_type) != (0)) __PYX_ERR(0, 1000, __pyx_L1_error);
            __Pyx_INCREF(__pyx_v_tok_string);
            __Pyx_GIVEREF(__pyx_v_tok_string);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_tok_string) != (0)) __PYX_ERR(0, 1000, __pyx_L1_error);
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_t_1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1000, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "Cython/Tempita/_tempita.py":1001
 *                     break
 *                 parts.append((tok_type, tok_string))
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:             # <<<<<<<<<<<<<<
 *                     nest_count += 1
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
*/
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1001, __pyx_L1_error)
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L41_bool_binop_done;
            }
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1001, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1001, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L41_bool_binop_done;
            }
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_string, __pyx_v_nest_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1001, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_9 = __pyx_t_12;
            __pyx_L41_bool_binop_done:;
            if (__pyx_t_9) {

              /* "Cython/Tempita/_tempita.py":1002
 *                 parts.append((tok_type, tok_string))
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:
 *                     nest_count += 1             # <<<<<<<<<<<<<<
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
 *                     nest_count -= 1
*/
              __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_v_nest_count, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1002, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF_SET(__pyx_v_nest_count, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "Cython/Tempita/_tempita.py":1001
 *                     break
 *                 parts.append((tok_type, tok_string))
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:             # <<<<<<<<<<<<<<
 *                     nest_count += 1
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
*/
              goto __pyx_L40;
            }

            /* "Cython/Tempita/_tempita.py":1003
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:
 *                     nest_count += 1
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:             # <<<<<<<<<<<<<<
 *                     nest_count -= 1
 *                     if not nest_count:
*/
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L44_bool_binop_done;
            }
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_12) {
            } else {
              __pyx_t_9 = __pyx_t_12;
              goto __pyx_L44_bool_binop_done;
            }
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_string, __pyx_v_unnest_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_9 = __pyx_t_12;
            __pyx_L44_bool_binop_done:;
            if (__pyx_t_9) {

              /* "Cython/Tempita/_tempita.py":1004
 *                     nest_count += 1
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
 *                     nest_count -= 1             # <<<<<<<<<<<<<<
 *                     if not nest_count:
 *                         nest_type = unnest_type = None
*/
              __pyx_t_1 = __Pyx_PyLong_SubtractObjC(__pyx_v_nest_count, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1004, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF_SET(__pyx_v_nest_count, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "Cython/Tempita/_tempita.py":1005
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
 *                     nest_count -= 1
 *                     if not nest_count:             # <<<<<<<<<<<<<<
 *                         nest_type = unnest_type = None
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):
*/
              __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1005, __pyx_L1_error)
              __pyx_t_12 = (!__pyx_t_9);
              if (__pyx_t_12) {

                /* "Cython/Tempita/_tempita.py":1006
 *                     nest_count -= 1
 *                     if not nest_count:
 *                         nest_type = unnest_type = None             # <<<<<<<<<<<<<<
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):
 *                     nest_type = tok_string
*/
                __Pyx_INCREF(Py_None);
                __Pyx_DECREF_SET(__pyx_v_nest_type, Py_None);
                __Pyx_INCREF(Py_None);
                __Pyx_DECREF_SET(__pyx_v_unnest_type, Py_None);

                /* "Cython/Tempita/_tempita.py":1005
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:
 *                     nest_count -= 1
 *                     if not nest_count:             # <<<<<<<<<<<<<<
 *                         nest_type = unnest_type = None
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):
*/
              }

              /* "Cython/Tempita/_tempita.py":1003
 *                 if nest_count and tok_type == tokenize.OP and tok_string == nest_type:
 *                     nest_count += 1
 *                 elif nest_count and tok_type == tokenize.OP and tok_string == unnest_type:             # <<<<<<<<<<<<<<
 *                     nest_count -= 1
 *                     if not nest_count:
*/
              goto __pyx_L40;
            }

            /* "Cython/Tempita/_tempita.py":1007
 *                     if not nest_count:
 *                         nest_type = unnest_type = None
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):             # <<<<<<<<<<<<<<
 *                     nest_type = tok_string
 *                     nest_count = 1
*/
            __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_nest_count); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1007, __pyx_L1_error)
            __pyx_t_10 = (!__pyx_t_9);
            if (__pyx_t_10) {
            } else {
              __pyx_t_12 = __pyx_t_10;
              goto __pyx_L48_bool_binop_done;
            }
            __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tokenize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_OP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1007, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_tok_type, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1007, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_10) {
            } else {
              __pyx_t_12 = __pyx_t_10;
              goto __pyx_L48_bool_binop_done;
            }
            __Pyx_INCREF(__pyx_v_tok_string);
            __pyx_t_1 = __pyx_v_tok_string;
            __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1007, __pyx_L1_error)
            if (!__pyx_t_9) {
            } else {
              __pyx_t_10 = __pyx_t_9;
              goto __pyx_L51_bool_binop_done;
            }
            __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__19, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1007, __pyx_L1_error)
            if (!__pyx_t_9) {
            } else {
              __pyx_t_10 = __pyx_t_9;
              goto __pyx_L51_bool_binop_done;
            }
            __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__20, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1007, __pyx_L1_error)
            __pyx_t_10 = __pyx_t_9;
            __pyx_L51_bool_binop_done:;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_9 = __pyx_t_10;
            __pyx_t_12 = __pyx_t_9;
            __pyx_L48_bool_binop_done:;
            if (__pyx_t_12) {

              /* "Cython/Tempita/_tempita.py":1008
 *                         nest_type = unnest_type = None
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):
 *                     nest_type = tok_string             # <<<<<<<<<<<<<<
 *                     nest_count = 1
 *                     unnest_type = {'(': ')', '[': ']', '{': '}'}[nest_type]
*/
              __Pyx_INCREF(__pyx_v_tok_string);
              __Pyx_DECREF_SET(__pyx_v_nest_type, __pyx_v_tok_string);

              /* "Cython/Tempita/_tempita.py":1009
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):
 *                     nest_type = tok_string
 *                     nest_count = 1             # <<<<<<<<<<<<<<
 *                     unnest_type = {'(': ')', '[': ']', '{': '}'}[nest_type]
 *     return sig_args, var_arg, var_kw, defaults
*/
              __Pyx_INCREF(__pyx_mstate_global->__pyx_int_1);
              __Pyx_DECREF_SET(__pyx_v_nest_count, __pyx_mstate_global->__pyx_int_1);

              /* "Cython/Tempita/_tempita.py":1010
 *                     nest_type = tok_string
 *                     nest_count = 1
 *                     unnest_type = {'(': ')', '[': ']', '{': '}'}[nest_type]             # <<<<<<<<<<<<<<
 *     return sig_args, var_arg, var_kw, defaults
 * 
*/
              __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1010, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__7, __pyx_mstate_global->__pyx_kp_u__16) < (0)) __PYX_ERR(0, 1010, __pyx_L1_error)
              if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__19, __pyx_mstate_global->__pyx_kp_u__21) < (0)) __PYX_ERR(0, 1010, __pyx_L1_error)
              if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__20, __pyx_mstate_global->__pyx_kp_u__22) < (0)) __PYX_ERR(0, 1010, __pyx_L1_error)
              __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_t_1, __pyx_v_nest_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1010, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF_SET(__pyx_v_unnest_type, __pyx_t_6);
              __pyx_t_6 = 0;

              /* "Cython/Tempita/_tempita.py":1007
 *                     if not nest_count:
 *                         nest_type = unnest_type = None
 *                 elif not nest_count and tok_type == tokenize.OP and tok_string in ('(', '[', '{'):             # <<<<<<<<<<<<<<
 *                     nest_type = tok_string
 *                     nest_count = 1
*/
            }
            __pyx_L40:;
          }
          __pyx_L28_break:;

          /* "Cython/Tempita/_tempita.py":980
 *             raise TemplateError('Invalid signature: (%s)' % sig_text,
 *                                 position=pos, name=name)
 *         if tok_type == tokenize.OP and tok_string == '=':             # <<<<<<<<<<<<<<
 *             nest_type = None
 *             unnest_type = None
*/
        }
        __pyx_L3_continue:;
      }
      __pyx_L4_break:;

      /* "Cython/Tempita/_tempita.py":1011
 *                     nest_count = 1
 *                     unnest_type = {'(': ')', '[': ']', '{': '}'}[nest_type]
 *     return sig_args, var_arg, var_kw, defaults             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_sig_args);
      __Pyx_GIVEREF(__pyx_v_sig_args);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_sig_args) != (0)) __PYX_ERR(0, 1011, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_var_arg);
      __Pyx_GIVEREF(__pyx_v_var_arg);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_var_arg) != (0)) __PYX_ERR(0, 1011, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_var_kw);
      __Pyx_GIVEREF(__pyx_v_var_kw);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_var_kw) != (0)) __PYX_ERR(0, 1011, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_defaults);
      __Pyx_GIVEREF(__pyx_v_defaults);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_v_defaults) != (0)) __PYX_ERR(0, 1011, __pyx_L1_error);
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":938
 * 
 * 
 * def parse_signature(sig_text, name, pos):             # <<<<<<<<<<<<<<
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6);
      __Pyx_AddTraceback("Cython.Tempita._tempita.parse_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_sig_args);
      __Pyx_XDECREF(__pyx_v_var_arg);
      __Pyx_XDECREF(__pyx_v_var_kw);
      __Pyx_XDECREF(__pyx_v_defaults);
      __Pyx_XDECREF(__pyx_v_get_token);
      __Pyx_XDECREF(__pyx_v_var_arg_type);
      __Pyx_XDECREF(__pyx_v_tok_type);
      __Pyx_XDECREF(__pyx_v_tok_string);
      __Pyx_XDECREF(__pyx_v_var_name);
      __Pyx_XDECREF(__pyx_v_nest_type);
      __Pyx_XDECREF(__pyx_v_unnest_type);
      __Pyx_XDECREF(__pyx_v_nest_count);
      __Pyx_XDECREF(__pyx_v_start_pos);
      __Pyx_XDECREF(__pyx_v_end_pos);
      __Pyx_XDECREF(__pyx_v_parts);
      __Pyx_XDECREF(__pyx_v_s);
      __Pyx_XDECREF(__pyx_v_e);
      __Pyx_XDECREF(__pyx_v_default_expr);
      __Pyx_DECREF((PyObject *)__pyx_cur_scope);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":1014
 * 
 * 
 * def isolate_expression(string, start_pos, end_pos):             # <<<<<<<<<<<<<<
 *     srow, scol = start_pos
 *     srow -= 1
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_33isolate_expression(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_33isolate_expression = {"isolate_expression", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_33isolate_expression, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_33isolate_expression(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_string = 0;
      PyObject *__pyx_v_start_pos = 0;
      PyObject *__pyx_v_end_pos = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[3] = {0,0,0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("isolate_expression (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_string_2,&__pyx_mstate_global->__pyx_n_u_start_pos,&__pyx_mstate_global->__pyx_n_u_end_pos,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1014, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  3:
            values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1014, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  2:
            values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1014, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1014, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "isolate_expression", 0) < (0)) __PYX_ERR(0, 1014, __pyx_L3_error)
          for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
            if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("isolate_expression", 1, 3, 3, i); __PYX_ERR(0, 1014, __pyx_L3_error) }
          }
        } else if (unlikely(__pyx_nargs != 3)) {
          goto __pyx_L5_argtuple_error;
        } else {
          values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1014, __pyx_L3_error)
          values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1014, __pyx_L3_error)
          values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
          if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1014, __pyx_L3_error)
        }
        __pyx_v_string = values[0];
        __pyx_v_start_pos = values[1];
        __pyx_v_end_pos = values[2];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("isolate_expression", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1014, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.isolate_expression", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_32isolate_expression(__pyx_self, __pyx_v_string, __pyx_v_start_pos, __pyx_v_end_pos);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_32isolate_expression(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_string, PyObject *__pyx_v_start_pos, PyObject *__pyx_v_end_pos) {
      PyObject *__pyx_v_srow = NULL;
      PyObject *__pyx_v_scol = NULL;
      PyObject *__pyx_v_erow = NULL;
      PyObject *__pyx_v_ecol = NULL;
      PyObject *__pyx_v_lines = NULL;
      PyObject *__pyx_v_parts = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      PyObject *__pyx_t_3 = NULL;
      PyObject *(*__pyx_t_4)(PyObject *);
      size_t __pyx_t_5;
      int __pyx_t_6;
      int __pyx_t_7;
      Py_ssize_t __pyx_t_8;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("isolate_expression", 0);

      /* "Cython/Tempita/_tempita.py":1015
 * 
 * def isolate_expression(string, start_pos, end_pos):
 *     srow, scol = start_pos             # <<<<<<<<<<<<<<
 *     srow -= 1
 *     erow, ecol = end_pos
*/
      if ((likely(PyTuple_CheckExact(__pyx_v_start_pos))) || (PyList_CheckExact(__pyx_v_start_pos))) {
        PyObject* sequence = __pyx_v_start_pos;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1015, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_2);
        } else {
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_1);
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
        }
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_v_start_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1015, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
        index = 0; __pyx_t_1 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_2 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_4(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 1015, __pyx_L1_error)
        __pyx_t_4 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L4_unpacking_done;
        __pyx_L3_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1015, __pyx_L1_error)
        __pyx_L4_unpacking_done:;
      }
      __pyx_v_srow = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_scol = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":1016
 * def isolate_expression(string, start_pos, end_pos):
 *     srow, scol = start_pos
 *     srow -= 1             # <<<<<<<<<<<<<<
 *     erow, ecol = end_pos
 *     erow -= 1
*/
      __pyx_t_2 = __Pyx_PyLong_SubtractObjC(__pyx_v_srow, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_srow, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":1017
 *     srow, scol = start_pos
 *     srow -= 1
 *     erow, ecol = end_pos             # <<<<<<<<<<<<<<
 *     erow -= 1
 *     lines = string.splitlines(True)
*/
      if ((likely(PyTuple_CheckExact(__pyx_v_end_pos))) || (PyList_CheckExact(__pyx_v_end_pos))) {
        PyObject* sequence = __pyx_v_end_pos;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1017, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_1);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1017, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1017, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_1);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1017, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1017, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_v_end_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1017, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
        index = 0; __pyx_t_2 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_1 = __pyx_t_4(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_4(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 1017, __pyx_L1_error)
        __pyx_t_4 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L6_unpacking_done;
        __pyx_L5_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1017, __pyx_L1_error)
        __pyx_L6_unpacking_done:;
      }
      __pyx_v_erow = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_ecol = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1018
 *     srow -= 1
 *     erow, ecol = end_pos
 *     erow -= 1             # <<<<<<<<<<<<<<
 *     lines = string.splitlines(True)
 *     if srow == erow:
*/
      __pyx_t_1 = __Pyx_PyLong_SubtractObjC(__pyx_v_erow, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1018, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_erow, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1019
 *     erow, ecol = end_pos
 *     erow -= 1
 *     lines = string.splitlines(True)             # <<<<<<<<<<<<<<
 *     if srow == erow:
 *         return lines[srow][scol:ecol]
*/
      __pyx_t_2 = __pyx_v_string;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, Py_True};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_splitlines, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_lines = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1020
 *     erow -= 1
 *     lines = string.splitlines(True)
 *     if srow == erow:             # <<<<<<<<<<<<<<
 *         return lines[srow][scol:ecol]
 *     parts = [lines[srow][scol:]]
*/
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_srow, __pyx_v_erow, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1020, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1020, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_6) {

        /* "Cython/Tempita/_tempita.py":1021
 *     lines = string.splitlines(True)
 *     if srow == erow:
 *         return lines[srow][scol:ecol]             # <<<<<<<<<<<<<<
 *     parts = [lines[srow][scol:]]
 *     parts.extend(lines[srow+1:erow])
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_lines, __pyx_v_srow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, &__pyx_v_scol, &__pyx_v_ecol, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        goto __pyx_L0;

        /* "Cython/Tempita/_tempita.py":1020
 *     erow -= 1
 *     lines = string.splitlines(True)
 *     if srow == erow:             # <<<<<<<<<<<<<<
 *         return lines[srow][scol:ecol]
 *     parts = [lines[srow][scol:]]
*/
      }

      /* "Cython/Tempita/_tempita.py":1022
 *     if srow == erow:
 *         return lines[srow][scol:ecol]
 *     parts = [lines[srow][scol:]]             # <<<<<<<<<<<<<<
 *     parts.extend(lines[srow+1:erow])
 *     if erow < len(lines):
*/
      __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_lines, __pyx_v_srow); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 0, &__pyx_v_scol, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1022, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_v_parts = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Tempita/_tempita.py":1023
 *         return lines[srow][scol:ecol]
 *     parts = [lines[srow][scol:]]
 *     parts.extend(lines[srow+1:erow])             # <<<<<<<<<<<<<<
 *     if erow < len(lines):
 *         # It'll sometimes give (end_row_past_finish, 0)
*/
      __pyx_t_2 = __Pyx_PyLong_AddObjC(__pyx_v_srow, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_lines, 0, 0, &__pyx_t_2, &__pyx_v_erow, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyList_Extend(__pyx_v_parts, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1023, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1024
 *     parts = [lines[srow][scol:]]
 *     parts.extend(lines[srow+1:erow])
 *     if erow < len(lines):             # <<<<<<<<<<<<<<
 *         # It'll sometimes give (end_row_past_finish, 0)
 *         parts.append(lines[erow][:ecol])
*/
      __pyx_t_8 = PyObject_Length(__pyx_v_lines); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1024, __pyx_L1_error)
      __pyx_t_1 = PyLong_FromSsize_t(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_erow, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1024, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1024, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_6) {

        /* "Cython/Tempita/_tempita.py":1026
 *     if erow < len(lines):
 *         # It'll sometimes give (end_row_past_finish, 0)
 *         parts.append(lines[erow][:ecol])             # <<<<<<<<<<<<<<
 *     return ''.join(parts)
 * 
*/
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_lines, __pyx_v_erow); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 0, NULL, &__pyx_v_ecol, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1026, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Tempita/_tempita.py":1024
 *     parts = [lines[srow][scol:]]
 *     parts.extend(lines[srow+1:erow])
 *     if erow < len(lines):             # <<<<<<<<<<<<<<
 *         # It'll sometimes give (end_row_past_finish, 0)
 *         parts.append(lines[erow][:ecol])
*/
      }

      /* "Cython/Tempita/_tempita.py":1027
 *         # It'll sometimes give (end_row_past_finish, 0)
 *         parts.append(lines[erow][:ecol])
 *     return ''.join(parts)             # <<<<<<<<<<<<<<
 * 
 * _fill_command_usage = """\
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__4, __pyx_v_parts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Tempita/_tempita.py":1014
 * 
 * 
 * def isolate_expression(string, start_pos, end_pos):             # <<<<<<<<<<<<<<
 *     srow, scol = start_pos
 *     srow -= 1
*/

      /* function exit code */
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3);
      __Pyx_AddTraceback("Cython.Tempita._tempita.isolate_expression", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_srow);
      __Pyx_XDECREF(__pyx_v_scol);
      __Pyx_XDECREF(__pyx_v_erow);
      __Pyx_XDECREF(__pyx_v_ecol);
      __Pyx_XDECREF(__pyx_v_lines);
      __Pyx_XDECREF(__pyx_v_parts);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    /* "Cython/Tempita/_tempita.py":1037
 * 
 * 
 * def fill_command(args=None):             # <<<<<<<<<<<<<<
 *     import sys
 *     import optparse
*/

    /* Python wrapper */
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_35fill_command(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
    static PyMethodDef __pyx_mdef_6Cython_7Tempita_8_tempita_35fill_command = {"fill_command", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_7Tempita_8_tempita_35fill_command, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
    static PyObject *__pyx_pw_6Cython_7Tempita_8_tempita_35fill_command(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
      PyObject *__pyx_v_args = 0;
      #if !CYTHON_METH_FASTCALL
      CYTHON_UNUSED Py_ssize_t __pyx_nargs;
      #endif
      CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
      PyObject* values[1] = {0};
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      PyObject *__pyx_r = 0;
      __Pyx_RefNannyDeclarations
      __Pyx_RefNannySetupContext("fill_command (wrapper)", 0);
      #if !CYTHON_METH_FASTCALL
      #if CYTHON_ASSUME_SAFE_SIZE
      __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
      #else
      __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
      #endif
      #endif
      __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
      {
        PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_args,0};
        const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
        if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1037, __pyx_L3_error)
        if (__pyx_kwds_len > 0) {
          switch (__pyx_nargs) {
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1037, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          const Py_ssize_t kwd_pos_args = __pyx_nargs;
          if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "fill_command", 0) < (0)) __PYX_ERR(0, 1037, __pyx_L3_error)
          if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
        } else {
          switch (__pyx_nargs) {
            case  1:
            values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
            if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1037, __pyx_L3_error)
            CYTHON_FALLTHROUGH;
            case  0: break;
            default: goto __pyx_L5_argtuple_error;
          }
          if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
        }
        __pyx_v_args = values[0];
      }
      goto __pyx_L6_skip;
      __pyx_L5_argtuple_error:;
      __Pyx_RaiseArgtupleInvalid("fill_command", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1037, __pyx_L3_error)
      __pyx_L6_skip:;
      goto __pyx_L4_argument_unpacking_done;
      __pyx_L3_error:;
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_AddTraceback("Cython.Tempita._tempita.fill_command", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __Pyx_RefNannyFinishContext();
      return NULL;
      __pyx_L4_argument_unpacking_done:;
      __pyx_r = __pyx_pf_6Cython_7Tempita_8_tempita_34fill_command(__pyx_self, __pyx_v_args);

      /* function exit code */
      for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
        Py_XDECREF(values[__pyx_temp]);
      }
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }

    static PyObject *__pyx_pf_6Cython_7Tempita_8_tempita_34fill_command(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_args) {
      PyObject *__pyx_v_sys = NULL;
      PyObject *__pyx_v_optparse = NULL;
      PyObject *__pyx_v_os = NULL;
      PyObject *__pyx_v_parser = NULL;
      PyObject *__pyx_v_options = NULL;
      PyObject *__pyx_v_template_name = NULL;
      PyObject *__pyx_v_vars = NULL;
      PyObject *__pyx_v_value = NULL;
      PyObject *__pyx_v_name = NULL;
      PyObject *__pyx_v_template_content = NULL;
      PyObject *__pyx_v_f = NULL;
      PyObject *__pyx_v_template = NULL;
      PyObject *__pyx_v_result = NULL;
      PyObject *__pyx_r = NULL;
      __Pyx_RefNannyDeclarations
      PyObject *__pyx_t_1 = NULL;
      PyObject *__pyx_t_2 = NULL;
      int __pyx_t_3;
      PyObject *__pyx_t_4 = NULL;
      PyObject *__pyx_t_5 = NULL;
      size_t __pyx_t_6;
      PyObject *__pyx_t_7 = NULL;
      PyObject *(*__pyx_t_8)(PyObject *);
      Py_ssize_t __pyx_t_9;
      PyObject *(*__pyx_t_10)(PyObject *);
      PyObject *__pyx_t_11 = NULL;
      PyObject *__pyx_t_12 = NULL;
      PyObject *__pyx_t_13 = NULL;
      PyObject *__pyx_t_14 = NULL;
      PyObject *__pyx_t_15 = NULL;
      int __pyx_t_16;
      int __pyx_lineno = 0;
      const char *__pyx_filename = NULL;
      int __pyx_clineno = 0;
      __Pyx_RefNannySetupContext("fill_command", 0);
      __Pyx_INCREF(__pyx_v_args);

      /* "Cython/Tempita/_tempita.py":1038
 * 
 * def fill_command(args=None):
 *     import sys             # <<<<<<<<<<<<<<
 *     import optparse
 *     import os
*/
      __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, 0, 0, NULL, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_sys = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1039
 * def fill_command(args=None):
 *     import sys
 *     import optparse             # <<<<<<<<<<<<<<
 *     import os
 *     if args is None:
*/
      __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_optparse, 0, 0, NULL, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1039, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_optparse = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1040
 *     import sys
 *     import optparse
 *     import os             # <<<<<<<<<<<<<<
 *     if args is None:
 *         args = sys.argv[1:]
*/
      __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, 0, 0, NULL, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_os = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Tempita/_tempita.py":1041
 *     import optparse
 *     import os
 *     if args is None:             # <<<<<<<<<<<<<<
 *         args = sys.argv[1:]
 *     parser = optparse.OptionParser(
*/
      __pyx_t_3 = (__pyx_v_args == Py_None);
      if (__pyx_t_3) {

        /* "Cython/Tempita/_tempita.py":1042
 *     import os
 *     if args is None:
 *         args = sys.argv[1:]             # <<<<<<<<<<<<<<
 *     parser = optparse.OptionParser(
 *         usage=_fill_command_usage)
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sys, __pyx_mstate_global->__pyx_n_u_argv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1042, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_1, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1042, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":1041
 *     import optparse
 *     import os
 *     if args is None:             # <<<<<<<<<<<<<<
 *         args = sys.argv[1:]
 *     parser = optparse.OptionParser(
*/
      }

      /* "Cython/Tempita/_tempita.py":1043
 *     if args is None:
 *         args = sys.argv[1:]
 *     parser = optparse.OptionParser(             # <<<<<<<<<<<<<<
 *         usage=_fill_command_usage)
 *     parser.add_option(
*/
      __pyx_t_1 = __pyx_v_optparse;
      __Pyx_INCREF(__pyx_t_1);

      /* "Cython/Tempita/_tempita.py":1044
 *         args = sys.argv[1:]
 *     parser = optparse.OptionParser(
 *         usage=_fill_command_usage)             # <<<<<<<<<<<<<<
 *     parser.add_option(
 *         '-o', '--output',
*/
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_fill_command_usage); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1044, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, NULL};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1043, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_usage, __pyx_t_5, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1043, __pyx_L1_error)
        __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_OptionParser, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1043, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_parser = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Tempita/_tempita.py":1045
 *     parser = optparse.OptionParser(
 *         usage=_fill_command_usage)
 *     parser.add_option(             # <<<<<<<<<<<<<<
 *         '-o', '--output',
 *         dest='output',
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_parser, __pyx_mstate_global->__pyx_n_u_add_option); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "Cython/Tempita/_tempita.py":1047
 *     parser.add_option(
 *         '-o', '--output',
 *         dest='output',             # <<<<<<<<<<<<<<
 *         metavar="FILENAME",
 *         help="File to write output to (default stdout)")
*/
      __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_dest, __pyx_mstate_global->__pyx_n_u_output_2) < (0)) __PYX_ERR(0, 1047, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_metavar, __pyx_mstate_global->__pyx_n_u_FILENAME) < (0)) __PYX_ERR(0, 1047, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_help, __pyx_mstate_global->__pyx_kp_u_File_to_write_output_to_default) < (0)) __PYX_ERR(0, 1047, __pyx_L1_error)

      /* "Cython/Tempita/_tempita.py":1045
 *     parser = optparse.OptionParser(
 *         usage=_fill_command_usage)
 *     parser.add_option(             # <<<<<<<<<<<<<<
 *         '-o', '--output',
 *         dest='output',
*/
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[10], __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":1050
 *         metavar="FILENAME",
 *         help="File to write output to (default stdout)")
 *     parser.add_option(             # <<<<<<<<<<<<<<
 *         '--env',
 *         dest='use_env',
*/
      __pyx_t_7 = __pyx_v_parser;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_env};
        __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1050, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_dest, __pyx_mstate_global->__pyx_n_u_use_env, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1050, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_action, __pyx_mstate_global->__pyx_n_u_store_true, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1050, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_help, __pyx_mstate_global->__pyx_kp_u_Put_the_environment_in_as_top_le, __pyx_t_4, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1050, __pyx_L1_error)
        __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_add_option, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1050, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":1055
 *         action='store_true',
 *         help="Put the environment in as top-level variables")
 *     options, args = parser.parse_args(args)             # <<<<<<<<<<<<<<
 *     if len(args) < 1:
 *         print('You must give a template filename')
*/
      __pyx_t_4 = __pyx_v_parser;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_args};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_parse_args, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1055, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_7);
        } else {
          __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1055, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_4);
          __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1055, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_7);
        }
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
        index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        index = 1; __pyx_t_7 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_7)) goto __pyx_L4_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_1), 2) < (0)) __PYX_ERR(0, 1055, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L5_unpacking_done;
        __pyx_L4_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1055, __pyx_L1_error)
        __pyx_L5_unpacking_done:;
      }
      __pyx_v_options = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":1056
 *         help="Put the environment in as top-level variables")
 *     options, args = parser.parse_args(args)
 *     if len(args) < 1:             # <<<<<<<<<<<<<<
 *         print('You must give a template filename')
 *         sys.exit(2)
*/
      __pyx_t_9 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1056, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_9 < 1);
      if (__pyx_t_3) {

        /* "Cython/Tempita/_tempita.py":1057
 *     options, args = parser.parse_args(args)
 *     if len(args) < 1:
 *         print('You must give a template filename')             # <<<<<<<<<<<<<<
 *         sys.exit(2)
 *     template_name = args[0]
*/
        __pyx_t_7 = NULL;
        __pyx_t_6 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_You_must_give_a_template_filenam};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1057, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":1058
 *     if len(args) < 1:
 *         print('You must give a template filename')
 *         sys.exit(2)             # <<<<<<<<<<<<<<
 *     template_name = args[0]
 *     args = args[1:]
*/
        __pyx_t_7 = __pyx_v_sys;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_int_2};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":1056
 *         help="Put the environment in as top-level variables")
 *     options, args = parser.parse_args(args)
 *     if len(args) < 1:             # <<<<<<<<<<<<<<
 *         print('You must give a template filename')
 *         sys.exit(2)
*/
      }

      /* "Cython/Tempita/_tempita.py":1059
 *         print('You must give a template filename')
 *         sys.exit(2)
 *     template_name = args[0]             # <<<<<<<<<<<<<<
 *     args = args[1:]
 *     vars = {}
*/
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1059, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_template_name = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":1060
 *         sys.exit(2)
 *     template_name = args[0]
 *     args = args[1:]             # <<<<<<<<<<<<<<
 *     vars = {}
 *     if options.use_env:
*/
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_args, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1060, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":1061
 *     template_name = args[0]
 *     args = args[1:]
 *     vars = {}             # <<<<<<<<<<<<<<
 *     if options.use_env:
 *         vars.update(os.environ)
*/
      __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1061, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_vars = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Tempita/_tempita.py":1062
 *     args = args[1:]
 *     vars = {}
 *     if options.use_env:             # <<<<<<<<<<<<<<
 *         vars.update(os.environ)
 *     for value in args:
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_use_env); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_3) {

        /* "Cython/Tempita/_tempita.py":1063
 *     vars = {}
 *     if options.use_env:
 *         vars.update(os.environ)             # <<<<<<<<<<<<<<
 *     for value in args:
 *         if '=' not in value:
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_os, __pyx_mstate_global->__pyx_n_u_environ); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1063, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type__update, __pyx_v_vars, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1063, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Tempita/_tempita.py":1062
 *     args = args[1:]
 *     vars = {}
 *     if options.use_env:             # <<<<<<<<<<<<<<
 *         vars.update(os.environ)
 *     for value in args:
*/
      }

      /* "Cython/Tempita/_tempita.py":1064
 *     if options.use_env:
 *         vars.update(os.environ)
 *     for value in args:             # <<<<<<<<<<<<<<
 *         if '=' not in value:
 *             print('Bad argument: %r' % value)
*/
      if (likely(PyList_CheckExact(__pyx_v_args)) || PyTuple_CheckExact(__pyx_v_args)) {
        __pyx_t_7 = __pyx_v_args; __Pyx_INCREF(__pyx_t_7);
        __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1064, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1064, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1064, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_9;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1064, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_9));
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_9);
            #endif
            ++__pyx_t_9;
          }
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1064, __pyx_L1_error)
        } else {
          __pyx_t_5 = __pyx_t_10(__pyx_t_7);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1064, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "Cython/Tempita/_tempita.py":1065
 *         vars.update(os.environ)
 *     for value in args:
 *         if '=' not in value:             # <<<<<<<<<<<<<<
 *             print('Bad argument: %r' % value)
 *             sys.exit(2)
*/
        __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__6, __pyx_v_value, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1065, __pyx_L1_error)
        if (__pyx_t_3) {

          /* "Cython/Tempita/_tempita.py":1066
 *     for value in args:
 *         if '=' not in value:
 *             print('Bad argument: %r' % value)             # <<<<<<<<<<<<<<
 *             sys.exit(2)
 *         name, value = value.split('=', 1)
*/
          __pyx_t_4 = NULL;
          __pyx_t_1 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Bad_argument_r, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1066, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_1};
            __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1066, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "Cython/Tempita/_tempita.py":1067
 *         if '=' not in value:
 *             print('Bad argument: %r' % value)
 *             sys.exit(2)             # <<<<<<<<<<<<<<
 *         name, value = value.split('=', 1)
 *         if name.startswith('py:'):
*/
          __pyx_t_1 = __pyx_v_sys;
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_int_2};
            __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1067, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "Cython/Tempita/_tempita.py":1065
 *         vars.update(os.environ)
 *     for value in args:
 *         if '=' not in value:             # <<<<<<<<<<<<<<
 *             print('Bad argument: %r' % value)
 *             sys.exit(2)
*/
        }

        /* "Cython/Tempita/_tempita.py":1068
 *             print('Bad argument: %r' % value)
 *             sys.exit(2)
 *         name, value = value.split('=', 1)             # <<<<<<<<<<<<<<
 *         if name.startswith('py:'):
 *             name = name[:3]
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_split); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1068, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[6], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1068, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1068, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_5);
            __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_4);
          } else {
            __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1068, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1068, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_4);
          }
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_11 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
          index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_11); if (unlikely(!__pyx_t_5)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_11); if (unlikely(!__pyx_t_4)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_11), 2) < (0)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __pyx_t_8 = NULL;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L12_unpacking_done;
          __pyx_L11_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_8 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1068, __pyx_L1_error)
          __pyx_L12_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Tempita/_tempita.py":1069
 *             sys.exit(2)
 *         name, value = value.split('=', 1)
 *         if name.startswith('py:'):             # <<<<<<<<<<<<<<
 *             name = name[:3]
 *             value = eval(value)
*/
        __pyx_t_4 = __pyx_v_name;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_py_2};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1069, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_3) {

          /* "Cython/Tempita/_tempita.py":1070
 *         name, value = value.split('=', 1)
 *         if name.startswith('py:'):
 *             name = name[:3]             # <<<<<<<<<<<<<<
 *             value = eval(value)
 *         vars[name] = value
*/
          __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_name, 0, 3, NULL, NULL, &__pyx_mstate_global->__pyx_slice[5], 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1070, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Tempita/_tempita.py":1071
 *         if name.startswith('py:'):
 *             name = name[:3]
 *             value = eval(value)             # <<<<<<<<<<<<<<
 *         vars[name] = value
 *     if template_name == '-':
*/
          __pyx_t_4 = NULL;
          __pyx_t_5 = __Pyx_Globals(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1071, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_11 = __Pyx_PyDict_NewPresized(14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1071, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (__pyx_v_args) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_args, __pyx_v_args) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_f) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_f, __pyx_v_f) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_name) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_name, __pyx_v_name) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_options) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_options, __pyx_v_options) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_optparse) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_optparse, __pyx_v_optparse) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_os) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_os, __pyx_v_os) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_parser) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_parser, __pyx_v_parser) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_result) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_result, __pyx_v_result) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_sys) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_sys, __pyx_v_sys) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_template) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_template, __pyx_v_template) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_template_content) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_template_content, __pyx_v_template_content) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_template_name) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_template_name_2, __pyx_v_template_name) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_value) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_value, __pyx_v_value) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          if (__pyx_v_vars) {
            if (PyDict_SetItem(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_vars, __pyx_v_vars) < (0)) __PYX_ERR(0, 1071, __pyx_L1_error)
          }
          __pyx_t_6 = 1;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_value, __pyx_t_5, __pyx_t_11};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_eval, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1071, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Tempita/_tempita.py":1069
 *             sys.exit(2)
 *         name, value = value.split('=', 1)
 *         if name.startswith('py:'):             # <<<<<<<<<<<<<<
 *             name = name[:3]
 *             value = eval(value)
*/
        }

        /* "Cython/Tempita/_tempita.py":1072
 *             name = name[:3]
 *             value = eval(value)
 *         vars[name] = value             # <<<<<<<<<<<<<<
 *     if template_name == '-':
 *         template_content = sys.stdin.read()
*/
        if (unlikely((PyDict_SetItem(__pyx_v_vars, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)

        /* "Cython/Tempita/_tempita.py":1064
 *     if options.use_env:
 *         vars.update(os.environ)
 *     for value in args:             # <<<<<<<<<<<<<<
 *         if '=' not in value:
 *             print('Bad argument: %r' % value)
*/
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Tempita/_tempita.py":1073
 *             value = eval(value)
 *         vars[name] = value
 *     if template_name == '-':             # <<<<<<<<<<<<<<
 *         template_content = sys.stdin.read()
 *         template_name = '<stdin>'
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_template_name, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1073, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Tempita/_tempita.py":1074
 *         vars[name] = value
 *     if template_name == '-':
 *         template_content = sys.stdin.read()             # <<<<<<<<<<<<<<
 *         template_name = '<stdin>'
 *     else:
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_sys, __pyx_mstate_global->__pyx_n_u_stdin); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1074, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_1 = __pyx_t_11;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_read, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1074, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_v_template_content = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "Cython/Tempita/_tempita.py":1075
 *     if template_name == '-':
 *         template_content = sys.stdin.read()
 *         template_name = '<stdin>'             # <<<<<<<<<<<<<<
 *     else:
 *         with open(template_name, 'rb') as f:
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_stdin_2);
        __Pyx_DECREF_SET(__pyx_v_template_name, __pyx_mstate_global->__pyx_kp_u_stdin_2);

        /* "Cython/Tempita/_tempita.py":1073
 *             value = eval(value)
 *         vars[name] = value
 *     if template_name == '-':             # <<<<<<<<<<<<<<
 *         template_content = sys.stdin.read()
 *         template_name = '<stdin>'
*/
        goto __pyx_L15;
      }

      /* "Cython/Tempita/_tempita.py":1077
 *         template_name = '<stdin>'
 *     else:
 *         with open(template_name, 'rb') as f:             # <<<<<<<<<<<<<<
 *             template_content = f.read()
 *     template = Template(template_content, name=template_name)
*/
      /*else*/ {
        /*with:*/ {
          __pyx_t_11 = NULL;
          __pyx_t_6 = 1;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_v_template_name, __pyx_mstate_global->__pyx_n_u_rb};
            __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_open, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1077, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = NULL;
          __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1077, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
            __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1077, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __pyx_t_5 = __pyx_t_11;
          __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          /*try:*/ {
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_14);
              /*try:*/ {
                __pyx_v_f = __pyx_t_5;
                __pyx_t_5 = 0;

                /* "Cython/Tempita/_tempita.py":1078
 *     else:
 *         with open(template_name, 'rb') as f:
 *             template_content = f.read()             # <<<<<<<<<<<<<<
 *     template = Template(template_content, name=template_name)
 *     result = template.substitute(vars)
*/
                __pyx_t_7 = __pyx_v_f;
                __Pyx_INCREF(__pyx_t_7);
                __pyx_t_6 = 0;
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
                  __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_read, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1078, __pyx_L20_error)
                  __Pyx_GOTREF(__pyx_t_5);
                }
                __pyx_v_template_content = __pyx_t_5;
                __pyx_t_5 = 0;

                /* "Cython/Tempita/_tempita.py":1077
 *         template_name = '<stdin>'
 *     else:
 *         with open(template_name, 'rb') as f:             # <<<<<<<<<<<<<<
 *             template_content = f.read()
 *     template = Template(template_content, name=template_name)
*/
              }
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              goto __pyx_L25_try_end;
              __pyx_L20_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              /*except:*/ {
                __Pyx_AddTraceback("Cython.Tempita._tempita.fill_command", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_11) < 0) __PYX_ERR(0, 1077, __pyx_L22_except_error)
                __Pyx_XGOTREF(__pyx_t_5);
                __Pyx_XGOTREF(__pyx_t_7);
                __Pyx_XGOTREF(__pyx_t_11);
                __pyx_t_1 = PyTuple_Pack(3, __pyx_t_5, __pyx_t_7, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1077, __pyx_L22_except_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, NULL);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1077, __pyx_L22_except_error)
                __Pyx_GOTREF(__pyx_t_15);
                __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                if (__pyx_t_3 < (0)) __PYX_ERR(0, 1077, __pyx_L22_except_error)
                __pyx_t_16 = (!__pyx_t_3);
                if (unlikely(__pyx_t_16)) {
                  __Pyx_GIVEREF(__pyx_t_5);
                  __Pyx_GIVEREF(__pyx_t_7);
                  __Pyx_XGIVEREF(__pyx_t_11);
                  __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_7, __pyx_t_11);
                  __pyx_t_5 = 0;  __pyx_t_7 = 0;  __pyx_t_11 = 0; 
                  __PYX_ERR(0, 1077, __pyx_L22_except_error)
                }
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                goto __pyx_L21_exception_handled;
              }
              __pyx_L22_except_error:;
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
              goto __pyx_L1_error;
              __pyx_L21_exception_handled:;
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
              __pyx_L25_try_end:;
            }
          }
          /*finally:*/ {
            /*normal exit:*/{
              if (__pyx_t_2) {
                __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[0], NULL);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1077, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              }
              goto __pyx_L19;
            }
            __pyx_L19:;
          }
          goto __pyx_L29;
          __pyx_L16_error:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L1_error;
          __pyx_L29:;
        }
      }
      __pyx_L15:;

      /* "Cython/Tempita/_tempita.py":1079
 *         with open(template_name, 'rb') as f:
 *             template_content = f.read()
 *     template = Template(template_content, name=template_name)             # <<<<<<<<<<<<<<
 *     result = template.substitute(vars)
 *     if options.output:
*/
      __pyx_t_7 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Template); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(!__pyx_v_template_content)) { __Pyx_RaiseUnboundLocalError("template_content"); __PYX_ERR(0, 1079, __pyx_L1_error) }
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_v_template_content};
        __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_template_name, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1079, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_v_template = __pyx_t_11;
      __pyx_t_11 = 0;

      /* "Cython/Tempita/_tempita.py":1080
 *             template_content = f.read()
 *     template = Template(template_content, name=template_name)
 *     result = template.substitute(vars)             # <<<<<<<<<<<<<<
 *     if options.output:
 *         with open(options.output, 'wb') as f:
*/
      __pyx_t_5 = __pyx_v_template;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_vars};
        __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_substitute, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1080, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_v_result = __pyx_t_11;
      __pyx_t_11 = 0;

      /* "Cython/Tempita/_tempita.py":1081
 *     template = Template(template_content, name=template_name)
 *     result = template.substitute(vars)
 *     if options.output:             # <<<<<<<<<<<<<<
 *         with open(options.output, 'wb') as f:
 *             f.write(result)
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_output_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1081, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_16) {

        /* "Cython/Tempita/_tempita.py":1082
 *     result = template.substitute(vars)
 *     if options.output:
 *         with open(options.output, 'wb') as f:             # <<<<<<<<<<<<<<
 *             f.write(result)
 *     else:
*/
        /*with:*/ {
          __pyx_t_5 = NULL;
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_output_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1082, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = 1;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_1, __pyx_mstate_global->__pyx_n_u_wb};
            __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_open, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1082, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __pyx_t_2 = __Pyx_PyObject_LookupSpecial(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1082, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_5 = NULL;
          __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1082, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = 1;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
            assert(__pyx_t_5);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
            __pyx_t_6 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1082, __pyx_L31_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __pyx_t_7 = __pyx_t_1;
          __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          /*try:*/ {
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_12);
              /*try:*/ {
                __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_7);
                __pyx_t_7 = 0;

                /* "Cython/Tempita/_tempita.py":1083
 *     if options.output:
 *         with open(options.output, 'wb') as f:
 *             f.write(result)             # <<<<<<<<<<<<<<
 *     else:
 *         sys.stdout.write(result)
*/
                __pyx_t_11 = __pyx_v_f;
                __Pyx_INCREF(__pyx_t_11);
                __pyx_t_6 = 0;
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_result};
                  __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1083, __pyx_L35_error)
                  __Pyx_GOTREF(__pyx_t_7);
                }
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

                /* "Cython/Tempita/_tempita.py":1082
 *     result = template.substitute(vars)
 *     if options.output:
 *         with open(options.output, 'wb') as f:             # <<<<<<<<<<<<<<
 *             f.write(result)
 *     else:
*/
              }
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L40_try_end;
              __pyx_L35_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              /*except:*/ {
                __Pyx_AddTraceback("Cython.Tempita._tempita.fill_command", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_11, &__pyx_t_1) < 0) __PYX_ERR(0, 1082, __pyx_L37_except_error)
                __Pyx_XGOTREF(__pyx_t_7);
                __Pyx_XGOTREF(__pyx_t_11);
                __Pyx_XGOTREF(__pyx_t_1);
                __pyx_t_5 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_11, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1082, __pyx_L37_except_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1082, __pyx_L37_except_error)
                __Pyx_GOTREF(__pyx_t_15);
                __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                if (__pyx_t_16 < (0)) __PYX_ERR(0, 1082, __pyx_L37_except_error)
                __pyx_t_3 = (!__pyx_t_16);
                if (unlikely(__pyx_t_3)) {
                  __Pyx_GIVEREF(__pyx_t_7);
                  __Pyx_GIVEREF(__pyx_t_11);
                  __Pyx_XGIVEREF(__pyx_t_1);
                  __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_11, __pyx_t_1);
                  __pyx_t_7 = 0;  __pyx_t_11 = 0;  __pyx_t_1 = 0; 
                  __PYX_ERR(0, 1082, __pyx_L37_except_error)
                }
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                goto __pyx_L36_exception_handled;
              }
              __pyx_L37_except_error:;
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_13, __pyx_t_12);
              goto __pyx_L1_error;
              __pyx_L36_exception_handled:;
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_13, __pyx_t_12);
              __pyx_L40_try_end:;
            }
          }
          /*finally:*/ {
            /*normal exit:*/{
              if (__pyx_t_2) {
                __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[0], NULL);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1082, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_12);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              }
              goto __pyx_L34;
            }
            __pyx_L34:;
          }
          goto __pyx_L44;
          __pyx_L31_error:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L1_error;
          __pyx_L44:;
        }

        /* "Cython/Tempita/_tempita.py":1081
 *     template = Template(template_content, name=template_name)
 *     result = template.substitute(vars)
 *     if options.output:             # <<<<<<<<<<<<<<
 *         with open(options.output, 'wb') as f:
 *             f.write(result)
*/
        goto __pyx_L30;
      }

      /* "Cython/Tempita/_tempita.py":1085
 *             f.write(result)
 *     else:
 *         sys.stdout.write(result)             # <<<<<<<<<<<<<<
 * 
 * if __name__ == '__main__':
*/
      /*else*/ {
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_sys, __pyx_mstate_global->__pyx_n_u_stdout); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = __pyx_t_7;
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_result};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1085, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L30:;

      /* "Cython/Tempita/_tempita.py":1037
 * 
 * 
 * def fill_command(args=None):             # <<<<<<<<<<<<<<
 *     import sys
 *     import optparse
*/

      /* function exit code */
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
      __pyx_L1_error:;
      __Pyx_XDECREF(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_11);
      __Pyx_AddTraceback("Cython.Tempita._tempita.fill_command", __pyx_clineno, __pyx_lineno, __pyx_filename);
      __pyx_r = NULL;
      __pyx_L0:;
      __Pyx_XDECREF(__pyx_v_sys);
      __Pyx_XDECREF(__pyx_v_optparse);
      __Pyx_XDECREF(__pyx_v_os);
      __Pyx_XDECREF(__pyx_v_parser);
      __Pyx_XDECREF(__pyx_v_options);
      __Pyx_XDECREF(__pyx_v_template_name);
      __Pyx_XDECREF(__pyx_v_vars);
      __Pyx_XDECREF(__pyx_v_value);
      __Pyx_XDECREF(__pyx_v_name);
      __Pyx_XDECREF(__pyx_v_template_content);
      __Pyx_XDECREF(__pyx_v_f);
      __Pyx_XDECREF(__pyx_v_template);
      __Pyx_XDECREF(__pyx_v_result);
      __Pyx_XDECREF(__pyx_v_args);
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      return __pyx_r;
    }
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_defaults(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_defaults(PyObject *o) {
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_defaults) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->arg0);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_defaults(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->arg0) {
    e = (*v)(p->arg0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_defaults(PyObject *o) {
  PyObject* tmp;
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  tmp = ((PyObject*)p->arg0);
  p->arg0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_defaults},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_defaults},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_defaults},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_defaults},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults_spec = {
  "Cython.Tempita._tempita.__pyx_defaults",
  sizeof(struct __pyx_defaults),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Tempita._tempita.""__pyx_defaults", /*tp_name*/
  sizeof(struct __pyx_defaults), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_defaults, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_defaults, /*tp_traverse*/
  __pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_defaults, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_defaults, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, sizeof(struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature[--__pyx_mstate_global->__pyx_freecount_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(PyObject *o) {
  struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *p = (struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_tokens);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, sizeof(struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature))))
  {
    __pyx_mstate_global->__pyx_freelist_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature[__pyx_mstate_global->__pyx_freecount_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature++] = ((struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *p = (struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_tokens) {
    e = (*v)(p->__pyx_v_tokens, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *p = (struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature *)o;
  tmp = ((PyObject*)p->__pyx_v_tokens);
  p->__pyx_v_tokens = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature_spec = {
  "Cython.Tempita._tempita.__pyx_scope_struct__parse_signature",
  sizeof(struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Tempita._tempita.""__pyx_scope_struct__parse_signature", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, /*tp_traverse*/
  __pyx_tp_clear_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults)) __PYX_ERR(0, 153, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults_spec, __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults) < (0)) __PYX_ERR(0, 153, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults = &__pyx_type_6Cython_7Tempita_8_tempita___pyx_defaults;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults) < (0)) __PYX_ERR(0, 153, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature)) __PYX_ERR(0, 938, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature_spec, __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature) < (0)) __PYX_ERR(0, 938, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature = &__pyx_type_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature) < (0)) __PYX_ERR(0, 938, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_scope_struct__parse_signature->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__tempita(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__tempita},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_tempita",
      __pyx_k_A_small_templating_language_Thi, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__tempita(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__tempita(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec__tempita(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_tempita' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_tempita" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__tempita", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_Cython__Tempita___tempita) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Cython.Tempita._tempita")) {
      if (unlikely((PyDict_SetItemString(modules, "Cython.Tempita._tempita", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "Cython/Tempita/_tempita.py":33
 * 
 * 
 * import re             # <<<<<<<<<<<<<<
 * import sys
 * import os
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_re, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 33, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_re, __pyx_t_2) < (0)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":34
 * 
 * import re
 * import sys             # <<<<<<<<<<<<<<
 * import os
 * import tokenize
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_sys, __pyx_t_2) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":35
 * import re
 * import sys
 * import os             # <<<<<<<<<<<<<<
 * import tokenize
 * from io import StringIO
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_os, __pyx_t_2) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":36
 * import sys
 * import os
 * import tokenize             # <<<<<<<<<<<<<<
 * from io import StringIO
 * 
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_tokenize, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_tokenize, __pyx_t_2) < (0)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":37
 * import os
 * import tokenize
 * from io import StringIO             # <<<<<<<<<<<<<<
 * 
 * from ._looper import looper
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringIO};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_io, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringIO};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 37, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 37, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":39
 * from io import StringIO
 * 
 * from ._looper import looper             # <<<<<<<<<<<<<<
 * 
 * __all__ = ['TemplateError', 'Template', 'sub', 'bunch']
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_looper_2};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_looper, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Tempita__looper, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_looper_2};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 39, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 39, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":41
 * from ._looper import looper
 * 
 * __all__ = ['TemplateError', 'Template', 'sub', 'bunch']             # <<<<<<<<<<<<<<
 * 
 * in_re = re.compile(r'\s+in\s+')
*/
  __pyx_t_2 = __Pyx_PyList_Pack(4, __pyx_mstate_global->__pyx_n_u_TemplateError, __pyx_mstate_global->__pyx_n_u_Template, __pyx_mstate_global->__pyx_n_u_sub, __pyx_mstate_global->__pyx_n_u_bunch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_2) < (0)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":43
 * __all__ = ['TemplateError', 'Template', 'sub', 'bunch']
 * 
 * in_re = re.compile(r'\s+in\s+')             # <<<<<<<<<<<<<<
 * var_re = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_s_in_s};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_in_re, __pyx_t_2) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":44
 * 
 * in_re = re.compile(r'\s+in\s+')
 * var_re = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)             # <<<<<<<<<<<<<<
 * 
 * def coerce_text(v):
*/
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_I); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_a_z__a_z0_9, __pyx_t_8};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_var_re, __pyx_t_2) < (0)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":46
 * var_re = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)
 * 
 * def coerce_text(v):             # <<<<<<<<<<<<<<
 *     if not isinstance(v, str):
 *         if hasattr(v, '__str__'):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_1coerce_text, 0, __pyx_mstate_global->__pyx_n_u_coerce_text, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_coerce_text, __pyx_t_2) < (0)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":54
 *     return v
 * 
 * class TemplateError(Exception):             # <<<<<<<<<<<<<<
 *     """Exception raised while parsing a template
 *     """
*/
  __pyx_t_2 = PyTuple_Pack(1, ((PyObject *)(((PyTypeObject*)PyExc_Exception)))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_8, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_TemplateError, __pyx_mstate_global->__pyx_n_u_TemplateError, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_kp_u_Exception_raised_while_parsing_a); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_5 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 54, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":58
 *     """
 * 
 *     def __init__(self, message, position, name=None):             # <<<<<<<<<<<<<<
 *         Exception.__init__(self, message)
 *         self.position = position
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_13TemplateError_1__init__, 0, __pyx_mstate_global->__pyx_n_u_TemplateError___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[11]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":63
 *         self.name = name
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         msg = ' '.join(self.args)
 *         if self.position:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_13TemplateError_3__str__, 0, __pyx_mstate_global->__pyx_n_u_TemplateError___str, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_str, __pyx_t_2) < (0)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":54
 *     return v
 * 
 * class TemplateError(Exception):             # <<<<<<<<<<<<<<
 *     """Exception raised while parsing a template
 *     """
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateError, __pyx_t_5, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateError, __pyx_t_2) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":73
 * 
 * 
 * class _TemplateContinue(Exception):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
  __pyx_t_5 = PyTuple_Pack(1, ((PyObject *)(((PyTypeObject*)PyExc_Exception)))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PEP560_update_bases(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_CalculateMetaclass(NULL, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare(__pyx_t_6, __pyx_t_8, __pyx_mstate_global->__pyx_n_u_TemplateContinue, __pyx_mstate_global->__pyx_n_u_TemplateContinue, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__pyx_t_8 != __pyx_t_5) {
    if (unlikely((PyDict_SetItemString(__pyx_t_2, "__orig_bases__", __pyx_t_5) < 0))) __PYX_ERR(0, 73, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_TemplateContinue, __pyx_t_8, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateContinue, __pyx_t_5) < (0)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "Cython/Tempita/_tempita.py":77
 * 
 * 
 * class _TemplateBreak(Exception):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
  __pyx_t_8 = PyTuple_Pack(1, ((PyObject *)(((PyTypeObject*)PyExc_Exception)))); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PEP560_update_bases(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_TemplateBreak, __pyx_mstate_global->__pyx_n_u_TemplateBreak, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__pyx_t_6 != __pyx_t_8) {
    if (unlikely((PyDict_SetItemString(__pyx_t_5, "__orig_bases__", __pyx_t_8) < 0))) __PYX_ERR(0, 77, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TemplateBreak, __pyx_t_6, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateBreak, __pyx_t_8) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":81
 * 
 * 
 * def get_file_template(name, from_template):             # <<<<<<<<<<<<<<
 *     path = os.path.join(os.path.dirname(from_template.name), name)
 *     return from_template.__class__.from_filename(
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_3get_file_template, 0, __pyx_mstate_global->__pyx_n_u_get_file_template, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_get_file_template, __pyx_t_6) < (0)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":88
 * 
 * 
 * class Template:             # <<<<<<<<<<<<<<
 * 
 *     default_namespace = {
*/
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_Template, __pyx_mstate_global->__pyx_n_u_Template, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "Cython/Tempita/_tempita.py":91
 * 
 *     default_namespace = {
 *         'start_braces': '{{',             # <<<<<<<<<<<<<<
 *         'end_braces': '}}',
 *         'looper': looper,
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_start_braces, __pyx_mstate_global->__pyx_kp_u__25) < (0)) __PYX_ERR(0, 91, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_end_braces, __pyx_mstate_global->__pyx_kp_u__26) < (0)) __PYX_ERR(0, 91, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":93
 *         'start_braces': '{{',
 *         'end_braces': '}}',
 *         'looper': looper,             # <<<<<<<<<<<<<<
 *         }
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_looper_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_looper_2, __pyx_t_5) < (0)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_default_namespace, __pyx_t_2) < (0)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":96
 *         }
 * 
 *     default_encoding = 'utf8'             # <<<<<<<<<<<<<<
 *     default_inherit = None
 * 
*/
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_default_encoding, __pyx_mstate_global->__pyx_n_u_utf8) < (0)) __PYX_ERR(0, 96, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":97
 * 
 *     default_encoding = 'utf8'
 *     default_inherit = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,
*/
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_default_inherit, Py_None) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_1__init__, 0, __pyx_mstate_global->__pyx_n_u_Template___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[12]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":153
 *             self.default_inherit = default_inherit
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,             # <<<<<<<<<<<<<<
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_3from_filename, 0, __pyx_mstate_global->__pyx_n_u_Template_from_filename, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6Cython_7Tempita_8_tempita___pyx_defaults)) __PYX_ERR(0, 153, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":154
 * 
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):             # <<<<<<<<<<<<<<
 *         with open(filename, 'rb') as f:
 *             c = f.read()
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_get_file_template); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_t_2)->arg0 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_6Cython_7Tempita_8_tempita_36__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_from_filename, __pyx_t_2) < (0)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":162
 *                    default_inherit=default_inherit, get_template=get_template)
 * 
 *     from_filename = classmethod(from_filename)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __pyx_t_2 = PyObject_GetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_from_filename);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_from_filename);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_from_filename, __pyx_t_5) < (0)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":164
 *     from_filename = classmethod(from_filename)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s name=%r>' % (
 *             self.__class__.__name__,
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_5__repr__, 0, __pyx_mstate_global->__pyx_n_u_Template___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_5) < (0)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":169
 *             hex(id(self))[2:], self.name)
 * 
 *     def substitute(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         if args:
 *             if kw:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_7substitute, 0, __pyx_mstate_global->__pyx_n_u_Template_substitute, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_substitute, __pyx_t_5) < (0)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":193
 *         return result
 * 
 *     def _interpret(self, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         parts = []
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_9_interpret, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret, __pyx_t_5) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":204
 *         return ''.join(parts), defs, inherit
 * 
 *     def _interpret_inherit(self, body, defs, inherit_template, ns):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         if not self.get_template:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_11_interpret_inherit, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret_inherit, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret_inherit, __pyx_t_5) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":219
 *         return templ.substitute(ns)
 * 
 *     def _interpret_codes(self, codes, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in codes:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_13_interpret_codes, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret_codes, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret_codes, __pyx_t_5) < (0)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":227
 *                 self._interpret_code(item, ns, out, defs)
 * 
 *     def _interpret_code(self, code, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         name, pos = code[0], code[1]
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_15_interpret_code, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret_code, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret_code, __pyx_t_5) < (0)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":270
 *             assert 0, "Unknown code: %r" % name
 * 
 *     def _interpret_for(self, vars, expr, content, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         for item in expr:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_17_interpret_for, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret_for, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret_for, __pyx_t_5) < (0)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":289
 *                 break
 * 
 *     def _interpret_if(self, parts, ns, out, defs):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         # @@: if/else/else gets through
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_19_interpret_if, 0, __pyx_mstate_global->__pyx_n_u_Template__interpret_if, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interpret_if, __pyx_t_5) < (0)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":303
 *                 break
 * 
 *     def _eval(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_21_eval, 0, __pyx_mstate_global->__pyx_n_u_Template__eval, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_eval_2, __pyx_t_5) < (0)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":320
 *             raise
 * 
 *     def _exec(self, code, ns, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_23_exec, 0, __pyx_mstate_global->__pyx_n_u_Template__exec, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_exec, __pyx_t_5) < (0)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":331
 *             raise
 * 
 *     def _repr(self, value, pos):             # <<<<<<<<<<<<<<
 *         __traceback_hide__ = True
 *         try:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_25_repr, 0, __pyx_mstate_global->__pyx_n_u_Template__repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_repr, __pyx_t_5) < (0)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":373
 *             return value
 * 
 *     def _add_line_info(self, msg, pos):             # <<<<<<<<<<<<<<
 *         msg = "%s at line %s column %s" % (
 *             msg, pos[0], pos[1])
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_8Template_27_add_line_info, 0, __pyx_mstate_global->__pyx_n_u_Template__add_line_info, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_add_line_info, __pyx_t_5) < (0)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":88
 * 
 * 
 * class Template:             # <<<<<<<<<<<<<<
 * 
 *     default_namespace = {
*/
  __pyx_t_5 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_Template, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Template, __pyx_t_5) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":381
 * 
 * 
 * def sub(content, delimiters=None, **kw):             # <<<<<<<<<<<<<<
 *     name = kw.get('__name')
 *     delimeters = kw.pop('delimeters') if 'delimeters' in kw else None  # for legacy code
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5sub, 0, __pyx_mstate_global->__pyx_n_u_sub, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[11]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_sub, __pyx_t_6) < (0)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":388
 * 
 * 
 * def paste_script_template_renderer(content, vars, filename=None):             # <<<<<<<<<<<<<<
 *     tmpl = Template(content, name=filename)
 *     return tmpl.substitute(vars)
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_7paste_script_template_renderer, 0, __pyx_mstate_global->__pyx_n_u_paste_script_template_renderer, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[11]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_paste_script_template_renderer, __pyx_t_6) < (0)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":393
 * 
 * 
 * class bunch(dict):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, **kw):
*/
  __pyx_t_6 = PyTuple_Pack(1, ((PyObject *)(&PyDict_Type))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_bunch, __pyx_mstate_global->__pyx_n_u_bunch, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__pyx_t_5 != __pyx_t_6) {
    if (unlikely((PyDict_SetItemString(__pyx_t_8, "__orig_bases__", __pyx_t_6) < 0))) __PYX_ERR(0, 393, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":395
 * class bunch(dict):
 * 
 *     def __init__(self, **kw):             # <<<<<<<<<<<<<<
 *         for name, value in kw.items():
 *             setattr(self, name, value)
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_1__init__, 0, __pyx_mstate_global->__pyx_n_u_bunch___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_6) < (0)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":399
 *             setattr(self, name, value)
 * 
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         self[name] = value
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_3__setattr__, 0, __pyx_mstate_global->__pyx_n_u_bunch___setattr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_setattr, __pyx_t_6) < (0)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":402
 *         self[name] = value
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_5__getattr__, 0, __pyx_mstate_global->__pyx_n_u_bunch___getattr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_getattr, __pyx_t_6) < (0)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":408
 *             raise AttributeError(name)
 * 
 *     def __getitem__(self, key):             # <<<<<<<<<<<<<<
 *         if 'default' in self:
 *             try:
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_7__getitem__, 0, __pyx_mstate_global->__pyx_n_u_bunch___getitem, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_getitem, __pyx_t_6) < (0)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":417
 *             return dict.__getitem__(self, key)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (
 *             self.__class__.__name__,
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_5bunch_9__repr__, 0, __pyx_mstate_global->__pyx_n_u_bunch___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_6) < (0)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Tempita/_tempita.py":393
 * 
 * 
 * class bunch(dict):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, **kw):
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_bunch, __pyx_t_5, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_bunch, __pyx_t_6) < (0)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":423
 * 
 * 
 * class TemplateDef:             # <<<<<<<<<<<<<<
 *     def __init__(self, template, func_name, func_signature,
 *                  body, ns, pos, bound_self=None):
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_TemplateDef, __pyx_mstate_global->__pyx_n_u_TemplateDef, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Tempita/_tempita.py":424
 * 
 * class TemplateDef:
 *     def __init__(self, template, func_name, func_signature,             # <<<<<<<<<<<<<<
 *                  body, ns, pos, bound_self=None):
 *         self._template = template
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_1__init__, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[11]);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":434
 *         self._bound_self = bound_self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<tempita function %s(%s) at %s:%s>' % (
 *             self._func_name, self._func_signature,
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_3__repr__, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_2) < (0)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":439
 *             self._template.name, self._pos)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_5__str__, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef___str, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_str, __pyx_t_2) < (0)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":442
 *         return self()
 * 
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         values = self._parse_signature(args, kw)
 *         ns = self._ns.copy()
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_7__call__, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef___call, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_call, __pyx_t_2) < (0)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":453
 *         return ''.join(out)
 * 
 *     def __get__(self, obj, type=None):             # <<<<<<<<<<<<<<
 *         if obj is None:
 *             return self
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_9__get__, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef___get, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[11]);
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_get_2, __pyx_t_2) < (0)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":460
 *             self._body, self._ns, self._pos, bound_self=obj)
 * 
 *     def _parse_signature(self, args, kw):             # <<<<<<<<<<<<<<
 *         values = {}
 *         sig_args, var_args, var_kw, defaults = self._func_signature
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11TemplateDef_11_parse_signature, 0, __pyx_mstate_global->__pyx_n_u_TemplateDef__parse_signature, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_parse_signature, __pyx_t_2) < (0)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":423
 * 
 * 
 * class TemplateDef:             # <<<<<<<<<<<<<<
 *     def __init__(self, template, func_name, func_signature,
 *                  body, ns, pos, bound_self=None):
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_TemplateDef, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateDef, __pyx_t_2) < (0)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":500
 * 
 * 
 * class TemplateObject:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, name):
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_TemplateObject, __pyx_mstate_global->__pyx_n_u_TemplateObject, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Tempita/_tempita.py":502
 * class TemplateObject:
 * 
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.__name = name
 *         self.get = TemplateObjectGetter(self)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_14TemplateObject_1__init__, 0, __pyx_mstate_global->__pyx_n_u_TemplateObject___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":506
 *         self.get = TemplateObjectGetter(self)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s %s>' % (self.__class__.__name__, self.__name)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_14TemplateObject_3__repr__, 0, __pyx_mstate_global->__pyx_n_u_TemplateObject___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_2) < (0)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":500
 * 
 * 
 * class TemplateObject:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, name):
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_TemplateObject, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateObject, __pyx_t_2) < (0)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":510
 * 
 * 
 * class TemplateObjectGetter:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, template_obj):
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Tempita/_tempita.py":512
 * class TemplateObjectGetter:
 * 
 *     def __init__(self, template_obj):             # <<<<<<<<<<<<<<
 *         self.__template_obj = template_obj
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_1__init__, 0, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":515
 *         self.__template_obj = template_obj
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.__template_obj, attr, Empty)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_3__getattr__, 0, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter___getattr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_getattr, __pyx_t_2) < (0)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":518
 *         return getattr(self.__template_obj, attr, Empty)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s around %r>' % (self.__class__.__name__, self.__template_obj)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_20TemplateObjectGetter_5__repr__, 0, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_2) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":510
 * 
 * 
 * class TemplateObjectGetter:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, template_obj):
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_TemplateObjectGetter, __pyx_t_2) < (0)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":522
 * 
 * 
 * class _Empty:             # <<<<<<<<<<<<<<
 *     def __call__(self, *args, **kw):
 *         return self
*/
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_Empty_2, __pyx_mstate_global->__pyx_n_u_Empty_2, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Tempita/_tempita.py":523
 * 
 * class _Empty:
 *     def __call__(self, *args, **kw):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_1__call__, 0, __pyx_mstate_global->__pyx_n_u_Empty___call, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_call, __pyx_t_2) < (0)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":526
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_3__str__, 0, __pyx_mstate_global->__pyx_n_u_Empty___str, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_str, __pyx_t_2) < (0)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":529
 *         return ''
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Empty'
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_5__repr__, 0, __pyx_mstate_global->__pyx_n_u_Empty___repr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_repr_2, __pyx_t_2) < (0)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":532
 *         return 'Empty'
 * 
 *     def __unicode__(self):             # <<<<<<<<<<<<<<
 *         return ''
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_7__unicode__, 0, __pyx_mstate_global->__pyx_n_u_Empty___unicode, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_unicode_2, __pyx_t_2) < (0)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":535
 *         return ''
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return iter(())
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_9__iter__, 0, __pyx_mstate_global->__pyx_n_u_Empty___iter, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_iter, __pyx_t_2) < (0)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":538
 *         return iter(())
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_6_Empty_11__bool__, 0, __pyx_mstate_global->__pyx_n_u_Empty___bool, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_bool, __pyx_t_2) < (0)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Tempita/_tempita.py":522
 * 
 * 
 * class _Empty:             # <<<<<<<<<<<<<<
 *     def __call__(self, *args, **kw):
 *         return self
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_Empty_2, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Empty_2, __pyx_t_2) < (0)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":541
 *         return False
 * 
 * Empty = _Empty()             # <<<<<<<<<<<<<<
 * del _Empty
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_Empty_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Empty, __pyx_t_5) < (0)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":542
 * 
 * Empty = _Empty()
 * del _Empty             # <<<<<<<<<<<<<<
 * 
 * ############################################################
*/
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Empty_2) < (0)) __PYX_ERR(0, 542, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":549
 * 
 * 
 * def lex(s, name=None, trim_whitespace=True, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     """
 *     Lex a string into chunks:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_9lex, 0, __pyx_mstate_global->__pyx_n_u_lex, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[13]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_lex, __pyx_t_5) < (0)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":612
 *     return chunks
 * 
 * statement_re = re.compile(r'^(?:if |elif |for |def |inherit |default |py:)')             # <<<<<<<<<<<<<<
 * single_statements = ['else', 'endif', 'endfor', 'enddef', 'continue', 'break']
 * trail_whitespace_re = re.compile(r'\n\r?[\t ]*$')
*/
  __pyx_t_8 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_kp_u_if_elif_for_def_inherit_default};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 612, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_statement_re, __pyx_t_5) < (0)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":613
 * 
 * statement_re = re.compile(r'^(?:if |elif |for |def |inherit |default |py:)')
 * single_statements = ['else', 'endif', 'endfor', 'enddef', 'continue', 'break']             # <<<<<<<<<<<<<<
 * trail_whitespace_re = re.compile(r'\n\r?[\t ]*$')
 * lead_whitespace_re = re.compile(r'^[\t ]*\n')
*/
  __pyx_t_5 = __Pyx_PyList_Pack(6, __pyx_mstate_global->__pyx_n_u_else, __pyx_mstate_global->__pyx_n_u_endif, __pyx_mstate_global->__pyx_n_u_endfor, __pyx_mstate_global->__pyx_n_u_enddef, __pyx_mstate_global->__pyx_n_u_continue, __pyx_mstate_global->__pyx_n_u_break); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_single_statements, __pyx_t_5) < (0)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":614
 * statement_re = re.compile(r'^(?:if |elif |for |def |inherit |default |py:)')
 * single_statements = ['else', 'endif', 'endfor', 'enddef', 'continue', 'break']
 * trail_whitespace_re = re.compile(r'\n\r?[\t ]*$')             # <<<<<<<<<<<<<<
 * lead_whitespace_re = re.compile(r'^[\t ]*\n')
 * 
*/
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_n_r_t};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_trail_whitespace_re, __pyx_t_5) < (0)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":615
 * single_statements = ['else', 'endif', 'endfor', 'enddef', 'continue', 'break']
 * trail_whitespace_re = re.compile(r'\n\r?[\t ]*$')
 * lead_whitespace_re = re.compile(r'^[\t ]*\n')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_compile); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_t_n};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_lead_whitespace_re, __pyx_t_5) < (0)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":618
 * 
 * 
 * def trim_lex(tokens):             # <<<<<<<<<<<<<<
 *     r"""
 *     Takes a lexed set of tokens, and removes whitespace when there is
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_11trim_lex, 0, __pyx_mstate_global->__pyx_n_u_trim_lex, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_trim_lex, __pyx_t_5) < (0)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":676
 * 
 * 
 * def find_position(string, index, last_index, last_pos):             # <<<<<<<<<<<<<<
 *     """Given a string and index, return (line, column)"""
 *     lines = string.count('\n', last_index, index)
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_13find_position, 0, __pyx_mstate_global->__pyx_n_u_find_position, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_find_position, __pyx_t_5) < (0)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":686
 * 
 * 
 * def parse(s, name=None, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     r"""
 *     Parses a string into a kind of AST
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_15parse, 0, __pyx_mstate_global->__pyx_n_u_parse, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[14]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse, __pyx_t_5) < (0)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":747
 * 
 * 
 * def parse_expr(tokens, name, context=()):             # <<<<<<<<<<<<<<
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_17parse_expr, 0, __pyx_mstate_global->__pyx_n_u_parse_expr, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[15]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_expr, __pyx_t_5) < (0)) __PYX_ERR(0, 747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":800
 * 
 * 
 * def parse_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     start = tokens[0][1]
 *     pieces = []
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_19parse_cond, 0, __pyx_mstate_global->__pyx_n_u_parse_cond, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_cond, __pyx_t_5) < (0)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":816
 * 
 * 
 * def parse_one_cond(tokens, name, context):             # <<<<<<<<<<<<<<
 *     (first, pos), tokens = tokens[0], tokens[1:]
 *     content = []
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_21parse_one_cond, 0, __pyx_mstate_global->__pyx_n_u_parse_one_cond, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_one_cond, __pyx_t_5) < (0)) __PYX_ERR(0, 816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":843
 * 
 * 
 * def parse_for(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_23parse_for, 0, __pyx_mstate_global->__pyx_n_u_parse_for, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_for, __pyx_t_5) < (0)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":878
 * 
 * 
 * def parse_default(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_25parse_default, 0, __pyx_mstate_global->__pyx_n_u_parse_default, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[51])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_default, __pyx_t_5) < (0)) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":900
 * 
 * 
 * def parse_inherit(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, pos = tokens[0]
 *     assert first.startswith('inherit ')
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_27parse_inherit, 0, __pyx_mstate_global->__pyx_n_u_parse_inherit, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[52])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_inherit, __pyx_t_5) < (0)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":907
 * 
 * 
 * def parse_def(tokens, name, context):             # <<<<<<<<<<<<<<
 *     first, start = tokens[0]
 *     tokens = tokens[1:]
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_29parse_def, 0, __pyx_mstate_global->__pyx_n_u_parse_def, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[53])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_def, __pyx_t_5) < (0)) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":938
 * 
 * 
 * def parse_signature(sig_text, name, pos):             # <<<<<<<<<<<<<<
 *     tokens = tokenize.generate_tokens(StringIO(sig_text).readline)
 *     sig_args = []
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_31parse_signature, 0, __pyx_mstate_global->__pyx_n_u_parse_signature_2, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[54])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_signature_2, __pyx_t_5) < (0)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":1014
 * 
 * 
 * def isolate_expression(string, start_pos, end_pos):             # <<<<<<<<<<<<<<
 *     srow, scol = start_pos
 *     srow -= 1
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_33isolate_expression, 0, __pyx_mstate_global->__pyx_n_u_isolate_expression, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[55])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_isolate_expression, __pyx_t_5) < (0)) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":1029
 *     return ''.join(parts)
 * 
 * _fill_command_usage = """\             # <<<<<<<<<<<<<<
 * %prog [OPTIONS] TEMPLATE arg=value
 * 
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_fill_command_usage, __pyx_mstate_global->__pyx_kp_u_prog_OPTIONS_TEMPLATE_arg_value) < (0)) __PYX_ERR(0, 1029, __pyx_L1_error)

  /* "Cython/Tempita/_tempita.py":1037
 * 
 * 
 * def fill_command(args=None):             # <<<<<<<<<<<<<<
 *     import sys
 *     import optparse
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_7Tempita_8_tempita_35fill_command, 0, __pyx_mstate_global->__pyx_n_u_fill_command, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Tempita__tempita, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[56])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[11]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_fill_command, __pyx_t_5) < (0)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Tempita/_tempita.py":1087
 *         sys.stdout.write(result)
 * 
 * if __name__ == '__main__':             # <<<<<<<<<<<<<<
 *     fill_command()
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_main, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_9) {

    /* "Cython/Tempita/_tempita.py":1088
 * 
 * if __name__ == '__main__':
 *     fill_command()             # <<<<<<<<<<<<<<
*/
    __pyx_t_8 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_fill_command); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1088, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Tempita/_tempita.py":1087
 *         sys.stdout.write(result)
 * 
 * if __name__ == '__main__':             # <<<<<<<<<<<<<<
 *     fill_command()
*/
  }

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init Cython.Tempita._tempita", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Cython.Tempita._tempita");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_open); if (!__pyx_builtin_open) __PYX_ERR(0, 155, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 167, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 280, __pyx_L1_error)
  __pyx_builtin_eval = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_eval); if (!__pyx_builtin_eval) __PYX_ERR(0, 307, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 630, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1057, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyDict_Type__update.type = (PyObject*)(&PyDict_Type);
  __pyx_mstate->__pyx_umethod_PyDict_Type__update.method_name = &__pyx_mstate->__pyx_n_u_update;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "Cython/Tempita/_tempita.py":137
 *                     name = globals['__file__']
 *                     if name.endswith('.pyc') or name.endswith('.pyo'):
 *                         name = name[:-1]             # <<<<<<<<<<<<<<
 *                 elif '__name__' in globals:
 *                     name = globals['__name__']
*/
  __pyx_mstate_global->__pyx_slice[0] = PySlice_New(Py_None, __pyx_mstate_global->__pyx_int_neg_1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[0])) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[0]);

  /* "Cython/Tempita/_tempita.py":155
 *     def from_filename(cls, filename, namespace=None, encoding=None,
 *                       default_inherit=None, get_template=get_file_template):
 *         with open(filename, 'rb') as f:             # <<<<<<<<<<<<<<
 *             c = f.read()
 *         if encoding:
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "Cython/Tempita/_tempita.py":241
 *             self._interpret_for(vars, expr, content, ns, out, defs)
 *         elif name == 'cond':
 *             parts = code[2:]             # <<<<<<<<<<<<<<
 *             self._interpret_if(parts, ns, out, defs)
 *         elif name == 'expr':
*/
  __pyx_mstate_global->__pyx_slice[1] = PySlice_New(__pyx_mstate_global->__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[1])) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[1]);

  /* "Cython/Tempita/_tempita.py":246
 *             parts = code[2].split('|')
 *             base = self._eval(parts[0], ns, pos)
 *             for part in parts[1:]:             # <<<<<<<<<<<<<<
 *                 func = self._eval(part, ns, pos)
 *                 base = func(base)
*/
  __pyx_mstate_global->__pyx_slice[2] = PySlice_New(__pyx_mstate_global->__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[2])) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[2]);

  /* "Cython/Tempita/_tempita.py":753
 *     expr = expr.strip()
 *     if expr.startswith('py:'):
 *         expr = expr[3:].lstrip(' \t')             # <<<<<<<<<<<<<<
 *         if expr.startswith('\n') or expr.startswith('\r'):
 *             expr = expr.lstrip('\r\n')
*/
  __pyx_mstate_global->__pyx_slice[3] = PySlice_New(__pyx_mstate_global->__pyx_int_3, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[3])) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[3]);

  /* "Cython/Tempita/_tempita.py":757
 *             expr = expr.lstrip('\r\n')
 *             if '\r' in expr:
 *                 expr = expr.replace('\r\n', '\n')             # <<<<<<<<<<<<<<
 *                 expr = expr.replace('\r', '')
 *             expr += '\n'
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__13, __pyx_mstate_global->__pyx_kp_u__10); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Tempita/_tempita.py":758
 *             if '\r' in expr:
 *                 expr = expr.replace('\r\n', '\n')
 *                 expr = expr.replace('\r', '')             # <<<<<<<<<<<<<<
 *             expr += '\n'
 *         else:
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__12, __pyx_mstate_global->__pyx_kp_u__4); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "Cython/Tempita/_tempita.py":803
 *     start = tokens[0][1]
 *     pieces = []
 *     context = context + ('if',)             # <<<<<<<<<<<<<<
 *     while 1:
 *         if not tokens:
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_if_2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "Cython/Tempita/_tempita.py":824
 *         part = ('if', pos, first[3:].lstrip(), content)
 *     elif first.startswith('elif '):
 *         part = ('elif', pos, first[5:].lstrip(), content)             # <<<<<<<<<<<<<<
 *     elif first == 'else':
 *         part = ('else', pos, None, content)
*/
  __pyx_mstate_global->__pyx_slice[4] = PySlice_New(__pyx_mstate_global->__pyx_int_5, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[4])) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[4]);

  /* "Cython/Tempita/_tempita.py":846
 *     first, pos = tokens[0]
 *     tokens = tokens[1:]
 *     context = ('for',) + context             # <<<<<<<<<<<<<<
 *     content = []
 *     assert first.startswith('for '), first
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_for); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "Cython/Tempita/_tempita.py":881
 *     first, pos = tokens[0]
 *     assert first.startswith('default ')
 *     first = first.split(None, 1)[1]             # <<<<<<<<<<<<<<
 *     parts = first.split('=', 1)
 *     if len(parts) == 1:
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(2, Py_None, __pyx_mstate_global->__pyx_int_1); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "Cython/Tempita/_tempita.py":882
 *     assert first.startswith('default ')
 *     first = first.split(None, 1)[1]
 *     parts = first.split('=', 1)             # <<<<<<<<<<<<<<
 *     if len(parts) == 1:
 *         raise TemplateError(
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_int_1); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "Cython/Tempita/_tempita.py":922
 *     else:
 *         first = first[:-1]
 *         func_name, sig_text = first.split('(', 1)             # <<<<<<<<<<<<<<
 *         sig = parse_signature(sig_text, name, start)
 *     context = context + ('def',)
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__7, __pyx_mstate_global->__pyx_int_1); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);

  /* "Cython/Tempita/_tempita.py":924
 *         func_name, sig_text = first.split('(', 1)
 *         sig = parse_signature(sig_text, name, start)
 *     context = context + ('def',)             # <<<<<<<<<<<<<<
 *     content = []
 *     while 1:
*/
  __pyx_mstate_global->__pyx_tuple[8] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_def); if (unlikely(!__pyx_mstate_global->__pyx_tuple[8])) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[8]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[8]);

  /* "Cython/Tempita/_tempita.py":945
 *     defaults = {}
 * 
 *     def get_token(pos=False):             # <<<<<<<<<<<<<<
 *         try:
 *             tok_type, tok_string, (srow, scol), (erow, ecol), line = next(tokens)
*/
  __pyx_mstate_global->__pyx_tuple[9] = PyTuple_Pack(1, ((PyObject*)Py_False)); if (unlikely(!__pyx_mstate_global->__pyx_tuple[9])) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[9]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[9]);

  /* "Cython/Tempita/_tempita.py":1045
 *     parser = optparse.OptionParser(
 *         usage=_fill_command_usage)
 *     parser.add_option(             # <<<<<<<<<<<<<<
 *         '-o', '--output',
 *         dest='output',
*/
  __pyx_mstate_global->__pyx_tuple[10] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_o, __pyx_mstate_global->__pyx_kp_u_output); if (unlikely(!__pyx_mstate_global->__pyx_tuple[10])) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[10]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[10]);

  /* "Cython/Tempita/_tempita.py":1070
 *         name, value = value.split('=', 1)
 *         if name.startswith('py:'):
 *             name = name[:3]             # <<<<<<<<<<<<<<
 *             value = eval(value)
 *         vars[name] = value
*/
  __pyx_mstate_global->__pyx_slice[5] = PySlice_New(Py_None, __pyx_mstate_global->__pyx_int_3, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[5])) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[5]);

  /* "Cython/Tempita/_tempita.py":58
 *     """
 * 
 *     def __init__(self, message, position, name=None):             # <<<<<<<<<<<<<<
 *         Exception.__init__(self, message)
 *         self.position = position
*/
  __pyx_mstate_global->__pyx_tuple[11] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[11])) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[11]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[11]);

  /* "Cython/Tempita/_tempita.py":99
 *     default_inherit = None
 * 
 *     def __init__(self, content, name=None, namespace=None, stacklevel=None,             # <<<<<<<<<<<<<<
 *                  get_template=None, default_inherit=None, line_offset=0,
 *                  delimiters=None, delimeters=None):
*/
  __pyx_mstate_global->__pyx_tuple[12] = PyTuple_Pack(8, Py_None, Py_None, Py_None, Py_None, Py_None, ((PyObject*)__pyx_mstate_global->__pyx_int_0), Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[12])) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[12]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[12]);

  /* "Cython/Tempita/_tempita.py":549
 * 
 * 
 * def lex(s, name=None, trim_whitespace=True, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     """
 *     Lex a string into chunks:
*/
  __pyx_mstate_global->__pyx_tuple[13] = PyTuple_Pack(4, Py_None, ((PyObject*)Py_True), ((PyObject*)__pyx_mstate_global->__pyx_int_0), Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[13])) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[13]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[13]);

  /* "Cython/Tempita/_tempita.py":686
 * 
 * 
 * def parse(s, name=None, line_offset=0, delimiters=None):             # <<<<<<<<<<<<<<
 *     r"""
 *     Parses a string into a kind of AST
*/
  __pyx_mstate_global->__pyx_tuple[14] = PyTuple_Pack(3, Py_None, ((PyObject*)__pyx_mstate_global->__pyx_int_0), Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[14])) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[14]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[14]);

  /* "Cython/Tempita/_tempita.py":747
 * 
 * 
 * def parse_expr(tokens, name, context=()):             # <<<<<<<<<<<<<<
 *     if isinstance(tokens[0], str):
 *         return tokens[0], tokens[1:]
*/
  __pyx_mstate_global->__pyx_tuple[15] = PyTuple_Pack(1, ((PyObject*)__pyx_mstate_global->__pyx_empty_tuple)); if (unlikely(!__pyx_mstate_global->__pyx_tuple[15])) __PYX_ERR(0, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[15]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[15]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<16; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_slice;
    for (Py_ssize_t i=0; i<6; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 10; } index[] = {{1},{16},{23},{72},{72},{22},{26},{46},{58},{28},{40},{42},{111},{23},{20},{18},{17},{46},{38},{13},{12},{31},{4},{45},{45},{22},{13},{17},{16},{41},{51},{61},{58},{33},{1},{2},{1},{2},{1},{1},{1},{1},{2},{1},{1},{1},{1},{1},{1},{1},{2},{2},{1},{1},{0},{1},{1},{1},{1},{2},{18},{8},{5},{4},{9},{8},{28},{4},{8},{39},{107},{7},{5},{6},{5},{4},{2},{3},{46},{11},{6},{13},{8},{32},{9},{12},{6},{2},{8},{110},{3},{4},{4},{3},{8},{20},{21},{25},{21},{7},{8},{9},{18},{23},{9},{5},{6},{15},{15},{15},{15},{14},{18},{8},{1},{4},{2},{12},{20},{8},{8},{14},{17},{11},{20},{19},{20},{20},{19},{28},{13},{22},{21},{14},{20},{32},{29},{29},{35},{23},{23},{21},{17},{17},{23},{14},{14},{19},{24},{25},{23},{22},{27},{14},{22},{19},{6},{14},{10},{7},{6},{4},{4},{4},{18},{4},{4},{4},{5},{8},{10},{11},{5},{12},{5},{17},{17},{14},{14},{17},{1},{8},{6},{6},{9},{17},{18},{3},{4},{5},{11},{6},{7},{7},{4},{7},{7},{8},{4},{5},{7},{6},{3},{7},{16},{12},{15},{17},{8},{4},{10},{10},{4},{7},{7},{1},{4},{4},{4},{6},{8},{3},{10},{7},{6},{6},{5},{8},{9},{9},{7},{4},{6},{4},{5},{5},{8},{4},{4},{8},{1},{9},{8},{8},{8},{12},{19},{13},{8},{5},{3},{13},{13},{8},{4},{9},{10},{14},{15},{15},{3},{7},{17},{12},{9},{11},{9},{11},{7},{5},{4},{1},{2},{2},{7},{5},{5},{11},{7},{16},{8},{10},{15},{16},{14},{13},{18},{2},{13},{18},{4},{5},{8},{4},{1},{3},{2},{4},{10},{8},{9},{18},{3},{4},{11},{6},{5},{7},{6},{6},{1},{8},{5},{7},{13},{7},{10},{15},{3},{4},{8},{6},{9},{10},{9},{4},{10},{2},{3},{3},{6},{4},{7},{8},{2},{3},{6},{5},{10},{10},{9},{13},{10},{9},{13},{14},{16},{15},{34},{7},{6},{4},{5},{30},{4},{6},{3},{3},{4},{8},{11},{4},{7},{5},{2},{12},{2},{2},{4},{8},{6},{7},{5},{8},{6},{5},{1},{4},{6},{4},{5},{12},{11},{10},{3},{8},{8},{9},{17},{5},{10},{4},{10},{5},{12},{9},{10},{12},{5},{6},{10},{7},{6},{5},{3},{7},{10},{3},{5},{8},{9},{16},{17},{13},{12},{4},{10},{8},{8},{8},{6},{18},{19},{8},{15},{4},{8},{11},{11},{6},{5},{7},{4},{1},{5},{10},{6},{3},{7},{12},{8},{6},{8},{6},{4},{4},{8},{2},{5},{3},{58},{389},{68},{54},{29},{78},{30},{58},{199},{332},{286},{180},{26},{18},{48},{11},{136},{17},{26},{323},{21},{55},{122},{113},{105},{137},{50},{461},{79},{77},{307},{56},{10},{99},{72},{7},{27},{33},{45},{9},{11},{18},{77},{137},{262},{67},{400},{536},{628},{467},{100},{49},{383}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (6110 bytes) */
const char* const cstring = "(\265/\375`\360/\245\276\000\272\265\004';\360X7\314\300\304\210\255\002\036+\032\035\326\220BR\006\371\204\271i\241h\334\264\311\315\372\335\007\326\337))\223\352\322\264\022\205\024f\225\245O\303\322hy\211\202\305\264p^,\276\010N\002G\002o\002O\303\237\037\237\037\037\034\034\317\255\007\267\203Ss\236o\377qw\335\350y\256m\273;\317\220s\370\376\234p@8\035\240\033\017M\017\216W\272\260IK00owiY\236Z\262\254\352\321\223z\215\245E]!\335\305\373\272\252\302\267-[\312\037\336\205\\.\234\356\266\363\303\203\323\225JA=>8\272\037\037\244\262W\003\001iA^\3127\t)\306Mb\223\322\256>\355\227\035\252n\315};\313\360\307S\251\225K\261\304p,\241=\020\020^W\323\020\227)\355\233\257?e\210\272\256\374\327_\267E\3356\270y(O\371N\330Tnt\227\253+O7\334\366\367\203{\331\325rj*$$\344\211\227\252\035f\325\227u\202\327\362\335\245\215\326\241t\256\200\214(\235P \033i\251\374`\341x\221\202\211\231\232\212\212\n\001\231R\212rA\352\350\350\260}d\270`\260\203\322\305W\243\363\345=\270\345(\353r\037\357\260\315\335%\257\345\235\303\327\335V8\344Me\207\333v\254\233\363\240\332+\207+\333\226\354F\215JV\330\262M\254P\311\362\246\366\345\254P_y\220\257 ?\266u\325 \367\375LMq\247\315\356\266Z\356\266\207\357\265\364\365\332\324T\333c{\333\036G\331\204\356_Y\2525\336#\344l\371\272\373\355\275\tm\327]9dUuj\252w\225\307\326k\034%\013w\341w\263\275TeqJ\036\334\275\026[\312\235J\033GWC8\312\027\345L\273&u\005\031\272[M?\370\332;\334\016K\036\216\255\364\275\352\006\333y\253\262*\312\3025\266\364\355\034/\374{\341\266\344\257\352\nkzW{\373+\267\373>\341R\026~)[\246\246^\334\250\250\222\357\312\267\303N\275s\367\367\204+]\374\335k\271\273\273\177%_U\237\260LyW\267[\262\255\372\3768\372\204\033\376\336SD\304\345\277\266]\317\220\375\252?'\256\013a[\337;\344\266\224\247j\260u\177e\217UY~\276+\274y*\013\227\355\313\341u\007\313\316\337\341\256\344i\213\362\264|[\226\3353\254Z\3320X\025\243lY\216\322myn\255dyY\356\004\367\334]\246[\246\014\350\\!\333 j`l\022\307b\262E\306:\"\t\021\241e$c\022\2406\177\006B\355)^5""\351y |P\314rdT\033\t\325\036VJ4\305\214\"\363o\344o\036\276\3057\267\217Aa\036\315/\360\313\006\343\376%\377\365\027\0208sk\016\222\213\376\355\257\3707~\220\031\315\024?!3\222\037\365-1\303\202\021\350\035X_\303O\220\300\277\177\216g\360\021\013F\330\313\270e\341\3279\211\005\342\223\233\274\362g\337\345w\2167\231\3654\337\263\351\034\3152\227\260\212@\372h>\311\250\027\352\231\225P\021WRK\310\272_[\250I\030\200\301\225\205\004k\036\261\250i^\302\243qK\305B\206\217\"*\274\216\344\202\221\364\270X\3662\312\030\214&\361u\000@p\005\214u\210/\003\343\354c\220\306\031\315B\253i\244\321\244[<j\204_\266j\026\215$\367>\355\327\370\2267 g\235\014\3734\376\025/\274\2149\317\022\277D\205\230\341e\234\305\235hBD00\232~\242U\377T\250\235\220\355n\017\252\360^8\310\302\351\017>W\225\247\252\357\204R\335\367\354\303\316\341&\264\277\352\372\353\274\237\273\273}e\333\276s\327\r\003\177oS{\006\371\357<\177-\312\325\237\357u9\372\3667\004\006mW\227\020\266={\333\333\316\236\357\323o\370\236o\257s\325m]8m}\350\313\252\333\351\327y\274v}\317t\363\325\351\02465\261j\313\324\333\256\236]=\317'\316]5U\325\337\312}\277\236\313\353\347y\276\335Uy\275\335\341}\256\347\331\262\274\276\356]\273\366N\036O\330t\276\352\311\177[\330\272\334\355j\373\353\273\223\363\276r\316\333\364<]\265\367_w]\030n\331\224]\325\237S\213\276'\357+\272\343\350v\337\023\355{\355M,\354C]\216v\037\312\366U\205w\274\225\367sw\016\323v\267\353!\255\212\356`\037IY\376\373\355\363\327n\376\302\257\372\366\035\334O\247\326\345\361\324~\276(\177\342-\357L\323}\236\357~\271\215\217\333\272.\356\374\275\235\307if\2326weN\235\017N\020\217\003\275O\274\347\244\tu\311\0216b$\032\252\207\202j\033+\270\250Cp\363D\254Y\262\316\370`j\2747\271\305c\251l\323\r8@\257\3003a\3214\300\367\273bu\014FC0\323\261<\315m\206\207h\014\244\207R\201\262\340\267\241_X\342' \214\021\020\035^B&\360\203Jb\006\002\026}b\"\317\344\264&\253e\262#\271u\032\032\237\374PG\326\254!bD\214:n\377\300\341\373\024I\273sJ\323\217\331\250M`:,D X\356\007\267O""\270\315&\0305\371y\342\026K\246\371\260w\250\360>\027\263Y\271\301P\333\314r2\211\354A\223kJ\331\220i0\223\311\350\317}\331\257\311d\226|\022#\267\371\024?\264Jd\001\223mB\370\005\251xF\006\222Afr\nm~obd\215\371\207l\264n\366\220]SD\223$\200\350\210\022ed\336\370\201xp\"t\"\004\023g\266\307k#\027\027\021o\300\330\207\271\351\342[\314\300\2229\022\352\004V\221\206\236\230\241\276\311\317P\250\025B\026\024L\016\212+\364\320\\$\337\344\217\210Z\347\300\232\201\262\016Soc \3243\242\213\010\223\305\344k\342\241e\222\022\277\246\2175\310\324\330\341f\026g\305\032\272c\026\222=r\177\340?\240\261\217\251\005\3125np$g\234L\364k\024\024\265\rv\200r\233\251\010\r\216d\364\215\346\31592\357\023\330\304\267\317\360Q\222\232X\266\220\372\\\216\331@\202\304\261\227\0218\340\323\032\342\236\t\202\001\377\304\363\230\346@<\000\376\032/Wc\311\273\257a\016\221\003\361B.\306!\302\tn\374DT\030\"\302\200\362\226\t\344\007\322\243\260\366o\3708\277\022sb\002\nl\023K\210\257F\034\020\003\2115\242\253U\363Bq\203U\314\n\347\345\224\2133\342\024\342\214\330\253\n\374\000\353\357<\001\216\370\232\311\244\214\362m\314\017\364@>\030\357\230\340\346M\217\340\020\243\260P\"bR\356h\325d\221g6\311\2503\346#\231\345s_\342Ub\005\226\1770w\334\020\263>\216\357\210aF\222^q0\346\346\223Z]k\325\263\231\004@)n\3700\317DL\230C^rt\321\014\223\201\377\311\327|\200\007\306\265X\210Ue\372\231I\024\3552#\310\032_\310\343\304f\254R\204\240\003\244gy\215\243m\003\t\030\361E\2162\356\363\250\\\036\373\200\037\350\327b\265\220\224\211\205q\253e\242x\370\232\003\217\335_\010%\036e\231E\004\372\005\307\202\261\322+\340W\250\272m\310\035\254\242\006\215\334\222\021 \021p\275\311<\233Sd\017\210\032Bv\274\001\251\320`\244\273\036\003\021\t|$\253\232]lv\345#\034/ \016\262\250Kb\0134\014\261K\202\341\217&\212\3241\247\n\260br\000\300\341\352\373\274Q\314\302\202\347\332@\306L\266\244T+\005\325\257\225N\261u33\314\007\023>b\356\3714\010\243l[\225\320\030\3404X1X5\245\263\317\366S\226\314D\324`\223d\205Pd\312\220\031{\274""\232\207\326\250\256\326\375\324\006VAE\034\272U\3643>F\004\002\237\033f\223\003\243(\303Q\003?\310\236iO+e\320\202\321\307w\275 2\346\250\027\201W\201\207\260\360\022SFEuQZ\244\0259\350>\253Q\\n\2401h\026\001+$:\203N\347\222\031\341]\221\207\004\003\000\261\253\326q\350k\250q{\316\315A\367o\004\263\310\017)>\313\3762\237\306\372\006249@\346p\2718\220j<o\373\2178%\345\224\n\363x\273\3117*\2639#0D\t\343\231\026\023\240\006\321\245A\306P\000\365\3546\017\277\303\237\315\254\\\305\035\r\003\244\t\306\374\306\261w\333\271\342\255\330A\007\320*\246\300Qi+\315\242DY\263\300\346\001\321\240\305\241\341*\370h\035eZ\027\017\306\231yQGU\031\014\000|\\\231\264\217\374\341PW\321\004\264\201\222gQ\231Y\221V\272b\217\026\316\0163\204\323A\317\r\341\357\310\222\027\213~\230\315X}<\3505\021\023\016\2146\\g\3137\332@\357f\211\236\32153Y\350\223\334\264H\310\200\026A\006\304\221E\357\270\300\240)K\035\347\032\371#.\362h\032M\322(3\227Kf>C\256\346\311\200\331\206w\301d\374\312\212\374\316~\304\002\232\243\007n\034\352\031\2249\265!\213u\032\r\265l{\213\231\324\021\370]`\014\267O\004\2611\223\022\236$\211}\010\220\207zE\242\266\221MYb\226\235\344\036X\0249:\362\006\016\342a\306\014\362\216[\316\311mD\034\003\201\262\310D\375>\271G \r\246xB\333\320\310\035rL\2669\004\206\330\250C\027\254\254\223\210dD$IRHkS0@\000a\021\301lB\2562?\243D\014]\0102\215BB2\"\242$IQAJ\303\032\231\332\266^\364G\370\275d]\264\325 +\330\267|\206A^`\3550nv\255\2562x\230[Y\242\3045G\003\213W\341\330o\373\336mO\2524\235\026\245\357p\330\375\263\240\345TU\005P \303w\233r \374ANI\rK\370\343J\361S\303K\"\370]/\242.\273\274x\207`\332\010\305.\350\234N<\216xr\007\352\232\3774\033\027rp=\031{\261\242t1\210!\254\266,\250t\375G\254[\2425\377\243\013\027\3573q\264\271\342\321\031\2500\"\004\223:\340V^_\231,\212\001\264\253\375\031@-\361[\242\255#~w\r\005;b\203jNa/\341\037\021\242\275\250\350\326\r\306\313\005\027\355\371\323\371g\337J\250\321\202\375L\245\016#\250s\024\202n\307\274U\321D\254\233@*\363\370s+x\236\320\261""\3277|\341\300\353\375]\236\036*eTe\000\r\352\220+*`L\035\300\332\013\324?Yf\326&\340\362y:}\203244o\353$$\366\257\021J)\n\014\276\332`u\215\371\207\\q\216\372\270I\004\374\216,CCFW\002*\376b\315\005\000-/-\362\213H\360]\334`\244\005\302\304\231\270\273hc\026\270^}\2435d=J\201\272\202@u\036\244\3570:\3067\334\242}\035\302\271\273\266\331\\\003h\246\272\320\331\177\260P<\210\301\257\207\265aA1\267LRx\335\010\204k\370-\340,\202\272\276o\026\377YE]t\350,\r\014G\265\345A+\205\r\237\233&^\316P\274\221;\337\376\337o\260\332\350\305@yd\377>P8gM\032\250\310\0268\024\250\"\014\233!\177\017\322\375\356\377-\312E\231K\350\037\315\274\324Q,I?\000\367\363\316\023j\236\373b0\320\177\2264\361|\002\332,\t\031JR\341.\350\366\265\203\323\017q+\371\311\034T\372\014?\235\301c\255qtC\020\246W\201\034\262z\001\317q\220\231Bq\341\344\302\255\255\t\247\307w\336\037\237B/P\254`N'\225 \214\372\26237)\271\370\025\343\270\221Z3A\210Q\227H\016\260\267\027\nr\013\307\377b\213w\364\331\031*\201\256\361y+\377U\3739\307\341\n\262lj\3634=\314\002\013\037\033\265G\340O\321\026]&\302\352\317e\323$\010+@*\320\336\324@\342\247u\233\313m\377\034\026j\311\247 )\0177H\013,\264zD\004Z\253\303y\0012\312A\361\306Q[\254\247{\0040>\374\204\r\"\343\246\243\201\206\"\232t$;\211B\246H\025\3248\364\201\252\3133\375\364\303\254\274\3258\225\351Cx}9;\315\274\276\215\357\0173U\240\271\273\217\201J\206g&\236\t`U\241\022\260\356\316\352\204\253h\202\216D\204\265?\314*\236\017\356\266\332\311\245$\005\320bK\014\206\224\276\356N\374\272\272\202@\207\021\323f\275\264\230\014$!\356\214\010[\272\213\025Rb\206gx\301\200\357\324\255\376\276\310\223\272jN\275\367b\205:\215\242\203\tA<8b\037\310\321\364`\211\312x\352\315\227%u\271W\034[\034U\225~\017S7L\3549q\211\021\232\000sQw!\022j\312H\307\002\202\214\200x\334\201\346\010\245<\263]\215\003\204\262f\034X\252\231\214\r\256\205\2116\277\240\003\304\270\177\321\225\353\033\341\351\235P{\321\260\335\315\237\256\201\351=t\025\302\206\360\254\356 =\031JL\221\345eA\335\354P\243\204""\215\205 \306O\366\362\005#\322O\254\307\224\240\223/\220\255S6\322\361\010\\l\320\317\306:\236\244D\333\010y\201#`D\2117\213\215%\346Z<\030\342\034&\205\031Zr\222Q\264q\345\317UP\222\3741j\254\225\255\344\356o\003\273\326\202Dn\200r\237\302\222\037\361\002\017\225\310\000\261\010\322\013T\267\265\256\004\002\353\301\217\027\247\331l$\246\343\177\022\022\250\030\311\201\016; \010\020\304\0052\260\032B\2231\334\227\204\224\203\303\306\025\213\226r\002\224\307\235\t~\202\267\247\r6\316\334\324?M,a\033\304\251\257*\r\322\372l49,\321\332\337\375\375\307~\345\204\241\002\367\303\344_J\223RW\227j\361\243\r\270F$\213\361x\273\005u\016\000\217\014R\362a\213E;\0240(\\\2533\324Vp\206\231V&AY\270\367\316\344\247nB\327\371\354\204\207\372\\s\233\322\367B\331\247\n\316!\365b\313N\301\233\374F\3210p\"\221\377\234[\240r\3136\371\335x\257R4N\230\201\211\247//\371\306\037\314\233\002R\220\2752\213B,\241\203VV\"\340\003[\364\225%I\214U$hw\343e&\354\026~\244i*\330\266\013P\346\233\355$\"\177y^w\n\364<\000r\034\316\367{\016\224\305T-O>\241<Q5KG\030\325\371\201&\021\207\t\322\345\243\216S\245\250\307DZ\003\036\200\343V\005\2170\207\271ar\346\276A\340\231\275\006\225\036\306\n\036r\330\372\030\210!7q\235\211\010\267\235h~\254\000\224I\341C\252\313\361\000\342V:\t\263\027\216\022F\331\354\004+^Z)\306\253f%k\004V=\313\210]\211<y$\304\231\207:E\024\226\200\032+\316\022\236A\001\303\262\270&\363\364U\321\250\251\313!\225\227\274`\345\371:\211\noZa\306>+Cf\245\t\203\001\207C6\346I\360\005\302|\252\020\305\351\360\3433\351\024\032 iS\372\274TN\025s'&a\367ge\300f\352\202\352\271\325L\260\211\267\303\340\024\006\275BX5\361\3035a\317\014B\363U\302\221\357@&HPSN*\r\230\344\233\021\213R\261\261\205\330t:\345U\225]\010\336\3445\264\"D\2074\274O=\023\3401\370\2235yV\n\352\03762\332^q\323*\354\264eE\265_\366\016\354R\327\235\373\361\214\n\212\226S\250\024z\326\363\242\233/{\205\"\200\255\025\306\337\005\244\254\033\r\342\237\221\350\331;\033\263\320\242\2520\226E\000\016$\335p\3454Y\303o\032Y\225#""\rP\026\321\256\255y\nW\333\315y\3458%|:S\216Dk\244w.\300\243\322\310S@}\320\2722\313\211\241\233\014>R\337YP\316\376\364\3003d3\305n\n\004\214\201\371\003\004\2167z\324\356\272j\360\r`\377\010\231\345\207\024\021@\026\036\241V>\014\375\013$\375\276-'h^d\264\377\352j|^r\237\022:<\035\236\373\025l\356 \250/tAN\246$z\244\354\250,\206\256\344\346.\370\210'\342N\260!\022\021\035\001\365\005\232\316K\255r\377\325\001Yy\377!\217\240\230\017?\216TTNe\332\033\244#\226fO\020\225\267\307\275\002Q.\"\227i\371\333e\304\327\000\306\215$\240\271\210n9\317\351\257l \226\264B4\236*\302\230E-i\344a\325\200\326\374\302\365\002\333`X\227\236\345\345\367\231\324\365\222\350\215\334\341\356\2232\240\343\n\311\224\303\205\020\t\372\336\254\227\367\003\253\247\322\332\352\032\010e\351h\3561\211\362\235\361R\253a\005\350T?\025&Qk\010\233P\375\373\020^X\372\275M\332\323\370\320\005\235xy\335A\3432wa\266\200\273\206P\300V\234NT\222^+\010\275\260P\253\200g\017S\266\301\373\302\005i\314v\033\032\370\256T\\\366\271\362\320\364\032p\014\021Z\306\240\265\367\014LWj$\t\241y,$\312K\024\216\205\261\353\307\034 '\213\305:\276&\202\302\322\276\241*\037\311P\t#\217R\373\220\220\224m\177\374\016\236F\021\004\301\273\314\300\034\014\320X\275K\366\241cU\322\373l\206\341\013'R\220V2\345\330\331\271\366\222\223\257nF\244[]\035\210#\364\037\n\260\235\232\314\372\000\342\226\376_\331\014\n\254\234\035\375S\347ZEU\234\364\306\242\377x_\351\370\204\333\302\001/\232T\271\317\021\205c\214\355\210\211\215N8\227\304\334z\220\303u\217\321)\312j\241?\027\365W5q\202\003\244\337\351\031\030ye8O\254\321\321\324e\362/4\262\261cY\350\216\226\365\336\026\326\240\203\230[\3249\355\313\023\254\335n\234}\010d\367\247 \243\0379\024P\354\002P\364 E\247\304f\\\032mk\305\344\216(\216\307\243\331\010_\235\273(YG\360~V\222\273W\033\330\207\375\354\323\r\217G<\331\213\001\324\037R\276\347d\2311\215Z\373w\202\316\360t_i\232R\006J\2265P\246%h\271u*bO\357\361\355\010j\361\215\374\034|\327\016\222\356\243\033Y\017h\314\336\331y\177\321""\023\250@\366\213\264\323\327`\3722\220\300\254\254c\206\033\020\245\322L\273\254\263\336\323'\335\377\320\357S\352\021\325\304'\335\337\001\360\312\023\006\344\376\320\271\261<8'.\350\253\030\201\243,\004(\316F\340u\025\230\324!f-\177U\210\313\023R3\205OpS\\\255\370\277\262\241\225\233}\365\005p?\352\323zQs\203\364\232^a\247yc\266\033a\306\301`u\205J\333\341[\335\013\205\231C\215&\374\247C~\013\273!T\334\306X\345#2\261/,l\3760F\241k\td\354p\002xN`d\\\273;\264V\202\n\3775\305`\025\363\246\310*V\254)\004\215\371\212H\355\260o\017RH\325\242p9\363\306^Ak\262\324\220\374\3133\345F`\317\312\203\275\352W\236\345\345t1\300\261MK$\216\307\017}\tL\304o\327\023\321\262`\302\024G\246'\231-a\205\300\035\\\226R\027\241\362t\322?:\227\342z\002\272Y_u\3057\3636b~u7\303\270\022\221\276\037\216S\266\003^\006\305\242\023@t\233\336\000\004\\\313\347\370\034>\036ZH\210\034\301\374\217\234\277\3403%\351\371fI\242\2630\264\235\305\232R\240\234m\263\253+\211\373\242}\373nK\223K\322\000\275D\332\251~\354\217Zu\213mE\260\017.\276CD\267\232\354\327b\243\350W<\326\251][x@U\005J\345\026\365\215\300\273{\366}\253\230\006\340\270\304\213\033\016\232K\275YA\250P\222\206k&S`\350H/\3138\253g\316\025\023D\205\n,\365S\252\324\013e\232vB\276\016G\305%\341g\226\244\253)@\301\302\374#\274)m\326\345\224AgP\000L\210\265w\333\254\341\312a\347\001\255G\241g\301\244\352\234\367B\\\026\007\303\337\367yS\033S\320\311\266(\274\230f\230~\203\320$\375\026\306\331\232\234\271^\221\220`5T\022\304\"\245\372\343>U\001Z\360'\350\347\363\221)\225l\303\"\013\021\3669\000h\014\361\300\370\036\377\326_G\"\210\252,\017@}\223\006\244G\227:\216\354\354\364d\271(\242#\256V0\346\243\016\212\302N\247\243ri\037\035T\266\210\261v9\200\324\316\373\251~\310Z\276\345\257\310IY\270\250[\266\026y\377\324Gfy\347\373\277\266\241\304\331BH\001.k\2057\220\001\323\373\032\252\247a\004\324\347\022e\272Z\001\262\217n\366-\021\244^\264\326\"E\244\272\002L\322o\340\363\225\333`\272u\3628\253\360\204\026\212\343U'\2360\263X\276W\216DD\372s\037""\"x\326M\375\214\307\274\231\320\303-\202\235\001\257\006\333h\240!.\324Gk\271\2521\210U\036\005\016\251\347\316W\325\366*\3424.?2\302n[\354\305\241\307\332\221rh\270\000\233`F\013\312h\223\205\314%$$\303Y\r\3259+\346\023\200\202;@\241\035\232\276\270\030\246\344\235A\362\304p7{q#\341\257\264Dd~16N\330\271\"\337\373\244p_}y_\314\030\201\221#=\343\254sN\006\266.\251\272\006\265\356\300Tf\030$\303\315\246\314A\373\036\000\"(\033R\372H6\305t\024\320\2570w:\217C\372\246~\320j\264\311\007\304\250\274\220\237RL!\245&*T\356\303\200D\002\375\375\346\331\335\377\033\033\016\214\277\351\036o,a\260\\\244;A\017\n\225\356\031\023=HM-a\216\306\035F\n\253\270\261\014,\254\017\261\351\371\001\322k\362\311\324\201%\277\"\245\273\345\013f)\225\227\3022a\304\2178\216\024\253\324\342\004\345\323N\227\030\226S*|\252\241\335\212\261\236?\360\237\370\305\246\356\226\343\353\003\270\003P\272\322\232p\317R\307B@\334\302oZ?s^d\363\250\177D\"\344!\254\241\272`6 \252&\021%-\203G~\033\234\230\203-\3456:\253\263\035\307\310\377\331\013\003]_\235|\373^T\351\034\300K\023?\233\306\363a\313&\363\263,\257\016\351\nV\365\327\346\353\200\213\200,&\311\021\020\273\237s|\204\254p!?\023\324\t\025\372\n(R\032\036;\227\024_eYB5\267\016\014\356\264\222\002b\0077]\377\236\255\207\r\240\304\035\006b\0105\255e\000\032\352\364\204\214\244\342\rz\013\345\345]`\323$\025*\347\243\212\007\324L_U\005\n\246@\235V5\3721Km\361\022\356Z\362\260*W\240\231XQ\232\243A0\003I\010\233\223\247[\360p\344\252M\306E\204\233\227\235\202h\321\014\375\325\010qc8\306kQDMF\221\234\226\346_&qO\322Q`\361\204\020,\006";
    PyObject *data = __Pyx_DecompressString(cstring, 6110, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (5690 bytes) */
const char* const cstring = "BZh91AY&SY\201+\367\352\000\004\032\177\377\377\377\377\377\377\377\377\377\277\377\377\377\277\377\377\377@@@@@@@@@@@@@\000@\000`\027\314\370=\"kA\317\035q\303{\234n\341\235\272\3300\367\263\242\022\327p\000P4\335w\025Wc@\\\034\240\036\353\n\232\322\201\362gHQ\r\002\020\204i\222mC\321O&\210\362i\240\206\023G\246G\244\304fF\206\215\020\364h\324\362I\240i\243\312=L\032\230h@\323@M\022#S\3256I\206\244\315OM&\365&@\000\320\310\003!\232\200\001\352\006\200\000\001\246\232\006\2004\302$\212j\200\320dh\000\320\032\006CCG\250\3656\232\231\001\352<\221\354\2155G\351C\322\033H\006\2324i\207\251\224\t5\"MFT\364A\372\220\307\250\200= \323d\310\200\3044\006@\000a\r\000\r\000\r4=@h\004T\365\021\210\030\20010\232\003@=L\232z\236M\032 \r\036\221\350O\324\215\000\323L\324\017H\3042i\2020\002D\221\210\320A24LF\201\241)\352y\242\217iOD\365444z\217Hdl\246\200\000\000\3204\000h=D\344\307\241\034\243\370\201\207\266\005\256?p\367\373\210\017y\021\005\"R\037\002\343\0177\233\307\300\325\035\006\340 4\264\202\303\220^\260h\330\216\340\006\025\025\220\301 \026\265\216\010\202\226\300\323\265\200*\200`\276k\002\305\325\217awE\001C\274\304\206\301\275B\224J\361Q\031,VG\025\203\250TUU\247 \377\342iL&\023K\024S\252\240)\227\225\304B3bI\261\r\240\033\020\206\300\006\3206\000L\232\304)\215C\023L\267\342\013\206;J\310_\323x\316\357\017\307+\312\246\303P\3245\325sYp(\252\322i0`\233cC\006\014\006\232h\033\342\341\340\2140\321q\304\235\330\201\301\222E\213\001d\"\220\212\003\030\241\005\010\2632\215\260\361Zc\030\322k\214B\033\0222\030w-\363\241\207\030\021\343)\203m\214\033\341I\027]\r\250$-\326\335\256\351\244\2662\246\r0\301J\0266(\266Z\t\2469\214j\030\214\305\205\022\250h\254RR\305\212\010\210\240\215\204\241X.L\265\214\324H)\026,\202\204REX\261a4\203 ^E\021\031\212R\217)z4uty\357~c~\345\216\026yII\266\324\315\000\310F\t\033E\300Yt\361\316\264\250\306\331\016\342\tH\202n\t1\264\332!\324\254\257\335r\3167aQ);\024M\244 B\300\2145%\240\203\367\276\330\013\214\363\3231\021 lC\031\222\301[+hL\273""\317\270Y\334\226#\036p\325\244(b\250(\252\225Fi\2304\244\313\227L\206q\200\214\021\212k\014\r\032,\362\204\335\310y,\221\220\263\026w\253\373\321e\221v-\331(\265\005ek\026\333\350\026\354\226}wd\031\245\020\202\014\220d\006J\325\0140\256l\305\246\324\017\004``\260.\301\013\000\214J\3044\352\025\014\363\261\352\307\032\373@\361\001\260\217j\312\313K\225j\261\0140\034C\245\013IeCn{\361\236Z\302\354\226[u,N\272\270\243\024\345\313\020\233E\372UOOnA!%\330\303\3010|C\016o\247\351f\025= \307\002\253\330\234\364\200OR\301\376\217b\361G\027\242@={\034<\200>\02397\223>\270p\265\355\330\365v&\253\231Q\321\270\303\247Z\236\306\371\321/y*Q\022\244\225>~\337\334\016\266l\325\232\r\277\212\274\013F\226P\315\276e\371\333Z\305\354\n\357\316\364\177\364\317\276\027e\261Q\377\177\260\357z<\363C;\271\006\266\352\360\357\346\"\215\220\242\025\301\031\263\206\034\200\212=^\021\306\204\227p\254n\211\205\246/,\363\317\025\014\241\241\351\274\035\217=\260v\332\230\255[\010\357\215\205\326\355\373\247fl\310k\302\030\362\036\021\014\223\036\024\357\373\3542\242\301c\232\016T(,\301W\270\353\202\241\354\341\205\233\221\004K\\1w\210R\031\005b\361\262p\371zmC\360\017Q\241\365\275\230\231\032\372\354,\322VV\372\277\036X\354\267\322\273\322Z\312\302\273\331\354\3048\"\3266W}\271\216\246~\213\003\354t\021\360]\010\366?\006\365a\033\373]\347G.\316\010\340\034;}\231\346\226a\237,\000\300\350\3579\375\033x\344\262\022\306\006l\271w\2022\2277\257\354\273p)B\234\355i\356\325\243~:M@\260\246\216\205\002+\247\213\343\034\352\001\371\003\261\210\021\361\210\360c\021\362\304\371\224\017\000G\03768\3601\306_'\"\372\264\251C\247\213H\252\321\353ur\266+\367{T\261\333$M\000\246\346Q\300\313\346\346^}\242\353$\317\033,9V\374\331\316r3\234\031X8\200\273dK\344\026\2456\017\372\353\333\253\322\347M\211y\002\377\343\330\313\2561\236p\220\302\363\330\202\221\022\220&@\034\017\244\007\267\257\027\312\363k\"\3239od\362\312*h\220Y\331\211\016\"j\010:\243\242tbrY\360\3314 \273{%De\206\016fI\006+\220_t\321yzE\364>J{\264(""\250\024\n/l\241\214\347D\"\000 (\225\003\331\352\302\352\tQPR\n_\363\263\023:\212\240T\n\205gx8\203\2019\330\2708p(\010\000\324\006\003\2108\235\030\214t\245\342t\271\230\335\206\303lL\\\023\027&\221M\000M\232)\336\212\023e\335\306Q\227F\330\315li\335\023\342\232\004\313\241\363\272\306\035IB\377\227)\327\316\235\233\312\276\221\267\306\376\372\343\234\351\000B)\344B\374\257\t\303\010B\016|\014*l\231\304\r\215\306f\002\031\302)\232\330\204h\005\031\264\0208\265*\355\010\322\026\201B:UH\254X8s\003\237\1776\321\240\2226\341]\0306\326-\020X\027\303\010\236\031\315\004\3210224G\370\357{\375\371\177o\333K\3745Z\372\367mF\325\264[v\377\005\273x\325\005PUT*s\034\307G\241\025*\212\205k[\372\232\t\315Nd\376\347\317\313\305\257\202\301`,Z\326\327\363|UEkIrh\272\343\005]\337w\373\250a\375\237p\337\317\273\312P\323t\361\177w\267\252\270\276\373\274\3667\343\217\246&\203t\367y4>,\272\273\266\303\337\313ai!H\024\030\003\234=\300\360\006X\314I\3248E\313\2471\2136B\n\026\013!^7qK\261\205BPD\022\021\r\344\270\350\370\023\276\357\376\026\372\336,\204\221\335\214^\274\004\001\010\023\312T\227w\262t\207\347Bx\352\355\345\317v\027&{#D\030\310\"\242}\350\223/k\253\201\301pG:\342\034\227=\3748\033\027\037\326\262&\"\302\265\221\216\023S!%'^\234\211\0231\352a%\004\010\030\227\365/\247\034x\362\370\274\32697\356\333\325w\003\222\375\177\337\355p\366~\257\314\363J\306\007\232\277?y\277\324l\345\333\250\371}\031\223\313\205?\r\335\273\000\370Z\031\321\330B\243\272\200\025*\250@6\024\017\031\002\003\006l\206AB\020\3448\221\334\372\017\350\314]\253\326\302\344\320\362)\347O\363\251q\344\300kpv;\314_\tt\016`\3535\211w4\316w\232\t#\n\245\031eV\225\3105\"\037\336\250\303\247/FY\020\022\010\034\243\t\246P\341P\362\026\332Ia\017\261\014\333\224\333\007r\n\001g'\204\010$\026$\252\242d1c'q\251\330\247\231\032\320\232\305\0003\236\001V\341S\376\033\301\336EI\260\036D\260E.]\260h:(\260QPo\366\227{\215\351\315\263t\021+9I\325\337u\314\304\333^AG\233\017\021$K\355\031\033#\346\301\3361\214\377\302\206""\177\352=\016|\344Ya\243\221\231\300S\340`\317\343y\227\210\230\025`\251y\236'\373\022X\324\013S_\243\232_n\237\246\324\222{pT.\252K\341e\332(\031\032\337\226\3273\202l\033\235\353l\220\013v\327\006#\333Y#L\200\320\001n\277uko\266;^\001b\022\200\2648\001\2610\302\370\026\262\336\366,\332\271\023\010\317\230\235\021\224iL\005\274F\027\226\310\231\322L\336\232\303\211\332o\355\347$|H\032\363\212Ge\030\266\326\252[\332;(Yj\215\272w\345]#\212$\022\3009\357\277b\325\207\241\334\313\275\306.\211\342\371];4\357\217\313\217G}\251\033\304*\035\361\014\025@e1\264\010U\202:\032\013\277\216\374\033\020\200Y\002\301\312Pa\330u\207:\016u\317\356~\315U\235\270\271K!\267\017\203PoLW\277\023\204\313\311\203\023k~\310\220\311\374\277/\276RL\247Nq\342\347\326U\215k\177?\242\357\317\223{f\366)@I\355e\257\006uKyj^]\225\360Qt\256\224\035)t\236^\243\343\356x\373\272\3338\366\035<\344s\006o\030\214\\Gn\005N!\254S9\221}=\207\333 $\220V\266p\023 \240\013\005\341\303\314!e=\013\006L\246\260h\2410ba\032d\006l\261\005@\260\254g\303W`!V\003wCv\255:\365\267\230\020i/\r:\242\220p\033J\375\257\205\014\363\225\037 '\311*\020\016\035E\nA;\350\036<xJ\301\263\313\246\001M8\371q\311/\305\033i\244\003m\001\310<y\3306KN\t\306\223\315\371\267\356\326P\310\227<\363\334D\031\213V<4$\237\330\327Yi6\301k\265\246\214\0206\327\257\341os\340\004\026\036\346\000\002\017`\326;+\201\345.\353\333\003p1J\2553K\016\374\340}\365\020\t\252H\r\215 \214T\311\247\354\357\306>\242\r>*8q:\235G\000w\357\240\013\2627\024\007E:\035\201\251n`u\335\356\240\325\223WVj\356\267\"\347\252\344Qi34\352\033\333n\356\001\237\n\272\350\323\327\311\325\213&\347\0348_(\221.\346\274t9k\021un\365a#M\221^\307\014\254ft\035\035\013\240:\016\203\327nn,60i\226#2^\320\364\327\223/\221\276IN\3452D\352\007\267\027as!\261\240\334\033\266\232\357\340\260{P\363\210<6\021\032u\005\362I\266d\270\231q\371\211\354X\243\323\323\322\266\007\233\254\343\273\r\233\353\354|\303\260Y\"\262\345\307?\257\005\354]\331\224\007\220/\236\337f\325\236q\333\020`\227\006""\206\344_\2517\200\311\020A\007\006wL\256p\030\264\237\212\353\260\274\024\024\271G4#\02640\033\271zi\316cS\013\2736c\246\277\234\262RK\327\007\0215\252\273/#\364\350i\007J\307\rRf\230\260\343'\221\352W\371@\356\356\367\020\265z\371g\345;\374\007!\365\217\311\tz\2725\275\227DK?\201\344dz,svDY\215\2503\353\315e\307\247\227L\304#\026\202\274\271\341\267\345\211>\277\2125\231Y\004\245\356tn\342\303zj\346\033\243]\363/\335\033\372\264\215\345\221\251X7\037\361\260\324\261\333Ji\224\244;\270\002\311\345\020\213\304L\3524\252\235\305\033\307\210\352\200\303\006\025\276\010w\036\031\221C8\234\226\n\204\342\341\t[\345\003\342\220_\200u\244u\254V\023\202\037>\222$\031\300\307\003i\241\207\371j*\253\032\241\245R\207)\232\223\252\3534X\270\355\332Lp\003r2iv\314ZH \272q\225\305\322\271\205\303C\207\016\030\306\0048j7\360\323\344R\272sI*\243X\002N\347;\313\223\300=\334\030\350\261P\373gL's\215n\211\001\243&\356\035\300\240%\n@\323\367\242\003?&>\376\310m4A\335Kzg[\245\304\323g\303\312^;\327o\211\010\345\334E\370\0052\307j\tq2\256\255Q0\325,\330\323\021\013\035\330N\362\342+)\207\324z\033\021\226m\265\343\266\230\327p}\363>\266\2047\335h&7\214093\303\277$o\371\003\223fXq\032\014\374\335f\035K\353\362\252D&\307\271\331\034\342\320G\020\274\230\315\203\034\344\205\017\250hT\227f:\367\256\351\363\335x5=\335]\251j\322\005Q\235\221\201\263I2\003,r\301\006n\370K@]r\221\342\3701$fW\352b\265\003z\247\275\362\307\256\3477\206~\357\264\367\224\212,\214\003x\023\202\022\360\327\271p\272UU\360\340\334\276\r\317<e\207e\230\356\311\"\310\271$\224A\000alT\212\013 \202\325^\366%\233\255\363u\256\340`\271\324w:\327.\227\320\332\315\216\246UR\010%D\260`\314\220Q\200\356\003\340x\222\033\212\311\2546\220\226\361#\342\351k\302\253U\225\327\036K\320R\227^\225\303\004\306\331k\253d\"As\026\221\007\232izF\216\232\035\224\332\2565W\372r&W\311\022\220\223\327\326\244\024\020`\302\366\032R/wt\207%\323\323\340\360\025-\303Q\236IB\346\316r\336]\017\254\346\335\346\275Q\266\307]\215\255\245\366f\r\305\337""\230jF\213\365\366\353r\016\\\347\331\270\n@\031\217\n]\352\316\373\362\322\201Y\236\267\\6m\214e\252\333\266\270\264\\Z\340\2738K~\202\226\030\354\213\235\006\263f\336\026\2207\207V\344:%\021\\\235I :\241\035\032\255r\236<=\256\0056c\352\337\334K,\002\230y\344g\276\276}{\265\306q\234q\317I\317\314x\322\361\257\014L\345\303\313\342-\371H\363T,\366\260\375\223\315,\n\361.d\300\255\002\n\016\235K9V(\204\024\366\273\003m\200T\021F\212\2275\356U]1E%T\205Nv\310\022Vw\315\023$\304\221\014\307\022\0360\257L}<\216a\254\032o\026\261\230X\340\021\016\034\002\2347\3245\235\210\254\334]ZI\030\233%\200]\203\265H\214Th\333{\024C\033\212\253'+\275s\333\2341\263\016Q\251\202q\\r\245\266n\241MO\002\010\007p\3225\306\321\022<\362\201`N\022V\365\013\006\320r\204W\231\001,\002\274\222\347\005\311%\336\007xw\251\037\221\310\017\243xb\2671\355\210a\342\360\357\005\360\2725\324\225(y\205Q?\247\220u\234\027\230q#\235\344\372\300\354\235\363~\200\360\323\360\272\310\300\367\241I\245\330\227b\027R\354\027Y\347\372\272\007A\263\366\330\334\237f\227K\301\340\234\371\375\251M9_3\306\2561\3342\351G\336\337\275oA\275\036@\346\367k\241\224\265\352[\243\351\262m\337\255=7\367J\375\206\3006\033\026\316[\361\266^\363\020\332I\265\202\300F\t\223\352\362-\335b\222\354py\241\263\036b*\027\242\\\305>\222\244f\2637r\370O\0058\321nT=\277\252\226\304\275qB\210\246U=\237.\002\234\324\317\263\365\332V\352\357\335\344\247\203\220\007'\365\377g\350\372\276\330~\243\333c2\340\2300}3\020\264\244\314Q\3765\020d\253\341\216\324\220\350\013?#\262<\"\035\t\r\303\016s\n\031\000\351\331H\325@\246\220\247i\rL\t\340\306JH\rJ\221J\0316\333v\007y\373P\213j\244\2240\237x\031\373\332\367\204\256MBN\214?t\344\244\3269\227\264`2S%|\224JHY!H\noX4\024\262?\304\362\276\317\316\314\354{\n\023\013\322\026\207E\246\303\017a\226\013Q9\336\207\227\317\342\347P\203\344\217\t\217X\263\363R\334C{\222\027Su\026\232.\246\225y\235?_\372\277[\303\014\233\316\301sE\275O\024:\002\035\216\014y{<\362H\231t\314Q\332\304\225m\255mv\276\202\237""\202\255\017DKiT\331\300\243\026,\033\321\no\211\304\205\242\210*\276\271\300\343$W7\211\342\204\327vR\203\320e\000\221\270\002\363\350J\037j*\314n\206\0350\350a\202\237\247\347u\253\353_n\277|\361\327\216\265\373\261)\350\2145C\324\036\270\037\372\r\331\300r\210\340B\226\313\002\337q}\276xg\330<\335\005!C\274\003\234\372\2625\367Hlc@\326\261\366\304\335\250\317\374+\371\007\316:B\364EcH\327@\003]\036\207\373#\3112y\t\220{\232\2500\005\251y\322\027\242,\330h\2127\224\200\203d6e\034H\020PtK\035\027\344\016\210_\340\232\n\241<\335\240\274\241\345\002G\247hd\255\232\"\024\220CLM.\236\363\240C\331\322\376\031\275\247}\316\016\226t\274\320Q\374!}\373\020\205\345\225\374A\000B'5\350\241\025W\276\256\342\272S\202\020\201\261\210\331\224!\230\225\024f\332C<\364P\207\030\032K\244&~\237\241\350\010^\361`\342\360In\360\302\314\032\261Ma$\347N\376\263\355\263\316\n \200\251\303\247\341/n\234\303\340=StL+\263\331\210\321\010\035x\315\304\340B0\344\256\225\332\201\260w\353k\233\014\263\241\350\233\2268\"\321\033\366\352\364\300\374\307\365\016\247\253(\227DXk\322\\\234\\/Y\032\311\2231\r\270V\363\256+\336=\"x3]N\023\327\342\035j\017\204\016\361\034?\337\034\003\256@\353\235$\331\323\275\200\2653\227B\366\354\215\321`\334.\023P\003\213\233\256:\335\257\321\307\306\373<G\272\221\030H;\263\261r\201 \"9)H\343d\334G\233\025\213\026|\376K;\203\376\335\371\371w\300\220\255\264\024\256\006\221\036\t\322J\"|\221A\356@p\001\266\315f\264\001W\270f\016>O;\320\343\213\265`\236\321\313\037\317\227\266\254h\232\252\306\3445\026\327\310!\005H\341*$\361mX\334\262ct\036\351\245\267\200\242\324-\226\205\304\270\344\001_\tq\004t\261\001\032\027\032?\307g{x\\k\213s\317\256\031\367\025\255\300\332\016R\371z\330E\354\324]\262\246\r\323\240c\254\210\277\254;\375\377K\355\375\317\264\307\321\250Nd\304\210\237J#\270\371\032/\034R\230\356F\276In\222EsI1f\"#-\274\273{\264A\331\002\335\233Fb\323\206\334\272\271\244\265\373.\354B\312\0305\330\344\345U\321dqq\242;\037\246\357\026\003\331\\\235\300\252w\357""\375\267l\335\350X\360\355\262\013\014-B\021\273u\320CK1\304\0325AJ\316\315u\341\033\200/\202\371\215\347\340\026\032\306\341\277i\020\304\004\270\230\244\331\241\263\341\025\366|\301\034\017\274\214v\"\n\314\355D\366\330\353\216Y\333H\0063g\325\351\365\027\013\352y\235P}_\177\345\323\255\333\213\013\027\344\255\246\232\275\306\325mU\025\205w\272#\025\327^\266\256\271\374\253k\013\315L\355p\212z\372\357=h9b\253\245\225XUC\252\312^\336C\265\331\034g\021/\224S\321\322\250\r)\r%\253\371?R$ud\241Y\312\220\216\240\320\323J\225Q4\220\223P+\325\017@g\367\317xS\031MUt\336\333\307\023\217\3443\264s\251\333\317]\013\201\304\250\310\033\024w\314[\316\003>\231\324\340G\3321\n\231\372\035N\360Z\201?\203\024\302\204:}\374\274\263\314\314\314\350g\302\002\014\266sO\023\271|\211K5\346\233f\354\256\177k\265\267E\262\235K%\251\037kkk%K'\223\372\235.\345\227\303\360,\256\200\311\311\261\342\354\371S\267z7\356X\245\010\223\177+\263\221\333\312Lup\260\357\006I\231\311\0130W\023:\234\202 X\201,\303M,h\002\006\230\354]\000%\030$\2222\200\311Z\332\342o\354T18\363\321\0029OL\004HJ\211\372\272\001\264\207\211\331\314Y\267;3$\0314\353\032\370\216y\366T\002.\006<b\212\221\016:\345\312\233\035j\263\371e\016,5\231\033\270\000\337\363\177d\370\256\220\373\275\277\td\036\265\347v\257Tt\3073\242[B\370}\\\022p\0178\220\t\363\371T\206\022I\257\271\027\3217W\225:~\330\247D\266\2615;<\311\336*\035\354\005\010\246\351\346\022xF\313\230#\016I1_\324\230\023Q\035\225\266\3260m,\262a\251h\342@\233\032h\254\254\0174\206\231\221\335\241\255f\254\330\027\nZjvv\203\347\001\217\263B\331g\t\214\033\205h\250\2540o\2158\210\201P\264N\317G.\344;\230B`:ZZ\213J\365\2239N\303m!\233'\250\316\316\363C3\020\314\005i\271\254\313\243\251\220$\261EaV\353\312\0231\303\n\2448GI\n\370\303\342\210\245\241\207\222\276q\r\022\200P\222AG&\243piiR\322]\221\227Z\233\025Z\030\214\301\231/\347\231\\D\2720\213#'\251o\214\223\030\013\n\264,Z\310i\247X-@:\250\362\034.&1\004b&`]L\322c\020L\010\244\276\230\334[X9\260\254\332\231\263\234(X""\031\003g\253\021X\275\265\220\357:\261M\r\206\3334]\346\220Q\200\236L\3562\335\262\025\215\0064\366_\031]C\343P\326\311e\013\271\246{a\"\203\306(\n0kX|>1\202\320 \203\343J\261\030o\320\353x\272\367\372\013\020uYa\211\000\247\351\244\310r\035F\025\030\374\331\0279\2127\210\231\337/\226/)L!\352\333Hh!\236\322f\256\377\370\273\222)\302\204\204\t_\277P";
    PyObject *data = __Pyx_DecompressString(cstring, 5690, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (6193 bytes) */
const char* const cstring = "x\332\245YIw\323\330\266&`\2504\016\304\211\323\320T\225L\032\222@Re\022\272\320\3242\220@\212\242\t\204\256(\312K\261\345D\304\261lKNC\310]\014=\324PC\r5\324\320\303\0143\324\320\303\374\204\372\t\357\333\373H\262Ms\357}\353\262\210t:\235\263\233ow\307\322]9+\311\345\325\312\206R0\346\244\3212\365sZY\032/h\322y\265p~BR\013\030\276'\027\n\232!e\225\214\226U\244\225\035C\321\245M9_Q0\207\025\206&U\n*\317\321\207Y%'W\362FZ)`H-\254J\305\262\266\251f\225\354\204\277\017O(\3417\255;\211\335\377\303>;\306\232V\230^V6\212\252!O\247\363\232VT\312b\364\027\177\364\227\264\341O\027w\346\2673J\321P\265\202T\226U]\311J[kj^\221\212rY\247}e\211\226\346eC\351\224\360o~\273XVt\235\226oTtCZQ\244\335]\237\030\020[\276\315\004\357\355\335\224@\344m\310\253R\310\n9\315o\033eY*j\272\312\207\005\222\325!Z}\201N\004\177[e\325P$\255b\024+\006\365\307\203\235u#\213\321\211\205J!\303_c\\-\210\215\262\232\242\027.\220\340@\272j\254I\023\264\343bN\332\321*\340B\327\351xY\"fpHp\354%\236f\026\032k\262*\357.\227w\246\362\352:\010Y\371\240d\014i\234\267\225\245i\020\267\241\217OH\033\n\204\231\235\270\311{\254\312\233\212\264X\000\337j\026\247\254\026d\243RV\346\244\361Q}\342\261\252\013!6`\244\007c\273\273\240\030|\354\355\265\214\2504\000\226U\220P\200\032v\244\225\274\226Y\327\005\255\272!\227\r\311\247\247\240l\321\232'\n\2246\252JL\235\304x+\312\231ui|\025p\n\306'\236hb\177 xo/\350\320ah\217\362g$Q}M\312\3138G\t\325\374D\303\t\330H\226\004\207\320\261*\257@\222\005yCa{\010\365\277\267Gf\362\214T\267\246@\037\233jY+\020\333,]:\2438\225W6\225|\270\211\376\262\200\223 c\245aj\240\246i\264\245ch\353JAzYX/h[\005\211\354\203\016|\013%d\344\202\244\025\362;\322\252\nmh$8\037hr>\334\371\353\205M\213&\265\362\244\264\256\354li\345\006-\272\377\t\031\346\032\351y\234\215\236\330\013\345\240+\002\222Z\0162\"y\220\301A\373\345\211\246\217+\272\202\017\327\024\340[.d\024\326 \000\315\330#\325c\323U\305H\007\246\3666\300&S\3310A\350(\257\220\340;\245\216\356\356\316\341K\023\223\223\223\357n\355\276\337""\233\232\336\335\335\333\373\355\316\247\333\343s\227\244\277\337\311S\037\323\357\351\371\353\324\215\364\373\311\021\260\304\2468!\311\206\024\3741\302 \307|e\203\304Y0\324B\205\315O\207'!\206\002v\240\340\300\3434\231\3736\214\0106>==\275\267'\251\272D\214\352\225bQ+CY\027\262J^\205\241(e\375\202\264\276\005\211\322\222\025\205\270\315*@WF&\225\202\361\234\274\211cpZF+c\330\200r\364\242\222\317cVl\242\362&\323\322\263\274\"C\216r\366\003\211\006\266Wf\014LgU\2354\201\2459\240\216\232SS@\037\021\277\232\301\330\337\343\277\315\341\365\211\027|\242\341O\304\320'_!\334c\206>\025w\346X\301$f\262\nr\\\374\324\2152\021>Z\016\276Q\003\203\337)\030\3626-i\230\014Y9<)S\222\375\253\360W\371\267w\177\031\022)\201Tw{J\233\232\022.n\024N{Uz\367\364\331\362\342\323'/\336K\313\363\217\237\375\221Z\236'\374\tG\332\331\371R''0\027\216\220\245\352\n\331\3433v\351\"B\334\2244\200\262\274\245\222|\362y1\250c\037\245S\220\256Owb\027\270\373\014\376\264\271Q\375/\375\242Z\300\203\371c}7\030\300X\000\202o\016\022\324\013\022\204\311\256\t\023\354\220\340\360\033\253o\301c\253\205;\267\304\351w\376\026\022\370\253p\313\017<R.p\345_\306+\177\301\374\223\373\217S\317\037\315?\237\337(\032;\351\246\347t:\275\242i\371t:\354f\300rS\227\360\322\324-\003mM]P\324\324\363\343l:\275\260\370\307\374\223\324\343\371Ez<}\366\224C\3423\004A\332\353\331\3166\376\356#<\244\237(\333\306s%\367\202\371Z|\272\354[f:h\334-+\362z\330\273\347\033U\320\277\257\344\232\232!\351\255c\344\t\276\030\242`\367\345\230\340\253u\214\231k\031\2428\256\244\303\270\024\314\315\227\313Z\271\245\363\325)\301h\313\236O9$\266\366\036(\006$\376\2551\301\214l|\275C8\337z\346\027\223\276\352\2765\233\016\235e\032a\272u\305w\266\375\336\206\3514\331e0\366\325\307_\211z:-g\263ir\236X\231\323\032\303\n\314\256\251\267\255d\032=\344oJ\031\326a|c(M\020\374\336\270\376\255\211\\Cy\315\303j\356\233\243\302g5\246\210\235\260\227+k\033\351 \256\204\243zeE7T\243b(2\233i+\313\324\321\330B\322i\006\260\\,\"\235\200\223\372\025\177:\3766ex""\306\214\252M\303\251\303m\340C\235`\260\002\007\276\242ew\322\374\360\355x\205\"SZW\362\271\246\346\n\333Qz\245\242\"\027*\350\324*d\326\370\321\214\252\246\001\312s\032\003B\207AO(0\350\351\301\327\231\300\000\351\251\2243k\225\302:\216\312 \007\302+h\204{g|\001\244\221\311f\224\025$Y\231\274N:b=e4\354\240\000\226\333\206\010\251\031m\203\222\010\274\212\020/\342k\226b,\217\024\304*\341\0342\032\3342\03072\025\004\300\202!\366CP\362\343\322\227\271~\330\207\267\r\332\276\216\203.\351RG\026\250\370\003:\336z#\"7\302*\350\206\243.\323\372t:\253A \nN\317S\250T\362\272\"\252\221\340`\250\030\377\323+\304\275N-\344O\"\211\025\211%g\224x\350\024\017\260S\201\355T) \227*\003T~F\250\224\265-HK.*d/i\361\200\255`\3456\351\214\236\034H\250`H\257o\345r\351\325\274\266\"\347\365\034#\260\240\245\031\257\351\020\265x\347\323$m\0314\265t*\272\274J\245\002\223\312\251\036u\210\363\234Z\326\r\320\334\002\177\356\204~%M1J<\271\305B\n[\334\010\375j\272\265\013Q1\313iNYu\366\350\341\203\211\017NiN\373\270M\0374\001\234Z\2712\253'\304\241/\216UXVqM\311\027U\025r\007,Ijx\225\221de\225\355t\000\212\260\021\364\033\034\n+i\361\025\315\276\347KW\324\352\201Z\034\317\327\376F\325\322\252\236\016\355_\3255>\263\221#\0203\\\234\004!\373\203\246\026\326\221\203\257oQ\021B\177i\346\204[P \277\021x7\220\010f\323\250S\r\001rp\234\307*\034\302\006\252\345r\260p\001\025z\352~\r\354?)%)B\212\0332d\205\247\221Y\203\261\020P\320\203\330}\353\247&\222|4\264l\205\320\206VY#P\227U\205\346\365Ua5\342)\336\241\335\341T\222\031\214\232[\306\016\374#\000M\177iv3pi\005\035\221K\324\230 \254 \034\252\216\027\307lM\207\334D\236\310}\021\310\311\275\212\026\371\023\321\202\375\205\r2v\321!9\213\026T%\032\276bD\007\206\310{|\231!\374\373\356\364-\244|\300\336\235\351\006Xy\211\240\205\016\242\375\r\020\251C\331z\006\262n\002\034\271\010\245L\313\214\265\242\252\300\215\0245\024\014:i7\260\320t\272\310\307*\334\330\244\277\264\266N\3106\212\210\031\245\212\234\027\"/#F Jd\351\217\364\214\267\256\025\360m^`\202""\\~\360\324!\2272\331\276\016?\r\307&\303\331S\230\341\250\303\021!\324c\030\035\320\010\334\247\272\212\377,|z\223\363\016%\".\026\220%\201?\256\031\365b^5\370\301\340\323\341\3560\231Y\347\322\227\013x~\370nT\264\301\273\230!\317\031nEtS\032-n?t\003\036\026\360\257(~N\346g\366\004g\n\327\225\025r\362\215\300\255\357\350,\367P\370A#\034\360\303QS*%d\320\322mN\263\014\332N[\367O\246\026\001[\240\240,\336\352G\361\206\205\204Q2\275\246R\212\215\276\232o5[2\346t\236<=\336\215\031\332\265\221\23275Bc\252\024\263\240\211\335{\205\300^\330\254\030\271\353\233\\\367\360\203\361/\312 X1\0312g%\374\342\035\3746\315\"\310\320\223\270\245w\231\236:J\326\002\375\221\210\267V\370f\352\243Z\364\"g\255d\275\275\253:[\325\315D=\332g\242w\252j\230s\326R=\332cF\255\373v\267\263\354\306\250\323nE\254\005{\304^u\336\325\332\274\210dwy\027o\326\222\365\330\21072WK\324c\347\355D\275=Z}d\226\3769q\244#ZM\326\373\342\365h\334\234\267b\365\236\330!\376GOUw\255a\354\335\363#\0368\367\246\231\301d\364\2145\342\375\364\253\333\206\203\316\374\344\267\376i?\322\035\363zF\355e\347\21473\277\377\362\000\004\366x=8\305\033\276\342\376Y+\355\2675\006f\334\271\332RM\246\363\237X#V\301I\035\242\371\207\325i'\354\033N\212\316\272b\0363\257\200\207G\366\226#\327\243\335\365\236\323V\237\365\273-\333%\020\n\222cg\2551\273\215\206\007\254R\275\247\317\274ie\354X=~\326\272\206]\222\365\370\240iX7\354\224\375\306y\341F\334E>p\350g\313\260gl\271\336/\331\307h\221\277\3720N\242\355!\211\306\317An\347\355\024\021\367\320L\t\031U\254\224\365\326V\234\253\356\271\332\373\203\213\336\313\267\336\333?\211\3149\363\205\005\306\206\360\300\302\307\020O{\324\213\236\263\210\007\257\213wg\266\207\355\244w$f\306\352\221\256\352\345\352\262\031\203\002#1\263\327\2345K\336\320\204\363\243\233\251\r\355\363\364u3i.Z/\3551\247\313\275U\333\205 #\244\362]+a%?\267\211\r^\232\243f\311:j\215Z\333v\311\351v\337\324\226h\3426$8\355\202\224\223\325\017V\267\r\245\365\233\357!\360#\227\335D\363\326\315[z\221Qo\364\212\273T\037""\270Q\213\325\273A\2439i-\332\214\2506\263\337\224\211\315\244\350\rZm\304\341)\302\237y\335\232\261\024{\316\371\323\205F\206\275\341Y\367\361~\314\213L:\300U\314<\215\275\257\332$\016\350\265\315\027\246 \377\2529\000\342\271y\305\354\262\222\020\0267O\230\262\271i=\267J6\317%Y\356\017\354\253N\314I|\377\313hu\236GOX+v\033\016\014\007\216\003\264\221\037>\353\325D\365\2329l.\221T6\240\345\350\342A\357\001^\375\346K\310\257T\217tVG\253%\363\2509F;\377\360\331\250\316T\345pqw\323B\232\273\032\010\2411\177\262\252\2307\254y\273\037\270b\312\332\240\327\253V\254\301\304\274=\350\234pd\247\364\005\033\335\325W\320\010\2308U\3356\313\364\305\311\252\334\340\216\264\200C+\325Es\211\364\320c\036g\2701\2131\360\364\n\024pG\320\304\004&C\322\306\354\025\247\255\211|\332\366(\200\263)\004\363\025\237'\2539F\307\250]\n\370\000\237\035\325\001\250{\304T\254+\366Q\314m\302\234N\2702\224N\270\250.\230\211`q\277\231\265\3209.\\T\251\036\3555\247\3104cd\244\375\300J\222`\360;ky\311\312\002\205=qs\0018\271\214n\306\356\203\315\221O3\037\340\244\023v\316\371\335\315\325R\000v{\034d\375\t\234\267\323\301\004\277-\354\341\313\362:I\232\216\re\371\357\260\361-a\222$\256\201\013\034\223\022\376\364*\273\224\216n\230\331\004o$\204\344\235\023\31097j\277v\346\335\330a\270G;y\037\205\221:\352\224h\271\006\226>\220\316I\245k\3547\205n\277-\235A\3738Y\353\177'\235k\366E\347\245;Y[\330O\354'\277+\235\224o\267\247pV\317\200\251\342\254x?u\311v\257Z\275\344\357\232\207\r\363\032\016\233\205\365EpTcj\360,\213 \0323\343Bp\335UP\332YMx]\347\021_\344\220\237\223\325U, \010@.'\314\017\330\347\221S\"o\344/\030\020\223LU\277\271\354\235\276\344\244\2347\356\253\332\215}\026<\323\334A\\\316\262y\234\352!!M\223\346h\346\224wj\330\236\265?\272gk\367\367\333h\344\244wr\234\020\0363\373\314\224\271\214\370\220\022\201\212\217\3533\357\330\275\370\240\024\356\035\255\246\252o\314%\002Ng\365\202\311\276\"\325\332\216\002\320\027!pY`\345^\225\277\256`\373\227\220\316\025\233\215/\005`$\020\235\330\346:\252""\203\302O\"\334$\255\273\301\227w\253\031r\362\207\020\327\353\360\353\243\302\363^\346\357\223\314Tu\017Q\273\323\271\350.\327b\202\306\005\200\356\262\365\n\326\302\372^\2400G3\024=\332{\341\234\037B\256\206\233$\324%\277\370@\250q\004X\274\0067\034(q\312y\016TF\211\217{&\243A6?!\350\365 lYCvL\240\236\214\247=\220};\201\025\322\237\000\"(\304\034sf\200e|\020a\031\013T\r\232\333\010\247I\001\027\231;\02074\022\353\r\016\271\342\2649\"\237\010\001\025'\034\214\222\227\267\343\366\222\235q\342@sB02m\267\263\3210\255\017\004D\305\306s\316+\260\034\227\200\252\005g\304\221\203\360\334\274\222\017\270\350\\v\226|\224\365B\314\224\0345\000\360\273\311_>\360\372.\020\245\030\224\022\215\310\215l$\301\001\374g\354\204\356\242\311F\371@\310\331\317\006\236Z\254\271\037\003\250Ar\255\306<`U\354\373\220\002\314 b>\266c\336\371Y7E\275\223\226L\362\nt6kmR\230\025F\315\261\262\233\340I\257\347\0049\2662d\030K\002\202\217Hd\341\311\035\234\023\t}\274\262g\275\013\224\334a\257\337l\326\373:\245B\327\3342Bz\220'\356Y,-\362\016\2725N\313\006E\224\264\344C4w9k\212vW\337B=\277\300\223\215\301t\243\335\376\201\207\201\270\t \037\355\030\262\2236\342z\214\tXfM\312M\020;mA\345\247\2558\301\222\204\001%sb\312\270\211{\361Q\254\317:\tg\026H\276RC\032\027\0139\013\365*\034\025\214\272\336C\212\234eG\016Z\373\314\031\366\222/(\205\003\370\342g\254I\274\206N\327\207\316\"'\221\255-\200*\346\370\016t\202\362=D\255%\002\036a\251\304\222\363iP\375\363\221\373By\374\374\232\220\217\2100\234k\366\261\217\204\341\340\353\021\244\226\257@\177\305M\205_P\004\275\017\233\212C\"1;\021\344\261\234=\235\360=\304}\366\257\335\275\234\222D{\275^\244\206\215.\271\273\246\336\030\022:\370X\333\300A%d\261\367kmB\243\263\034%r\2143l~\n\330\240\220\271\0107\322\217<7\330!\316\344pAp\222\005\223\345\000\325:\335K\340\263\023\215m\025\326Y\004\2118\027\022\014\021B\213\301\013\307x\206\273\311\006\244\202\271\006\3651d%_\200\203cL=\304\2050dV.\215\007\037\006>\210\311\203\306a&\313\016\363\320\346q\331\362\325""\302\320-\205\374\302}!\245\"\n\037r\024:\201\\\342\321~\345\340\201\367\342\225\367\352u\375W2\311`\237\356Cl5\343\rL8\275N\303\266q\034;\016v\010?rL\236t\356C\t\017jW\3669\252\335apr\\\033\001\231\245C49\002\2279\036l\223}7\033,\245\320\003\246\341\235\375\305)5Yd\311$\374#c\036\2614g\ti\" E\341\340\260i0\007rCc\344\315NU79\367 +\026\262M\022\204Q\276\334\343\014zp\210\332\363\244Y2\031a\265\027\034^\361\210\2754\314\343w\006\005\352\242s\300e\233\370`\220\255u)$\260\341\021\022\316\025\324zqW\210LT\236\313\366\031'\351<p\271z\232%\211\303\036\2753\010\355d\2207\310+\t\252\032\033\367\014z\203Sd\217\341:h\354\353\307\220\335K\225\342e\034\027C\272`\235\341\340\037s/\300\002\276\177\326\020\340\372\032\246\311\210\351\023A6,\323\272\005lo\201}\2122d\356M\375C\006\324'\006f\202\303\205\027\375\311\222E\354\215{\375c\276\037\201\177^F2\364\222b\005\347\016fBD\202=T+I\201\275\217\200\370\222\210\242\210\331\034b~\367\006(\346D\234\2070\343\343\265\245\006P86\235D\302\340g\021\215\024\321\353%\346z\210\375\323\360\317\263p\0047\000\216\346$\347\006r\016\312\026\203\030\327x\021\340\272\311\023Q\243\323\272@v\3304\325\t\372\031}G\331\317\306\020\223\021\234\276^@\311\317\022\002J\237}\017\307\3178\212{\265\026\253\215\324r\373\251\317~\302\234\014\033\246?\306.\301;{\311YpQ\273\035r^\205\372\n\261\361\223\223\244\014i\0231\256D\202\035@\3413@\226\002\367\365G\255\355\020CC f\030\356\375\004\0270\021\366\303P\340Q\260\020\373\334&\222\264\204y\231\323\321\010\245\243\215\034\373\177N\257\037B\207\227\355\227\300\372\rw\241\226\250\371\t\366\337\000\371C\032 EQ\236+\203\220\343\"\216\223\343\033\001\365)g\311O\362\277]fT\350\262\305j\023\3511\225Sm8\366\001y\366z\307\311\352:\2271\355\302\341\242DG\330Z\345\230\331\301\2210\230\201\337<\244\002\334\353M\272\203\010\\\377\237r+\032\343j\350(\270\236\341\313\222XC\004+v\027XL5\017\205R\241Z\366{e\306\023\"\255\203\234\340\006\352\237!w\300\335\252\255\356/\037\304\016\022\234\300\367\231\327\311\276\374\204\254\017\036\343=""2\213\366\332\211\032\333\033\262\263\317]\325\233\336\300%\347i-\371\317\245#\307\333?\357\212j\035\331\245\367s\022\006\237\250\017\376\034\264\204|Y\347\264a\204n\275\356\022/\207\021\262&B\316%\240\346\007\270\374N\326\336\330xS'\322^\355\300\232\323\234\352pRE\274\006\0253\034g\205\343\336\202\033\206\3569\226C\334^\362\305\353I\224T\235\331O\242d\221&\340c$d\021\"\220\374\t\267{\214M4\031.\276^;Z\233\334O\355/5-n\332Y\026\230Kq\205\316\311\240_\255\255\212I\204\223Clu\201\2525\004\270\227\\~S\262\034\004\232\n\305;Q\010\000`\245\260P\275S[\331\357<HP\261\232\260\007\354\035\327\277QIU\227\302\205\253\302~\270'l\216\213\223\244w\344GqA\360\021\236m\214\263\031\366U\233\\\335\215\211B\272\263:\306\031MI\334$aN\024\3227y\314\367\005\367\314-\n\213\002\240\273|!\324\007\001w\271I\327\317$\305|#m$o|\035\016\370a\220a\\\027\336\230\"{\352\260\271\202\331\240\333;\024\023?\372\027\026\344\264\330\254\256Q\022\002Y\303\244\262\346%\213\353S\276\264\371\246\201\210\257r\326\002C\002%\377\273\340\212\213\222\276qNh:\003\343\354\244\033\201\346\233\244q\347(R\230\234{\227\357C\302\233\026>z\314j\267\333\302\225#\366]J\201ZVLXsvc\257s\\;6V4\221\262\303e\332\200\335:\212\340l\275A\n\232\374/F\277\275C\311\354\342\253\026\331.\363\315\305\246\273\344\312\002(\017\315y\272\004\241\212\0255\\xw\205\002\305\353\247\274y\r#;\344~\010\260MF\211\356a\004\001\357\237\336#\307O\220\r\227(\376MY;\016gL7\240>?\003\017{\006\016\350rg\334lm\270\366\356\340\030]\315\321e,{\024\37728\374\3147\253\271\332\371\032\333_?\242QP\010\177u\314.t\243\272zm|\177d?K\227\266o\2747o\tl{\224\"\325{\316@\245\261\237\330\021\212ze\310\372\201S\247(\t\354\030a\217\300\"h\275Ms\337%\240\301\313\254\275\353\016S\206DW\302Q:\"J\371\014\272\235\266\2001\247!g\340\246\250\362}\313\310\351!G\370\202\0220\211\312\014\372\252\207\"\373=\324\336\273\356\010\224\202\032g\312.y\343w\367\317\303\363\214'\335~W\241t\207\022\336.\320y\372\274=l\277q\336\325\"\265\305\375\027\007\355\336\263eo\031\374f\274L\316\313""\255\326\343\303t\r\277\344~\330\357:\340;\356\224\365\227\310\005\037\210\032\252\237\262\214\327\300\340\007\247M\334\246g\355\tD\3735\350e\244\266~\320w\200E\224|\367S\t\276\350\274\200\017\217\324\356c\273\231\003Y\314\360\215{\262>4b?\201\213\352?m\235\205\261w\270}\356C\254\213\354?:0\274\027 \351\275\367\376o\301h<AU\3520\364\177\034^m\324\255\320\305\216\270\004\2373\337Zk6\202\354?\003G\216\307\220 \303u\037\203wQYA\234\321-Q\347\220\264\343\307\"\341g>\361\215\376U\276U\240TQ\250\317O\226\222\207\"\234Y\347\331\332\332\351.\3469\342F\037\271\025R\030\341 z\332\207\276\377+\300}\312\2048\210\365\264T\277\335\2049\272\030\235\361~\342`\214\323x\307\027H\251F\270(\310\331)\337W\023\305\257\221\004\307\355?\235\262\333\013\274\257\260\374\"\373\013\007\201?\247\033(\276g{g\037#u\275\346\353O$\277\317Q\261\017#$\254!\264\221\307\311\212\333\077\077\\\210\371\363\\Y\336\347\304\026u\360u\376\231\003\260\241X\376\034\201-u\030\037\362\206.:\327\334\204\313\277w\314Ze\346\344\030_\2304\257\364\367\245_1\300\361e\344/\307\270\220\272\213\343#(\201:kc(\200\276\332{\322\271\3001\032j\245\232 \305\331K\313\276\344Z>\223\003:e\227\376\311\266\375\307`\337\rQ\266A9\363\2347\336\256u\355'}?\323YM4\247$mM\001\215\316\360\257u\t$\224\026B\372\327\2201\316\230\034p\351\366\240D@\360o\3608\346\321\355ZW\324\377\337|\367\247\363O-\302\367\321\217)\"\251\007\001\027\315 \301\347\033Q.\027}\332x\252\303\237\340\022\222'\350*p\301\272\310\325\260\377\313\304U\263\227|\027\246\253\262\310\014\350\322=\022\324\261\034\\\251>\024\331\316\017\237\267\252\262\177#e\336%f)\241\211\t\200o\021w`\303\353\035\265\237\333\2450u'\"\327\200RJSG\355\246h\234\0241\230~w\010\013\347\340\216\224\316\372\227\270\333\246;\225\234=\017o\321\016\237v\310\277\020\375b\237\246\240\3743\314\2042k\376\375\242D\010\240\333\005\226\324\273\340\302\235(\346o. \357\232p\370\212\211o\352\017Y+\224`\304\376\017\266\252\006D";
    PyObject *data = __Pyx_DecompressString(cstring, 6193, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (12528 bytes) */
const char* const bytes = " Bad argument: %rBad for (no \"in\") in %rCannot decode bytes value %r into unicode (no default_encoding provided)Cannot encode unicode value %r into bytes (no default_encoding provided)Cython.Tempita._looperCython/Tempita/_tempita.pyException raised while parsing a template\n    Expression must be {{default var=value}}; no = found in %rExtra position arguments: %sFile to write output to (default stdout)Function definition doesn't end with ): %sIf you pass in a single argument, you must pass in a dictionary-like object (with a .items() method); you gave Invalid signature: (%s)Missing argument: %sMissing {{enddef}}Missing {{endif}}Multi-line py blocks must start with a newlineNeed %i items to unpack (got %i items)No {{endfor}}No {{endif}}No %s to finish last expressionNoneNot a valid variable name for {{default}}: %rPut the environment in as top-level variablesUnexpected argument %sUnexpected %sUnexpected token Unknown code: %rYou can only give one positional argumentYou can only give positional *or* keyword argumentsYou cannot have () in the variable section of a for loop (%r)You cannot use inheritance without passing in get_templateYou must give a template filename\n \t\r\r\n#,)***[<{]}-.{{}}?>|=(:, ^[a-z_][a-z0-9_]*$ around ) at  at  at line  column continue outside of for loopdef default {{default x, y = ...}} is not supported'delimeters' kwarg is being deprecated in favor of correctly spelled 'delimiters'. Please adjust your code.disableelif enable--envfor gcif ^(?:if |elif |for |def |inherit |default |py:) in file %s in %s in string %rinherit invalid syntax in expression: %sisenabled\\n\\r?[\\t ]*$ name=-o--output%prog [OPTIONS] TEMPLATE arg=value\n\nUse py:arg=value to set a Python value; otherwise all values are\nstrings.\npy:.pyc.pyo:%s\\s+in\\s+%s inside expression%s outside expression%s outside of an if block%s with no expression<stdin><string>^[\\t ]*\\n<tempita function Cython.Tempita._tempitaENDMARKEREmpty_Empty_Empty.__bool___Empty.__call___Empty.__ite""r___Empty.__repr___Empty.__str___Empty.__unicode__FILENAMEINAMEOPOptionParser__Pyx_PyDict_NextRefStringIOTemplate_TemplateBreak_TemplateContinueTemplateDefTemplateDef.__call__TemplateDef.__get__TemplateDef.__init__TemplateDef.__repr__TemplateDef.__str__TemplateDef._parse_signatureTemplateErrorTemplateError.__init__TemplateError.__str__TemplateObjectTemplateObjectGetterTemplateObjectGetter.__getattr__TemplateObjectGetter.__init__TemplateObjectGetter.__repr___TemplateObjectGetter__template_objTemplateObject.__init__TemplateObject.__repr___TemplateObject__nameTemplate.__init__Template.__repr__Template._add_line_infoTemplate._evalTemplate._execTemplate._interpretTemplate._interpret_codeTemplate._interpret_codesTemplate._interpret_forTemplate._interpret_ifTemplate._interpret_inheritTemplate._reprTemplate.from_filenameTemplate.substituteaction_add_line_infoadd_option__all__appendarg0argsargvasyncio.coroutinesattrbasebody_body__bool__bound_self_bound_selfbreak__builtins__bunchbunch.__getattr__bunch.__getitem__bunch.__init__bunch.__repr__bunch.__setattr__c__call__callerchunks__class____class_getitem__cline_in_tracebackclscodecodescoerce_textcolumncommentcompilecondcontentcontextcontinuecopycountcurrentdecodedefdefaultdefault_encodingdefault_exprdefault_inheritdefault_namespacedefaultsdefsdelimetersdelimitersdestdirname__doc__eecolelifelseencodeencodingendend_bracesend_posenddefendforendifendswith__enter__enumerateenvironerowescapeeval_eval_exec__exit__exitexprextra_kwff_globalsf_lineno__file__filenamefill_command_fill_command_usagefind_positionfinditerfirstforfrom_filenamefrom_template__func__funcfunc_name_func_namefunc_signature_func_signaturegenerate_tokensget__get__get_file_templateget_templateget_token__getattr___getframe__getitem__globalsgrouphelpiidifin_exprin_reindex__inherit__inheritinherit_template__init___interpret_interpret_code_interpret_codes_interpret_for_interpret_if_interpret_inheritio_is_coroutineisolate_expressionitemitems__iter__joinkkeykwlastlast_indexla""st_poslast_trimlead_whitespace_relexlineline_offsetlinenolines_looperlooperlstripm__main__matchmessage__metaclass__metavar__module____mro_entries__msgname__name____namenamespacenest_countnest_typenextnext_chunkns_nsobjobjectopenoptionsoptparseosoutoutputparseparse_argsparse_condparse_defparse_defaultparse_exprparse_forparse_inheritparse_one_cond_parse_signatureparse_signatureparse_signature.<locals>.get_token_parsedparserpartpartspaste_script_template_rendererpathpiecespoppos_posposition__prepare__prevprev_okprintpy__qualname__rbrereadreadlinereasonreplace_repr__repr__resultrfindsscolsearchselfself___set_name____setattr__setdefaultsigsig_argssig_textsignaturesingle_statementssplitsplitlinessrowstacklevelstartstart_bracesstart_posstartswithstatement_restdinstdoutstore_true__str__stringstripsubsubdefssubstitutesystempltemplate_templatetemplate_content__template_name__template_nametemplate_objtmpltok_stringtok_typetoken_retokenizetokens__traceback_hide__trail_whitespace_retrim_lextrim_whitespacetype_unicode__unicode__unnest_typeupdateusageuse_envutf8vvaluevalue_exprvaluesvarvar_argvar_arg_typevar_argsvar_kwvar_namevar_revarswarnwarningswbwritezip\320\004\033\2301\330\010\013\2104\210s\220!\330\014\023\2201\330\010\017\210t\220:\230Q\330\014\020\220\014\230D\240\r\250T\260\021\330\014\020\220\010\230\004\230F\240$\240g\250[\270\001\320\004 \240\013\320+;\2701\330\021$\320$:\270!\330\021\"\240!\330\010\014\210K\220q\360\006\000\t\014\2101\330\023\024\330\014\024\220E\230\021\330\020\021\340\020\021\340\014\017\210{\230#\230Q\330\020\035\230Q\330\010\013\210;\220c\230\021\330\014\032\230$\320\0360\260\001\260\021\330\032\036\320\0360\260\001\260\021\360\010\000\r\021\320\020%\240T\250\032\3203E\300U\310!\330\014\020\320\020\"\240!\320#5\260Z\270q\300\001\330\014\020\320\020\"\240!\320#3\260:\270Q\270a\330\010\014\210N\230$\230n\250A\340\010\014\210L\230\n\240!\2409\250A\330\010\013\2105\220\003\2205\230\004\230K\240w\250a\330\014\r\330\020\031\230\023\230J\240a\240q\330""\023\024\360\006\000\021\033\230&\240\001\330\020\031\230\026\230q\330\020\023\220;\230c\240\021\330\024\033\2307\240!\2401\330\024\027\220t\2309\240A\240X\250S\260\004\260I\270Q\270a\330\030\037\230t\2403\240a\330\025 \240\003\2401\330\024\033\2307\240!\2401\340\024\033\2301\330\020\023\2201\330\024\034\230F\240\"\240A\330\010\014\210H\220A\330\010\014\210K\220u\230A\230Y\240e\2506\260\034\270]\310+\320UY\320YZ\330\010\013\210:\220S\230\001\330\014\030\230\001\330\010\014\210M\230\021\330\010\014\320\014\034\230A\330\010\013\320\013\033\2307\240!\330\014\020\320\020#\2401\320\000\021\220\021\330\004\013\2102\210T\220\021\220!\330\004\021\220\022\2204\220q\320\030)\250\035\260c\270\030\300\021\330\004\013\2108\2201\220I\230U\240&\250\013\260<\270{\310!\330\004\013\2104\210{\230!\2301\200\001\330\004\013\2102\210U\220%\220q\230\002\230%\230x\240q\250\r\260X\270Q\330\004\013\210=\230\n\240.\260\001\330\010\016\210j\230\r\240Q\330\010\025\220]\240!\320\0002\260!\330\004\013\2108\2201\220I\230U\240!\330\004\013\2104\210{\230!\2301\320\004%\320%5\260Q\330\0269\270\021\330\r\021\220\021\220*\230I\240Q\330\014\020\220\001\220\025\220a\330\010\013\2101\330\014\020\220\001\220\027\230\001\230\021\330\010\017\210s\220!\2208\2303\230e\240:\250Z\260q\330\023#\320#4\260M\300\021\320\004*\250!\330\010\021\220\031\230!\2306\240\021\330\010\014\210L\230\001\330\010\014\210H\220A\200\001\330\004\013\2106\220\026\220q\230\001\330\004\013\2105\220\013\2301\230A\330\004\013\2105\220\006\220a\220v\230R\230q\240\001\330\004\013\2101\210K\220u\230G\2406\250\021\250!\200\001\330\004\013\2106\220\026\220q\230\001\330\004\013\2105\220\013\2301\230A\330\004\014\210E\220\026\220q\230\006\230b\240\001\240\021\330\004\014\210E\220\026\220q\230\005\230Q\330\004\007\200s\210!\2107\220#\220Q\330\010\016\210m\2301\330\014I\310\022\3101\330\014\025\220U\230%\230q\330\004\n\210%\210q\220\002\220&\230\001\330\004\007\200t\2103\210a\330\010\016\210m\2301\330\014\r\330\014\025\220U\230%\230q\330\004\007""\200t\2106\220\027\230\001\230\021\330\010\016\210m\2301\330\014\r\330\014\016\210e\2209\230E\240\025\240a\330\004\013\2105\220\001\220\022\2206\230\021\330\004\013\2101\210K\220u\230E\240\027\250\006\250a\250q\200\001\330\004\013\2106\220\026\220q\230\001\330\004\r\210V\2201\220A\330\004\017\210x\220r\230\021\330\004\016\210a\330\004\013\2105\220\013\2301\230I\240Q\330\004\007\200u\210I\220Q\220a\330\010\020\220\005\220S\230\001\330\004\014\210E\220\021\220#\220V\2301\330\004\014\210E\220\027\230\001\230\021\330\004\007\200t\2101\330\010\016\210m\2301\330\014&\240b\250\001\330\014\025\220U\230%\230q\330\004\013\2105\220\002\220%\220v\230Q\330\004\007\200t\2103\210a\330\010\016\210m\2301\330\014\r\330\014\016\210f\220I\230U\240%\240q\330\004\013\2105\220\001\220\021\330\010\t\210\026\210s\220$\220e\2305\240\002\240%\240v\250S\260\006\260a\260q\330\010\013\2101\210F\220!\330\004\013\2105\220\001\220\025\220d\230!\330\004\005\330\010\013\2104\210q\330\014\022\220-\230q\330\020\021\330\020\031\230\025\230e\2401\330\010\014\210J\220a\220v\230Q\230d\240!\330\020\024\220F\230!\2302\230Q\230c\240\023\240A\330\014\023\2201\220G\2305\240\006\240f\250J\260f\270A\270Q\330\010\024\220I\230Z\240q\250\010\260\006\260a\330\010\017\210w\220a\220q\200\001\330\004\013\2108\2206\230\021\230!\330\004\r\210V\2201\220A\330\004\013\2105\220\013\2301\230A\330\004\014\210E\220\026\220q\230\006\230b\240\001\240\021\330\004\007\200u\210I\220Q\220a\330\010\020\220\005\220S\230\001\330\004\007\200t\2107\220!\330\010\024\220A\330\010\017\210t\2206\230\026\230q\330\t\r\210U\220)\2301\230A\330\010\016\210m\2301\320\034I\310\022\3101\330\034%\240W\250E\260\021\340\010\020\220\005\220S\230\001\330\010\023\220;\230e\2406\250\021\250%\250q\330\010\016\210o\230Q\230j\250\006\250a\330\004\016\210h\220c\230\021\330\004\016\210a\330\004\005\330\010\013\2104\210q\330\014\022\220-\230q\330\020\021\330\020\031\230\027\240\005\240Q\330\010\014\210J\220a\220v\230Q\230d\240!\330\020\024\220F\230!\2302\230Q\230c""\240\023\240A\330\014\023\2201\220G\2307\240+\250U\260*\270F\300!\3001\330\010\024\220I\230Z\240q\250\010\260\006\260a\330\010\017\210w\220a\220q\200A\330\010\013\2101\330\014\017\210q\330\020\026\220i\230q\330\024\025\330\014\017\210s\220!\2206\230\022\2301\330\020\026\220i\230q\330\024\025\330\014\017\210t\2207\230!\2304\230q\240\004\240A\330\020\026\220i\230q\330\024\025\330\027\033\2301\230A\330\014\021\220\024\220Q\220a\330\010\r\210Q\330\010\n\210!\320\013\"\240$\240a\330\010\013\2104\210q\330\014\016\210g\220Q\220d\230!\330\010\020\220\006\220j\240\004\240K\250q\260\001\330\010\013\2104\210q\330\014\026\220d\230!\330\010\013\2101\330\014\025\220T\320\031,\250A\250X\260V\2709\300A\330\010\017\210q\200A\330\010\t\330\014\023\2204\220q\230\001\330\017\020\330\014\022\220.\240\001\240\021\200A\330\010\017\320\017#\2404\240z\260\033\270D\300\001\200A\330\010\016\320\016(\250\001\330\014\021\220\023\220A\220T\230\023\230A\230Q\330\010\013\2104\210q\330\014\023\220>\240\022\2404\240q\330\010\017\210q\200A\330\010\014\210A\210X\220Q\200\001\330\004\n\210'\220\021\330\004\014\210A\330\004\n\210'\220\021\330\004\014\210A\330\004\014\210F\220+\230Q\230a\330\004\007\200u\210C\210q\330\010\017\210u\220A\220U\230!\2305\240\001\330\004\014\210A\210U\220!\2205\230\001\230\021\330\004\t\210\027\220\001\220\025\220a\220t\2301\230B\230a\330\004\007\200u\210B\210c\220\021\220!\340\010\r\210W\220A\220U\230!\2305\240\002\240!\330\004\013\2102\210U\220!\2201\200A\330\010\017\210}\230D\240\n\250+\260T\270\021\200A\330\010\014\210F\220)\2302\230V\2401\330\014\023\2201\220F\230&\240\001\200A\330\010\021\220\021\330\010\022\220*\230H\240K\250t\2601\330\010\023\2201\330\010\014\210F\220)\2302\230V\2401\330\014\017\210t\2207\230$\230e\2407\250!\330\020\026\220i\230q\330\024-\250R\250q\330\014\017\210u\220C\220q\330\020\026\220a\220|\2401\340\020\030\230\001\230\030\240\021\330\010\017\210t\2201\220A\330\010\023\2204\220q\230\001\330\010\016\210a\330\014\022\220)\2304\230x\240q\250\003""\2503\250a\330\020\030\230\004\230A\230Q\330\014\017\210q\330\020\027\220x\230t\2401\240A\330\020\026\220a\220x\230t\2404\240q\250\001\330\021\022\330\020\026\220a\220|\2405\250\001\250\021\330\020\021\340\020\026\220i\230q\330\024\025\330\024\026\220d\230%\230q\240\001\240\024\240Q\240c\250\024\250U\260!\330\010\014\210F\220.\240\010\250\006\250a\330\014\017\210u\220G\2301\330\020\026\220a\220x\230t\240:\250V\2601\330\024 \240\004\240F\250$\250a\330\010\014\210H\220A\330\014\017\210u\220G\2301\330\020\026\220i\230q\330\024+\2502\250Q\330\010\013\2101\330\014\022\220!\220:\230Q\330\010\017\210q\200A\330\010\014\210J\220a\330\010\014\210G\320\023'\240q\250\001\200A\330 !\330\010\014\210M\230\021\330\010\014\210N\230!\330\010\014\320\014\037\230q\330\010\014\210I\220Q\330\010\014\210G\2201\330\010\014\210H\220A\330\010\014\210O\2301\200A\330\010\035\230Q\330\010\013\2104\210t\2201\330\014\022\220-\230q\330\020\021\330\020\031\230\026\230u\240D\250\001\330\010\020\220\004\220M\240\021\320\"4\260A\330\010\020\220\016\230a\230t\2401\330\010\014\210F\220)\2304\230v\240Q\330\014\023\2201\220G\2306\240\021\330\010\r\210X\220Q\330\010\r\210R\210u\220A\330\010\n\210!\210:\220Q\330\010\017\210u\220K\230q\240\001\200A\330\010\035\230Q\330\010\t\330\014\r\330\020\030\230\004\230A\230V\2404\320';\2701\330\014\023\220?\240!\330\020\026\220k\240\021\330\0247\260r\270\021\330\014\023\2201\330\010\017\210}\230A\330\014\017\210w\220a\220s\230(\240!\330\020\027\220q\230\005\230Q\230a\340\020\027\220{\240!\2401\330\014\r\210Y\220d\230/\250\021\250&\260\001\330\014\r\200A\330\010\035\230Q\340\010\014\210H\220A\330\014\023\2204\220z\240\021\240&\250\001\330\014\022\220&\230\004\230A\230T\240\024\240Q\240a\330\014\017\210u\220C\220q\330\020\031\230\021\340\020\031\230\024\230V\2401\240D\250\001\250\024\250T\260\021\330\014\017\210q\330\020\024\320\024%\240Q\240d\250!\2504\250t\2605\270\001\330\020\021\200A\330\010\035\230Q\330\010\014\210H\220A\330\014\017\210s\220!\2206\230\023\230A\330""\020\022\220!\2204\220q\230\006\230a\340\020\023\2203\220a\220v\230S\240\003\2401\240A\330\024\032\230*\240A\330\030\031\330\030\033\2303\230a\230w\240c\250\021\250!\330\020\024\220F\230)\2403\240a\240v\250Q\330\024\026\220a\220x\230q\330\014\r\330\020\024\320\024%\240Q\240i\250t\2605\270\001\330\023\024\330\020\021\330\023\024\330\020\021\200A\330\010\035\230Q\330\010\014\210H\220A\330\014\017\210z\230\021\230&\240\001\330\020\023\2207\230!\2301\340\020\024\320\024$\240A\240V\2504\250u\260A\200A\330\010\035\230Q\330\010\016\210f\220D\230\001\230\024\230T\240\021\240!\330\010\013\2105\220\003\2201\330\014\020\220\006\220a\220t\2301\230D\240\004\240A\330\r\022\220#\220Q\330\014\022\320\022#\2401\330\r\022\220#\220Q\330\014\022\220.\240\001\330\r\022\220#\220Q\330\014\022\220&\230\n\240$\240a\240t\2504\250q\260\004\260D\270\001\270\021\330\014\023\2204\220v\230Q\230f\240D\250\001\330\014\020\220\017\230q\240\006\240f\250I\260T\270\025\270a\330\r\022\220#\220Q\330\014\024\220D\230\001\230\021\330\014\020\220\016\230a\230w\240d\250%\250q\330\r\022\220#\220Q\330\014\024\220D\230\001\230\022\2306\240\021\240!\330\014\023\2204\220v\230Q\230e\2401\240D\250\004\250A\330\014\020\220\010\230\005\230Q\230a\330\020\027\220t\2306\240\021\240&\250\004\250A\330\020\027\220t\2301\230A\330\014\017\210w\220a\220t\2306\240\021\240&\250\001\330\r\022\220#\220Q\330\014\021\220\027\230\004\230A\230T\240\024\240Q\240a\330\014\017\210t\2207\230!\330\020\031\230\024\230V\2401\240F\250$\250a\330\020\022\220!\2207\230!\330\r\022\220#\220Q\330\014\023\2204\220q\230\001\330\014\024\220D\230\006\230a\230v\240T\250\021\330\014\020\220\001\320\021\"\240!\330\r\022\220#\220Q\330\014\023\2204\220q\230\001\330\014\030\230\004\230A\230Q\330\014\024\220D\230\001\230\021\330\014\016\210a\210x\220t\2301\230H\240K\250q\260\006\260f\270K\300u\310G\320SV\320VW\33004\260A\330\r\022\220#\220Q\330\014\r\340\014\023\2203\320\026)\250\022\2501\200A\330\010\035\230Q\330\010\020\220\001\330\010\017\210q\330\010""\014\320\014\035\230Q\230d\240*\250D\260\004\260G\2705\300\001\330\010\013\210>\230\023\230A\330\014\026\220d\230$\230a\230q\340\014\026\220a\330\010\017\210r\220\025\220a\220x\230v\240Q\200A\330\010\035\230Q\330\010\t\330\014\020\220\001\220\026\220t\320\033/\250q\330\010\017\210}\230A\330\014\017\210q\220\001\330\020\021\220\031\230$\230o\250Q\250a\250u\260A\260T\270\021\340\020\021\220\031\230$\230o\250Q\250f\260A\330\014\r\200A\330\010\035\230Q\330\010\t\330\014\017\210v\220S\230\001\330\020\027\220q\330\014\017\210t\2201\330\020\021\330\024\034\230C\230q\240\001\330\027\030\330\024\034\230E\240\021\240!\340\020\023\2204\220z\240\021\240'\250\021\330\024\034\230K\240q\250\001\330\020\024\220J\230a\230w\240a\330\030\034\230D\240\001\330\024\034\230E\240\027\250\001\250\024\250Q\330\010\017\210}\230A\330\014\r\210Y\220d\230/\250\021\250!\2505\260\001\260\024\260Q\330\014\r\340\014\017\210t\220:\230T\240\032\2501\250G\2601\330\020\023\2204\220t\2301\330\024\032\320\032,\250A\330\030\031\3309;\2701\330\020\021\330\024\034\230E\240\027\250\001\250\024\250Q\330\020\027\320\027-\250Q\330\024\032\320\032,\250A\330\030\031\230\021\330\030\031\230\021\330\030\031\230\021\330\030\031\230\021\330\030\031\230\030\240\022\320#3\2602\260Q\330\021\025\220T\230\032\2404\240z\260\021\260'\270\021\330\020\023\2204\220t\2301\330\024\032\320\032,\250A\330\030\031\3309;\2701\330\020\030\230\005\230W\240A\240T\250\021\330\014\023\2201\200A\330\010\013\210:\220S\230\001\330\014\r\330\020\027\220t\230<\240q\250\006\250a\330\023\024\330\020\027\220t\230<\240q\250\006\250a\340\014\023\2204\220|\2401\240F\250!\200A\330\010\014\320\014\036\230a\200A\330\010\021\220\024\320\025&\240a\240v\250Q\330\010\r\210T\220\024\220U\230!\330\010\n\210'\220\021\220!\330\010\013\2104\210}\230G\2401\330\014\016\210a\210z\230\024\230Q\330\010\016\210a\330\010\022\220!\330\010\014\210J\320\026'\240q\250\004\250H\260D\270\005\270Q\330\010\017\210r\220\025\220a\220q\200A\330\010\016\210c\220\025\220a\220t\2301""\330\010\013\2104\210q\330\014\022\320\022,\250A\330\020\025\220T\230\031\240!\2404\240t\2509\260A\260Q\330\010\013\2104\210q\330\014\023\2209\230B\230d\240!\330\010\017\210q\200A\330\010\017\210q\200A\330\010\017\210q\330\014\020\220\r\230T\240\021\330\014\020\220\n\230'\240\024\240Q\200A\330\010\017\210q\330\014\020\220\n\230!\330\014\017\210q\220\002\220!\2206\230\021\230%\230t\2401\200A\330\010\017\210q\330\014\020\220\n\230!\330\014\017\210u\220A\220Q\220k\240\023\240C\240t\2503\250e\2606\270\021\270$\270f\300A\200A\330\010\017\210t\2201\200A\330\010\017\210t\2201\220A\200A\330\010\017\210w\220a\220t\320\033,\250F\260!\200\001\340\004\014\210F\220&\230\001\230\026\230|\2501\330\004\007\200v\210R\210q\330\010\021\220\026\220r\230\026\230v\240Q\240f\250L\270\001\340\010\021\220\030\230\021\230#\230S\240\006\240b\250\001\330\004\014\210H\220A\220S\230\002\230'\240\021\200\001\330\004\014\210F\220!\2202\220Q\220a\330\004\r\210Q\330\004\016\210h\220c\230\021\330\004\005\330\010\013\2104\210q\330\014\022\220-\230q\330\020\021\330\020\031\230\027\240\005\240Q\330\010\014\210J\220a\220v\230Q\230d\240!\330\020\024\220F\230!\2302\230Q\230c\240\023\240A\330\014\023\2201\220H\230G\2402\240U\250!\2509\260F\270!\2701\330\010\024\220I\230^\2501\250H\260F\270!\330\010\016\210g\220Q\220a\200\001\330\005\014\210F\220)\2306\240\021\240$\240f\250A\250Q\330\004\016\210a\330\004\007\200u\210I\220Q\220a\330\010\020\220\005\220S\230\001\330\004\007\200u\210K\220q\230\001\330\010\020\220\006\220e\2305\240\001\240\023\240G\2504\250q\330\t\016\210k\230\021\230!\330\010\020\220\010\230\005\230U\240!\2403\240g\250T\260\021\330\t\017\210s\220!\330\010\020\220\010\230\005\230V\2401\340\010\017\210s\320\0221\260\027\270\001\330\004\005\330\010\013\2104\210q\330\014\022\220-\230q\330\020\021\330\020\031\230\025\230e\2401\330\010\014\210J\220a\220v\230Q\230d\240!\330\014\021\220\026\220q\230\002\230!\2303\230c\240\021\330\021\024\220F\230!\2302\230Q\230b\240\013\2501\250A\330\021\024\220F\230!""\2302\230Q\230c\240\023\240A\330\014\023\2206\230\021\330\010\024\220I\230Z\240q\250\010\260\006\260a\330\010\017\210w\220a\220q\200N\220!\330\010\t\330\014\026\220m\2406\250\030\260\026\260w\270g\300T\310\021\310!\330\017\020\330\014\023\2208\230<\240q\330\010\013\2101\330\014\023\220:\230]\250&\260\010\270\006\270a\340\014\023\220:\230Q\200\013\210;\320\026,\250O\2701\360,\000\005\010\200{\220#\220Q\330\010\027\220x\320\0371\260\021\260!\330\027\037\320\0371\260\021\260!\330\004\016\210a\330\004\r\210Q\330\004\013\2101\330\004\020\220\014\230B\230c\240\021\340\004\017\210r\220\030\230\021\230,\240b\250\007\250q\260\n\270!\2701\330&(\250\007\250q\260\n\270!\2701\330\004\010\210\t\220\030\230\031\240!\2401\330\010\017\210u\220F\230!\2301\330\010\016\210m\2301\230C\230u\240D\250\004\250F\260!\330\010\013\2105\220\003\220:\230Q\230c\240\024\240Q\330\014\022\220-\230q\320 7\260r\270\032\3001\300A\330 )\250\021\330 %\240Q\330\r\022\220#\220Z\230q\240\003\2404\240t\2501\330\014\022\220-\230q\320 8\270\002\270*\300A\300Q\330 )\250\021\330 %\240Q\330\010\013\2105\220\003\220:\230Q\230a\330\014\023\2201\220A\220U\230%\230v\240Q\330\014\017\210q\330\020\026\220g\230Q\230a\330\014\026\220a\340\014\022\220'\230\022\2301\230A\230U\240%\240v\250U\260!\330\014\026\220a\330\010\017\210u\220D\230\001\330\010\023\2201\330\004\007\200q\330\010\016\210m\2301\320\034>\270b\300\n\310!\3101\330\034!\240\026\240y\260\001\330\004\013\2101\210A\210Q\330\004\007\200q\330\010\016\210g\220Q\220a\330\004\007\200q\330\010\021\220\030\230\021\230!\330\004\013\2101\320\000\035\230Q\330\004\007\200z\220\021\220&\230\001\230\024\230Q\330\010\017\210v\220Q\220d\230&\240\001\240\021\330\004\n\210&\220\006\220a\220q\330\004\013\2104\210v\220Q\330\004\007\200t\210;\220a\220q\330\010\017\210t\2201\220C\220w\230a\230q\330\010\013\2104\210{\230!\2306\240\023\240D\250\013\2601\260A\330\014\023\2204\220w\230a\230q\330\014\017\210u\220C\220q\330\020\027\220t\2308\2401\240H\250A\330\020\027\220t\2308\2401\240F""\250!\330\014\024\220A\340\014\017\210u\220C\220q\330\020\026\220m\2401\330\024\025\330\024\035\230U\240%\240q\330\010\017\210q\220\006\220e\2307\240&\250\001\250\021\330\t\016\210d\220,\230a\330\010\013\2106\220\027\230\001\330\014\022\220-\230q\330\020\021\330\020\031\230\025\230e\2401\330\010\017\210q\220\006\220f\230F\240!\2401\330\t\r\210[\230\001\230\021\330\010\017\210z\230\021\230(\240&\250\001\330\n\016\210k\230\021\230!\330\n\r\210U\220#\220Q\330\010\016\210m\2301\330\014(\250\002\250$\250f\260B\260a\260q\330\014\025\220U\230%\230q\330\t\016\210d\220&\230\010\240\001\330\010\016\210m\2301\330\014$\240B\240a\330\014\025\220U\230%\230q\330\t\016\210d\220)\230:\240Q\330\010\016\210m\2301\330\014\034\230B\230a\330\014\025\220U\230%\230q\330\t\r\210[\230\001\230\021\330\010\017\210y\230\001\230\030\240\026\240q\330\t\r\210[\230\001\230\021\330\010\017\210}\230A\230X\240V\2501\330\t\r\210[\230\001\230\021\330\010\017\210}\230A\230X\240V\2501\330\t\r\210[\230\001\230\021\330\010\017\210y\230\001\230\030\240\026\240q\330\t\r\210[\230\001\230\021\330\010\017\210q\220\013\2305\240\006\240a\240r\250\021\250%\250v\260Q\260a\330\004\013\2101\210H\220E\230\026\230q\240\002\240!\2405\250\006\250a\250q\200\001\330\004\r\210X\320\025%\240Q\240h\250a\250y\270\001\330\004\017\210q\330\004\016\210a\330\004\r\210Q\330\004\017\210q\340\004\022\220!\360\022\000\005\006\330\010\027\220q\330\010\022\220-\230y\250\001\330\010\013\2109\220C\220x\230q\330\014\r\330\010\013\2109\220C\220x\230t\2405\250\013\2603\260d\270#\270[\310\003\3101\330\014\033\2301\330\014\026\220m\2409\250A\330\010\013\2109\220C\220x\230q\330\014\022\220-\230q\320 :\270\"\270A\330 )\250\025\250e\2601\330\010\023\2201\330\010\022\220-\230y\250\001\330\010\013\2109\220C\220x\230{\250$\250i\260s\270(\300$\300d\310+\320UX\320XY\330\014\017\210}\230C\230q\330\020\032\230!\330\021\036\230c\240\021\330\020\031\230\021\340\020\030\230\007\230q\240\001\330\014\017\210y\230\003\2308\2401\330\020\021\330\014\r\330\010""\013\210=\230\007\230q\330\014\022\220-\230q\320 :\270\"\270A\330 )\250\025\250e\2601\330\010\013\2109\220C\220x\230t\2404\240{\260#\260Q\330\014\030\230\001\330\014\032\230!\330\014\031\230\021\330\014\030\230\n\240!\330\014\024\220A\330\014\r\330\020\032\230,\240c\250\024\250Y\260a\260q\330\020\023\220:\230S\240\001\330\024 \240\001\330\020\032\230!\330\020\023\2209\230C\230x\240{\260$\260a\330\024\032\230-\240q\320(B\300\"\300A\330(1\260\025\260e\2701\330\020\024\220D\230\013\2401\330\031\"\240#\240X\250[\270\004\270I\300S\310\010\320PT\320TX\320Xc\320cf\320fg\330\024#\320#5\260Q\260j\300\013\3101\330\024\034\230A\230\\\250\021\330\024\034\230G\2401\240A\330\024\025\330\020\025\220W\230B\230j\250\001\330\020\023\220;\230d\240)\2503\250h\260d\270$\270k\310\023\310A\330\024\"\240!\330\025 \240\004\240I\250S\260\010\270\004\270D\300\013\3103\310a\330\024\"\240!\330\024\027\220t\2301\330\030$\240N\260!\330\025\031\230\033\240D\250\t\260\023\260H\270D\300\004\300K\310t\320SX\320X]\320]^\330\024 \240\001\330\024!\240\021\330\024#\2405\250\005\250U\260%\260u\270D\300\001\300\021\330\004\013\210:\220Y\230h\240a\200\001\360\026\000\005\021\220\001\330\004\010\210\003\210;\220i\230q\240\001\330\010\013\210:\220Q\220i\230q\340\014\r\330\010\017\210w\220a\220q\330\010\013\2104\210|\2307\240!\2406\250\024\250U\260'\270\021\330\014\r\330\010\013\2104\210q\330\014\023\2201\340\014\023\2206\230\021\230\"\230B\230a\330\010\013\2102\210R\210r\220\023\220C\220q\230\001\330\014\031\230\021\340\014\031\230\026\230q\240\002\240\"\240A\330\010\014\210D\220\n\230!\230<\240q\330\020\023\2204\220z\240\021\240&\250\001\330\014\r\330\010\022\220$\220e\2303\320\0361\260\027\270\001\270\021\330\010\013\2102\210S\220\002\220$\220d\230$\230f\240A\330\014\026\220a\330\010\013\210:\220W\230E\240\024\240Z\250r\260\022\2603\260b\270\004\270D\300\004\300F\310!\330\014\026\220a\330\010\014\210A\330\014\021\220\024\220[\240\003\320#5\260W\270A\270Q\330\021\025\220R\220s\230#\230Q\230h\240b\250\002""\250$\250d\260*\270F\300!\330\014\017\210q\330\020\025\220R\220s\230\"\230D\240\004\240D\250\006\250a\330\030\033\2308\2403\240a\330\024\032\230!\2302\230R\230u\240A\340\024\030\320\030+\2507\260!\2601\340\024\033\2304\230r\240\021\240&\250\003\2502\250Q\330\024\032\230!\2302\230R\230u\240A\330\014\017\210q\330\020\034\230A\330\020\023\2202\220S\230\003\2301\230H\240B\240b\250\004\250D\260\n\270&\300\001\330\024\032\230!\2302\230R\230u\240A\340\024\030\320\030*\250'\260\021\260!\330\024!\240\032\2501\250A\250T\260\021\330\024\032\230!\2302\230R\230u\240A\330\004\013\2101\200\r\210[\230\017\240q\360d\001\000\005\010\200{\220#\220Q\330\010\027\220x\320\0371\260\021\260!\330\027\037\320\0371\260\021\260!\330\004\r\210S\220\001\220\023\220E\230\026\230|\250=\270\013\3001\330\004\r\210Q\330\004\n\210!\330\010\024\220I\230Z\240q\250\010\260\001\330\010\016\210g\220Q\220a\330\004\013\2101\200\001\330\004\007\200t\210:\220Q\220c\230\021\330\010\013\2107\220!\2203\220a\330\014\023\2203\220a\220q\340\014\023\2205\230\001\230\021\330\004\013\2101\320\000\021\220\021\330\013\014\330\013\014\330\013\014\330\004\007\200u\210C\210q\330\010\017\210s\220%\220q\230\001\330\004\r\210X\220]\240!\330\010\016\210a\330\004\n\210+\220Q\330\010\016\210a\330\010\r\210Q\330\010\020\220\001\330\010\r\210Q\330\004\n\210+\220Q\330\010\t\330\010\r\210Q\330\010\017\210q\330\010\r\210Q\330\004\r\210W\220F\230+\240Q\240a\330\004\007\200s\210!\2106\220\022\2201\330\010\r\210Q\210a\330\010\013\2105\220\001\220\021\330\004\024\220D\230\001\230\021\330\004\013\2104\210q\220\001\330\004\013\2101\330\004\007\200w\210a\330\010\014\210G\2201\220B\220a\330\004\010\210\t\220\021\330\010\013\2104\210w\220a\330\014\021\220\021\320\022%\240R\240q\330\014\017\210u\220A\220Q\330\010\016\210h\220e\2306\240\021\240%\240q\330\010\013\2104\210{\230!\2301\330\014\023\2204\220r\230\021\330\014\024\220D\230\001\230\021\330\010\014\210A\210X\220Q\330\004\007\200~\220S\230\001\330\010\033\2303\230f\240E\250\021\330\010""\030\230\001\340\r\021\220\021\220/\240\031\250!\330\014\037\230q\240\005\240Q\330\004\017\210x\220q\320\030*\250%\250q\330\004\r\210X\220[\240\001\240\021\330\004\007\200w\210a\330\r\021\220\021\220'\230\031\240)\2501\330\014\r\210V\2201\220A\340\010\013\2107\220&\230\001\230\021";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 450; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 103) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 450; i < 503; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 503; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 450;
      for (Py_ssize_t i=0; i<53; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,-1,1,2,3,5};
    for (int i = 0; i < 6; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<6; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 4;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 5;
    unsigned int flags : 10;
    unsigned int first_line : 11;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 945};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_tok_type, __pyx_mstate->__pyx_n_u_tok_string, __pyx_mstate->__pyx_n_u_srow, __pyx_mstate->__pyx_n_u_scol, __pyx_mstate->__pyx_n_u_erow, __pyx_mstate->__pyx_n_u_ecol, __pyx_mstate->__pyx_n_u_line};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_get_token, __pyx_mstate->__pyx_kp_b_iso88591_N_m6_wgT_8_q_1_a_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 46};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_v};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_coerce_text, __pyx_mstate->__pyx_kp_b_iso88591_t_Qc_7_3a_3aq_5_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 58};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_position, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_6_L_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 63};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_str, __pyx_mstate->__pyx_kp_b_iso88591_A_c_at1_4q_A_T_4t9AQ_4q_9Bd_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 81};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_from_template, __pyx_mstate->__pyx_n_u_path};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_get_file_template, __pyx_mstate->__pyx_kp_b_iso88591_2U_q_xq_XQ_j_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {10, 0, 0, 14, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 99};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_namespace, __pyx_mstate->__pyx_n_u_stacklevel, __pyx_mstate->__pyx_n_u_get_template, __pyx_mstate->__pyx_n_u_default_inherit, __pyx_mstate->__pyx_n_u_line_offset, __pyx_mstate->__pyx_n_u_delimiters, __pyx_mstate->__pyx_n_u_delimeters, __pyx_mstate->__pyx_n_u_warnings, __pyx_mstate->__pyx_n_u_caller, __pyx_mstate->__pyx_n_u_globals, __pyx_mstate->__pyx_n_u_lineno};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_1_Kq_1_E_Q_Q_c_0_0_T_3EU_5Zq_3, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {6, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 153};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_filename, __pyx_mstate->__pyx_n_u_namespace, __pyx_mstate->__pyx_n_u_encoding, __pyx_mstate->__pyx_n_u_default_inherit, __pyx_mstate->__pyx_n_u_get_template, __pyx_mstate->__pyx_n_u_f, __pyx_mstate->__pyx_n_u_c};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_from_filename, __pyx_mstate->__pyx_kp_b_iso88591_5Q_9_IQ_a_1_s_83e_Zq_4M, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 164};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q_q_6_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 169};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_inherit_2};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_substitute, __pyx_mstate->__pyx_kp_b_iso88591_A_1_q_iq_s_6_1_iq_t7_4q_A_iq_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 193};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_inherit_2};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_q_Qd_D_G5_A_d_aq_a_r_axvQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 204};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_inherit_template, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_templ, __pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret_inherit, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_4t1_q_uD_M_4A_at1_F_4vQ_1G6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 219};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_codes, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_item};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret_codes, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_HA_z_7_1_AV4uA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 19, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 227};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_vars, __pyx_mstate->__pyx_n_u_expr, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_base, __pyx_mstate->__pyx_n_u_part, __pyx_mstate->__pyx_n_u_func_2, __pyx_mstate->__pyx_n_u_var, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_signature};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret_code, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_fD_T_5_1_at1D_A_Q_1_Q_Q_at4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {7, 0, 0, 11, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 270};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_vars, __pyx_mstate->__pyx_n_u_expr, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_item, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret_for, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_HA_s_6_A_4q_a_3avS_1A_A_3awc, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 289};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_defs, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_part, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_interpret_if, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_HA_4z_AT_Qa_uCq_V1D_T_q_Qd_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 303};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_e, __pyx_mstate->__pyx_n_u_arg0};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_eval_2, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_AV4_1_k_7r_1_A_was_q_Qa_1_Yd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 320};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_exec, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_t_q_A_q_oQauAT_oQfA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 331};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_traceback_hide, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_vS_q_t1_Cq_E_4z_Kq_Jawa_D_E, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 373};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_pos};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_add_line_info, __pyx_mstate->__pyx_kp_b_iso88591_A_AT_AQ_4q_4q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS), 381};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_delimiters, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_delimeters, __pyx_mstate->__pyx_n_u_tmpl};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_sub, __pyx_mstate->__pyx_kp_b_iso88591_2T_4q_c_81IU_4_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 388};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_vars, __pyx_mstate->__pyx_n_u_filename, __pyx_mstate->__pyx_n_u_tmpl};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_paste_script_template_renderer, __pyx_mstate->__pyx_kp_b_iso88591_2_81IU_4_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS), 395};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_F_2V1_1F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 399};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_setattr, __pyx_mstate->__pyx_kp_b_iso88591_A_AXQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 402};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_getattr, __pyx_mstate->__pyx_kp_b_iso88591_A_4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 408};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_key};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_getitem, __pyx_mstate->__pyx_kp_b_iso88591_A_S_t_q_a_t_q_a_4_1F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 417};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_k, __pyx_mstate->__pyx_n_u_v};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q_uAQk_Ct3e6_fA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {8, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 424};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_template, __pyx_mstate->__pyx_n_u_func_name, __pyx_mstate->__pyx_n_u_func_signature, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_bound_self};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_M_N_q_IQ_G1_HA_O1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 434};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q_T_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 439};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_str, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 442};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_values, __pyx_mstate->__pyx_n_u_ns, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_subdefs};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_call, __pyx_mstate->__pyx_kp_b_iso88591_A_avQ_T_U_4_G1_az_Q_a_J_q_HD_Q_r, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 453};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_type};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_get_2, __pyx_mstate->__pyx_kp_b_iso88591_1_4s_1_t_Q_D_T_F_g, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 13, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 460};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_values, __pyx_mstate->__pyx_n_u_sig_args, __pyx_mstate->__pyx_n_u_var_args, __pyx_mstate->__pyx_n_u_var_kw, __pyx_mstate->__pyx_n_u_defaults, __pyx_mstate->__pyx_n_u_extra_kw, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_value_expr, __pyx_mstate->__pyx_n_u_v};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_signature, __pyx_mstate->__pyx_kp_b_iso88591_A_HKt1_1_F_2V1_t7_e7_iq_Rq_uCq_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 502};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_Ja_G_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 506};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_D_T, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 512};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_template_obj};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 515};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_attr};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_getattr, __pyx_mstate->__pyx_kp_b_iso88591_A_wat_F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 518};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_4z_D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 523};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kw};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_call, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 526};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_str, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 529};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_repr_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 532};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_unicode_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 535};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_iter, __pyx_mstate->__pyx_kp_b_iso88591_A_t1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 538};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_bool, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 14, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 549};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s_2, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_trim_whitespace, __pyx_mstate->__pyx_n_u_line_offset, __pyx_mstate->__pyx_n_u_delimiters, __pyx_mstate->__pyx_n_u_in_expr, __pyx_mstate->__pyx_n_u_chunks, __pyx_mstate->__pyx_n_u_last, __pyx_mstate->__pyx_n_u_last_pos, __pyx_mstate->__pyx_n_u_token_re, __pyx_mstate->__pyx_n_u_match, __pyx_mstate->__pyx_n_u_expr, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_part};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_lex, __pyx_mstate->__pyx_kp_b_iso88591_O1_Q_x_1_1_a_Q_1_Bc_r_b_q_1_q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 618};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_last_trim, __pyx_mstate->__pyx_n_u_i, __pyx_mstate->__pyx_n_u_current, __pyx_mstate->__pyx_n_u_item, __pyx_mstate->__pyx_n_u_prev, __pyx_mstate->__pyx_n_u_next_chunk, __pyx_mstate->__pyx_n_u_prev_ok, __pyx_mstate->__pyx_n_u_m};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_trim_lex, __pyx_mstate->__pyx_kp_b_iso88591_iq_Qiq_waq_4_7_6_U_4q_1_6_Ba_2R, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 676};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_string_2, __pyx_mstate->__pyx_n_u_index, __pyx_mstate->__pyx_n_u_last_index, __pyx_mstate->__pyx_n_u_last_pos, __pyx_mstate->__pyx_n_u_lines, __pyx_mstate->__pyx_n_u_column_2};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_find_position, __pyx_mstate->__pyx_kp_b_iso88591_F_1_vRq_r_vQfL_S_b_HAS, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 686};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s_2, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_line_offset, __pyx_mstate->__pyx_n_u_delimiters, __pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_next_chunk};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse, __pyx_mstate->__pyx_kp_b_iso88591_qd_Q_x_1_1_S_E_1_Q_IZq_gQa_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 747};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_expr, __pyx_mstate->__pyx_n_u_pos};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_expr, __pyx_mstate->__pyx_kp_b_iso88591_Q_z_Q_vQd_aq_4vQ_t_aq_t1Cwaq_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 800};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_n_u_pieces, __pyx_mstate->__pyx_n_u_next_chunk};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_cond, __pyx_mstate->__pyx_kp_b_iso88591_F_2Qa_Q_hc_4q_q_Q_JavQd_F_2Qc_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 816};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_first, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_part, __pyx_mstate->__pyx_n_u_next_chunk};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_one_cond, __pyx_mstate->__pyx_kp_b_iso88591_F_6_fAQ_a_uIQa_S_uKq_e5_G4q_k_U, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 11, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 843};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_first, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_match, __pyx_mstate->__pyx_n_u_vars, __pyx_mstate->__pyx_n_u_expr, __pyx_mstate->__pyx_n_u_next_chunk, __pyx_mstate->__pyx_n_u_v};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_for, __pyx_mstate->__pyx_kp_b_iso88591_6_q_V1A_xr_a_5_1IQ_uIQa_S_E_V1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 878};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_first, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_var, __pyx_mstate->__pyx_n_u_expr};
    __pyx_mstate_global->__pyx_codeobj_tab[51] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_default, __pyx_mstate->__pyx_kp_b_iso88591_6_q_5_1A_E_q_b_E_q_Q_s_7_Q_m1_I, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[51])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 900};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_first, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_expr};
    __pyx_mstate_global->__pyx_codeobj_tab[52] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_inherit, __pyx_mstate->__pyx_kp_b_iso88591_6_q_5_1A_5_avRq_1KuG6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[52])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 907};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_first, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_n_u_func_name, __pyx_mstate->__pyx_n_u_sig, __pyx_mstate->__pyx_n_u_sig_text, __pyx_mstate->__pyx_n_u_content, __pyx_mstate->__pyx_n_u_next_chunk};
    __pyx_mstate_global->__pyx_codeobj_tab[53] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_def, __pyx_mstate->__pyx_kp_b_iso88591_86_V1A_5_1A_E_q_b_uIQa_S_t7_A_t, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[53])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 23, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 938};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_sig_text, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_sig_args, __pyx_mstate->__pyx_n_u_var_arg, __pyx_mstate->__pyx_n_u_var_kw, __pyx_mstate->__pyx_n_u_defaults, __pyx_mstate->__pyx_n_u_get_token, __pyx_mstate->__pyx_n_u_get_token, __pyx_mstate->__pyx_n_u_var_arg_type, __pyx_mstate->__pyx_n_u_tok_type, __pyx_mstate->__pyx_n_u_tok_string, __pyx_mstate->__pyx_n_u_var_name, __pyx_mstate->__pyx_n_u_nest_type, __pyx_mstate->__pyx_n_u_unnest_type, __pyx_mstate->__pyx_n_u_nest_count, __pyx_mstate->__pyx_n_u_start_pos, __pyx_mstate->__pyx_n_u_end_pos, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_s_2, __pyx_mstate->__pyx_n_u_e, __pyx_mstate->__pyx_n_u_default_expr};
    __pyx_mstate_global->__pyx_codeobj_tab[54] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_parse_signature_2, __pyx_mstate->__pyx_kp_b_iso88591_X_Qhay_q_a_Q_q_q_y_9Cxq_9Cxt5_3, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[54])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1014};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_string_2, __pyx_mstate->__pyx_n_u_start_pos, __pyx_mstate->__pyx_n_u_end_pos, __pyx_mstate->__pyx_n_u_srow, __pyx_mstate->__pyx_n_u_scol, __pyx_mstate->__pyx_n_u_erow, __pyx_mstate->__pyx_n_u_ecol, __pyx_mstate->__pyx_n_u_lines, __pyx_mstate->__pyx_n_u_parts};
    __pyx_mstate_global->__pyx_codeobj_tab[55] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_isolate_expression, __pyx_mstate->__pyx_kp_b_iso88591_A_A_F_Qa_uCq_uAU_5_AU_5_at1Ba_u, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[55])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 14, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1037};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_sys, __pyx_mstate->__pyx_n_u_optparse, __pyx_mstate->__pyx_n_u_os, __pyx_mstate->__pyx_n_u_parser, __pyx_mstate->__pyx_n_u_options, __pyx_mstate->__pyx_n_u_template_name_2, __pyx_mstate->__pyx_n_u_vars, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_template_content, __pyx_mstate->__pyx_n_u_f, __pyx_mstate->__pyx_n_u_template, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[56] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Tempita__tempita_py, __pyx_mstate->__pyx_n_u_fill_command, __pyx_mstate->__pyx_kp_b_iso88591_uCq_s_q_X_a_Q_a_Q_Q_Q_Q_q_Q_WF, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[56])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyLong_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyLong_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    #if !CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    #endif
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(length < 0)) return NULL;
    #endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    if (start == 0 && stop == length)
        return __Pyx_NewRef(text);
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyUnicode_Substring(text, start, stop);
#else
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#endif
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    int was_initialized =  __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return __Pyx_CallCFunction(cfunc, self, arg);
        } else if (flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, &arg, 1);
        } else if (flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, &arg, 1, NULL);
        }
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod1(&tmp_cfunc, self, arg);
    }
#endif
    PyObject* result = __Pyx__CallUnboundCMethod1(cfunc, self, arg);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *args = PyTuple_New(1);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
    } else
#endif
    {
        result = __Pyx_PyObject_Call2Args(cfunc->method, self, arg);
    }
    return result;
}

/* py_dict_pop */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop)
    PyObject *value;
    if (PyDict_Pop(d, key, &value) == 0) {
        if (default_value) {
            Py_INCREF(default_value);
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
        value = default_value;
    }
    return value;
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    return _PyDict_Pop(d, key, default_value);
#else
    if (default_value) {
        return __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key, default_value);
    } else {
        return __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key);
    }
#endif
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* PyObjectCallMethod1 (used by append) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* PyExec */
static CYTHON_INLINE PyObject* __Pyx_PyExec2(PyObject* o, PyObject* globals) {
    return __Pyx_PyExec3(o, globals, NULL);
}
static PyObject* __Pyx_PyExec3(PyObject* o, PyObject* globals, PyObject* locals) {
    PyObject* result;
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyObject* s = 0;
    char *code = 0;
#endif
    if (!globals || globals == Py_None) {
        globals = __pyx_mstate_global->__pyx_d;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    else if (unlikely(!PyDict_Check(globals))) {
        __Pyx_TypeName globals_type_name =
            __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(globals));
        PyErr_Format(PyExc_TypeError,
                     "exec() arg 2 must be a dict, not " __Pyx_FMT_TYPENAME,
                     globals_type_name);
        __Pyx_DECREF_TypeName(globals_type_name);
        goto bad;
    }
#endif
    if (!locals || locals == Py_None) {
        locals = globals;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    if (__Pyx_PyDict_GetItemStr(globals, __pyx_mstate_global->__pyx_n_u_builtins) == NULL) {
        if (unlikely(PyDict_SetItem(globals, __pyx_mstate_global->__pyx_n_u_builtins, PyEval_GetBuiltins()) < 0))
            goto bad;
    }
    if (PyCode_Check(o)) {
        if (unlikely(__Pyx_PyCode_HasFreeVars((PyCodeObject *)o))) {
            PyErr_SetString(PyExc_TypeError,
                "code object passed to exec() may not contain free variables");
            goto bad;
        }
        #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM < 0x07030400
        result = PyEval_EvalCode((PyCodeObject *)o, globals, locals);
        #else
        result = PyEval_EvalCode(o, globals, locals);
        #endif
    } else {
        PyCompilerFlags cf;
        cf.cf_flags = 0;
        cf.cf_feature_version = PY_MINOR_VERSION;
        if (PyUnicode_Check(o)) {
            cf.cf_flags = PyCF_SOURCE_IS_UTF8;
            s = PyUnicode_AsUTF8String(o);
            if (unlikely(!s)) goto bad;
            o = s;
        } else if (unlikely(!PyBytes_Check(o))) {
            __Pyx_TypeName o_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(o));
            PyErr_Format(PyExc_TypeError,
                "exec: arg 1 must be string, bytes or code object, got " __Pyx_FMT_TYPENAME,
                o_type_name);
            __Pyx_DECREF_TypeName(o_type_name);
            goto bad;
        }
        code = PyBytes_AS_STRING(o);
        if (PyEval_MergeCompilerFlags(&cf)) {
            result = PyRun_StringFlags(code, Py_file_input, globals, locals, &cf);
        } else {
            result = PyRun_String(code, Py_file_input, globals, locals);
        }
        Py_XDECREF(s);
    }
    return result;
bad:
    Py_XDECREF(s);
    return 0;
#else // CYTHON_COMPILING_IN_LIMITED_API
    {
        PyObject *builtins, *exec, *exec_str;
        builtins = PyEval_GetBuiltins();
        if (!builtins) return NULL;
        exec_str = PyUnicode_FromStringAndSize("exec", 4);
        if (!exec_str) return NULL;
        exec = PyObject_GetItem(builtins, exec_str);
        Py_DECREF(exec_str);
        if (!exec) return NULL;
        result = PyObject_CallFunctionObjArgs(exec, o, globals, locals, NULL);
        Py_DECREF(exec);
        return result;
    }
#endif
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyLong_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return PyLong_FromLong(-intval);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a - b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla - llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_SubtractObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) - (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_SubtractObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_SubtractObjC(op1, op2, inplace);
}
#endif

/* PyLongCompare */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = __Pyx_PyFloat_AS_DOUBLE(op1);
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* IterNextPlain (used by IterNext) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void) {
    if (unlikely(!__pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache))
        __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_next);
    return __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator) {
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    PyObject *result;
    PyObject *next = __Pyx_GetBuiltinNext_LimitedAPI();
    if (unlikely(!next)) return NULL;
    result = PyObject_CallFunctionObjArgs(next, iterator, NULL);
    return result;
#else
    (void)__Pyx_GetBuiltinName; // only for early limited API
    iternextfunc iternext = __Pyx_PyObject_GetIterNextFunc(iterator);
    assert(iternext);
    return iternext(iterator);
#endif
}

/* IterNext */
static PyObject *__Pyx_PyIter_Next2Default(PyObject* defval) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (!defval || unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return NULL;
        __Pyx_PyErr_Clear();
        Py_INCREF(defval);
        return defval;
    }
    if (defval) {
        Py_INCREF(defval);
        return defval;
    }
    __Pyx_PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}
static void __Pyx_PyIter_Next_ErrorNoIterator(PyObject *iterator) {
    __Pyx_TypeName iterator_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(iterator));
    PyErr_Format(PyExc_TypeError,
        __Pyx_FMT_TYPENAME " object is not an iterator", iterator_type_name);
    __Pyx_DECREF_TypeName(iterator_type_name);
}
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
#if !CYTHON_COMPILING_IN_LIMITED_API
    iternextfunc iternext = __Pyx_PyObject_TryGetSlot(iterator, tp_iternext, iternextfunc);
    if (likely(iternext)) {
        next = iternext(iterator);
        if (likely(next))
            return next;
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
        if (unlikely(iternext == &_PyObject_NextNotImplemented))
            return NULL;
    #endif
    } else if (CYTHON_USE_TYPE_SLOTS) {
        __Pyx_PyIter_Next_ErrorNoIterator(iterator);
        return NULL;
    } else
#endif
    if (unlikely(!PyIter_Check(iterator))) {
        __Pyx_PyIter_Next_ErrorNoIterator(iterator);
        return NULL;
    } else {
        next = defval ? PyIter_Next(iterator) : __Pyx_PyIter_Next_Plain(iterator);
        if (likely(next))
            return next;
    }
    return __Pyx_PyIter_Next2Default(defval);
}

/* RaiseClosureNameError */
static void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__24);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    if (__Pyx_TypeCheck(method, &PyMethodDescr_Type))
#endif
    {
#if CYTHON_COMPILING_IN_LIMITED_API
        return PyErr_Format(
            PyExc_SystemError,
            "Cython cannot yet handle classmethod on a MethodDescriptorType (%S) in limited API mode. "
            "This is most likely a classmethod in a cdef class method with binding=False. "
            "Try setting 'binding' to True.",
            method);
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
        PyTypeObject *d_type = GraalPyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, GraalPyMethodDescrObject_GetMethod(method));
#elif CYTHON_COMPILING_IN_GRAAL
        PyTypeObject *d_type = PyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, PyMethodDescrObject_GetMethod(method));
#else
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        PyTypeObject *d_type = descr->d_common.d_type;
        return PyDescr_NewClassMethod(d_type, descr->d_method);
#endif
    }
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
#else
    {
        PyObject *func=NULL;
        PyObject *builtins, *classmethod, *classmethod_str, *result=NULL;
        if (__Pyx_TypeCheck(method, __pyx_mstate_global->__Pyx_CachedMethodType)) {
            func = PyObject_GetAttrString(method, "__func__");
            if (!func) goto bad;
        } else {
            func = method;
            Py_INCREF(func);
        }
        builtins = PyEval_GetBuiltins(); // borrowed
        if (unlikely(!builtins)) goto bad;
        classmethod_str = PyUnicode_FromString("classmethod");
        if (unlikely(!classmethod_str)) goto bad;
        classmethod = PyObject_GetItem(builtins, classmethod_str);
        Py_DECREF(classmethod_str);
        if (unlikely(!classmethod)) goto bad;
        result = PyObject_CallFunctionObjArgs(classmethod, func, NULL);
        Py_DECREF(classmethod);
        bad:
        Py_XDECREF(func);
        return result;
    }
#endif
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_mstate_global->__pyx_d);
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__27);
    }
    goto done;
}
#endif

/* CIntFromPyVerify (used by CIntFromPy) */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
