/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/build/cython/src/cython/Cython/Compiler/Parsing.pxd"
        ],
        "name": "Cython.Compiler.Parsing",
        "sources": [
            "/build/cython/src/cython/Cython/Compiler/Parsing.py"
        ]
    },
    "module_name": "Cython.Compiler.Parsing"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Cython__Compiler__Parsing
#define __PYX_HAVE_API__Cython__Compiler__Parsing
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "Cython/Compiler/Parsing.py",
  "Cython/Plex/Actions.pxd",
  "Cython/Plex/Scanners.pxd",
  "Cython/Compiler/Scanning.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6Cython_4Plex_7Actions_Action;
struct __pyx_obj_6Cython_4Plex_7Actions_Return;
struct __pyx_obj_6Cython_4Plex_7Actions_Call;
struct __pyx_obj_6Cython_4Plex_7Actions_Method;
struct __pyx_obj_6Cython_4Plex_7Actions_Begin;
struct __pyx_obj_6Cython_4Plex_7Actions_Ignore;
struct __pyx_obj_6Cython_4Plex_7Actions_Text;
struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner;
struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope;
struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner;
struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState;
struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce;

/* "Plex/Scanners.pxd":45
 * 
 *     cdef inline begin(self, state)
 *     cdef inline produce(self, value, text = *)             # <<<<<<<<<<<<<<
*/
struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce {
  int __pyx_n;
  PyObject *text;
};
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_ident;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_yield_expression;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_opt_string_literal;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_expr_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_pass_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_from_import_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_iterator;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_with_items;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_complex_base_type;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_simple_base_type;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_list;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_decl;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_py_arg_decl;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_code;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_module;
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree;

/* "Cython/Compiler/Parsing.pxd":6
 * from .Scanning cimport PyrexScanner
 * 
 * ctypedef object (*p_sub_expr_func)(PyrexScanner obj)             # <<<<<<<<<<<<<<
 * 
 * cdef p_binop_expr(PyrexScanner s, ops, p_sub_expr_func p_sub_expr)
*/
typedef PyObject *(*__pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *);

/* "Cython/Compiler/Parsing.py":65
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_ident {
  int __pyx_n;
  PyObject *message;
};

/* "Cython/Compiler/Parsing.py":444
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_yield_expression(s: PyrexScanner, statement_terminators: frozenset = statement_terminators):
 *     # s.sy == "yield"
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_yield_expression {
  int __pyx_n;
  PyObject *statement_terminators;
};

/* "Cython/Compiler/Parsing.py":552
 * #             star_expr )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call_parse_args(s: PyrexScanner, allow_genexp: cython.bint = True) -> tuple:
 *     # s.sy == '('
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args {
  int __pyx_n;
  int allow_genexp;
};

/* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node {
  int __pyx_n;
  PyObject *stop;
  PyObject *step;
};

/* "Cython/Compiler/Parsing.py":988
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_opt_string_literal {
  int __pyx_n;
  PyObject *required_type;
};

/* "Cython/Compiler/Parsing.py":1060
 *     return ''
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_string_literal(s: PyrexScanner, kind_override=None) -> tuple:
 *     # A single string or char literal.  Returns (kind, bvalue, uvalue)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal {
  int __pyx_n;
  PyObject *kind_override;
};

/* "Cython/Compiler/Parsing.py":1577
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_expr_list {
  int __pyx_n;
  PyObject *expr;
};

/* "Cython/Compiler/Parsing.py":1588
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list {
  int __pyx_n;
  PyObject *expr;
};

/* "Cython/Compiler/Parsing.py":1599
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list {
  int __pyx_n;
  PyObject *expr;
};

/* "Cython/Compiler/Parsing.py":1809
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):
 *     pos = s.position()
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_pass_statement {
  int __pyx_n;
  int with_newline;
};

/* "Cython/Compiler/Parsing.py":1909
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_from_import_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     # s.sy == 'from'
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_from_import_statement {
  int __pyx_n;
  int first_statement;
};

/* "Cython/Compiler/Parsing.py":2080
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_statement(s: PyrexScanner, is_async: cython.bint = False):
 *     # s.sy == 'for'
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_statement {
  int __pyx_n;
  int is_async;
};

/* "Cython/Compiler/Parsing.py":2092
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds {
  int __pyx_n;
  int allow_testlist;
  int is_async;
};

/* "Cython/Compiler/Parsing.py":2183
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_iterator {
  int __pyx_n;
  int allow_testlist;
  int is_async;
};

/* "Cython/Compiler/Parsing.py":2286
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_items(s: PyrexScanner, is_async: cython.bint = False):
 *     """
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_with_items {
  int __pyx_n;
  int is_async;
};

/* "Cython/Compiler/Parsing.py":2389
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     #print "p_simple_statement:", s.sy, s.systring ###
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement {
  int __pyx_n;
  int first_statement;
};

/* "Cython/Compiler/Parsing.py":2425
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of simple statements on one line
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement_list {
  int __pyx_n;
  int first_statement;
};

/* "Cython/Compiler/Parsing.py":2516
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):
 *     cdef_flag: cython.bint = ctx.cdef_flag
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement {
  int __pyx_n;
  int first_statement;
};

/* "Cython/Compiler/Parsing.py":2638
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of statements separated by newlines.
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list {
  int __pyx_n;
  int first_statement;
};

/* "Cython/Compiler/Parsing.py":2657
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite(s: PyrexScanner, ctx=Ctx()):
 *     return p_suite_with_docstring(s, ctx, with_doc_only=False)[1]
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite {
  int __pyx_n;
  PyObject *ctx;
};

/* "Cython/Compiler/Parsing.py":2662
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:
 *     s.expect(':')
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring {
  int __pyx_n;
  int with_doc_only;
};

/* "Cython/Compiler/Parsing.py":2686
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_positional_and_keyword_args(s: PyrexScanner, end_sy_set, templates = None) -> tuple:
 *     """
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args {
  int __pyx_n;
  PyObject *templates;
};

/* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type {
  int __pyx_n;
  int nonempty;
  PyObject *templates;
};

/* "Cython/Compiler/Parsing.py":2766
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_complex_base_type(s: PyrexScanner, templates = None):
 *     # s.sy == '('
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_complex_base_type {
  int __pyx_n;
  PyObject *templates;
};

/* "Cython/Compiler/Parsing.py":2796
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):
 *     is_basic = False
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_simple_base_type {
  int __pyx_n;
  PyObject *templates;
};

/* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator {
  int __pyx_n;
  PyObject *ctx;
  int empty;
  int is_type;
  int cmethod_flag;
  int assignable;
  int nonempty;
  int calling_convention_allowed;
};

/* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_list {
  int __pyx_n;
  PyObject *ctx;
  int in_pyfunc;
  int cmethod_flag;
  int nonempty_declarators;
  int kw_only;
  int annotated;
};

/* "Cython/Compiler/Parsing.py":3375
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,
 *                  nonempty: cython.bint = False,
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_decl {
  int __pyx_n;
  int cmethod_flag;
  int nonempty;
  int kw_only;
  int annotated;
};

/* "Cython/Compiler/Parsing.py":3849
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_def_statement(s: PyrexScanner, decorators: list = None, is_async_def: cython.bint = False):
 *     # s.sy == 'def'
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement {
  int __pyx_n;
  PyObject *decorators;
  int is_async_def;
};

/* "Cython/Compiler/Parsing.py":3882
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist {
  int __pyx_n;
  Py_UCS4 terminator;
  int annotated;
};

/* "Cython/Compiler/Parsing.py":3920
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):
 *     pos = s.position()
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_py_arg_decl {
  int __pyx_n;
  int annotated;
};

/* "Cython/Compiler/Parsing.py":4128
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_code {
  int __pyx_n;
  PyObject *level;
  PyObject *ctx;
};

/* "Cython/Compiler/Parsing.py":4181
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):
 *     pos = s.position()
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_module {
  int __pyx_n;
  PyObject *ctx;
};

/* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/
struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree {
  int __pyx_n;
  PyObject *key;
};

/* "Cython/Plex/Actions.pxd":1
 * cdef class Action:             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Action {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action *__pyx_vtab;
};


/* "Cython/Plex/Actions.pxd":4
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Return(Action):             # <<<<<<<<<<<<<<
 *     cdef object value
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Return {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *value;
};


/* "Cython/Plex/Actions.pxd":8
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Call(Action):             # <<<<<<<<<<<<<<
 *     cdef object function
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Call {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *function;
};


/* "Cython/Plex/Actions.pxd":12
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Method(Action):             # <<<<<<<<<<<<<<
 *     cdef str name
 *     cdef dict kwargs
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Method {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *name;
  PyObject *kwargs;
};


/* "Cython/Plex/Actions.pxd":16
 *     cdef dict kwargs
 * 
 * cdef class Begin(Action):             # <<<<<<<<<<<<<<
 *     cdef object state_name
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Begin {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
  PyObject *state_name;
};


/* "Cython/Plex/Actions.pxd":20
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Ignore(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Ignore {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
};


/* "Cython/Plex/Actions.pxd":23
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Text(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
*/
struct __pyx_obj_6Cython_4Plex_7Actions_Text {
  struct __pyx_obj_6Cython_4Plex_7Actions_Action __pyx_base;
};


/* "Plex/Scanners.pxd":7
 * from Cython.Plex.Actions cimport Action
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 * 
 *     cdef public lexicon
*/
struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner *__pyx_vtab;
  PyObject *lexicon;
  PyObject *stream;
  PyObject *name;
  PyObject *buffer;
  Py_ssize_t buf_start_pos;
  Py_ssize_t next_pos;
  Py_ssize_t cur_pos;
  Py_ssize_t cur_line;
  Py_ssize_t cur_line_start;
  Py_ssize_t start_pos;
  PyObject *current_scanner_position_tuple;
  PyObject *last_token_position_tuple;
  PyObject *text;
  PyObject *initial_state;
  PyObject *state_name;
  PyObject *queue;
  int trace;
  PyObject *cur_char;
  long input_state;
  PyObject *level;
};


/* "Scanning.pxd":12
 * ## methods commented with '##' out are used by Parsing.py when compiled.
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class CompileTimeScope:
 *     cdef public dict entries
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope {
  PyObject_HEAD
  PyObject *entries;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *outer;
};


/* "Scanning.pxd":20
 *     ##cpdef lookup(self, name)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class PyrexScanner(Scanner):
 *     cdef public context
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner {
  struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner __pyx_base;
  PyObject *context;
  PyObject *included_files;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *compile_time_env;
  int compile_time_eval;
  int compile_time_expr;
  int parse_comments;
  int in_python_file;
  PyObject *source_encoding;
  PyObject *keywords;
  PyObject *indentation_stack;
  Py_UCS4 indentation_char;
  int bracket_nesting_level;
  int async_enabled;
  PyObject *sy;
  PyObject *systring;
  PyObject *put_back_on_failure;
  PyObject *ft_string_state_stack;
  int in_ft_string_expr_prescan;
};


/* "Scanning.pxd":46
 * 
 * 
 * cdef class FTStringState:             # <<<<<<<<<<<<<<
 *     cdef list bracket_states
 *     cdef readonly str scanner_state
*/
struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState {
  PyObject_HEAD
  PyObject *bracket_states;
  PyObject *scanner_state;
};



/* "Cython/Plex/Actions.pxd":1
 * cdef class Action:             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action {
  PyObject *(*perform)(struct __pyx_obj_6Cython_4Plex_7Actions_Action *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action *__pyx_vtabptr_6Cython_4Plex_7Actions_Action;


/* "Cython/Plex/Actions.pxd":4
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Return(Action):             # <<<<<<<<<<<<<<
 *     cdef object value
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return *__pyx_vtabptr_6Cython_4Plex_7Actions_Return;


/* "Cython/Plex/Actions.pxd":8
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Call(Action):             # <<<<<<<<<<<<<<
 *     cdef object function
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call *__pyx_vtabptr_6Cython_4Plex_7Actions_Call;


/* "Cython/Plex/Actions.pxd":12
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Method(Action):             # <<<<<<<<<<<<<<
 *     cdef str name
 *     cdef dict kwargs
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method *__pyx_vtabptr_6Cython_4Plex_7Actions_Method;


/* "Cython/Plex/Actions.pxd":16
 *     cdef dict kwargs
 * 
 * cdef class Begin(Action):             # <<<<<<<<<<<<<<
 *     cdef object state_name
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin *__pyx_vtabptr_6Cython_4Plex_7Actions_Begin;


/* "Cython/Plex/Actions.pxd":20
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Ignore(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
 * 
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore *__pyx_vtabptr_6Cython_4Plex_7Actions_Ignore;


/* "Cython/Plex/Actions.pxd":23
 *     cdef perform(self, token_stream, text)
 * 
 * cdef class Text(Action):             # <<<<<<<<<<<<<<
 *     cdef perform(self, token_stream, text)
*/

struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text {
  struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text *__pyx_vtabptr_6Cython_4Plex_7Actions_Text;


/* "Plex/Scanners.pxd":7
 * from Cython.Plex.Actions cimport Action
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 * 
 *     cdef public lexicon
*/

struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner {
  PyObject *(*read)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, int __pyx_skip_dispatch);
  PyObject *(*unread)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *, PyObject *, PyObject *);
  PyObject *(*get_current_scan_pos)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*scan_a_token)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*position)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, int __pyx_skip_dispatch);
  PyObject *(*run_machine_inlined)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *);
  PyObject *(*begin)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *);
  PyObject *(*produce)(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *, PyObject *, struct __pyx_opt_args_6Cython_4Plex_8Scanners_7Scanner_produce *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner *__pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner;


/* "Scanning.pxd":20
 *     ##cpdef lookup(self, name)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class PyrexScanner(Scanner):
 *     cdef public context
*/

struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner {
  struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner __pyx_base;
  Py_ssize_t (*current_level)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *);
  int (*error_at_scanpos)(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* SetStringIndexingError.proto (used by GetItemIntUnicode) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil);

/* GetItemIntUnicode.proto */
#define __Pyx_GetItemInt_Unicode(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Unicode_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, has_gil) :\
    (__Pyx_SetStringIndexingError("string index out of range", has_gil), (Py_UCS4)-1))
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck, int has_gil);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* StringJoin.proto */
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);

/* unicode_iter.proto */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* UnicodeAsUCS4.proto (used by object_ord) */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
static long __Pyx__PyObject_Ord(PyObject* c);

/* pyint_simplify.proto */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none);

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* PyLongCompare.proto */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto (used by MergeKeywords) */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* DelItemInt.proto */
#define __Pyx_DelItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_DelItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_DelItem_Generic(o, to_py_func(i))))
static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j);
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, int wraparound);

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PySequenceMultiply.proto */
#define __Pyx_PySequence_Multiply_Left(mul, seq)  __Pyx_PySequence_Multiply(seq, mul)
#if !CYTHON_USE_TYPE_SLOTS
#define  __Pyx_PySequence_Multiply PySequence_Repeat
#else
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul);
#endif

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* CalculateMetaclass.proto (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* PyUCS4InUnicode.proto */
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* ObjectAsUCS4.proto */
static Py_UCS4 __Pyx__PyObject_AsPy_UCS4(PyObject*);
static CYTHON_INLINE Py_UCS4 __Pyx_PyObject_AsPy_UCS4(PyObject *x) {
    return (likely(PyUnicode_Check(x)) ? __Pyx_PyUnicode_AsPy_UCS4(x) : __Pyx__PyObject_AsPy_UCS4(x));
}

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."


/* Module declarations from "cython" */

/* Module declarations from "Cython.Plex.Actions" */

/* Module declarations from "Cython.Plex.Scanners" */

/* Module declarations from "Cython.Compiler.Scanning" */
static PyObject **__pyx_vp_6Cython_8Compiler_8Scanning_any_string_prefix = 0;
#define __pyx_v_6Cython_8Compiler_8Scanning_any_string_prefix (*__pyx_vp_6Cython_8Compiler_8Scanning_any_string_prefix)
static PyObject **__pyx_vp_6Cython_8Compiler_8Scanning_IDENT = 0;
#define __pyx_v_6Cython_8Compiler_8Scanning_IDENT (*__pyx_vp_6Cython_8Compiler_8Scanning_IDENT)

/* Module declarations from "Cython.Compiler.Parsing" */
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_Nodes = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_EncodedString = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_bytes_literal = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_StringEncoding = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_Future = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_Options = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_error = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_warning = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_Builtin = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_ModuleNode = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_Utils = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_re = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_partial = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_reduce = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing__CDEF_MODIFIERS = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_comparison_ops = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_expr_terminators = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_inequality_relations = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing_c_arg_list_terminators = 0;
static PyObject *__pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment = 0;
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, __pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, __pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ident(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_ident *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ident_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_binop_operator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_lambdef(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_allow_walrus_after(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_or_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_and_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_not_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comparison(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cascaded_cmp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cmp_op(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_xor_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_and_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_shift_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_arith_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_term(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_factor(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__p_factor(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_typecast(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_yield_expression *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_yield_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_async_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_power(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_new_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_trailer(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call_parse_args(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call_build_packed_args(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_index(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_subscript_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_subscript(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_slice_element(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_expect_ellipsis(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_make_slice_nodes(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_make_slice_node(PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom_string(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom_ident_constants(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_int_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_wrap_compile_time_constant(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cat_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_opt_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_opt_string_literal *__pyx_optional_args); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_check_for_non_ascii_characters(PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_string_literal_shared_read(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *, PyObject *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__validate_kind_string(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_read_ft_string_expression(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_replacement_field(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int, int, Py_UCS4); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_middles(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int, int, int, Py_UCS4); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__append_escape_sequence(PyObject *, PyObject *, PyObject *, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_list_maker(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_iter(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_if(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_dict_or_set_maker(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_backquote_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_expr_list *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist_star_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist_comp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_genexp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_global_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_nonlocal_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_expression_or_assignment(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_print_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_exec_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_del_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_pass_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_break_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_continue_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_return_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_raise_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_import_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_from_import_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_from_import_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_imported_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_dotted_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_as_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_assert_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_if_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_if_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_else_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_while_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_bounds(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_from_relation(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_from_step(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_iterator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_iterator *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_try_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_except_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_include_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_items(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_with_items *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_items_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_item(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_template(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement_list *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_compile_time_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_DEF_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_IF_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_suite(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_calling_convention(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_complex_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_complex_base_type *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_simple_base_type *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_buffer_or_template(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_is_memoryviewslice_access(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_memoryviewslice_access(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_dotted_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sign_and_longness(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_array_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_func_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *, PyObject *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, int, int, int, int, int); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_p_with_gil(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_exception_value_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_list *__pyx_optional_args); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_p_optional_ellipsis(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, int, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_decl *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_annotation(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static int __pyx_f_6Cython_8Compiler_7Parsing_p_api(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_extern_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_line(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_item(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_struct_or_union_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_fused_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_struct_enum(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_visibility(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_modifiers(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ctypedef_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_decorators(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__reject_cdef_modifier_in_py(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_def_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_varargslist(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_py_arg_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_py_arg_decl *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_class_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_class_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_class_options(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_property_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ignorable_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__extract_docstring(PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_code(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_code *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_compiler_directive_comments(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_module(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_module *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_template_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_attribute(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_match_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_case_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_patterns(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_maybe_star_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_closed_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_literal_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_capture_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_value_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_group_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sequence_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_mapping_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_class_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_keyword_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(PyObject *, PyObject *, long, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree *__pyx_optional_args); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "Cython.Compiler.Parsing"
extern int __pyx_module_is_main_Cython__Compiler__Parsing;
int __pyx_module_is_main_Cython__Compiler__Parsing = 0;

/* Implementation of "Cython.Compiler.Parsing" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_reversed;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_3Ctx___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_3Ctx_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_make_slice_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_start, PyObject *__pyx_v_stop, PyObject *__pyx_v_step); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_2p_c_base_type(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_nonempty, PyObject *__pyx_v_templates); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_4p_c_declarator(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_empty, int __pyx_v_is_type, int __pyx_v_cmethod_flag, int __pyx_v_assignable, int __pyx_v_nonempty, int __pyx_v_calling_convention_allowed); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_6p_c_arg_list(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_in_pyfunc, int __pyx_v_cmethod_flag, int __pyx_v_nonempty_declarators, int __pyx_v_kw_only, int __pyx_v_annotated); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_8p_code(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_level, PyObject *__pyx_v_ctx); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_10p_module(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pxd, PyObject *__pyx_v_full_module_name, PyObject *__pyx_v_ctx); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_12print_parse_tree(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f, PyObject *__pyx_v_node, long __pyx_v_level, PyObject *__pyx_v_key); /* proto */
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Action;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Return;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Call;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Method;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Begin;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Ignore;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_7Actions_Text;
  PyTypeObject *__pyx_ptype_6Cython_4Plex_8Scanners_Scanner;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type__update;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__rsplit;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__rstrip;
  PyObject *__pyx_k__25;
  PyObject *__pyx_k__44;
  PyObject *__pyx_k__45;
  PyObject *__pyx_k__52;
  PyObject *__pyx_k__54;
  PyObject *__pyx_k__56;
  PyObject *__pyx_slice[3];
  PyObject *__pyx_tuple[31];
  PyObject *__pyx_codeobj_tab[9];
  PyObject *__pyx_string_tab[828];
  PyObject *__pyx_number_tab[9];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_3 __pyx_string_tab[1]
#define __pyx_kp_u_An_axis_specification_in_memoryv __pyx_string_tab[2]
#define __pyx_kp_u_Argument_expansion_not_allowed_h __pyx_string_tab[3]
#define __pyx_kp_u_C_classes_cannot_take_keyword_ba __pyx_string_tab[4]
#define __pyx_kp_u_C_function_definition_not_allowe __pyx_string_tab[5]
#define __pyx_kp_u_C_struct_union_cannot_be_declare __pyx_string_tab[6]
#define __pyx_kp_u_C_struct_union_enum_definition_n __pyx_string_tab[7]
#define __pyx_kp_u_Cannot_combine_api_with_s __pyx_string_tab[8]
#define __pyx_kp_u_Cannot_concatenate_char_literal __pyx_string_tab[9]
#define __pyx_kp_u_Cannot_mix_string_literals_of_di __pyx_string_tab[10]
#define __pyx_kp_u_Cannot_use_cdef_modifier_s_in_Py __pyx_string_tab[11]
#define __pyx_kp_u_Conflicting_settings_found_for_t __pyx_string_tab[12]
#define __pyx_kp_u_Conflicting_visibility_options __pyx_string_tab[13]
#define __pyx_kp_u_Cython __pyx_string_tab[14]
#define __pyx_kp_u_Cython_Compiler __pyx_string_tab[15]
#define __pyx_kp_u_Cython_Compiler_Errors __pyx_string_tab[16]
#define __pyx_kp_u_Cython_Compiler_ModuleNode __pyx_string_tab[17]
#define __pyx_kp_u_Cython_Compiler_Parsing_py __pyx_string_tab[18]
#define __pyx_kp_u_Cython_Compiler_Scanning __pyx_string_tab[19]
#define __pyx_kp_u_Cython_Compiler_StringEncoding __pyx_string_tab[20]
#define __pyx_kp_u_Declarator_should_be_empty __pyx_string_tab[21]
#define __pyx_kp_u_Decorators_can_only_be_followed __pyx_string_tab[22]
#define __pyx_kp_u_Duplicate_const __pyx_string_tab[23]
#define __pyx_kp_u_Duplicate_directive_found __pyx_string_tab[24]
#define __pyx_kp_u_Duplicate_string_prefix_characte __pyx_string_tab[25]
#define __pyx_kp_u_Duplicate_volatile __pyx_string_tab[26]
#define __pyx_kp_u_Empty_declarator __pyx_string_tab[27]
#define __pyx_kp_u_Empty_enum_definition_not_allowe __pyx_string_tab[28]
#define __pyx_kp_u_Empty_struct_or_union_definition __pyx_string_tab[29]
#define __pyx_kp_u_Executable_statement_not_allowed __pyx_string_tab[30]
#define __pyx_kp_u_Expected_None __pyx_string_tab[31]
#define __pyx_kp_u_Expected_a_newline __pyx_string_tab[32]
#define __pyx_kp_u_Expected_a_newline_after_decorat __pyx_string_tab[33]
#define __pyx_kp_u_Expected_a_number __pyx_string_tab[34]
#define __pyx_kp_u_Expected_an_identifier __pyx_string_tab[35]
#define __pyx_kp_u_Expected_an_identifier_before __pyx_string_tab[36]
#define __pyx_kp_u_Expected_an_identifier_found_s __pyx_string_tab[37]
#define __pyx_kp_u_Expected_an_identifier_or_litera __pyx_string_tab[38]
#define __pyx_kp_u_Expected_except_or_finally __pyx_string_tab[39]
#define __pyx_kp_u_Expected_found_s_Did_you_use_cde __pyx_string_tab[40]
#define __pyx_kp_u_Expected_identifier __pyx_string_tab[41]
#define __pyx_kp_u_Expected_imaginary_number __pyx_string_tab[42]
#define __pyx_kp_u_Expected_import_or_cimport __pyx_string_tab[43]
#define __pyx_kp_u_Expected_object_type_or_check_si __pyx_string_tab[44]
#define __pyx_kp_u_Expected_one_of __pyx_string_tab[45]
#define __pyx_kp_u_Expected_one_of_ignore_warn_or_e __pyx_string_tab[46]
#define __pyx_kp_u_Expected_or __pyx_string_tab[47]
#define __pyx_kp_u_Extension_type_definition_not_al __pyx_string_tab[48]
#define __pyx_kp_u_Extension_types_cannot_be_declar __pyx_string_tab[49]
#define __pyx_kp_u_Failed_to_match_literal __pyx_string_tab[50]
#define __pyx_kp_u_Found_the_C_operator __pyx_string_tab[51]
#define __pyx_kp_u_Fused_type_definition_not_allowe __pyx_string_tab[52]
#define __pyx_kp_u_Got_zero_positional_only_argumen __pyx_string_tab[53]
#define __pyx_kp_u_Illegal_next_symbol_s __pyx_string_tab[54]
#define __pyx_kp_u_Illegal_operand_for_inplace_oper __pyx_string_tab[55]
#define __pyx_kp_u_Invalid_class_visibility_s __pyx_string_tab[56]
#define __pyx_kp_u_Invalid_hex_escape_s __pyx_string_tab[57]
#define __pyx_kp_u_Invalid_pattern_target __pyx_string_tab[58]
#define __pyx_kp_u_Invalid_string_prefix __pyx_string_tab[59]
#define __pyx_kp_u_Invalid_string_prefix_for_charac __pyx_string_tab[60]
#define __pyx_kp_u_Invalid_type_for_compile_time_co __pyx_string_tab[61]
#define __pyx_kp_u_Invalid_unicode_escape_s __pyx_string_tab[62]
#define __pyx_kp_u_Left_hand_side_of_assignment_exp __pyx_string_tab[63]
#define __pyx_kp_u_Module_name_required_for_extern __pyx_string_tab[64]
#define __pyx_kp_u_Name_options_not_allowed_for_C_c __pyx_string_tab[65]
#define __pyx_kp_u_Name_options_only_allowed_for_pu __pyx_string_tab[66]
#define __pyx_kp_u_Need_at_least_one_type __pyx_string_tab[67]
#define __pyx_kp_u_Non_keyword_arg_following_keywor __pyx_string_tab[68]
#define __pyx_kp_u_None __pyx_string_tab[69]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[70]
#define __pyx_kp_u_Object_struct_name_specification __pyx_string_tab[71]
#define __pyx_kp_u_Object_struct_name_specification_2 __pyx_string_tab[72]
#define __pyx_kp_u_Overloading_operator_s_not_yet_s __pyx_string_tab[73]
#define __pyx_kp_u_Pattern_capture_target_cannot_be __pyx_string_tab[74]
#define __pyx_kp_u_Positional_patterns_follow_keywo __pyx_string_tab[75]
#define __pyx_kp_u_Python_3_requires_docstrings_to __pyx_string_tab[76]
#define __pyx_kp_u_Qualified_class_name_not_allowed __pyx_string_tab[77]
#define __pyx_kp_u_Qualified_class_name_only_allowe __pyx_string_tab[78]
#define __pyx_kp_u_Relation_directions_in_for_from __pyx_string_tab[79]
#define __pyx_kp_u_Return_type_annotation_is_not_al __pyx_string_tab[80]
#define __pyx_kp_u_String_prefixes __pyx_string_tab[81]
#define __pyx_kp_u_Syntax_error_in_C_class_definiti __pyx_string_tab[82]
#define __pyx_kp_u_Syntax_error_in_C_class_definiti_2 __pyx_string_tab[83]
#define __pyx_kp_u_Syntax_error_in_C_variable_decla __pyx_string_tab[84]
#define __pyx_kp_u_Syntax_error_in_Python_function __pyx_string_tab[85]
#define __pyx_kp_u_Syntax_error_in_ctypedef_stateme __pyx_string_tab[86]
#define __pyx_kp_u_Syntax_error_in_declarations __pyx_string_tab[87]
#define __pyx_kp_u_Syntax_error_in_doc_string __pyx_string_tab[88]
#define __pyx_kp_u_Syntax_error_in_enum_item_list __pyx_string_tab[89]
#define __pyx_kp_u_Syntax_error_in_include_statemen __pyx_string_tab[90]
#define __pyx_kp_u_Syntax_error_in_simple_statement __pyx_string_tab[91]
#define __pyx_kp_u_Syntax_error_in_statement __pyx_string_tab[92]
#define __pyx_kp_u_Syntax_error_in_string __pyx_string_tab[93]
#define __pyx_kp_u_Syntax_error_in_struct_or_union __pyx_string_tab[94]
#define __pyx_kp_u_Syntax_error_in_template_functio __pyx_string_tab[95]
#define __pyx_kp_u_Target_of_for_from_statement_mus __pyx_string_tab[96]
#define __pyx_kp_u_The_DEF_statement_will_be_remove __pyx_string_tab[97]
#define __pyx_kp_u_The_IF_statement_is_deprecated_a __pyx_string_tab[98]
#define __pyx_kp_u_The_cdef_keyword_is_only_allowed __pyx_string_tab[99]
#define __pyx_kp_u_The_keyword_nogil_should_appear __pyx_string_tab[100]
#define __pyx_kp_u_Type_object_name_specification_n __pyx_string_tab[101]
#define __pyx_kp_u_Type_object_name_specification_r __pyx_string_tab[102]
#define __pyx_kp_u_Type_object_name_specification_r_2 __pyx_string_tab[103]
#define __pyx_kp_u_Unclosed_string_literal __pyx_string_tab[104]
#define __pyx_kp_u_Unexpected_characters_after __pyx_string_tab[105]
#define __pyx_kp_u_Unexpected_symbol_s __pyx_string_tab[106]
#define __pyx_kp_u_Unexpected_token __pyx_string_tab[107]
#define __pyx_kp_u_Unknown_Unicode_character_name_s __pyx_string_tab[108]
#define __pyx_kp_u_Unknown_type __pyx_string_tab[109]
#define __pyx_kp_u_Unmatched_s __pyx_string_tab[110]
#define __pyx_kp_u_Unnamed_scoped_enum_not_allowed __pyx_string_tab[111]
#define __pyx_kp_u_Variable_name_in_for_from_range __pyx_string_tab[112]
#define __pyx_kp_u__10 __pyx_string_tab[113]
#define __pyx_kp_u__11 __pyx_string_tab[114]
#define __pyx_kp_u__12 __pyx_string_tab[115]
#define __pyx_kp_u__13 __pyx_string_tab[116]
#define __pyx_kp_u__14 __pyx_string_tab[117]
#define __pyx_kp_u__15 __pyx_string_tab[118]
#define __pyx_kp_u__16 __pyx_string_tab[119]
#define __pyx_kp_u__17 __pyx_string_tab[120]
#define __pyx_kp_u__18 __pyx_string_tab[121]
#define __pyx_kp_u__19 __pyx_string_tab[122]
#define __pyx_kp_u__2 __pyx_string_tab[123]
#define __pyx_kp_u__20 __pyx_string_tab[124]
#define __pyx_kp_u__21 __pyx_string_tab[125]
#define __pyx_kp_u__22 __pyx_string_tab[126]
#define __pyx_kp_u__23 __pyx_string_tab[127]
#define __pyx_kp_u__24 __pyx_string_tab[128]
#define __pyx_kp_u__26 __pyx_string_tab[129]
#define __pyx_kp_u__27 __pyx_string_tab[130]
#define __pyx_kp_u__28 __pyx_string_tab[131]
#define __pyx_kp_u__29 __pyx_string_tab[132]
#define __pyx_kp_u__3 __pyx_string_tab[133]
#define __pyx_kp_u__30 __pyx_string_tab[134]
#define __pyx_kp_u__31 __pyx_string_tab[135]
#define __pyx_kp_u__32 __pyx_string_tab[136]
#define __pyx_kp_u__33 __pyx_string_tab[137]
#define __pyx_kp_u__34 __pyx_string_tab[138]
#define __pyx_kp_u__35 __pyx_string_tab[139]
#define __pyx_kp_u__36 __pyx_string_tab[140]
#define __pyx_kp_u__37 __pyx_string_tab[141]
#define __pyx_kp_u__38 __pyx_string_tab[142]
#define __pyx_kp_u__39 __pyx_string_tab[143]
#define __pyx_kp_u__4 __pyx_string_tab[144]
#define __pyx_kp_u__40 __pyx_string_tab[145]
#define __pyx_kp_u__41 __pyx_string_tab[146]
#define __pyx_kp_u__42 __pyx_string_tab[147]
#define __pyx_kp_u__43 __pyx_string_tab[148]
#define __pyx_kp_u__46 __pyx_string_tab[149]
#define __pyx_kp_u__47 __pyx_string_tab[150]
#define __pyx_kp_u__48 __pyx_string_tab[151]
#define __pyx_kp_u__49 __pyx_string_tab[152]
#define __pyx_kp_u__5 __pyx_string_tab[153]
#define __pyx_kp_u__50 __pyx_string_tab[154]
#define __pyx_kp_u__51 __pyx_string_tab[155]
#define __pyx_kp_u__53 __pyx_string_tab[156]
#define __pyx_kp_u__55 __pyx_string_tab[157]
#define __pyx_kp_u__58 __pyx_string_tab[158]
#define __pyx_kp_u__59 __pyx_string_tab[159]
#define __pyx_kp_u__6 __pyx_string_tab[160]
#define __pyx_kp_u__60 __pyx_string_tab[161]
#define __pyx_kp_u__61 __pyx_string_tab[162]
#define __pyx_kp_u__62 __pyx_string_tab[163]
#define __pyx_kp_u__63 __pyx_string_tab[164]
#define __pyx_kp_u__64 __pyx_string_tab[165]
#define __pyx_kp_u__65 __pyx_string_tab[166]
#define __pyx_kp_u__66 __pyx_string_tab[167]
#define __pyx_kp_u__67 __pyx_string_tab[168]
#define __pyx_kp_u__68 __pyx_string_tab[169]
#define __pyx_kp_u__7 __pyx_string_tab[170]
#define __pyx_kp_u__8 __pyx_string_tab[171]
#define __pyx_kp_u__9 __pyx_string_tab[172]
#define __pyx_kp_u_a_starred_assignment_target_must __pyx_string_tab[173]
#define __pyx_kp_u_add_note __pyx_string_tab[174]
#define __pyx_kp_u_and_2 __pyx_string_tab[175]
#define __pyx_kp_u_and_3 __pyx_string_tab[176]
#define __pyx_kp_u_api_not_allowed_with_this_state __pyx_string_tab[177]
#define __pyx_kp_u_bytes_can_only_contain_ASCII_lit __pyx_string_tab[178]
#define __pyx_kp_u_cannot_be_combined __pyx_string_tab[179]
#define __pyx_kp_u_cannot_mix_t_string_literals_wit __pyx_string_tab[180]
#define __pyx_kp_u_cdef_blocks_cannot_be_declared_c __pyx_string_tab[181]
#define __pyx_kp_u_cdef_extern_blocks_cannot_be_dec __pyx_string_tab[182]
#define __pyx_kp_u_cdef_statement_not_allowed_here __pyx_string_tab[183]
#define __pyx_kp_u_class_definition_not_allowed_her __pyx_string_tab[184]
#define __pyx_kp_u_ctypedef_statement_not_allowed_h __pyx_string_tab[185]
#define __pyx_kp_u_cython_bint __pyx_string_tab[186]
#define __pyx_kp_u_cython_long __pyx_string_tab[187]
#define __pyx_kp_u_decorator_not_allowed_here __pyx_string_tab[188]
#define __pyx_kp_u_def_statement_not_allowed_here __pyx_string_tab[189]
#define __pyx_kp_u_default_values_cannot_be_specifi __pyx_string_tab[190]
#define __pyx_kp_u_did_you_mean_the_Python_operato __pyx_string_tab[191]
#define __pyx_kp_u_empty_expression_not_allowed_in __pyx_string_tab[192]
#define __pyx_kp_u_except_nogil_defines_an_excepti __pyx_string_tab[193]
#define __pyx_kp_u_expected_expression_found __pyx_string_tab[194]
#define __pyx_kp_u_expected_one_of_def_for_with_aft __pyx_string_tab[195]
#define __pyx_kp_u_expected_tuple_of_length_2_or_3 __pyx_string_tab[196]
#define __pyx_kp_u_f_string_conversion_type_must_co __pyx_string_tab[197]
#define __pyx_kp_u_f_string_not_allowed_here __pyx_string_tab[198]
#define __pyx_kp_u_from___future___imports_must_occ __pyx_string_tab[199]
#define __pyx_kp_u_future_feature_s_is_not_defined __pyx_string_tab[200]
#define __pyx_kp_u_got __pyx_string_tab[201]
#define __pyx_kp_u_illegal_integer_literal_syntax_i __pyx_string_tab[202]
#define __pyx_kp_u_in_2 __pyx_string_tab[203]
#define __pyx_kp_u_in_string_literal __pyx_string_tab[204]
#define __pyx_kp_u_include_statement_not_allowed_he __pyx_string_tab[205]
#define __pyx_kp_u_internal_parser_configuration_er __pyx_string_tab[206]
#define __pyx_kp_u_invalid_character_literal_r __pyx_string_tab[207]
#define __pyx_kp_u_invalid_conversion_character_s __pyx_string_tab[208]
#define __pyx_kp_u_invalid_string_kind __pyx_string_tab[209]
#define __pyx_kp_u_invalid_syntax __pyx_string_tab[210]
#define __pyx_kp_u_invalid_syntax_assignment_expres __pyx_string_tab[211]
#define __pyx_kp_u_item_found_in __pyx_string_tab[212]
#define __pyx_kp_u_iterable_unpacking_cannot_be_use __pyx_string_tab[213]
#define __pyx_kp_u_literal __pyx_string_tab[214]
#define __pyx_kp_u_missing_conversion_character __pyx_string_tab[215]
#define __pyx_kp_u_not_a_chance __pyx_string_tab[216]
#define __pyx_kp_u_or_2 __pyx_string_tab[217]
#define __pyx_kp_u_pattern_must_be_the_final_part __pyx_string_tab[218]
#define __pyx_kp_u_s_None_only_allowed_in_Python_f __pyx_string_tab[219]
#define __pyx_kp_u_s_cython_s_s_w_s __pyx_string_tab[220]
#define __pyx_kp_u_s_on_something_that_is_not_a_fu __pyx_string_tab[221]
#define __pyx_kp_u_string __pyx_string_tab[222]
#define __pyx_kp_u_string_expression __pyx_string_tab[223]
#define __pyx_kp_u_string_literal __pyx_string_tab[224]
#define __pyx_kp_u_tuple_like_pattern_of_length_1_m __pyx_string_tab[225]
#define __pyx_kp_u_tuple_variant_of_exec_does_not_s __pyx_string_tab[226]
#define __pyx_kp_u_type __pyx_string_tab[227]
#define __pyx_kp_u_unexpected __pyx_string_tab[228]
#define __pyx_kp_u_warn_deprecated_DEF __pyx_string_tab[229]
#define __pyx_kp_u_warn_deprecated_IF __pyx_string_tab[230]
#define __pyx_kp_u_with_gil_nogil_cannot_be_async __pyx_string_tab[231]
#define __pyx_kp_u_yield_from_requires_a_source_ar __pyx_string_tab[232]
#define __pyx_n_u_AmpersandNode __pyx_string_tab[233]
#define __pyx_n_u_AnnotationNode __pyx_string_tab[234]
#define __pyx_n_u_AsTupleNode __pyx_string_tab[235]
#define __pyx_n_u_AssertStatNode __pyx_string_tab[236]
#define __pyx_n_u_AssignmentExpressionNode __pyx_string_tab[237]
#define __pyx_n_u_AsyncIteratorNode __pyx_string_tab[238]
#define __pyx_n_u_AttributeNode __pyx_string_tab[239]
#define __pyx_n_u_AwaitExprNode __pyx_string_tab[240]
#define __pyx_n_u_BEGIN_FT_STRING __pyx_string_tab[241]
#define __pyx_n_u_BEGIN_STRING __pyx_string_tab[242]
#define __pyx_n_u_BackquoteNode __pyx_string_tab[243]
#define __pyx_n_u_BoolNode __pyx_string_tab[244]
#define __pyx_n_u_BreakStatNode __pyx_string_tab[245]
#define __pyx_n_u_Builtin __pyx_string_tab[246]
#define __pyx_n_u_BytesLiteralBuilder __pyx_string_tab[247]
#define __pyx_n_u_BytesNode __pyx_string_tab[248]
#define __pyx_n_u_CArgDeclNode __pyx_string_tab[249]
#define __pyx_n_u_CArrayDeclaratorNode __pyx_string_tab[250]
#define __pyx_n_u_CClassDefNode __pyx_string_tab[251]
#define __pyx_n_u_CComplexBaseTypeNode __pyx_string_tab[252]
#define __pyx_n_u_CConstDeclaratorNode __pyx_string_tab[253]
#define __pyx_n_u_CConstOrVolatileTypeNode __pyx_string_tab[254]
#define __pyx_n_u_CDefExternNode __pyx_string_tab[255]
#define __pyx_n_u_CEnumDefItemNode __pyx_string_tab[256]
#define __pyx_n_u_CEnumDefNode __pyx_string_tab[257]
#define __pyx_n_u_CFuncDeclaratorNode __pyx_string_tab[258]
#define __pyx_n_u_CFuncDefNode __pyx_string_tab[259]
#define __pyx_n_u_CHARS __pyx_string_tab[260]
#define __pyx_n_u_CImportStatNode __pyx_string_tab[261]
#define __pyx_n_u_CNameDeclaratorNode __pyx_string_tab[262]
#define __pyx_n_u_CNestedBaseTypeNode __pyx_string_tab[263]
#define __pyx_n_u_CPtrDeclaratorNode __pyx_string_tab[264]
#define __pyx_n_u_CReferenceDeclaratorNode __pyx_string_tab[265]
#define __pyx_n_u_CSimpleBaseTypeNode __pyx_string_tab[266]
#define __pyx_n_u_CStructOrUnionDefNode __pyx_string_tab[267]
#define __pyx_n_u_CTupleBaseTypeNode __pyx_string_tab[268]
#define __pyx_n_u_CTypeDefNode __pyx_string_tab[269]
#define __pyx_n_u_CVarDefNode __pyx_string_tab[270]
#define __pyx_n_u_CascadedAssignmentNode __pyx_string_tab[271]
#define __pyx_n_u_CascadedCmpNode __pyx_string_tab[272]
#define __pyx_n_u_CharNode __pyx_string_tab[273]
#define __pyx_n_u_ClassPatternNode __pyx_string_tab[274]
#define __pyx_n_u_CompileError __pyx_string_tab[275]
#define __pyx_n_u_ComprehensionAppendNode __pyx_string_tab[276]
#define __pyx_n_u_ComprehensionNode __pyx_string_tab[277]
#define __pyx_n_u_CondExprNode __pyx_string_tab[278]
#define __pyx_n_u_ContinueStatNode __pyx_string_tab[279]
#define __pyx_n_u_CppClassNode __pyx_string_tab[280]
#define __pyx_n_u_CppRvalueReferenceDeclaratorNode __pyx_string_tab[281]
#define __pyx_n_u_Ctx __pyx_string_tab[282]
#define __pyx_n_u_Ctx___call __pyx_string_tab[283]
#define __pyx_n_u_Ctx___init __pyx_string_tab[284]
#define __pyx_n_u_CythonArrayNode __pyx_string_tab[285]
#define __pyx_n_u_Cython_Compiler_Parsing __pyx_string_tab[286]
#define __pyx_n_u_DEDENT __pyx_string_tab[287]
#define __pyx_n_u_DEF __pyx_string_tab[288]
#define __pyx_n_u_DecoratorNode __pyx_string_tab[289]
#define __pyx_n_u_DefNode __pyx_string_tab[290]
#define __pyx_n_u_DelStatNode __pyx_string_tab[291]
#define __pyx_n_u_DictComprehensionAppendNode __pyx_string_tab[292]
#define __pyx_n_u_DictItemNode __pyx_string_tab[293]
#define __pyx_n_u_DictNode __pyx_string_tab[294]
#define __pyx_n_u_ELIF __pyx_string_tab[295]
#define __pyx_n_u_ELSE __pyx_string_tab[296]
#define __pyx_n_u_END_FT_STRING __pyx_string_tab[297]
#define __pyx_n_u_END_FT_STRING_EXPR __pyx_string_tab[298]
#define __pyx_n_u_END_STRING __pyx_string_tab[299]
#define __pyx_n_u_EOF __pyx_string_tab[300]
#define __pyx_n_u_ESCAPE __pyx_string_tab[301]
#define __pyx_n_u_Ellipsis __pyx_string_tab[302]
#define __pyx_n_u_EllipsisNode __pyx_string_tab[303]
#define __pyx_n_u_EncodedString __pyx_string_tab[304]
#define __pyx_n_u_ErrorNode __pyx_string_tab[305]
#define __pyx_n_u_Errors __pyx_string_tab[306]
#define __pyx_n_u_ExceptClauseNode __pyx_string_tab[307]
#define __pyx_n_u_ExecStatNode __pyx_string_tab[308]
#define __pyx_n_u_ExprNodes __pyx_string_tab[309]
#define __pyx_n_u_ExprStatNode __pyx_string_tab[310]
#define __pyx_n_u_FLOAT __pyx_string_tab[311]
#define __pyx_n_u_False __pyx_string_tab[312]
#define __pyx_n_u_FileSourceDescriptor __pyx_string_tab[313]
#define __pyx_n_u_FloatNode __pyx_string_tab[314]
#define __pyx_n_u_ForStatNode __pyx_string_tab[315]
#define __pyx_n_u_FormattedValueNode __pyx_string_tab[316]
#define __pyx_n_u_FromCImportStatNode __pyx_string_tab[317]
#define __pyx_n_u_FromImportStatNode __pyx_string_tab[318]
#define __pyx_n_u_FusedTypeNode __pyx_string_tab[319]
#define __pyx_n_u_Future __pyx_string_tab[320]
#define __pyx_n_u_GILStatNode __pyx_string_tab[321]
#define __pyx_n_u_GeneralCallNode __pyx_string_tab[322]
#define __pyx_n_u_GeneratorExpressionNode __pyx_string_tab[323]
#define __pyx_n_u_GlobalNode __pyx_string_tab[324]
#define __pyx_n_u_IDENT __pyx_string_tab[325]
#define __pyx_n_u_IF __pyx_string_tab[326]
#define __pyx_n_u_IMAG __pyx_string_tab[327]
#define __pyx_n_u_INDENT __pyx_string_tab[328]
#define __pyx_n_u_INT __pyx_string_tab[329]
#define __pyx_n_u_IdentifierStringNode __pyx_string_tab[330]
#define __pyx_n_u_IfClauseNode __pyx_string_tab[331]
#define __pyx_n_u_IfStatNode __pyx_string_tab[332]
#define __pyx_n_u_ImagNode __pyx_string_tab[333]
#define __pyx_n_u_ImportNode __pyx_string_tab[334]
#define __pyx_n_u_InPlaceAssignmentNode __pyx_string_tab[335]
#define __pyx_n_u_IndexNode __pyx_string_tab[336]
#define __pyx_n_u_IntNode __pyx_string_tab[337]
#define __pyx_n_u_IteratorNode __pyx_string_tab[338]
#define __pyx_n_u_JoinedStrNode __pyx_string_tab[339]
#define __pyx_n_u_L __pyx_string_tab[340]
#define __pyx_n_u_LL __pyx_string_tab[341]
#define __pyx_n_u_LambdaNode __pyx_string_tab[342]
#define __pyx_n_u_ListNode __pyx_string_tab[343]
#define __pyx_n_u_MatchAndAssignPatternNode __pyx_string_tab[344]
#define __pyx_n_u_MatchCaseNode __pyx_string_tab[345]
#define __pyx_n_u_MatchCaseNodes __pyx_string_tab[346]
#define __pyx_n_u_MatchMappingPatternNode __pyx_string_tab[347]
#define __pyx_n_u_MatchNode __pyx_string_tab[348]
#define __pyx_n_u_MatchSequencePatternNode __pyx_string_tab[349]
#define __pyx_n_u_MatchValuePatternNode __pyx_string_tab[350]
#define __pyx_n_u_MemoryViewSliceTypeNode __pyx_string_tab[351]
#define __pyx_n_u_MergedDictNode __pyx_string_tab[352]
#define __pyx_n_u_MergedSequenceNode __pyx_string_tab[353]
#define __pyx_n_u_ModuleNode __pyx_string_tab[354]
#define __pyx_n_u_NEWLINE __pyx_string_tab[355]
#define __pyx_n_u_NULL __pyx_string_tab[356]
#define __pyx_n_u_NameNode __pyx_string_tab[357]
#define __pyx_n_u_NewExprNode __pyx_string_tab[358]
#define __pyx_n_u_Node __pyx_string_tab[359]
#define __pyx_n_u_Nodes __pyx_string_tab[360]
#define __pyx_n_u_None __pyx_string_tab[361]
#define __pyx_n_u_NoneNode __pyx_string_tab[362]
#define __pyx_n_u_None_2 __pyx_string_tab[363]
#define __pyx_n_u_NonlocalNode __pyx_string_tab[364]
#define __pyx_n_u_NotNode __pyx_string_tab[365]
#define __pyx_n_u_NullNode __pyx_string_tab[366]
#define __pyx_n_u_Options __pyx_string_tab[367]
#define __pyx_n_u_OrPatternNode __pyx_string_tab[368]
#define __pyx_n_u_PassStatNode __pyx_string_tab[369]
#define __pyx_n_u_PrimaryCmpNode __pyx_string_tab[370]
#define __pyx_n_u_PrintStatNode __pyx_string_tab[371]
#define __pyx_n_u_PropertyNode __pyx_string_tab[372]
#define __pyx_n_u_PyArgDeclNode __pyx_string_tab[373]
#define __pyx_n_u_PyClassDefNode __pyx_string_tab[374]
#define __pyx_n_u_Py_UCS4 __pyx_string_tab[375]
#define __pyx_n_u_Py_UNICODE __pyx_string_tab[376]
#define __pyx_n_u_Py_hash_t __pyx_string_tab[377]
#define __pyx_n_u_Py_ssize_t __pyx_string_tab[378]
#define __pyx_n_u_Py_tss_t __pyx_string_tab[379]
#define __pyx_n_u_PyrexScanner __pyx_string_tab[380]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[381]
#define __pyx_n_u_RaiseStatNode __pyx_string_tab[382]
#define __pyx_n_u_ReraiseStatNode __pyx_string_tab[383]
#define __pyx_n_u_ReturnStatNode __pyx_string_tab[384]
#define __pyx_n_u_Scanning __pyx_string_tab[385]
#define __pyx_n_u_SetNode __pyx_string_tab[386]
#define __pyx_n_u_SimpleCallNode __pyx_string_tab[387]
#define __pyx_n_u_SingleAssignmentNode __pyx_string_tab[388]
#define __pyx_n_u_SizeofTypeNode __pyx_string_tab[389]
#define __pyx_n_u_SizeofVarNode __pyx_string_tab[390]
#define __pyx_n_u_SliceIndexNode __pyx_string_tab[391]
#define __pyx_n_u_SliceNode __pyx_string_tab[392]
#define __pyx_n_u_StarredUnpackingNode __pyx_string_tab[393]
#define __pyx_n_u_StatListNode __pyx_string_tab[394]
#define __pyx_n_u_StrLiteralBuilder __pyx_string_tab[395]
#define __pyx_n_u_StringEncoding __pyx_string_tab[396]
#define __pyx_n_u_StringIO __pyx_string_tab[397]
#define __pyx_n_u_TStringInterpolationNode __pyx_string_tab[398]
#define __pyx_n_u_TemplateStringNode __pyx_string_tab[399]
#define __pyx_n_u_TemplatedTypeNode __pyx_string_tab[400]
#define __pyx_n_u_True __pyx_string_tab[401]
#define __pyx_n_u_TryExceptStatNode __pyx_string_tab[402]
#define __pyx_n_u_TryFinallyStatNode __pyx_string_tab[403]
#define __pyx_n_u_TupleNode __pyx_string_tab[404]
#define __pyx_n_u_TypecastNode __pyx_string_tab[405]
#define __pyx_n_u_U __pyx_string_tab[406]
#define __pyx_n_u_UnaryMinusNode __pyx_string_tab[407]
#define __pyx_n_u_UnicodeLiteralBuilder __pyx_string_tab[408]
#define __pyx_n_u_UnicodeNode __pyx_string_tab[409]
#define __pyx_n_u_Utils __pyx_string_tab[410]
#define __pyx_n_u_Uu __pyx_string_tab[411]
#define __pyx_n_u_WhileStatNode __pyx_string_tab[412]
#define __pyx_n_u_WithStatNode __pyx_string_tab[413]
#define __pyx_n_u_YieldExprNode __pyx_string_tab[414]
#define __pyx_n_u_YieldFromExprNode __pyx_string_tab[415]
#define __pyx_n_u__35 __pyx_string_tab[416]
#define __pyx_n_u__57 __pyx_string_tab[417]
#define __pyx_n_u_absolute_import __pyx_string_tab[418]
#define __pyx_n_u_add __pyx_string_tab[419]
#define __pyx_n_u_allow_struct_enum_decorator __pyx_string_tab[420]
#define __pyx_n_u_alternatives __pyx_string_tab[421]
#define __pyx_n_u_and __pyx_string_tab[422]
#define __pyx_n_u_annotated __pyx_string_tab[423]
#define __pyx_n_u_annotation __pyx_string_tab[424]
#define __pyx_n_u_api __pyx_string_tab[425]
#define __pyx_n_u_append __pyx_string_tab[426]
#define __pyx_n_u_append_charval __pyx_string_tab[427]
#define __pyx_n_u_append_newline __pyx_string_tab[428]
#define __pyx_n_u_append_uescape __pyx_string_tab[429]
#define __pyx_n_u_arg __pyx_string_tab[430]
#define __pyx_n_u_arg_tuple __pyx_string_tab[431]
#define __pyx_n_u_args __pyx_string_tab[432]
#define __pyx_n_u_as __pyx_string_tab[433]
#define __pyx_n_u_as_name __pyx_string_tab[434]
#define __pyx_n_u_as_targets __pyx_string_tab[435]
#define __pyx_n_u_ascii __pyx_string_tab[436]
#define __pyx_n_u_assert __pyx_string_tab[437]
#define __pyx_n_u_assignable __pyx_string_tab[438]
#define __pyx_n_u_async __pyx_string_tab[439]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[440]
#define __pyx_n_u_attribute __pyx_string_tab[441]
#define __pyx_n_u_attributes __pyx_string_tab[442]
#define __pyx_n_u_await __pyx_string_tab[443]
#define __pyx_n_u_axes __pyx_string_tab[444]
#define __pyx_n_u_b __pyx_string_tab[445]
#define __pyx_n_u_base __pyx_string_tab[446]
#define __pyx_n_u_base_classes __pyx_string_tab[447]
#define __pyx_n_u_base_type __pyx_string_tab[448]
#define __pyx_n_u_base_type_node __pyx_string_tab[449]
#define __pyx_n_u_bases __pyx_string_tab[450]
#define __pyx_n_u_binop_node __pyx_string_tab[451]
#define __pyx_n_u_bint __pyx_string_tab[452]
#define __pyx_n_u_body __pyx_string_tab[453]
#define __pyx_n_u_bool __pyx_string_tab[454]
#define __pyx_n_u_bound1 __pyx_string_tab[455]
#define __pyx_n_u_bound2 __pyx_string_tab[456]
#define __pyx_n_u_braces __pyx_string_tab[457]
#define __pyx_n_u_break __pyx_string_tab[458]
#define __pyx_n_u_by __pyx_string_tab[459]
#define __pyx_n_u_bytes_literal __pyx_string_tab[460]
#define __pyx_n_u_bytes_value __pyx_string_tab[461]
#define __pyx_n_u_c __pyx_string_tab[462]
#define __pyx_n_u_c_class __pyx_string_tab[463]
#define __pyx_n_u_c_class_pxd __pyx_string_tab[464]
#define __pyx_n_u_call __pyx_string_tab[465]
#define __pyx_n_u_calling_convention __pyx_string_tab[466]
#define __pyx_n_u_calling_convention_allowed __pyx_string_tab[467]
#define __pyx_n_u_cascade __pyx_string_tab[468]
#define __pyx_n_u_case __pyx_string_tab[469]
#define __pyx_n_u_cases __pyx_string_tab[470]
#define __pyx_n_u_cause __pyx_string_tab[471]
#define __pyx_n_u_cdecl __pyx_string_tab[472]
#define __pyx_n_u_cdef __pyx_string_tab[473]
#define __pyx_n_u_cdef_flag __pyx_string_tab[474]
#define __pyx_n_u_char __pyx_string_tab[475]
#define __pyx_n_u_char_from_escape_sequence __pyx_string_tab[476]
#define __pyx_n_u_chars __pyx_string_tab[477]
#define __pyx_n_u_check_size __pyx_string_tab[478]
#define __pyx_n_u_cimport __pyx_string_tab[479]
#define __pyx_n_u_class __pyx_string_tab[480]
#define __pyx_n_u_class_2 __pyx_string_tab[481]
#define __pyx_n_u_class_3 __pyx_string_tab[482]
#define __pyx_n_u_class_getitem __pyx_string_tab[483]
#define __pyx_n_u_class_name __pyx_string_tab[484]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[485]
#define __pyx_n_u_cmethod_flag __pyx_string_tab[486]
#define __pyx_n_u_cname __pyx_string_tab[487]
#define __pyx_n_u_commentline __pyx_string_tab[488]
#define __pyx_n_u_compile __pyx_string_tab[489]
#define __pyx_n_u_compile_time_value __pyx_string_tab[490]
#define __pyx_n_u_compiler_directives __pyx_string_tab[491]
#define __pyx_n_u_complex __pyx_string_tab[492]
#define __pyx_n_u_components __pyx_string_tab[493]
#define __pyx_n_u_condition __pyx_string_tab[494]
#define __pyx_n_u_const __pyx_string_tab[495]
#define __pyx_n_u_constant_result __pyx_string_tab[496]
#define __pyx_n_u_continue __pyx_string_tab[497]
#define __pyx_n_u_conversion_char __pyx_string_tab[498]
#define __pyx_n_u_cpdef __pyx_string_tab[499]
#define __pyx_n_u_cpp __pyx_string_tab[500]
#define __pyx_n_u_cpp_class __pyx_string_tab[501]
#define __pyx_n_u_cppclass __pyx_string_tab[502]
#define __pyx_n_u_create_wrapper __pyx_string_tab[503]
#define __pyx_n_u_ctx __pyx_string_tab[504]
#define __pyx_n_u_ctypedef __pyx_string_tab[505]
#define __pyx_n_u_d __pyx_string_tab[506]
#define __pyx_n_u_declarator __pyx_string_tab[507]
#define __pyx_n_u_declarators __pyx_string_tab[508]
#define __pyx_n_u_declare __pyx_string_tab[509]
#define __pyx_n_u_decorator __pyx_string_tab[510]
#define __pyx_n_u_decorators __pyx_string_tab[511]
#define __pyx_n_u_def __pyx_string_tab[512]
#define __pyx_n_u_default __pyx_string_tab[513]
#define __pyx_n_u_del __pyx_string_tab[514]
#define __pyx_n_u_dict __pyx_string_tab[515]
#define __pyx_n_u_dict_2 __pyx_string_tab[516]
#define __pyx_n_u_dict_type __pyx_string_tab[517]
#define __pyx_n_u_dimension __pyx_string_tab[518]
#define __pyx_n_u_directive_comments __pyx_string_tab[519]
#define __pyx_n_u_directive_types __pyx_string_tab[520]
#define __pyx_n_u_discard __pyx_string_tab[521]
#define __pyx_n_u_division __pyx_string_tab[522]
#define __pyx_n_u_doc __pyx_string_tab[523]
#define __pyx_n_u_doc_2 __pyx_string_tab[524]
#define __pyx_n_u_double __pyx_string_tab[525]
#define __pyx_n_u_double_star_capture_target __pyx_string_tab[526]
#define __pyx_n_u_elif __pyx_string_tab[527]
#define __pyx_n_u_else __pyx_string_tab[528]
#define __pyx_n_u_else_clause __pyx_string_tab[529]
#define __pyx_n_u_empty __pyx_string_tab[530]
#define __pyx_n_u_encoding __pyx_string_tab[531]
#define __pyx_n_u_enter __pyx_string_tab[532]
#define __pyx_n_u_enter_async __pyx_string_tab[533]
#define __pyx_n_u_enum __pyx_string_tab[534]
#define __pyx_n_u_error __pyx_string_tab[535]
#define __pyx_n_u_exc_tb __pyx_string_tab[536]
#define __pyx_n_u_exc_type __pyx_string_tab[537]
#define __pyx_n_u_exc_value __pyx_string_tab[538]
#define __pyx_n_u_except __pyx_string_tab[539]
#define __pyx_n_u_except_clauses __pyx_string_tab[540]
#define __pyx_n_u_exception_check __pyx_string_tab[541]
#define __pyx_n_u_exception_value __pyx_string_tab[542]
#define __pyx_n_u_exec __pyx_string_tab[543]
#define __pyx_n_u_exit __pyx_string_tab[544]
#define __pyx_n_u_exit_async __pyx_string_tab[545]
#define __pyx_n_u_expect __pyx_string_tab[546]
#define __pyx_n_u_expect_dedent __pyx_string_tab[547]
#define __pyx_n_u_expect_indent __pyx_string_tab[548]
#define __pyx_n_u_expect_keyword __pyx_string_tab[549]
#define __pyx_n_u_expect_newline __pyx_string_tab[550]
#define __pyx_n_u_expected __pyx_string_tab[551]
#define __pyx_n_u_expr __pyx_string_tab[552]
#define __pyx_n_u_expression_str __pyx_string_tab[553]
#define __pyx_n_u_extend __pyx_string_tab[554]
#define __pyx_n_u_extern __pyx_string_tab[555]
#define __pyx_n_u_f __pyx_string_tab[556]
#define __pyx_n_u_false_val __pyx_string_tab[557]
#define __pyx_n_u_fastcall __pyx_string_tab[558]
#define __pyx_n_u_fatal __pyx_string_tab[559]
#define __pyx_n_u_finally __pyx_string_tab[560]
#define __pyx_n_u_finally_clause __pyx_string_tab[561]
#define __pyx_n_u_find_conversion_func __pyx_string_tab[562]
#define __pyx_n_u_find_include_file __pyx_string_tab[563]
#define __pyx_n_u_first __pyx_string_tab[564]
#define __pyx_n_u_float __pyx_string_tab[565]
#define __pyx_n_u_for __pyx_string_tab[566]
#define __pyx_n_u_force_py3_semantics __pyx_string_tab[567]
#define __pyx_n_u_format_spec __pyx_string_tab[568]
#define __pyx_n_u_from __pyx_string_tab[569]
#define __pyx_n_u_full_module_name __pyx_string_tab[570]
#define __pyx_n_u_func __pyx_string_tab[571]
#define __pyx_n_u_function __pyx_string_tab[572]
#define __pyx_n_u_functools __pyx_string_tab[573]
#define __pyx_n_u_fused __pyx_string_tab[574]
#define __pyx_n_u_future __pyx_string_tab[575]
#define __pyx_n_u_future_directives __pyx_string_tab[576]
#define __pyx_n_u_get __pyx_string_tab[577]
#define __pyx_n_u_get_file_object __pyx_string_tab[578]
#define __pyx_n_u_getchar __pyx_string_tab[579]
#define __pyx_n_u_getstring __pyx_string_tab[580]
#define __pyx_n_u_getstrings __pyx_string_tab[581]
#define __pyx_n_u_gil __pyx_string_tab[582]
#define __pyx_n_u_global __pyx_string_tab[583]
#define __pyx_n_u_group __pyx_string_tab[584]
#define __pyx_n_u_guard __pyx_string_tab[585]
#define __pyx_n_u_has_explicit_exc_clause __pyx_string_tab[586]
#define __pyx_n_u_has_local_scope __pyx_string_tab[587]
#define __pyx_n_u_has_varargs __pyx_string_tab[588]
#define __pyx_n_u_if __pyx_string_tab[589]
#define __pyx_n_u_if_clauses __pyx_string_tab[590]
#define __pyx_n_u_ignore __pyx_string_tab[591]
#define __pyx_n_u_ignore_semicolon __pyx_string_tab[592]
#define __pyx_n_u_ignore_unknown __pyx_string_tab[593]
#define __pyx_n_u_imag __pyx_string_tab[594]
#define __pyx_n_u_import __pyx_string_tab[595]
#define __pyx_n_u_imported_names __pyx_string_tab[596]
#define __pyx_n_u_in __pyx_string_tab[597]
#define __pyx_n_u_in_pxd __pyx_string_tab[598]
#define __pyx_n_u_in_pyfunc __pyx_string_tab[599]
#define __pyx_n_u_include __pyx_string_tab[600]
#define __pyx_n_u_include_file __pyx_string_tab[601]
#define __pyx_n_u_index __pyx_string_tab[602]
#define __pyx_n_u_init __pyx_string_tab[603]
#define __pyx_n_u_initial_pos __pyx_string_tab[604]
#define __pyx_n_u_inline __pyx_string_tab[605]
#define __pyx_n_u_int __pyx_string_tab[606]
#define __pyx_n_u_intern_ustring __pyx_string_tab[607]
#define __pyx_n_u_io __pyx_string_tab[608]
#define __pyx_n_u_is __pyx_string_tab[609]
#define __pyx_n_u_is_absolute __pyx_string_tab[610]
#define __pyx_n_u_is_async __pyx_string_tab[611]
#define __pyx_n_u_is_async_def __pyx_string_tab[612]
#define __pyx_n_u_is_attribute __pyx_string_tab[613]
#define __pyx_n_u_is_basic_c_type __pyx_string_tab[614]
#define __pyx_n_u_is_c_literal __pyx_string_tab[615]
#define __pyx_n_u_is_const __pyx_string_tab[616]
#define __pyx_n_u_is_const_method __pyx_string_tab[617]
#define __pyx_n_u_is_coroutine __pyx_string_tab[618]
#define __pyx_n_u_is_dict_literal __pyx_string_tab[619]
#define __pyx_n_u_is_except_as __pyx_string_tab[620]
#define __pyx_n_u_is_import_as_name __pyx_string_tab[621]
#define __pyx_n_u_is_is_check __pyx_string_tab[622]
#define __pyx_n_u_is_name __pyx_string_tab[623]
#define __pyx_n_u_is_not __pyx_string_tab[624]
#define __pyx_n_u_is_self_arg __pyx_string_tab[625]
#define __pyx_n_u_is_set_literal __pyx_string_tab[626]
#define __pyx_n_u_is_star __pyx_string_tab[627]
#define __pyx_n_u_is_starred __pyx_string_tab[628]
#define __pyx_n_u_is_string_literal __pyx_string_tab[629]
#define __pyx_n_u_is_subscript __pyx_string_tab[630]
#define __pyx_n_u_is_type __pyx_string_tab[631]
#define __pyx_n_u_is_volatile __pyx_string_tab[632]
#define __pyx_n_u_items __pyx_string_tab[633]
#define __pyx_n_u_iterator __pyx_string_tab[634]
#define __pyx_n_u_join __pyx_string_tab[635]
#define __pyx_n_u_key __pyx_string_tab[636]
#define __pyx_n_u_key_expr __pyx_string_tab[637]
#define __pyx_n_u_key_value_pairs __pyx_string_tab[638]
#define __pyx_n_u_keys __pyx_string_tab[639]
#define __pyx_n_u_keyword_args __pyx_string_tab[640]
#define __pyx_n_u_keyword_pattern_names __pyx_string_tab[641]
#define __pyx_n_u_keyword_pattern_patterns __pyx_string_tab[642]
#define __pyx_n_u_kind __pyx_string_tab[643]
#define __pyx_n_u_kw_only __pyx_string_tab[644]
#define __pyx_n_u_kwds __pyx_string_tab[645]
#define __pyx_n_u_lambda __pyx_string_tab[646]
#define __pyx_n_u_language_level __pyx_string_tab[647]
#define __pyx_n_u_legacy_implicit_noexcept __pyx_string_tab[648]
#define __pyx_n_u_level __pyx_string_tab[649]
#define __pyx_n_u_lhs __pyx_string_tab[650]
#define __pyx_n_u_lhs_list __pyx_string_tab[651]
#define __pyx_n_u_list_type __pyx_string_tab[652]
#define __pyx_n_u_long __pyx_string_tab[653]
#define __pyx_n_u_longness __pyx_string_tab[654]
#define __pyx_n_u_lookup __pyx_string_tab[655]
#define __pyx_n_u_lookup_here __pyx_string_tab[656]
#define __pyx_n_u_loop __pyx_string_tab[657]
#define __pyx_n_u_lower __pyx_string_tab[658]
#define __pyx_n_u_lstrip __pyx_string_tab[659]
#define __pyx_n_u_main __pyx_string_tab[660]
#define __pyx_n_u_make_slice_node __pyx_string_tab[661]
#define __pyx_n_u_manager __pyx_string_tab[662]
#define __pyx_n_u_match __pyx_string_tab[663]
#define __pyx_n_u_metaclass __pyx_string_tab[664]
#define __pyx_n_u_modifiers __pyx_string_tab[665]
#define __pyx_n_u_module __pyx_string_tab[666]
#define __pyx_n_u_module_2 __pyx_string_tab[667]
#define __pyx_n_u_module_name __pyx_string_tab[668]
#define __pyx_n_u_module_path __pyx_string_tab[669]
#define __pyx_n_u_module_pxd __pyx_string_tab[670]
#define __pyx_n_u_name __pyx_string_tab[671]
#define __pyx_n_u_name_2 __pyx_string_tab[672]
#define __pyx_n_u_names __pyx_string_tab[673]
#define __pyx_n_u_namespace __pyx_string_tab[674]
#define __pyx_n_u_new __pyx_string_tab[675]
#define __pyx_n_u_next __pyx_string_tab[676]
#define __pyx_n_u_node __pyx_string_tab[677]
#define __pyx_n_u_noexcept __pyx_string_tab[678]
#define __pyx_n_u_nogil __pyx_string_tab[679]
#define __pyx_n_u_nonempty __pyx_string_tab[680]
#define __pyx_n_u_nonempty_declarators __pyx_string_tab[681]
#define __pyx_n_u_nonlocal __pyx_string_tab[682]
#define __pyx_n_u_not __pyx_string_tab[683]
#define __pyx_n_u_not_in __pyx_string_tab[684]
#define __pyx_n_u_not_none __pyx_string_tab[685]
#define __pyx_n_u_obj __pyx_string_tab[686]
#define __pyx_n_u_object __pyx_string_tab[687]
#define __pyx_n_u_objstruct_name __pyx_string_tab[688]
#define __pyx_n_u_operand __pyx_string_tab[689]
#define __pyx_n_u_operand1 __pyx_string_tab[690]
#define __pyx_n_u_operand2 __pyx_string_tab[691]
#define __pyx_n_u_operator __pyx_string_tab[692]
#define __pyx_n_u_or __pyx_string_tab[693]
#define __pyx_n_u_or_none __pyx_string_tab[694]
#define __pyx_n_u_other __pyx_string_tab[695]
#define __pyx_n_u_overridable __pyx_string_tab[696]
#define __pyx_n_u_p_c_arg_list __pyx_string_tab[697]
#define __pyx_n_u_p_c_base_type __pyx_string_tab[698]
#define __pyx_n_u_p_c_declarator __pyx_string_tab[699]
#define __pyx_n_u_p_code __pyx_string_tab[700]
#define __pyx_n_u_p_module __pyx_string_tab[701]
#define __pyx_n_u_packed __pyx_string_tab[702]
#define __pyx_n_u_parent_scanner __pyx_string_tab[703]
#define __pyx_n_u_parse_comments __pyx_string_tab[704]
#define __pyx_n_u_parse_directive_list __pyx_string_tab[705]
#define __pyx_n_u_partial __pyx_string_tab[706]
#define __pyx_n_u_pass __pyx_string_tab[707]
#define __pyx_n_u_pattern __pyx_string_tab[708]
#define __pyx_n_u_patterns __pyx_string_tab[709]
#define __pyx_n_u_peek __pyx_string_tab[710]
#define __pyx_n_u_pop __pyx_string_tab[711]
#define __pyx_n_u_pos __pyx_string_tab[712]
#define __pyx_n_u_pos_only __pyx_string_tab[713]
#define __pyx_n_u_positional_args __pyx_string_tab[714]
#define __pyx_n_u_positional_patterns __pyx_string_tab[715]
#define __pyx_n_u_prepare __pyx_string_tab[716]
#define __pyx_n_u_print __pyx_string_tab[717]
#define __pyx_n_u_print_parse_tree __pyx_string_tab[718]
#define __pyx_n_u_private __pyx_string_tab[719]
#define __pyx_n_u_property __pyx_string_tab[720]
#define __pyx_n_u_ptrdiff_t __pyx_string_tab[721]
#define __pyx_n_u_public __pyx_string_tab[722]
#define __pyx_n_u_put_back __pyx_string_tab[723]
#define __pyx_n_u_pxd __pyx_string_tab[724]
#define __pyx_n_u_pyx_capi __pyx_string_tab[725]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[726]
#define __pyx_n_u_qualname __pyx_string_tab[727]
#define __pyx_n_u_r __pyx_string_tab[728]
#define __pyx_n_u_rRbBuUfFtT __pyx_string_tab[729]
#define __pyx_n_u_raise __pyx_string_tab[730]
#define __pyx_n_u_rbrurfrtr __pyx_string_tab[731]
#define __pyx_n_u_re __pyx_string_tab[732]
#define __pyx_n_u_readonly __pyx_string_tab[733]
#define __pyx_n_u_real __pyx_string_tab[734]
#define __pyx_n_u_reduce __pyx_string_tab[735]
#define __pyx_n_u_reject_duplicates __pyx_string_tab[736]
#define __pyx_n_u_relation1 __pyx_string_tab[737]
#define __pyx_n_u_relation2 __pyx_string_tab[738]
#define __pyx_n_u_relative_level __pyx_string_tab[739]
#define __pyx_n_u_result_expr __pyx_string_tab[740]
#define __pyx_n_u_return __pyx_string_tab[741]
#define __pyx_n_u_return_type_annotation __pyx_string_tab[742]
#define __pyx_n_u_reversed __pyx_string_tab[743]
#define __pyx_n_u_rhs __pyx_string_tab[744]
#define __pyx_n_u_rsplit __pyx_string_tab[745]
#define __pyx_n_u_rstrip __pyx_string_tab[746]
#define __pyx_n_u_s __pyx_string_tab[747]
#define __pyx_n_u_scoped __pyx_string_tab[748]
#define __pyx_n_u_self __pyx_string_tab[749]
#define __pyx_n_u_sequence __pyx_string_tab[750]
#define __pyx_n_u_set __pyx_string_tab[751]
#define __pyx_n_u_set_language_level __pyx_string_tab[752]
#define __pyx_n_u_set_name __pyx_string_tab[753]
#define __pyx_n_u_set_type __pyx_string_tab[754]
#define __pyx_n_u_setdefault __pyx_string_tab[755]
#define __pyx_n_u_short __pyx_string_tab[756]
#define __pyx_n_u_signed __pyx_string_tab[757]
#define __pyx_n_u_size_t __pyx_string_tab[758]
#define __pyx_n_u_sizeof __pyx_string_tab[759]
#define __pyx_n_u_source_encoding __pyx_string_tab[760]
#define __pyx_n_u_ssize_t __pyx_string_tab[761]
#define __pyx_n_u_star_arg __pyx_string_tab[762]
#define __pyx_n_u_starstar_arg __pyx_string_tab[763]
#define __pyx_n_u_start __pyx_string_tab[764]
#define __pyx_n_u_start_line __pyx_string_tab[765]
#define __pyx_n_u_state __pyx_string_tab[766]
#define __pyx_n_u_stats __pyx_string_tab[767]
#define __pyx_n_u_stdcall __pyx_string_tab[768]
#define __pyx_n_u_step __pyx_string_tab[769]
#define __pyx_n_u_stop __pyx_string_tab[770]
#define __pyx_n_u_stream __pyx_string_tab[771]
#define __pyx_n_u_strip __pyx_string_tab[772]
#define __pyx_n_u_struct __pyx_string_tab[773]
#define __pyx_n_u_subject __pyx_string_tab[774]
#define __pyx_n_u_t __pyx_string_tab[775]
#define __pyx_n_u_tag __pyx_string_tab[776]
#define __pyx_n_u_target __pyx_string_tab[777]
#define __pyx_n_u_template __pyx_string_tab[778]
#define __pyx_n_u_templates __pyx_string_tab[779]
#define __pyx_n_u_tentatively_scan __pyx_string_tab[780]
#define __pyx_n_u_test __pyx_string_tab[781]
#define __pyx_n_u_true_val __pyx_string_tab[782]
#define __pyx_n_u_truedivision __pyx_string_tab[783]
#define __pyx_n_u_try __pyx_string_tab[784]
#define __pyx_n_u_type_2 __pyx_string_tab[785]
#define __pyx_n_u_typecheck __pyx_string_tab[786]
#define __pyx_n_u_typedef_flag __pyx_string_tab[787]
#define __pyx_n_u_typeobj_name __pyx_string_tab[788]
#define __pyx_n_u_types __pyx_string_tab[789]
#define __pyx_n_u_u __pyx_string_tab[790]
#define __pyx_n_u_ub __pyx_string_tab[791]
#define __pyx_n_u_underlying_type __pyx_string_tab[792]
#define __pyx_n_u_unicode_literals __pyx_string_tab[793]
#define __pyx_n_u_unicodedata __pyx_string_tab[794]
#define __pyx_n_u_union __pyx_string_tab[795]
#define __pyx_n_u_unop_node __pyx_string_tab[796]
#define __pyx_n_u_unsigned __pyx_string_tab[797]
#define __pyx_n_u_update __pyx_string_tab[798]
#define __pyx_n_u_value __pyx_string_tab[799]
#define __pyx_n_u_value_expr __pyx_string_tab[800]
#define __pyx_n_u_value_patterns __pyx_string_tab[801]
#define __pyx_n_u_values __pyx_string_tab[802]
#define __pyx_n_u_verbatim_include __pyx_string_tab[803]
#define __pyx_n_u_visibility __pyx_string_tab[804]
#define __pyx_n_u_void __pyx_string_tab[805]
#define __pyx_n_u_volatile __pyx_string_tab[806]
#define __pyx_n_u_warn __pyx_string_tab[807]
#define __pyx_n_u_warning __pyx_string_tab[808]
#define __pyx_n_u_what __pyx_string_tab[809]
#define __pyx_n_u_while __pyx_string_tab[810]
#define __pyx_n_u_with __pyx_string_tab[811]
#define __pyx_n_u_with_gil __pyx_string_tab[812]
#define __pyx_n_u_write __pyx_string_tab[813]
#define __pyx_n_u_yield __pyx_string_tab[814]
#define __pyx_n_u_zip __pyx_string_tab[815]
#define __pyx_kp_b_PyObject_IDENT_any_string_prefix __pyx_string_tab[816]
#define __pyx_kp_b_PyObject_struct___pyx_obj_6Cytho __pyx_string_tab[817]
#define __pyx_kp_b__35 __pyx_string_tab[818]
#define __pyx_kp_b_iso88591_1_Q_55E_ST_1_4wa_G1L_E_A_7q_1D __pyx_string_tab[819]
#define __pyx_kp_b_iso88591_4A_t1_1_t1_y_t1_y_9Jaq_wfG1 __pyx_string_tab[820]
#define __pyx_kp_b_iso88591_8_uBa_V1A_q_q_1_t1_q_QfCq_q_1D __pyx_string_tab[821]
#define __pyx_kp_b_iso88591_9_9A_6aq_q_q_1_AQ_IQ_aq_1Cs_6_A __pyx_string_tab[822]
#define __pyx_kp_b_iso88591_A_1Cs_8_C1_q_Cq_q_AQa_1 __pyx_string_tab[823]
#define __pyx_kp_b_iso88591_A_IWAQ __pyx_string_tab[824]
#define __pyx_kp_b_iso88591_A_c_Cq_Q_q __pyx_string_tab[825]
#define __pyx_kp_b_iso88591_LA_q_Cq_A_A_1L0DA __pyx_string_tab[826]
#define __pyx_kp_b_iso88591_Q_8_F_iij_nA_Q_9A_q_Cq_a_1D_4s __pyx_string_tab[827]
#define __pyx_float_0_0 __pyx_number_tab[0]
#define __pyx_int_0 __pyx_number_tab[1]
#define __pyx_int_neg_1 __pyx_number_tab[2]
#define __pyx_int_1 __pyx_number_tab[3]
#define __pyx_int_2 __pyx_number_tab[4]
#define __pyx_int_3 __pyx_number_tab[5]
#define __pyx_int_8 __pyx_number_tab[6]
#define __pyx_int_16 __pyx_number_tab[7]
#define __pyx_int_1114111 __pyx_number_tab[8]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Action);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Return);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Call);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Method);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Begin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Ignore);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Text);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState);
  Py_CLEAR(clear_module_state->__pyx_k__25);
  Py_CLEAR(clear_module_state->__pyx_k__44);
  Py_CLEAR(clear_module_state->__pyx_k__45);
  Py_CLEAR(clear_module_state->__pyx_k__52);
  Py_CLEAR(clear_module_state->__pyx_k__54);
  Py_CLEAR(clear_module_state->__pyx_k__56);
  for (int i=0; i<3; ++i) { Py_CLEAR(clear_module_state->__pyx_slice[i]); }
  for (int i=0; i<31; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<9; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<828; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<9; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Action);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Return);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Call);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Method);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Begin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Ignore);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_7Actions_Text);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState);
  Py_VISIT(traverse_module_state->__pyx_k__25);
  Py_VISIT(traverse_module_state->__pyx_k__44);
  Py_VISIT(traverse_module_state->__pyx_k__45);
  Py_VISIT(traverse_module_state->__pyx_k__52);
  Py_VISIT(traverse_module_state->__pyx_k__54);
  Py_VISIT(traverse_module_state->__pyx_k__56);
  for (int i=0; i<3; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_slice[i]); }
  for (int i=0; i<31; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<9; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<828; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<9; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "Cython/Compiler/Parsing.py":54
 *     allow_struct_enum_decorator = False
 * 
 *     def __init__(self, **kwds):             # <<<<<<<<<<<<<<
 *         self.__dict__.update(kwds)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_3Ctx_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_kwds = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwds = PyDict_New(); if (unlikely(!__pyx_v_kwds)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwds);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 54, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 54, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwds, values, kwd_pos_args, __pyx_kwds_len, "__init__", 1) < (0)) __PYX_ERR(0, 54, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 54, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 54, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 54, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kwds); __pyx_v_kwds = 0;
  __Pyx_AddTraceback("Cython.Compiler.Parsing.Ctx.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_3Ctx___init__(__pyx_self, __pyx_v_self, __pyx_v_kwds);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kwds);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_3Ctx___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Parsing.py":55
 * 
 *     def __init__(self, **kwds):
 *         self.__dict__.update(kwds)             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, **kwds):
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_kwds};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":54
 *     allow_struct_enum_decorator = False
 * 
 *     def __init__(self, **kwds):             # <<<<<<<<<<<<<<
 *         self.__dict__.update(kwds)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.Ctx.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":57
 *         self.__dict__.update(kwds)
 * 
 *     def __call__(self, **kwds):             # <<<<<<<<<<<<<<
 *         ctx = Ctx()
 *         d = ctx.__dict__
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_3Ctx_3__call__ = {"__call__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_3__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3Ctx_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_kwds = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwds = PyDict_New(); if (unlikely(!__pyx_v_kwds)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwds);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 57, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 57, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwds, values, kwd_pos_args, __pyx_kwds_len, "__call__", 1) < (0)) __PYX_ERR(0, 57, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 57, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 57, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 57, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kwds); __pyx_v_kwds = 0;
  __Pyx_AddTraceback("Cython.Compiler.Parsing.Ctx.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_3Ctx_2__call__(__pyx_self, __pyx_v_self, __pyx_v_kwds);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_kwds);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_3Ctx_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_v_ctx = NULL;
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Compiler/Parsing.py":58
 * 
 *     def __call__(self, **kwds):
 *         ctx = Ctx()             # <<<<<<<<<<<<<<
 *         d = ctx.__dict__
 *         d.update(self.__dict__)
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_ctx = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":59
 *     def __call__(self, **kwds):
 *         ctx = Ctx()
 *         d = ctx.__dict__             # <<<<<<<<<<<<<<
 *         d.update(self.__dict__)
 *         d.update(kwds)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_d = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":60
 *         ctx = Ctx()
 *         d = ctx.__dict__
 *         d.update(self.__dict__)             # <<<<<<<<<<<<<<
 *         d.update(kwds)
 *         return ctx
*/
  __pyx_t_3 = __pyx_v_d;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":61
 *         d = ctx.__dict__
 *         d.update(self.__dict__)
 *         d.update(kwds)             # <<<<<<<<<<<<<<
 *         return ctx
 * 
*/
  __pyx_t_2 = __pyx_v_d;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_kwds};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":62
 *         d.update(self.__dict__)
 *         d.update(kwds)
 *         return ctx             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_r = __pyx_v_ctx;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":57
 *         self.__dict__.update(kwds)
 * 
 *     def __call__(self, **kwds):             # <<<<<<<<<<<<<<
 *         ctx = Ctx()
 *         d = ctx.__dict__
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.Ctx.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ctx);
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":65
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ident(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_ident *__pyx_optional_args) {
  PyObject *__pyx_v_message = ((PyObject *)__pyx_mstate_global->__pyx_kp_u_Expected_an_identifier);
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ident", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_message = __pyx_optional_args->message;
    }
  }

  /* "Cython/Compiler/Parsing.py":67
 * @cython.cfunc
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.context.intern_ustring(s.systring)
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 67, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":68
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':
 *         name = s.context.intern_ustring(s.systring)             # <<<<<<<<<<<<<<
 *         s.next()
 *         return name
*/
    __pyx_t_3 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_s->systring};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_name = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":69
 *     if s.sy == 'IDENT':
 *         name = s.context.intern_ustring(s.systring)
 *         s.next()             # <<<<<<<<<<<<<<
 *         return name
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":70
 *         name = s.context.intern_ustring(s.systring)
 *         s.next()
 *         return name             # <<<<<<<<<<<<<<
 *     else:
 *         s.error(message)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_name);
    __pyx_r = __pyx_v_name;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":67
 * @cython.cfunc
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.context.intern_ustring(s.systring)
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":72
 *         return name
 *     else:
 *         s.error(message)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_message};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":65
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ident(s: PyrexScanner, message="Expected an identifier"):
 *     if s.sy == 'IDENT':
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ident", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":75
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ident_list(s: PyrexScanner):
 *     names = []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ident_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ident_list", 0);

  /* "Cython/Compiler/Parsing.py":77
 * @cython.cfunc
 * def p_ident_list(s: PyrexScanner):
 *     names = []             # <<<<<<<<<<<<<<
 *     while s.sy == 'IDENT':
 *         names.append(s.context.intern_ustring(s.systring))
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_names = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":78
 * def p_ident_list(s: PyrexScanner):
 *     names = []
 *     while s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         names.append(s.context.intern_ustring(s.systring))
 *         s.next()
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 78, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":79
 *     names = []
 *     while s.sy == 'IDENT':
 *         names.append(s.context.intern_ustring(s.systring))             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy != ',':
*/
    __pyx_t_3 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_s->systring};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_names, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":80
 *     while s.sy == 'IDENT':
 *         names.append(s.context.intern_ustring(s.systring))
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":81
 *         names.append(s.context.intern_ustring(s.systring))
 *         s.next()
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 81, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":82
 *         s.next()
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     return names
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":81
 *         names.append(s.context.intern_ustring(s.systring))
 *         s.next()
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":83
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     return names
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":84
 *             break
 *         s.next()
 *     return names             # <<<<<<<<<<<<<<
 * 
 * #------------------------------------------
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_names);
  __pyx_r = __pyx_v_names;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":75
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ident_list(s: PyrexScanner):
 *     names = []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ident_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":92
 * #------------------------------------------
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_binop_operator(s: PyrexScanner) -> tuple:
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_binop_operator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_binop_operator", 0);

  /* "Cython/Compiler/Parsing.py":94
 * @cython.cfunc
 * def p_binop_operator(s: PyrexScanner) -> tuple:
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     op = s.sy
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":95
 * def p_binop_operator(s: PyrexScanner) -> tuple:
 *     pos = s.position()
 *     op = s.sy             # <<<<<<<<<<<<<<
 *     s.next()
 *     return op, pos
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_op = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":96
 *     pos = s.position()
 *     op = s.sy
 *     s.next()             # <<<<<<<<<<<<<<
 *     return op, pos
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":97
 *     op = s.sy
 *     s.next()
 *     return op, pos             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_op);
  __Pyx_GIVEREF(__pyx_v_op);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_op) != (0)) __PYX_ERR(0, 97, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 97, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":92
 * #------------------------------------------
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_binop_operator(s: PyrexScanner) -> tuple:
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_binop_operator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":101
 * 
 * # signature is currently overridden in pxd file
 * def p_binop_expr(s: PyrexScanner, ops, p_sub_expr):             # <<<<<<<<<<<<<<
 *     n1 = p_sub_expr(s)
 *     while s.sy in ops:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ops, __pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func __pyx_v_p_sub_expr) {
  PyObject *__pyx_v_n1 = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_n2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_binop_expr", 0);

  /* "Cython/Compiler/Parsing.py":102
 * # signature is currently overridden in pxd file
 * def p_binop_expr(s: PyrexScanner, ops, p_sub_expr):
 *     n1 = p_sub_expr(s)             # <<<<<<<<<<<<<<
 *     while s.sy in ops:
 *         op, pos = p_binop_operator(s)
*/
  __pyx_t_1 = __pyx_v_p_sub_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n1 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":103
 * def p_binop_expr(s: PyrexScanner, ops, p_sub_expr):
 *     n1 = p_sub_expr(s)
 *     while s.sy in ops:             # <<<<<<<<<<<<<<
 *         op, pos = p_binop_operator(s)
 *         n2 = p_sub_expr(s)
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_ops, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 103, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":104
 *     n1 = p_sub_expr(s)
 *     while s.sy in ops:
 *         op, pos = p_binop_operator(s)             # <<<<<<<<<<<<<<
 *         n2 = p_sub_expr(s)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_operator(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 104, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 104, __pyx_L1_error)
    }
    __Pyx_XDECREF_SET(__pyx_v_op, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":105
 *     while s.sy in ops:
 *         op, pos = p_binop_operator(s)
 *         n2 = p_sub_expr(s)             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *         if op == '/':
*/
    __pyx_t_1 = __pyx_v_p_sub_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_n2, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":106
 *         op, pos = p_binop_operator(s)
 *         n2 = p_sub_expr(s)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)             # <<<<<<<<<<<<<<
 *         if op == '/':
 *             if Future.division in s.context.future_directives:
*/
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_pos, __pyx_v_op, __pyx_v_n1, __pyx_v_n2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":107
 *         n2 = p_sub_expr(s)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *         if op == '/':             # <<<<<<<<<<<<<<
 *             if Future.division in s.context.future_directives:
 *                 n1.truedivision = True
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__2, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 107, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":108
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *         if op == '/':
 *             if Future.division in s.context.future_directives:             # <<<<<<<<<<<<<<
 *                 n1.truedivision = True
 *             else:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_division); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":109
 *         if op == '/':
 *             if Future.division in s.context.future_directives:
 *                 n1.truedivision = True             # <<<<<<<<<<<<<<
 *             else:
 *                 n1.truedivision = None  # unknown
*/
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_n1, __pyx_mstate_global->__pyx_n_u_truedivision, Py_True) < (0)) __PYX_ERR(0, 109, __pyx_L1_error)

        /* "Cython/Compiler/Parsing.py":108
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *         if op == '/':
 *             if Future.division in s.context.future_directives:             # <<<<<<<<<<<<<<
 *                 n1.truedivision = True
 *             else:
*/
        goto __pyx_L6;
      }

      /* "Cython/Compiler/Parsing.py":111
 *                 n1.truedivision = True
 *             else:
 *                 n1.truedivision = None  # unknown             # <<<<<<<<<<<<<<
 *     return n1
 * 
*/
      /*else*/ {
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_n1, __pyx_mstate_global->__pyx_n_u_truedivision, Py_None) < (0)) __PYX_ERR(0, 111, __pyx_L1_error)
      }
      __pyx_L6:;

      /* "Cython/Compiler/Parsing.py":107
 *         n2 = p_sub_expr(s)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *         if op == '/':             # <<<<<<<<<<<<<<
 *             if Future.division in s.context.future_directives:
 *                 n1.truedivision = True
*/
    }
  }

  /* "Cython/Compiler/Parsing.py":112
 *             else:
 *                 n1.truedivision = None  # unknown
 *     return n1             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_n1);
  __pyx_r = __pyx_v_n1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":101
 * 
 * # signature is currently overridden in pxd file
 * def p_binop_expr(s: PyrexScanner, ops, p_sub_expr):             # <<<<<<<<<<<<<<
 *     n1 = p_sub_expr(s)
 *     while s.sy in ops:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_binop_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n1);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_n2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":117
 * #lambdef: 'lambda' [varargslist] ':' test
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_lambdef(s: PyrexScanner):
 *     # s.sy == 'lambda'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_lambdef(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_star_arg = NULL;
  PyObject *__pyx_v_starstar_arg = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_lambdef", 0);

  /* "Cython/Compiler/Parsing.py":120
 * def p_lambdef(s: PyrexScanner):
 *     # s.sy == 'lambda'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy == ':':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":121
 *     # s.sy == 'lambda'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy == ':':
 *         args = []
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":122
 *     pos = s.position()
 *     s.next()
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         args = []
 *         star_arg = starstar_arg = None
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 122, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":123
 *     s.next()
 *     if s.sy == ':':
 *         args = []             # <<<<<<<<<<<<<<
 *         star_arg = starstar_arg = None
 *     else:
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_args = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":124
 *     if s.sy == ':':
 *         args = []
 *         star_arg = starstar_arg = None             # <<<<<<<<<<<<<<
 *     else:
 *         args, star_arg, starstar_arg = p_varargslist(
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_star_arg = Py_None;
    __Pyx_INCREF(Py_None);
    __pyx_v_starstar_arg = Py_None;

    /* "Cython/Compiler/Parsing.py":122
 *     pos = s.position()
 *     s.next()
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         args = []
 *         star_arg = starstar_arg = None
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":126
 *         star_arg = starstar_arg = None
 *     else:
 *         args, star_arg, starstar_arg = p_varargslist(             # <<<<<<<<<<<<<<
 *             s, terminator=':', annotated=False)
 *     s.expect(':')
*/
  /*else*/ {

    /* "Cython/Compiler/Parsing.py":127
 *     else:
 *         args, star_arg, starstar_arg = p_varargslist(
 *             s, terminator=':', annotated=False)             # <<<<<<<<<<<<<<
 *     s.expect(':')
 *     expr = p_test(s)
*/
    __pyx_t_5.__pyx_n = 2;
    __pyx_t_5.terminator = 58;
    __pyx_t_5.annotated = 0;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_varargslist(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 126, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 126, __pyx_L1_error)
    }

    /* "Cython/Compiler/Parsing.py":126
 *         star_arg = starstar_arg = None
 *     else:
 *         args, star_arg, starstar_arg = p_varargslist(             # <<<<<<<<<<<<<<
 *             s, terminator=':', annotated=False)
 *     s.expect(':')
*/
    __pyx_v_args = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_v_star_arg = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_v_starstar_arg = __pyx_t_7;
    __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":128
 *         args, star_arg, starstar_arg = p_varargslist(
 *             s, terminator=':', annotated=False)
 *     s.expect(':')             # <<<<<<<<<<<<<<
 *     expr = p_test(s)
 *     return ExprNodes.LambdaNode(
*/
  __pyx_t_7 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":129
 *             s, terminator=':', annotated=False)
 *     s.expect(':')
 *     expr = p_test(s)             # <<<<<<<<<<<<<<
 *     return ExprNodes.LambdaNode(
 *         pos, args = args,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":130
 *     s.expect(':')
 *     expr = p_test(s)
 *     return ExprNodes.LambdaNode(             # <<<<<<<<<<<<<<
 *         pos, args = args,
 *         star_arg = star_arg, starstar_arg = starstar_arg,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":133
 *         pos, args = args,
 *         star_arg = star_arg, starstar_arg = starstar_arg,
 *         result_expr = expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 130, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_star_arg, __pyx_v_star_arg, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 130, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_starstar_arg, __pyx_v_starstar_arg, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 130, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_result_expr, __pyx_v_expr, __pyx_t_6, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 130, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_LambdaNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":117
 * #lambdef: 'lambda' [varargslist] ':' test
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_lambdef(s: PyrexScanner):
 *     # s.sy == 'lambda'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_lambdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_star_arg);
  __Pyx_XDECREF(__pyx_v_starstar_arg);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":138
 * #test: or_test ['if' or_test 'else' test] | lambdef
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test(s: PyrexScanner):
 *     # The check for a following ':=' is only for error reporting purposes.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_test", 0);

  /* "Cython/Compiler/Parsing.py":146
 *     # It is close to what the PEG parser does in CPython, where an expression has
 *     # a lookahead assertion that it isn't followed by ':='
 *     expr = p_test_allow_walrus_after(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ':=':
 *         s.error("invalid syntax: assignment expression not allowed in this context")
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test_allow_walrus_after(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":147
 *     # a lookahead assertion that it isn't followed by ':='
 *     expr = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':             # <<<<<<<<<<<<<<
 *         s.error("invalid syntax: assignment expression not allowed in this context")
 *     return expr
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__4, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":148
 *     expr = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':
 *         s.error("invalid syntax: assignment expression not allowed in this context")             # <<<<<<<<<<<<<<
 *     return expr
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_invalid_syntax_assignment_expres};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":147
 *     # a lookahead assertion that it isn't followed by ':='
 *     expr = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':             # <<<<<<<<<<<<<<
 *         s.error("invalid syntax: assignment expression not allowed in this context")
 *     return expr
*/
  }

  /* "Cython/Compiler/Parsing.py":149
 *     if s.sy == ':=':
 *         s.error("invalid syntax: assignment expression not allowed in this context")
 *     return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_expr);
  __pyx_r = __pyx_v_expr;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":138
 * #test: or_test ['if' or_test 'else' test] | lambdef
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test(s: PyrexScanner):
 *     # The check for a following ':=' is only for error reporting purposes.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":152
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_allow_walrus_after(s: PyrexScanner):
 *     if s.sy == 'lambda':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_allow_walrus_after(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_test = NULL;
  PyObject *__pyx_v_other = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_test_allow_walrus_after", 0);

  /* "Cython/Compiler/Parsing.py":154
 * @cython.cfunc
 * def p_test_allow_walrus_after(s: PyrexScanner):
 *     if s.sy == 'lambda':             # <<<<<<<<<<<<<<
 *         return p_lambdef(s)
 *     pos = s.position()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_lambda, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 154, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":155
 * def p_test_allow_walrus_after(s: PyrexScanner):
 *     if s.sy == 'lambda':
 *         return p_lambdef(s)             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     expr = p_or_test(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_lambdef(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":154
 * @cython.cfunc
 * def p_test_allow_walrus_after(s: PyrexScanner):
 *     if s.sy == 'lambda':             # <<<<<<<<<<<<<<
 *         return p_lambdef(s)
 *     pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":156
 *     if s.sy == 'lambda':
 *         return p_lambdef(s)
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_or_test(s)
 *     if s.sy == 'if':
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pos = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":157
 *         return p_lambdef(s)
 *     pos = s.position()
 *     expr = p_or_test(s)             # <<<<<<<<<<<<<<
 *     if s.sy == 'if':
 *         s.next()
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_or_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_expr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":158
 *     pos = s.position()
 *     expr = p_or_test(s)
 *     if s.sy == 'if':             # <<<<<<<<<<<<<<
 *         s.next()
 *         test = p_or_test(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_if, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 158, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":159
 *     expr = p_or_test(s)
 *     if s.sy == 'if':
 *         s.next()             # <<<<<<<<<<<<<<
 *         test = p_or_test(s)
 *         s.expect('else')
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":160
 *     if s.sy == 'if':
 *         s.next()
 *         test = p_or_test(s)             # <<<<<<<<<<<<<<
 *         s.expect('else')
 *         other = p_test(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_or_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_test = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":161
 *         s.next()
 *         test = p_or_test(s)
 *         s.expect('else')             # <<<<<<<<<<<<<<
 *         other = p_test(s)
 *         return ExprNodes.CondExprNode(pos, test=test, true_val=expr, false_val=other)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_else};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":162
 *         test = p_or_test(s)
 *         s.expect('else')
 *         other = p_test(s)             # <<<<<<<<<<<<<<
 *         return ExprNodes.CondExprNode(pos, test=test, true_val=expr, false_val=other)
 *     else:
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_other = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":163
 *         s.expect('else')
 *         other = p_test(s)
 *         return ExprNodes.CondExprNode(pos, test=test, true_val=expr, false_val=other)             # <<<<<<<<<<<<<<
 *     else:
 *         return expr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_test, __pyx_v_test, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 163, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_true_val, __pyx_v_expr, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 163, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_false_val, __pyx_v_other, __pyx_t_5, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 163, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CondExprNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":158
 *     pos = s.position()
 *     expr = p_or_test(s)
 *     if s.sy == 'if':             # <<<<<<<<<<<<<<
 *         s.next()
 *         test = p_or_test(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":165
 *         return ExprNodes.CondExprNode(pos, test=test, true_val=expr, false_val=other)
 *     else:
 *         return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_expr);
    __pyx_r = __pyx_v_expr;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":152
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_allow_walrus_after(s: PyrexScanner):
 *     if s.sy == 'lambda':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_test_allow_walrus_after", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_test);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":168
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test(s: PyrexScanner):
 *     # defined in the LL parser as
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_v_position = NULL;
  PyObject *__pyx_v_rhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_namedexpr_test", 0);

  /* "Cython/Compiler/Parsing.py":177
 *     #     so look for expression
 *     #  2. Otherwise, look for expression
 *     lhs = p_test_allow_walrus_after(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ':=':
 *         position = s.position()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test_allow_walrus_after(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_lhs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":178
 *     #  2. Otherwise, look for expression
 *     lhs = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':             # <<<<<<<<<<<<<<
 *         position = s.position()
 *         if not lhs.is_name:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__4, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 178, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":179
 *     lhs = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':
 *         position = s.position()             # <<<<<<<<<<<<<<
 *         if not lhs.is_name:
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_position = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":180
 *     if s.sy == ':=':
 *         position = s.position()
 *         if not lhs.is_name:             # <<<<<<<<<<<<<<
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)
 *         s.next()
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (!__pyx_t_2);
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":181
 *         position = s.position()
 *         if not lhs.is_name:
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)             # <<<<<<<<<<<<<<
 *         s.next()
 *         rhs = p_test(s)
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Left_hand_side_of_assignment_exp};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 181, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 181, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":180
 *     if s.sy == ':=':
 *         position = s.position()
 *         if not lhs.is_name:             # <<<<<<<<<<<<<<
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":182
 *         if not lhs.is_name:
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)
 *         s.next()             # <<<<<<<<<<<<<<
 *         rhs = p_test(s)
 *         return ExprNodes.AssignmentExpressionNode(position, lhs=lhs, rhs=rhs)
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":183
 *             s.error("Left-hand side of assignment expression must be an identifier", fatal=False)
 *         s.next()
 *         rhs = p_test(s)             # <<<<<<<<<<<<<<
 *         return ExprNodes.AssignmentExpressionNode(position, lhs=lhs, rhs=rhs)
 *     return lhs
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_rhs = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":184
 *         s.next()
 *         rhs = p_test(s)
 *         return ExprNodes.AssignmentExpressionNode(position, lhs=lhs, rhs=rhs)             # <<<<<<<<<<<<<<
 *     return lhs
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_6, __pyx_v_position};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_lhs, __pyx_v_lhs, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs, __pyx_v_rhs, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AssignmentExpressionNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":178
 *     #  2. Otherwise, look for expression
 *     lhs = p_test_allow_walrus_after(s)
 *     if s.sy == ':=':             # <<<<<<<<<<<<<<
 *         position = s.position()
 *         if not lhs.is_name:
*/
  }

  /* "Cython/Compiler/Parsing.py":185
 *         rhs = p_test(s)
 *         return ExprNodes.AssignmentExpressionNode(position, lhs=lhs, rhs=rhs)
 *     return lhs             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_lhs);
  __pyx_r = __pyx_v_lhs;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":168
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test(s: PyrexScanner):
 *     # defined in the LL parser as
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_namedexpr_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XDECREF(__pyx_v_position);
  __Pyx_XDECREF(__pyx_v_rhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":192
 * COMMON_BINOP_MISTAKES = {'||': 'or', '&&': 'and'}
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_or_test(s: PyrexScanner):
 *     return p_rassoc_binop_expr(s, 'or', p_and_test)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_or_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_or_test", 0);

  /* "Cython/Compiler/Parsing.py":194
 * @cython.cfunc
 * def p_or_test(s: PyrexScanner):
 *     return p_rassoc_binop_expr(s, 'or', p_and_test)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_or, __pyx_f_6Cython_8Compiler_7Parsing_p_and_test); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":192
 * COMMON_BINOP_MISTAKES = {'||': 'or', '&&': 'and'}
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_or_test(s: PyrexScanner):
 *     return p_rassoc_binop_expr(s, 'or', p_and_test)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_or_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":198
 * 
 * # signature is currently overridden in pxd file
 * def p_rassoc_binop_expr(s: PyrexScanner, op, p_subexpr):             # <<<<<<<<<<<<<<
 *     n1 = p_subexpr(s)
 *     if s.sy == op:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_op, __pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func __pyx_v_p_subexpr) {
  PyObject *__pyx_v_n1 = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_n2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10[5];
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_rassoc_binop_expr", 0);
  __Pyx_INCREF(__pyx_v_op);

  /* "Cython/Compiler/Parsing.py":199
 * # signature is currently overridden in pxd file
 * def p_rassoc_binop_expr(s: PyrexScanner, op, p_subexpr):
 *     n1 = p_subexpr(s)             # <<<<<<<<<<<<<<
 *     if s.sy == op:
 *         pos = s.position()
*/
  __pyx_t_1 = __pyx_v_p_subexpr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n1 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":200
 * def p_rassoc_binop_expr(s: PyrexScanner, op, p_subexpr):
 *     n1 = p_subexpr(s)
 *     if s.sy == op:             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         op = s.sy
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_v_op, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 200, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":201
 *     n1 = p_subexpr(s)
 *     if s.sy == op:
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         op = s.sy
 *         s.next()
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_pos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":202
 *     if s.sy == op:
 *         pos = s.position()
 *         op = s.sy             # <<<<<<<<<<<<<<
 *         s.next()
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)
*/
    __pyx_t_1 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_op, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":203
 *         pos = s.position()
 *         op = s.sy
 *         s.next()             # <<<<<<<<<<<<<<
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":204
 *         op = s.sy
 *         s.next()
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *     elif s.sy in COMMON_BINOP_MISTAKES and COMMON_BINOP_MISTAKES[s.sy] == op:
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr(__pyx_v_s, __pyx_v_op, __pyx_v_p_subexpr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_n2 = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":205
 *         s.next()
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)             # <<<<<<<<<<<<<<
 *     elif s.sy in COMMON_BINOP_MISTAKES and COMMON_BINOP_MISTAKES[s.sy] == op:
 *         # Only report this for the current operator since we pass through here twice for 'and' and 'or'.
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_pos, __pyx_v_op, __pyx_v_n1, __pyx_v_n2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_4, (5-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":200
 * def p_rassoc_binop_expr(s: PyrexScanner, op, p_subexpr):
 *     n1 = p_subexpr(s)
 *     if s.sy == op:             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         op = s.sy
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":206
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *     elif s.sy in COMMON_BINOP_MISTAKES and COMMON_BINOP_MISTAKES[s.sy] == op:             # <<<<<<<<<<<<<<
 *         # Only report this for the current operator since we pass through here twice for 'and' and 'or'.
 *         warning(s.position(),
*/
  if (unlikely(__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 206, __pyx_L1_error)
  }
  __pyx_t_5 = (__Pyx_PyDict_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 206, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 206, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES, __pyx_v_s->sy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_v_op, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":208
 *     elif s.sy in COMMON_BINOP_MISTAKES and COMMON_BINOP_MISTAKES[s.sy] == op:
 *         # Only report this for the current operator since we pass through here twice for 'and' and 'or'.
 *         warning(s.position(),             # <<<<<<<<<<<<<<
 *                 "Found the C operator '%s', did you mean the Python operator '%s'?" % (s.sy, op),
 *                 level=1)
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
    __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "Cython/Compiler/Parsing.py":209
 *         # Only report this for the current operator since we pass through here twice for 'and' and 'or'.
 *         warning(s.position(),
 *                 "Found the C operator '%s', did you mean the Python operator '%s'?" % (s.sy, op),             # <<<<<<<<<<<<<<
 *                 level=1)
 *     return n1
*/
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_v_s->sy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyUnicode_Unicode(__pyx_v_op); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_Found_the_C_operator;
    __pyx_t_10[1] = __pyx_t_8;
    __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u_did_you_mean_the_Python_operato;
    __pyx_t_10[3] = __pyx_t_9;
    __pyx_t_10[4] = __pyx_mstate_global->__pyx_kp_u__5;
    __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_10, 5, 22 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 37 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9));
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_t_7, __pyx_t_11};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_int_1, __pyx_t_9, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 208, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":206
 *         n2 = p_rassoc_binop_expr(s, op, p_subexpr)
 *         n1 = ExprNodes.binop_node(pos, op, n1, n2)
 *     elif s.sy in COMMON_BINOP_MISTAKES and COMMON_BINOP_MISTAKES[s.sy] == op:             # <<<<<<<<<<<<<<
 *         # Only report this for the current operator since we pass through here twice for 'and' and 'or'.
 *         warning(s.position(),
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":211
 *                 "Found the C operator '%s', did you mean the Python operator '%s'?" % (s.sy, op),
 *                 level=1)
 *     return n1             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_n1);
  __pyx_r = __pyx_v_n1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":198
 * 
 * # signature is currently overridden in pxd file
 * def p_rassoc_binop_expr(s: PyrexScanner, op, p_subexpr):             # <<<<<<<<<<<<<<
 *     n1 = p_subexpr(s)
 *     if s.sy == op:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_rassoc_binop_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n1);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_n2);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":216
 * #and_test: not_test ('and' not_test)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_and_test(s: PyrexScanner):
 *     #return p_binop_expr(s, ('and',), p_not_test)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_and_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_and_test", 0);

  /* "Cython/Compiler/Parsing.py":219
 * def p_and_test(s: PyrexScanner):
 *     #return p_binop_expr(s, ('and',), p_not_test)
 *     return p_rassoc_binop_expr(s, 'and', p_not_test)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_and, __pyx_f_6Cython_8Compiler_7Parsing_p_not_test); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":216
 * #and_test: not_test ('and' not_test)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_and_test(s: PyrexScanner):
 *     #return p_binop_expr(s, ('and',), p_not_test)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_and_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":224
 * #not_test: 'not' not_test | comparison
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_not_test(s: PyrexScanner):
 *     if s.sy == 'not':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_not_test(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_not_test", 0);

  /* "Cython/Compiler/Parsing.py":226
 * @cython.cfunc
 * def p_not_test(s: PyrexScanner):
 *     if s.sy == 'not':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_not, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 226, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":227
 * def p_not_test(s: PyrexScanner):
 *     if s.sy == 'not':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.NotNode(pos, operand = p_not_test(s))
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":228
 *     if s.sy == 'not':
 *         pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.NotNode(pos, operand = p_not_test(s))
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":229
 *         pos = s.position()
 *         s.next()
 *         return ExprNodes.NotNode(pos, operand = p_not_test(s))             # <<<<<<<<<<<<<<
 *     else:
 *         return p_comparison(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_not_test(__pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 229, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NotNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":226
 * @cython.cfunc
 * def p_not_test(s: PyrexScanner):
 *     if s.sy == 'not':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":231
 *         return ExprNodes.NotNode(pos, operand = p_not_test(s))
 *     else:
 *         return p_comparison(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_comparison(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":224
 * #not_test: 'not' not_test | comparison
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_not_test(s: PyrexScanner):
 *     if s.sy == 'not':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_not_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":237
 * #comp_op: '<'|'>'|'=='|'>='|'<='|'<>'|'!='|'in'|'not' 'in'|'is'|'is' 'not'
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comparison(s: PyrexScanner):
 *     n1 = p_starred_expr(s)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comparison(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_n1 = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_v_n2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_comparison", 0);

  /* "Cython/Compiler/Parsing.py":239
 * @cython.cfunc
 * def p_comparison(s: PyrexScanner):
 *     n1 = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *     if s.sy in comparison_ops:
 *         pos = s.position()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n1 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":240
 * def p_comparison(s: PyrexScanner):
 *     n1 = p_starred_expr(s)
 *     if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         op = p_cmp_op(s)
*/
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_comparison_ops, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":241
 *     n1 = p_starred_expr(s)
 *     if s.sy in comparison_ops:
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         op = p_cmp_op(s)
 *         n2 = p_starred_expr(s)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_pos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":242
 *     if s.sy in comparison_ops:
 *         pos = s.position()
 *         op = p_cmp_op(s)             # <<<<<<<<<<<<<<
 *         n2 = p_starred_expr(s)
 *         n1 = ExprNodes.PrimaryCmpNode(pos,
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cmp_op(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_op = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":243
 *         pos = s.position()
 *         op = p_cmp_op(s)
 *         n2 = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.PrimaryCmpNode(pos,
 *             operator = op, operand1 = n1, operand2 = n2)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_n2 = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":244
 *         op = p_cmp_op(s)
 *         n2 = p_starred_expr(s)
 *         n1 = ExprNodes.PrimaryCmpNode(pos,             # <<<<<<<<<<<<<<
 *             operator = op, operand1 = n1, operand2 = n2)
 *         if s.sy in comparison_ops:
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);

    /* "Cython/Compiler/Parsing.py":245
 *         n2 = p_starred_expr(s)
 *         n1 = ExprNodes.PrimaryCmpNode(pos,
 *             operator = op, operand1 = n1, operand2 = n2)             # <<<<<<<<<<<<<<
 *         if s.sy in comparison_ops:
 *             n1.cascade = p_cascaded_cmp(s)
*/
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operator, __pyx_v_op, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 244, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand1, __pyx_v_n1, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 244, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand2, __pyx_v_n2, __pyx_t_5, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 244, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_PrimaryCmpNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":246
 *         n1 = ExprNodes.PrimaryCmpNode(pos,
 *             operator = op, operand1 = n1, operand2 = n2)
 *         if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *             n1.cascade = p_cascaded_cmp(s)
 *     return n1
*/
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_comparison_ops, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 246, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":247
 *             operator = op, operand1 = n1, operand2 = n2)
 *         if s.sy in comparison_ops:
 *             n1.cascade = p_cascaded_cmp(s)             # <<<<<<<<<<<<<<
 *     return n1
 * 
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cascaded_cmp(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_n1, __pyx_mstate_global->__pyx_n_u_cascade, __pyx_t_1) < (0)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":246
 *         n1 = ExprNodes.PrimaryCmpNode(pos,
 *             operator = op, operand1 = n1, operand2 = n2)
 *         if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *             n1.cascade = p_cascaded_cmp(s)
 *     return n1
*/
    }

    /* "Cython/Compiler/Parsing.py":240
 * def p_comparison(s: PyrexScanner):
 *     n1 = p_starred_expr(s)
 *     if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         op = p_cmp_op(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":248
 *         if s.sy in comparison_ops:
 *             n1.cascade = p_cascaded_cmp(s)
 *     return n1             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_n1);
  __pyx_r = __pyx_v_n1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":237
 * #comp_op: '<'|'>'|'=='|'>='|'<='|'<>'|'!='|'in'|'not' 'in'|'is'|'is' 'not'
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comparison(s: PyrexScanner):
 *     n1 = p_starred_expr(s)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_comparison", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n1);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_v_n2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":251
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_test_or_starred_expr", 0);

  /* "Cython/Compiler/Parsing.py":253
 * @cython.cfunc
 * def p_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         return p_starred_expr(s)
 *     else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 253, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":254
 * def p_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
 *         return p_starred_expr(s)             # <<<<<<<<<<<<<<
 *     else:
 *         return p_test(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":253
 * @cython.cfunc
 * def p_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         return p_starred_expr(s)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":256
 *         return p_starred_expr(s)
 *     else:
 *         return p_test(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":251
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_test_or_starred_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":259
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_namedexpr_test_or_starred_expr", 0);

  /* "Cython/Compiler/Parsing.py":261
 * @cython.cfunc
 * def p_namedexpr_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         return p_starred_expr(s)
 *     else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 261, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":262
 * def p_namedexpr_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
 *         return p_starred_expr(s)             # <<<<<<<<<<<<<<
 *     else:
 *         return p_namedexpr_test(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":261
 * @cython.cfunc
 * def p_namedexpr_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         return p_starred_expr(s)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":264
 *         return p_starred_expr(s)
 *     else:
 *         return p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":259
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test_or_starred_expr(s: PyrexScanner):
 *     if s.sy == '*':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_namedexpr_test_or_starred_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":267
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_starred_expr(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_starred;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_starred_expr", 0);

  /* "Cython/Compiler/Parsing.py":269
 * @cython.cfunc
 * def p_starred_expr(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if s.sy == '*':
 *         starred = True
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":270
 * def p_starred_expr(s: PyrexScanner):
 *     pos = s.position()
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         starred = True
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 270, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":271
 *     pos = s.position()
 *     if s.sy == '*':
 *         starred = True             # <<<<<<<<<<<<<<
 *         s.next()
 *     else:
*/
    __pyx_v_starred = 1;

    /* "Cython/Compiler/Parsing.py":272
 *     if s.sy == '*':
 *         starred = True
 *         s.next()             # <<<<<<<<<<<<<<
 *     else:
 *         starred = False
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":270
 * def p_starred_expr(s: PyrexScanner):
 *     pos = s.position()
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         starred = True
 *         s.next()
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":274
 *         s.next()
 *     else:
 *         starred = False             # <<<<<<<<<<<<<<
 *     expr = p_bit_expr(s)
 *     if starred:
*/
  /*else*/ {
    __pyx_v_starred = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":275
 *     else:
 *         starred = False
 *     expr = p_bit_expr(s)             # <<<<<<<<<<<<<<
 *     if starred:
 *         expr = ExprNodes.StarredUnpackingNode(pos, expr)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":276
 *         starred = False
 *     expr = p_bit_expr(s)
 *     if starred:             # <<<<<<<<<<<<<<
 *         expr = ExprNodes.StarredUnpackingNode(pos, expr)
 *     return expr
*/
  if (__pyx_v_starred) {

    /* "Cython/Compiler/Parsing.py":277
 *     expr = p_bit_expr(s)
 *     if starred:
 *         expr = ExprNodes.StarredUnpackingNode(pos, expr)             # <<<<<<<<<<<<<<
 *     return expr
 * 
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_StarredUnpackingNode, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":276
 *         starred = False
 *     expr = p_bit_expr(s)
 *     if starred:             # <<<<<<<<<<<<<<
 *         expr = ExprNodes.StarredUnpackingNode(pos, expr)
 *     return expr
*/
  }

  /* "Cython/Compiler/Parsing.py":278
 *     if starred:
 *         expr = ExprNodes.StarredUnpackingNode(pos, expr)
 *     return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_expr);
  __pyx_r = __pyx_v_expr;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":267
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_starred_expr(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_starred_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":281
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cascaded_cmp(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cascaded_cmp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_v_n2 = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cascaded_cmp", 0);

  /* "Cython/Compiler/Parsing.py":283
 * @cython.cfunc
 * def p_cascaded_cmp(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     op = p_cmp_op(s)
 *     n2 = p_starred_expr(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":284
 * def p_cascaded_cmp(s: PyrexScanner):
 *     pos = s.position()
 *     op = p_cmp_op(s)             # <<<<<<<<<<<<<<
 *     n2 = p_starred_expr(s)
 *     result = ExprNodes.CascadedCmpNode(pos,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cmp_op(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":285
 *     pos = s.position()
 *     op = p_cmp_op(s)
 *     n2 = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *     result = ExprNodes.CascadedCmpNode(pos,
 *         operator = op, operand2 = n2)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n2 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":286
 *     op = p_cmp_op(s)
 *     n2 = p_starred_expr(s)
 *     result = ExprNodes.CascadedCmpNode(pos,             # <<<<<<<<<<<<<<
 *         operator = op, operand2 = n2)
 *     if s.sy in comparison_ops:
*/
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":287
 *     n2 = p_starred_expr(s)
 *     result = ExprNodes.CascadedCmpNode(pos,
 *         operator = op, operand2 = n2)             # <<<<<<<<<<<<<<
 *     if s.sy in comparison_ops:
 *         result.cascade = p_cascaded_cmp(s)
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operator, __pyx_v_op, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 286, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand2, __pyx_v_n2, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 286, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CascadedCmpNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":288
 *     result = ExprNodes.CascadedCmpNode(pos,
 *         operator = op, operand2 = n2)
 *     if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *         result.cascade = p_cascaded_cmp(s)
 *     return result
*/
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_comparison_ops, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 288, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":289
 *         operator = op, operand2 = n2)
 *     if s.sy in comparison_ops:
 *         result.cascade = p_cascaded_cmp(s)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cascaded_cmp(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_result, __pyx_mstate_global->__pyx_n_u_cascade, __pyx_t_1) < (0)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":288
 *     result = ExprNodes.CascadedCmpNode(pos,
 *         operator = op, operand2 = n2)
 *     if s.sy in comparison_ops:             # <<<<<<<<<<<<<<
 *         result.cascade = p_cascaded_cmp(s)
 *     return result
*/
  }

  /* "Cython/Compiler/Parsing.py":290
 *     if s.sy in comparison_ops:
 *         result.cascade = p_cascaded_cmp(s)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":281
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cascaded_cmp(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cascaded_cmp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_v_n2);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":293
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cmp_op(s: PyrexScanner):
 *     if s.sy == 'not':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cmp_op(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cmp_op", 0);

  /* "Cython/Compiler/Parsing.py":295
 * @cython.cfunc
 * def p_cmp_op(s: PyrexScanner):
 *     if s.sy == 'not':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect('in')
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_not, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 295, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":296
 * def p_cmp_op(s: PyrexScanner):
 *     if s.sy == 'not':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.expect('in')
 *         op = 'not_in'
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":297
 *     if s.sy == 'not':
 *         s.next()
 *         s.expect('in')             # <<<<<<<<<<<<<<
 *         op = 'not_in'
 *     elif s.sy == 'is':
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_in};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":298
 *         s.next()
 *         s.expect('in')
 *         op = 'not_in'             # <<<<<<<<<<<<<<
 *     elif s.sy == 'is':
 *         s.next()
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_not_in);
    __pyx_v_op = __pyx_mstate_global->__pyx_n_u_not_in;

    /* "Cython/Compiler/Parsing.py":295
 * @cython.cfunc
 * def p_cmp_op(s: PyrexScanner):
 *     if s.sy == 'not':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect('in')
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":299
 *         s.expect('in')
 *         op = 'not_in'
 *     elif s.sy == 'is':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'not':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_is, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 299, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":300
 *         op = 'not_in'
 *     elif s.sy == 'is':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == 'not':
 *             s.next()
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":301
 *     elif s.sy == 'is':
 *         s.next()
 *         if s.sy == 'not':             # <<<<<<<<<<<<<<
 *             s.next()
 *             op = 'is_not'
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_not, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 301, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":302
 *         s.next()
 *         if s.sy == 'not':
 *             s.next()             # <<<<<<<<<<<<<<
 *             op = 'is_not'
 *         else:
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":303
 *         if s.sy == 'not':
 *             s.next()
 *             op = 'is_not'             # <<<<<<<<<<<<<<
 *         else:
 *             op = 'is'
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_is_not);
      __pyx_v_op = __pyx_mstate_global->__pyx_n_u_is_not;

      /* "Cython/Compiler/Parsing.py":301
 *     elif s.sy == 'is':
 *         s.next()
 *         if s.sy == 'not':             # <<<<<<<<<<<<<<
 *             s.next()
 *             op = 'is_not'
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":305
 *             op = 'is_not'
 *         else:
 *             op = 'is'             # <<<<<<<<<<<<<<
 *     else:
 *         op = s.sy
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_is);
      __pyx_v_op = __pyx_mstate_global->__pyx_n_u_is;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":299
 *         s.expect('in')
 *         op = 'not_in'
 *     elif s.sy == 'is':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'not':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":307
 *             op = 'is'
 *     else:
 *         op = s.sy             # <<<<<<<<<<<<<<
 *         s.next()
 *     if op == '<>':
*/
  /*else*/ {
    __pyx_t_2 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_op = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":308
 *     else:
 *         op = s.sy
 *         s.next()             # <<<<<<<<<<<<<<
 *     if op == '<>':
 *         op = '!='
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":309
 *         op = s.sy
 *         s.next()
 *     if op == '<>':             # <<<<<<<<<<<<<<
 *         op = '!='
 *     return op
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 309, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":310
 *         s.next()
 *     if op == '<>':
 *         op = '!='             # <<<<<<<<<<<<<<
 *     return op
 * 
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__8);
    __Pyx_DECREF_SET(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__8);

    /* "Cython/Compiler/Parsing.py":309
 *         op = s.sy
 *         s.next()
 *     if op == '<>':             # <<<<<<<<<<<<<<
 *         op = '!='
 *     return op
*/
  }

  /* "Cython/Compiler/Parsing.py":311
 *     if op == '<>':
 *         op = '!='
 *     return op             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_op);
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":293
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cmp_op(s: PyrexScanner):
 *     if s.sy == 'not':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cmp_op", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":322
 * #expr: xor_expr ('|' xor_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_bit_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('|',), p_xor_expr)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_bit_expr", 0);

  /* "Cython/Compiler/Parsing.py":324
 * @cython.cfunc
 * def p_bit_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('|',), p_xor_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[0], __pyx_f_6Cython_8Compiler_7Parsing_p_xor_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":322
 * #expr: xor_expr ('|' xor_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_bit_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('|',), p_xor_expr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_bit_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":329
 * #xor_expr: and_expr ('^' and_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_xor_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('^',), p_and_expr)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_xor_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_xor_expr", 0);

  /* "Cython/Compiler/Parsing.py":331
 * @cython.cfunc
 * def p_xor_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('^',), p_and_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[1], __pyx_f_6Cython_8Compiler_7Parsing_p_and_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":329
 * #xor_expr: and_expr ('^' and_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_xor_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('^',), p_and_expr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_xor_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":336
 * #and_expr: shift_expr ('&' shift_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_and_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('&',), p_shift_expr)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_and_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_and_expr", 0);

  /* "Cython/Compiler/Parsing.py":338
 * @cython.cfunc
 * def p_and_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('&',), p_shift_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[2], __pyx_f_6Cython_8Compiler_7Parsing_p_shift_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":336
 * #and_expr: shift_expr ('&' shift_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_and_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('&',), p_shift_expr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_and_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":343
 * #shift_expr: arith_expr (('<<'|'>>') arith_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_shift_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('<<', '>>'), p_arith_expr)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_shift_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_shift_expr", 0);

  /* "Cython/Compiler/Parsing.py":345
 * @cython.cfunc
 * def p_shift_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('<<', '>>'), p_arith_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[3], __pyx_f_6Cython_8Compiler_7Parsing_p_arith_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":343
 * #shift_expr: arith_expr (('<<'|'>>') arith_expr)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_shift_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('<<', '>>'), p_arith_expr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_shift_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":350
 * #arith_expr: term (('+'|'-') term)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_arith_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('+', '-'), p_term)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_arith_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_arith_expr", 0);

  /* "Cython/Compiler/Parsing.py":352
 * @cython.cfunc
 * def p_arith_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('+', '-'), p_term)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[4], __pyx_f_6Cython_8Compiler_7Parsing_p_term); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":350
 * #arith_expr: term (('+'|'-') term)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_arith_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('+', '-'), p_term)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_arith_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":357
 * #term: factor (('*'|'@'|'/'|'%'|'//') factor)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_term(s: PyrexScanner):
 *     return p_binop_expr(s, ('*', '@', '/', '%', '//'), p_factor)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_term(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_term", 0);

  /* "Cython/Compiler/Parsing.py":359
 * @cython.cfunc
 * def p_term(s: PyrexScanner):
 *     return p_binop_expr(s, ('*', '@', '/', '%', '//'), p_factor)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[5], __pyx_f_6Cython_8Compiler_7Parsing_p_factor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":357
 * #term: factor (('*'|'@'|'/'|'%'|'//') factor)*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_term(s: PyrexScanner):
 *     return p_binop_expr(s, ('*', '@', '/', '%', '//'), p_factor)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_term", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":364
 * #factor: ('+'|'-'|'~'|'&'|typecast|sizeof) factor | power
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_factor(s: PyrexScanner):
 *     # little indirection for C-ification purposes
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_factor(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_factor", 0);

  /* "Cython/Compiler/Parsing.py":367
 * def p_factor(s: PyrexScanner):
 *     # little indirection for C-ification purposes
 *     return _p_factor(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing__p_factor(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":364
 * #factor: ('+'|'-'|'~'|'&'|typecast|sizeof) factor | power
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_factor(s: PyrexScanner):
 *     # little indirection for C-ification purposes
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":370
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _p_factor(s: PyrexScanner):
 *     sy = s.sy
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__p_factor(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_p_factor", 0);

  /* "Cython/Compiler/Parsing.py":372
 * @cython.cfunc
 * def _p_factor(s: PyrexScanner):
 *     sy = s.sy             # <<<<<<<<<<<<<<
 *     if sy in ('+', '-', '~'):
 *         op = s.sy
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_sy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":373
 * def _p_factor(s: PyrexScanner):
 *     sy = s.sy
 *     if sy in ('+', '-', '~'):             # <<<<<<<<<<<<<<
 *         op = s.sy
 *         pos = s.position()
*/
  __Pyx_INCREF(__pyx_v_sy);
  __pyx_t_2 = __pyx_v_sy;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__14, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 373, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 373, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__19, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 373, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_3;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":374
 *     sy = s.sy
 *     if sy in ('+', '-', '~'):
 *         op = s.sy             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
    __pyx_t_1 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_op = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":375
 *     if sy in ('+', '-', '~'):
 *         op = s.sy
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_pos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":376
 *         op = s.sy
 *         pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
 *     elif not s.in_python_file:
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":377
 *         pos = s.position()
 *         s.next()
 *         return ExprNodes.unop_node(pos, op, p_factor(s))             # <<<<<<<<<<<<<<
 *     elif not s.in_python_file:
 *         if sy == '&':
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_factor(__pyx_v_s); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_pos, __pyx_v_op, __pyx_t_7};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unop_node, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":373
 * def _p_factor(s: PyrexScanner):
 *     sy = s.sy
 *     if sy in ('+', '-', '~'):             # <<<<<<<<<<<<<<
 *         op = s.sy
 *         pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":378
 *         s.next()
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
 *     elif not s.in_python_file:             # <<<<<<<<<<<<<<
 *         if sy == '&':
 *             pos = s.position()
*/
  __pyx_t_4 = (!__pyx_v_s->in_python_file);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":379
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
 *     elif not s.in_python_file:
 *         if sy == '&':             # <<<<<<<<<<<<<<
 *             pos = s.position()
 *             s.next()
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__11, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 379, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":380
 *     elif not s.in_python_file:
 *         if sy == '&':
 *             pos = s.position()             # <<<<<<<<<<<<<<
 *             s.next()
 *             arg = p_factor(s)
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_pos = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":381
 *         if sy == '&':
 *             pos = s.position()
 *             s.next()             # <<<<<<<<<<<<<<
 *             arg = p_factor(s)
 *             return ExprNodes.AmpersandNode(pos, operand = arg)
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":382
 *             pos = s.position()
 *             s.next()
 *             arg = p_factor(s)             # <<<<<<<<<<<<<<
 *             return ExprNodes.AmpersandNode(pos, operand = arg)
 *         elif sy == "<":
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_factor(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_arg = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":383
 *             s.next()
 *             arg = p_factor(s)
 *             return ExprNodes.AmpersandNode(pos, operand = arg)             # <<<<<<<<<<<<<<
 *         elif sy == "<":
 *             return p_typecast(s)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_v_pos};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 383, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_arg, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 383, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AmpersandNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":379
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
 *     elif not s.in_python_file:
 *         if sy == '&':             # <<<<<<<<<<<<<<
 *             pos = s.position()
 *             s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":384
 *             arg = p_factor(s)
 *             return ExprNodes.AmpersandNode(pos, operand = arg)
 *         elif sy == "<":             # <<<<<<<<<<<<<<
 *             return p_typecast(s)
 *         elif sy == 'IDENT' and s.systring == "sizeof":
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__20, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 384, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":385
 *             return ExprNodes.AmpersandNode(pos, operand = arg)
 *         elif sy == "<":
 *             return p_typecast(s)             # <<<<<<<<<<<<<<
 *         elif sy == 'IDENT' and s.systring == "sizeof":
 *             return p_sizeof(s)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_typecast(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":384
 *             arg = p_factor(s)
 *             return ExprNodes.AmpersandNode(pos, operand = arg)
 *         elif sy == "<":             # <<<<<<<<<<<<<<
 *             return p_typecast(s)
 *         elif sy == 'IDENT' and s.systring == "sizeof":
*/
    }

    /* "Cython/Compiler/Parsing.py":386
 *         elif sy == "<":
 *             return p_typecast(s)
 *         elif sy == 'IDENT' and s.systring == "sizeof":             # <<<<<<<<<<<<<<
 *             return p_sizeof(s)
 *     return p_power(s)
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 386, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_sizeof, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 386, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_3;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":387
 *             return p_typecast(s)
 *         elif sy == 'IDENT' and s.systring == "sizeof":
 *             return p_sizeof(s)             # <<<<<<<<<<<<<<
 *     return p_power(s)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_sizeof(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":386
 *         elif sy == "<":
 *             return p_typecast(s)
 *         elif sy == 'IDENT' and s.systring == "sizeof":             # <<<<<<<<<<<<<<
 *             return p_sizeof(s)
 *     return p_power(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":378
 *         s.next()
 *         return ExprNodes.unop_node(pos, op, p_factor(s))
 *     elif not s.in_python_file:             # <<<<<<<<<<<<<<
 *         if sy == '&':
 *             pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":388
 *         elif sy == 'IDENT' and s.systring == "sizeof":
 *             return p_sizeof(s)
 *     return p_power(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_power(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":370
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _p_factor(s: PyrexScanner):
 *     sy = s.sy
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing._p_factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":391
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_typecast(s: PyrexScanner):
 *     # s.sy == "<"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_typecast(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_base_type = NULL;
  int __pyx_v_is_memslice;
  int __pyx_v_is_other_unnamed_type;
  PyObject *__pyx_v_declarator = NULL;
  int __pyx_v_typecheck;
  PyObject *__pyx_v_operand = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_typecast", 0);

  /* "Cython/Compiler/Parsing.py":394
 * def p_typecast(s: PyrexScanner):
 *     # s.sy == "<"
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     base_type = p_c_base_type(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":395
 *     # s.sy == "<"
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     base_type = p_c_base_type(s)
 *     is_memslice = isinstance(base_type, Nodes.MemoryViewSliceTypeNode)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":396
 *     pos = s.position()
 *     s.next()
 *     base_type = p_c_base_type(s)             # <<<<<<<<<<<<<<
 *     is_memslice = isinstance(base_type, Nodes.MemoryViewSliceTypeNode)
 *     is_other_unnamed_type = isinstance(base_type, (
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_base_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":397
 *     s.next()
 *     base_type = p_c_base_type(s)
 *     is_memslice = isinstance(base_type, Nodes.MemoryViewSliceTypeNode)             # <<<<<<<<<<<<<<
 *     is_other_unnamed_type = isinstance(base_type, (
 *         Nodes.TemplatedTypeNode,
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_MemoryViewSliceTypeNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_base_type, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_is_memslice = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":399
 *     is_memslice = isinstance(base_type, Nodes.MemoryViewSliceTypeNode)
 *     is_other_unnamed_type = isinstance(base_type, (
 *         Nodes.TemplatedTypeNode,             # <<<<<<<<<<<<<<
 *         Nodes.CConstOrVolatileTypeNode,
 *         Nodes.CTupleBaseTypeNode,
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_TemplatedTypeNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "Cython/Compiler/Parsing.py":400
 *     is_other_unnamed_type = isinstance(base_type, (
 *         Nodes.TemplatedTypeNode,
 *         Nodes.CConstOrVolatileTypeNode,             # <<<<<<<<<<<<<<
 *         Nodes.CTupleBaseTypeNode,
 *     ))
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CConstOrVolatileTypeNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":401
 *         Nodes.TemplatedTypeNode,
 *         Nodes.CConstOrVolatileTypeNode,
 *         Nodes.CTupleBaseTypeNode,             # <<<<<<<<<<<<<<
 *     ))
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CTupleBaseTypeNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Compiler/Parsing.py":399
 *     is_memslice = isinstance(base_type, Nodes.MemoryViewSliceTypeNode)
 *     is_other_unnamed_type = isinstance(base_type, (
 *         Nodes.TemplatedTypeNode,             # <<<<<<<<<<<<<<
 *         Nodes.CConstOrVolatileTypeNode,
 *         Nodes.CTupleBaseTypeNode,
*/
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_base_type, __pyx_t_1); 
  if (!__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "Cython/Compiler/Parsing.py":400
 *     is_other_unnamed_type = isinstance(base_type, (
 *         Nodes.TemplatedTypeNode,
 *         Nodes.CConstOrVolatileTypeNode,             # <<<<<<<<<<<<<<
 *         Nodes.CTupleBaseTypeNode,
 *     ))
*/
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_base_type, __pyx_t_2); 
  if (!__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L3_bool_binop_done;
  }

  /* "Cython/Compiler/Parsing.py":401
 *         Nodes.TemplatedTypeNode,
 *         Nodes.CConstOrVolatileTypeNode,
 *         Nodes.CTupleBaseTypeNode,             # <<<<<<<<<<<<<<
 *     ))
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:
*/
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_base_type, __pyx_t_5); 
  __pyx_t_4 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_is_other_unnamed_type = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":403
 *         Nodes.CTupleBaseTypeNode,
 *     ))
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:             # <<<<<<<<<<<<<<
 *         s.error("Unknown type")
 *     declarator = p_c_declarator(s, empty=True)
*/
  if (!__pyx_v_is_memslice) {
  } else {
    __pyx_t_6 = __pyx_v_is_memslice;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_6 = __pyx_v_is_other_unnamed_type;
  __pyx_L9_bool_binop_done:;
  __pyx_t_7 = (!__pyx_t_6);
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_base_type, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":404
 *     ))
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:
 *         s.error("Unknown type")             # <<<<<<<<<<<<<<
 *     declarator = p_c_declarator(s, empty=True)
 *     if s.sy == '?':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Unknown_type};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":403
 *         Nodes.CTupleBaseTypeNode,
 *     ))
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:             # <<<<<<<<<<<<<<
 *         s.error("Unknown type")
 *     declarator = p_c_declarator(s, empty=True)
*/
  }

  /* "Cython/Compiler/Parsing.py":405
 *     if not (is_memslice or is_other_unnamed_type) and base_type.name is None:
 *         s.error("Unknown type")
 *     declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *     if s.sy == '?':
 *         s.next()
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 405, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_declarator = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":406
 *         s.error("Unknown type")
 *     declarator = p_c_declarator(s, empty=True)
 *     if s.sy == '?':             # <<<<<<<<<<<<<<
 *         s.next()
 *         typecheck = True
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__21, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 406, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":407
 *     declarator = p_c_declarator(s, empty=True)
 *     if s.sy == '?':
 *         s.next()             # <<<<<<<<<<<<<<
 *         typecheck = True
 *     else:
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":408
 *     if s.sy == '?':
 *         s.next()
 *         typecheck = True             # <<<<<<<<<<<<<<
 *     else:
 *         typecheck = False
*/
    __pyx_v_typecheck = 1;

    /* "Cython/Compiler/Parsing.py":406
 *         s.error("Unknown type")
 *     declarator = p_c_declarator(s, empty=True)
 *     if s.sy == '?':             # <<<<<<<<<<<<<<
 *         s.next()
 *         typecheck = True
*/
    goto __pyx_L11;
  }

  /* "Cython/Compiler/Parsing.py":410
 *         typecheck = True
 *     else:
 *         typecheck = False             # <<<<<<<<<<<<<<
 *     s.expect(">")
 *     operand = p_factor(s)
*/
  /*else*/ {
    __pyx_v_typecheck = 0;
  }
  __pyx_L11:;

  /* "Cython/Compiler/Parsing.py":411
 *     else:
 *         typecheck = False
 *     s.expect(">")             # <<<<<<<<<<<<<<
 *     operand = p_factor(s)
 *     if is_memslice:
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__22};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":412
 *         typecheck = False
 *     s.expect(">")
 *     operand = p_factor(s)             # <<<<<<<<<<<<<<
 *     if is_memslice:
 *         return ExprNodes.CythonArrayNode(pos, base_type_node=base_type, operand=operand)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_factor(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_operand = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":413
 *     s.expect(">")
 *     operand = p_factor(s)
 *     if is_memslice:             # <<<<<<<<<<<<<<
 *         return ExprNodes.CythonArrayNode(pos, base_type_node=base_type, operand=operand)
 * 
*/
  if (__pyx_v_is_memslice) {

    /* "Cython/Compiler/Parsing.py":414
 *     operand = p_factor(s)
 *     if is_memslice:
 *         return ExprNodes.CythonArrayNode(pos, base_type_node=base_type, operand=operand)             # <<<<<<<<<<<<<<
 * 
 *     return ExprNodes.TypecastNode(pos,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type_node, __pyx_v_base_type, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 414, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_operand, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 414, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CythonArrayNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":413
 *     s.expect(">")
 *     operand = p_factor(s)
 *     if is_memslice:             # <<<<<<<<<<<<<<
 *         return ExprNodes.CythonArrayNode(pos, base_type_node=base_type, operand=operand)
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":416
 *         return ExprNodes.CythonArrayNode(pos, base_type_node=base_type, operand=operand)
 * 
 *     return ExprNodes.TypecastNode(pos,             # <<<<<<<<<<<<<<
 *         base_type = base_type,
 *         declarator = declarator,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_8);

  /* "Cython/Compiler/Parsing.py":420
 *         declarator = declarator,
 *         operand = operand,
 *         typecheck = typecheck)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_typecheck); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_operand, __pyx_t_2, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typecheck, __pyx_t_5, __pyx_t_2, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TypecastNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":391
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_typecast(s: PyrexScanner):
 *     # s.sy == "<"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_typecast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_operand);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":423
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sizeof(s: PyrexScanner):
 *     # s.sy == ident "sizeof"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_operand = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_sizeof", 0);

  /* "Cython/Compiler/Parsing.py":426
 * def p_sizeof(s: PyrexScanner):
 *     # s.sy == ident "sizeof"
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     s.expect('(')
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":427
 *     # s.sy == ident "sizeof"
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     s.expect('(')
 *     # Here we decide if we are looking at an expression or type
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":428
 *     pos = s.position()
 *     s.next()
 *     s.expect('(')             # <<<<<<<<<<<<<<
 *     # Here we decide if we are looking at an expression or type
 *     # If it is actually a type, but parsable as an expression,
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__23};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":432
 *     # If it is actually a type, but parsable as an expression,
 *     # we treat it as an expression here.
 *     if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *         operand = p_test(s)
 *         node = ExprNodes.SizeofVarNode(pos, operand = operand)
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(__pyx_v_s); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 432, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":433
 *     # we treat it as an expression here.
 *     if looking_at_expr(s):
 *         operand = p_test(s)             # <<<<<<<<<<<<<<
 *         node = ExprNodes.SizeofVarNode(pos, operand = operand)
 *     else:
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_operand = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":434
 *     if looking_at_expr(s):
 *         operand = p_test(s)
 *         node = ExprNodes.SizeofVarNode(pos, operand = operand)             # <<<<<<<<<<<<<<
 *     else:
 *         base_type = p_c_base_type(s)
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_operand, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 434, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SizeofVarNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":432
 *     # If it is actually a type, but parsable as an expression,
 *     # we treat it as an expression here.
 *     if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *         operand = p_test(s)
 *         node = ExprNodes.SizeofVarNode(pos, operand = operand)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":436
 *         node = ExprNodes.SizeofVarNode(pos, operand = operand)
 *     else:
 *         base_type = p_c_base_type(s)             # <<<<<<<<<<<<<<
 *         declarator = p_c_declarator(s, empty=True)
 *         node = ExprNodes.SizeofTypeNode(pos,
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 436, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_base_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":437
 *     else:
 *         base_type = p_c_base_type(s)
 *         declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *         node = ExprNodes.SizeofTypeNode(pos,
 *             base_type = base_type, declarator = declarator)
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, ((PyObject *)__pyx_v_s)};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 437, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_declarator = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":438
 *         base_type = p_c_base_type(s)
 *         declarator = p_c_declarator(s, empty=True)
 *         node = ExprNodes.SizeofTypeNode(pos,             # <<<<<<<<<<<<<<
 *             base_type = base_type, declarator = declarator)
 *     s.expect(')')
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":439
 *         declarator = p_c_declarator(s, empty=True)
 *         node = ExprNodes.SizeofTypeNode(pos,
 *             base_type = base_type, declarator = declarator)             # <<<<<<<<<<<<<<
 *     s.expect(')')
 *     return node
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 438, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 438, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SizeofTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":440
 *         node = ExprNodes.SizeofTypeNode(pos,
 *             base_type = base_type, declarator = declarator)
 *     s.expect(')')             # <<<<<<<<<<<<<<
 *     return node
 * 
*/
  __pyx_t_6 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":441
 *             base_type = base_type, declarator = declarator)
 *     s.expect(')')
 *     return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":423
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sizeof(s: PyrexScanner):
 *     # s.sy == ident "sizeof"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_operand);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":444
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_yield_expression(s: PyrexScanner, statement_terminators: frozenset = statement_terminators):
 *     # s.sy == "yield"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_yield_expression *__pyx_optional_args) {
  PyObject *__pyx_v_statement_terminators = __pyx_mstate_global->__pyx_k__25;
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_is_yield_from;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_yield_expression", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_statement_terminators = __pyx_optional_args->statement_terminators;
    }
  }

  /* "Cython/Compiler/Parsing.py":447
 * def p_yield_expression(s: PyrexScanner, statement_terminators: frozenset = statement_terminators):
 *     # s.sy == "yield"
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     is_yield_from = False
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":448
 *     # s.sy == "yield"
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     is_yield_from = False
 *     if s.sy == 'from':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":449
 *     pos = s.position()
 *     s.next()
 *     is_yield_from = False             # <<<<<<<<<<<<<<
 *     if s.sy == 'from':
 *         is_yield_from = True
*/
  __pyx_v_is_yield_from = 0;

  /* "Cython/Compiler/Parsing.py":450
 *     s.next()
 *     is_yield_from = False
 *     if s.sy == 'from':             # <<<<<<<<<<<<<<
 *         is_yield_from = True
 *         s.next()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_from, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 450, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":451
 *     is_yield_from = False
 *     if s.sy == 'from':
 *         is_yield_from = True             # <<<<<<<<<<<<<<
 *         s.next()
 *     if s.sy != ')' and s.sy not in statement_terminators:
*/
    __pyx_v_is_yield_from = 1;

    /* "Cython/Compiler/Parsing.py":452
 *     if s.sy == 'from':
 *         is_yield_from = True
 *         s.next()             # <<<<<<<<<<<<<<
 *     if s.sy != ')' and s.sy not in statement_terminators:
 *         # "yield from" does not support implicit tuples, but "yield" does ("yield 1,2")
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":450
 *     s.next()
 *     is_yield_from = False
 *     if s.sy == 'from':             # <<<<<<<<<<<<<<
 *         is_yield_from = True
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":453
 *         is_yield_from = True
 *         s.next()
 *     if s.sy != ')' and s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         # "yield from" does not support implicit tuples, but "yield" does ("yield 1,2")
 *         arg = p_test(s) if is_yield_from else p_testlist(s)
*/
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 453, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_statement_terminators, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 453, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":455
 *     if s.sy != ')' and s.sy not in statement_terminators:
 *         # "yield from" does not support implicit tuples, but "yield" does ("yield 1,2")
 *         arg = p_test(s) if is_yield_from else p_testlist(s)             # <<<<<<<<<<<<<<
 *     else:
 *         if is_yield_from:
*/
    if (__pyx_v_is_yield_from) {
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __pyx_t_2;
      __pyx_t_2 = 0;
    } else {
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __pyx_t_2;
      __pyx_t_2 = 0;
    }
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":453
 *         is_yield_from = True
 *         s.next()
 *     if s.sy != ')' and s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         # "yield from" does not support implicit tuples, but "yield" does ("yield 1,2")
 *         arg = p_test(s) if is_yield_from else p_testlist(s)
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":457
 *         arg = p_test(s) if is_yield_from else p_testlist(s)
 *     else:
 *         if is_yield_from:             # <<<<<<<<<<<<<<
 *             s.error("'yield from' requires a source argument",
 *                     pos=pos, fatal=False)
*/
  /*else*/ {
    if (__pyx_v_is_yield_from) {

      /* "Cython/Compiler/Parsing.py":458
 *     else:
 *         if is_yield_from:
 *             s.error("'yield from' requires a source argument",             # <<<<<<<<<<<<<<
 *                     pos=pos, fatal=False)
 *         arg = None
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);

      /* "Cython/Compiler/Parsing.py":459
 *         if is_yield_from:
 *             s.error("'yield from' requires a source argument",
 *                     pos=pos, fatal=False)             # <<<<<<<<<<<<<<
 *         arg = None
 *     if is_yield_from:
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_yield_from_requires_a_source_ar};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 458, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 458, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":457
 *         arg = p_test(s) if is_yield_from else p_testlist(s)
 *     else:
 *         if is_yield_from:             # <<<<<<<<<<<<<<
 *             s.error("'yield from' requires a source argument",
 *                     pos=pos, fatal=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":460
 *             s.error("'yield from' requires a source argument",
 *                     pos=pos, fatal=False)
 *         arg = None             # <<<<<<<<<<<<<<
 *     if is_yield_from:
 *         return ExprNodes.YieldFromExprNode(pos, arg=arg)
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_arg = Py_None;
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":461
 *                     pos=pos, fatal=False)
 *         arg = None
 *     if is_yield_from:             # <<<<<<<<<<<<<<
 *         return ExprNodes.YieldFromExprNode(pos, arg=arg)
 *     else:
*/
  if (__pyx_v_is_yield_from) {

    /* "Cython/Compiler/Parsing.py":462
 *         arg = None
 *     if is_yield_from:
 *         return ExprNodes.YieldFromExprNode(pos, arg=arg)             # <<<<<<<<<<<<<<
 *     else:
 *         return ExprNodes.YieldExprNode(pos, arg=arg)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_v_arg, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 462, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_YieldFromExprNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":461
 *                     pos=pos, fatal=False)
 *         arg = None
 *     if is_yield_from:             # <<<<<<<<<<<<<<
 *         return ExprNodes.YieldFromExprNode(pos, arg=arg)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":464
 *         return ExprNodes.YieldFromExprNode(pos, arg=arg)
 *     else:
 *         return ExprNodes.YieldExprNode(pos, arg=arg)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 464, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_v_arg, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 464, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_YieldExprNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":444
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_yield_expression(s: PyrexScanner, statement_terminators: frozenset = statement_terminators):
 *     # s.sy == "yield"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_yield_expression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":467
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_yield_statement(s: PyrexScanner):
 *     # s.sy == "yield"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_yield_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_yield_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_yield_statement", 0);

  /* "Cython/Compiler/Parsing.py":470
 * def p_yield_statement(s: PyrexScanner):
 *     # s.sy == "yield"
 *     yield_expr = p_yield_expression(s)             # <<<<<<<<<<<<<<
 *     return Nodes.ExprStatNode(yield_expr.pos, expr=yield_expr)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_yield_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":471
 *     # s.sy == "yield"
 *     yield_expr = p_yield_expression(s)
 *     return Nodes.ExprStatNode(yield_expr.pos, expr=yield_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_yield_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_yield_expr, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 471, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExprStatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":467
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_yield_statement(s: PyrexScanner):
 *     # s.sy == "yield"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_yield_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_yield_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":474
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_async_statement(s: PyrexScanner, ctx, decorators):
 *     # s.sy >> 'async' ...
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_async_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, PyObject *__pyx_v_decorators) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_statement __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_with_items __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_async_statement", 0);

  /* "Cython/Compiler/Parsing.py":477
 * def p_async_statement(s: PyrexScanner, ctx, decorators):
 *     # s.sy >> 'async' ...
 *     if s.sy == 'def':             # <<<<<<<<<<<<<<
 *         # 'async def' statements aren't allowed in pxd files
 *         if 'pxd' in ctx.level:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_def, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 477, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":479
 *     if s.sy == 'def':
 *         # 'async def' statements aren't allowed in pxd files
 *         if 'pxd' in ctx.level:             # <<<<<<<<<<<<<<
 *             s.error('def statement not allowed here')
 *         s.level = ctx.level
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_pxd, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":480
 *         # 'async def' statements aren't allowed in pxd files
 *         if 'pxd' in ctx.level:
 *             s.error('def statement not allowed here')             # <<<<<<<<<<<<<<
 *         s.level = ctx.level
 *         return p_def_statement(s, decorators, is_async_def=True)
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_def_statement_not_allowed_here};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 480, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":479
 *     if s.sy == 'def':
 *         # 'async def' statements aren't allowed in pxd files
 *         if 'pxd' in ctx.level:             # <<<<<<<<<<<<<<
 *             s.error('def statement not allowed here')
 *         s.level = ctx.level
*/
    }

    /* "Cython/Compiler/Parsing.py":481
 *         if 'pxd' in ctx.level:
 *             s.error('def statement not allowed here')
 *         s.level = ctx.level             # <<<<<<<<<<<<<<
 *         return p_def_statement(s, decorators, is_async_def=True)
 *     elif decorators:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 481, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_s->__pyx_base.level);
    __Pyx_DECREF(__pyx_v_s->__pyx_base.level);
    __pyx_v_s->__pyx_base.level = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":482
 *             s.error('def statement not allowed here')
 *         s.level = ctx.level
 *         return p_def_statement(s, decorators, is_async_def=True)             # <<<<<<<<<<<<<<
 *     elif decorators:
 *         s.error("Decorators can only be followed by functions or classes")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_decorators;
    __Pyx_INCREF(__pyx_t_2);
    if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_2))) __PYX_ERR(0, 482, __pyx_L1_error)
    __pyx_t_5.__pyx_n = 2;
    __pyx_t_5.decorators = ((PyObject*)__pyx_t_2);
    __pyx_t_5.is_async_def = 1;
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_def_statement(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":477
 * def p_async_statement(s: PyrexScanner, ctx, decorators):
 *     # s.sy >> 'async' ...
 *     if s.sy == 'def':             # <<<<<<<<<<<<<<
 *         # 'async def' statements aren't allowed in pxd files
 *         if 'pxd' in ctx.level:
*/
  }

  /* "Cython/Compiler/Parsing.py":483
 *         s.level = ctx.level
 *         return p_def_statement(s, decorators, is_async_def=True)
 *     elif decorators:             # <<<<<<<<<<<<<<
 *         s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'for':
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_decorators); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 483, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":484
 *         return p_def_statement(s, decorators, is_async_def=True)
 *     elif decorators:
 *         s.error("Decorators can only be followed by functions or classes")             # <<<<<<<<<<<<<<
 *     elif s.sy == 'for':
 *         return p_for_statement(s, is_async=True)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Decorators_can_only_be_followed};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":483
 *         s.level = ctx.level
 *         return p_def_statement(s, decorators, is_async_def=True)
 *     elif decorators:             # <<<<<<<<<<<<<<
 *         s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'for':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":485
 *     elif decorators:
 *         s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'for':             # <<<<<<<<<<<<<<
 *         return p_for_statement(s, is_async=True)
 *     elif s.sy == 'with':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 485, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":486
 *         s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'for':
 *         return p_for_statement(s, is_async=True)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'with':
 *         s.next()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.is_async = 1;
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_statement(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":485
 *     elif decorators:
 *         s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'for':             # <<<<<<<<<<<<<<
 *         return p_for_statement(s, is_async=True)
 *     elif s.sy == 'with':
*/
  }

  /* "Cython/Compiler/Parsing.py":487
 *     elif s.sy == 'for':
 *         return p_for_statement(s, is_async=True)
 *     elif s.sy == 'with':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_with_items(s, is_async=True)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_with, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 487, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":488
 *         return p_for_statement(s, is_async=True)
 *     elif s.sy == 'with':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return p_with_items(s, is_async=True)
 *     else:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":489
 *     elif s.sy == 'with':
 *         s.next()
 *         return p_with_items(s, is_async=True)             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("expected one of 'def', 'for', 'with' after 'async'")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.is_async = 1;
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_items(__pyx_v_s, &__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":487
 *     elif s.sy == 'for':
 *         return p_for_statement(s, is_async=True)
 *     elif s.sy == 'with':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_with_items(s, is_async=True)
*/
  }

  /* "Cython/Compiler/Parsing.py":491
 *         return p_with_items(s, is_async=True)
 *     else:
 *         s.error("expected one of 'def', 'for', 'with' after 'async'")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_expected_one_of_def_for_with_aft};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":474
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_async_statement(s: PyrexScanner, ctx, decorators):
 *     # s.sy >> 'async' ...
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_async_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":497
 * #atom_expr: ['await'] atom trailer*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_power(s: PyrexScanner):
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_power(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_await_pos = NULL;
  PyObject *__pyx_v_n1 = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_n2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_power", 0);

  /* "Cython/Compiler/Parsing.py":499
 * @cython.cfunc
 * def p_power(s: PyrexScanner):
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':             # <<<<<<<<<<<<<<
 *         return p_new_expr(s)
 *     await_pos = None
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_new, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 499, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_peek, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":500
 * def p_power(s: PyrexScanner):
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':
 *         return p_new_expr(s)             # <<<<<<<<<<<<<<
 *     await_pos = None
 *     if s.sy == 'await':
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_new_expr(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":499
 * @cython.cfunc
 * def p_power(s: PyrexScanner):
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':             # <<<<<<<<<<<<<<
 *         return p_new_expr(s)
 *     await_pos = None
*/
  }

  /* "Cython/Compiler/Parsing.py":501
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':
 *         return p_new_expr(s)
 *     await_pos = None             # <<<<<<<<<<<<<<
 *     if s.sy == 'await':
 *         await_pos = s.position()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_await_pos = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":502
 *         return p_new_expr(s)
 *     await_pos = None
 *     if s.sy == 'await':             # <<<<<<<<<<<<<<
 *         await_pos = s.position()
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_await, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 502, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":503
 *     await_pos = None
 *     if s.sy == 'await':
 *         await_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *     n1 = p_atom(s)
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_await_pos, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":504
 *     if s.sy == 'await':
 *         await_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *     n1 = p_atom(s)
 *     while s.sy in ('(', '[', '.'):
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":502
 *         return p_new_expr(s)
 *     await_pos = None
 *     if s.sy == 'await':             # <<<<<<<<<<<<<<
 *         await_pos = s.position()
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":505
 *         await_pos = s.position()
 *         s.next()
 *     n1 = p_atom(s)             # <<<<<<<<<<<<<<
 *     while s.sy in ('(', '[', '.'):
 *         n1 = p_trailer(s, n1)
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_n1 = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":506
 *         s.next()
 *     n1 = p_atom(s)
 *     while s.sy in ('(', '[', '.'):             # <<<<<<<<<<<<<<
 *         n1 = p_trailer(s, n1)
 *     if await_pos:
*/
  while (1) {
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_6 = __pyx_v_s->sy;
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __pyx_t_1;
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":507
 *     n1 = p_atom(s)
 *     while s.sy in ('(', '[', '.'):
 *         n1 = p_trailer(s, n1)             # <<<<<<<<<<<<<<
 *     if await_pos:
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
*/
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_trailer(__pyx_v_s, __pyx_v_n1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_4);
    __pyx_t_4 = 0;
  }

  /* "Cython/Compiler/Parsing.py":508
 *     while s.sy in ('(', '[', '.'):
 *         n1 = p_trailer(s, n1)
 *     if await_pos:             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
 *     if s.sy == '**':
*/
  if (__pyx_v_await_pos == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_await_pos);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 508, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":509
 *         n1 = p_trailer(s, n1)
 *     if await_pos:
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)             # <<<<<<<<<<<<<<
 *     if s.sy == '**':
 *         pos = s.position()
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_await_pos};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 509, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_v_n1, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 509, __pyx_L1_error)
      __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AwaitExprNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 509, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":508
 *     while s.sy in ('(', '[', '.'):
 *         n1 = p_trailer(s, n1)
 *     if await_pos:             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
 *     if s.sy == '**':
*/
  }

  /* "Cython/Compiler/Parsing.py":510
 *     if await_pos:
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
 *     if s.sy == '**':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 510, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":511
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
 *     if s.sy == '**':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         n2 = p_factor(s)
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_pos = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":512
 *     if s.sy == '**':
 *         pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         n2 = p_factor(s)
 *         n1 = ExprNodes.binop_node(pos, '**', n1, n2)
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":513
 *         pos = s.position()
 *         s.next()
 *         n2 = p_factor(s)             # <<<<<<<<<<<<<<
 *         n1 = ExprNodes.binop_node(pos, '**', n1, n2)
 *     return n1
*/
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_factor(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_n2 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":514
 *         s.next()
 *         n2 = p_factor(s)
 *         n1 = ExprNodes.binop_node(pos, '**', n1, n2)             # <<<<<<<<<<<<<<
 *     return n1
 * 
*/
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u__28, __pyx_v_n1, __pyx_v_n2};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF_SET(__pyx_v_n1, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":510
 *     if await_pos:
 *         n1 = ExprNodes.AwaitExprNode(await_pos, arg=n1)
 *     if s.sy == '**':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":515
 *         n2 = p_factor(s)
 *         n1 = ExprNodes.binop_node(pos, '**', n1, n2)
 *     return n1             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_n1);
  __pyx_r = __pyx_v_n1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":497
 * #atom_expr: ['await'] atom trailer*
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_power(s: PyrexScanner):
 *     if s.systring == 'new' and s.peek()[0] == 'IDENT':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_power", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_await_pos);
  __Pyx_XDECREF(__pyx_v_n1);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_n2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":518
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_new_expr(s: PyrexScanner):
 *     # s.systring == 'new'.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_new_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_cppclass = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_new_expr", 0);

  /* "Cython/Compiler/Parsing.py":521
 * def p_new_expr(s: PyrexScanner):
 *     # s.systring == 'new'.
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     cppclass = p_c_base_type(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":522
 *     # s.systring == 'new'.
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     cppclass = p_c_base_type(s)
 *     return p_call(s, ExprNodes.NewExprNode(pos, cppclass = cppclass))
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":523
 *     pos = s.position()
 *     s.next()
 *     cppclass = p_c_base_type(s)             # <<<<<<<<<<<<<<
 *     return p_call(s, ExprNodes.NewExprNode(pos, cppclass = cppclass))
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cppclass = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":524
 *     s.next()
 *     cppclass = p_c_base_type(s)
 *     return p_call(s, ExprNodes.NewExprNode(pos, cppclass = cppclass))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cppclass, __pyx_v_cppclass, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 524, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NewExprNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_call(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":518
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_new_expr(s: PyrexScanner):
 *     # s.systring == 'new'.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_new_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_cppclass);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":529
 * #trailer: '(' [arglist] ')' | '[' subscriptlist ']' | '.' NAME
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_trailer(s: PyrexScanner, node1):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_trailer(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_node1) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_trailer", 0);

  /* "Cython/Compiler/Parsing.py":531
 * @cython.cfunc
 * def p_trailer(s: PyrexScanner, node1):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         return p_call(s, node1)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":532
 * def p_trailer(s: PyrexScanner, node1):
 *     pos = s.position()
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         return p_call(s, node1)
 *     elif s.sy == '[':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 532, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":533
 *     pos = s.position()
 *     if s.sy == '(':
 *         return p_call(s, node1)             # <<<<<<<<<<<<<<
 *     elif s.sy == '[':
 *         return p_index(s, node1)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call(__pyx_v_s, __pyx_v_node1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":532
 * def p_trailer(s: PyrexScanner, node1):
 *     pos = s.position()
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         return p_call(s, node1)
 *     elif s.sy == '[':
*/
  }

  /* "Cython/Compiler/Parsing.py":534
 *     if s.sy == '(':
 *         return p_call(s, node1)
 *     elif s.sy == '[':             # <<<<<<<<<<<<<<
 *         return p_index(s, node1)
 *     else:  # s.sy == '.'
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 534, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":535
 *         return p_call(s, node1)
 *     elif s.sy == '[':
 *         return p_index(s, node1)             # <<<<<<<<<<<<<<
 *     else:  # s.sy == '.'
 *         s.next()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_index(__pyx_v_s, __pyx_v_node1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":534
 *     if s.sy == '(':
 *         return p_call(s, node1)
 *     elif s.sy == '[':             # <<<<<<<<<<<<<<
 *         return p_index(s, node1)
 *     else:  # s.sy == '.'
*/
  }

  /* "Cython/Compiler/Parsing.py":537
 *         return p_index(s, node1)
 *     else:  # s.sy == '.'
 *         s.next()             # <<<<<<<<<<<<<<
 *         name = p_ident(s)
 *         return ExprNodes.AttributeNode(pos,
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":538
 *     else:  # s.sy == '.'
 *         s.next()
 *         name = p_ident(s)             # <<<<<<<<<<<<<<
 *         return ExprNodes.AttributeNode(pos,
 *             obj=node1, attribute=name)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":539
 *         s.next()
 *         name = p_ident(s)
 *         return ExprNodes.AttributeNode(pos,             # <<<<<<<<<<<<<<
 *             obj=node1, attribute=name)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);

    /* "Cython/Compiler/Parsing.py":540
 *         name = p_ident(s)
 *         return ExprNodes.AttributeNode(pos,
 *             obj=node1, attribute=name)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 539, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_obj, __pyx_v_node1, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 539, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_attribute, __pyx_v_name, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 539, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AttributeNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":529
 * #trailer: '(' [arglist] ')' | '[' subscriptlist ']' | '.' NAME
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_trailer(s: PyrexScanner, node1):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_trailer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":552
 * #             star_expr )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call_parse_args(s: PyrexScanner, allow_genexp: cython.bint = True) -> tuple:
 *     # s.sy == '('
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call_parse_args(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":553
 * 
 * @cython.cfunc
 * def p_call_parse_args(s: PyrexScanner, allow_genexp: cython.bint = True) -> tuple:             # <<<<<<<<<<<<<<
 *     # s.sy == '('
 *     s.next()
*/
  int __pyx_v_allow_genexp = ((int)1);
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  int __pyx_v_starstar_seen;
  int __pyx_v_last_was_tuple_unpack;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_encoded_name = NULL;
  PyObject *__pyx_v_keyword = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_call_parse_args", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_allow_genexp = __pyx_optional_args->allow_genexp;
    }
  }

  /* "Cython/Compiler/Parsing.py":555
 * def p_call_parse_args(s: PyrexScanner, allow_genexp: cython.bint = True) -> tuple:
 *     # s.sy == '('
 *     s.next()             # <<<<<<<<<<<<<<
 *     positional_args = []
 *     keyword_args = []
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":556
 *     # s.sy == '('
 *     s.next()
 *     positional_args = []             # <<<<<<<<<<<<<<
 *     keyword_args = []
 *     starstar_seen = False
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_positional_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":557
 *     s.next()
 *     positional_args = []
 *     keyword_args = []             # <<<<<<<<<<<<<<
 *     starstar_seen = False
 *     last_was_tuple_unpack = False
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_keyword_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":558
 *     positional_args = []
 *     keyword_args = []
 *     starstar_seen = False             # <<<<<<<<<<<<<<
 *     last_was_tuple_unpack = False
 *     while s.sy != ')':
*/
  __pyx_v_starstar_seen = 0;

  /* "Cython/Compiler/Parsing.py":559
 *     keyword_args = []
 *     starstar_seen = False
 *     last_was_tuple_unpack = False             # <<<<<<<<<<<<<<
 *     while s.sy != ')':
 *         if s.sy == '*':
*/
  __pyx_v_last_was_tuple_unpack = 0;

  /* "Cython/Compiler/Parsing.py":560
 *     starstar_seen = False
 *     last_was_tuple_unpack = False
 *     while s.sy != ')':             # <<<<<<<<<<<<<<
 *         if s.sy == '*':
 *             if starstar_seen:
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 560, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":561
 *     last_was_tuple_unpack = False
 *     while s.sy != ')':
 *         if s.sy == '*':             # <<<<<<<<<<<<<<
 *             if starstar_seen:
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 561, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":562
 *     while s.sy != ')':
 *         if s.sy == '*':
 *             if starstar_seen:             # <<<<<<<<<<<<<<
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
 *             s.next()
*/
      if (__pyx_v_starstar_seen) {

        /* "Cython/Compiler/Parsing.py":563
 *         if s.sy == '*':
 *             if starstar_seen:
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())             # <<<<<<<<<<<<<<
 *             s.next()
 *             positional_args.append(p_test(s))
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Non_keyword_arg_following_keywor};
          __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 563, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 563, __pyx_L1_error)
          __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 563, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":562
 *     while s.sy != ')':
 *         if s.sy == '*':
 *             if starstar_seen:             # <<<<<<<<<<<<<<
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
 *             s.next()
*/
      }

      /* "Cython/Compiler/Parsing.py":564
 *             if starstar_seen:
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
 *             s.next()             # <<<<<<<<<<<<<<
 *             positional_args.append(p_test(s))
 *             last_was_tuple_unpack = True
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 564, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":565
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
 *             s.next()
 *             positional_args.append(p_test(s))             # <<<<<<<<<<<<<<
 *             last_was_tuple_unpack = True
 *         elif s.sy == '**':
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_positional_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 565, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":566
 *             s.next()
 *             positional_args.append(p_test(s))
 *             last_was_tuple_unpack = True             # <<<<<<<<<<<<<<
 *         elif s.sy == '**':
 *             s.next()
*/
      __pyx_v_last_was_tuple_unpack = 1;

      /* "Cython/Compiler/Parsing.py":561
 *     last_was_tuple_unpack = False
 *     while s.sy != ')':
 *         if s.sy == '*':             # <<<<<<<<<<<<<<
 *             if starstar_seen:
 *                 s.error("Non-keyword arg following keyword arg", pos=s.position())
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":567
 *             positional_args.append(p_test(s))
 *             last_was_tuple_unpack = True
 *         elif s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             keyword_args.append(p_test(s))
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 567, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":568
 *             last_was_tuple_unpack = True
 *         elif s.sy == '**':
 *             s.next()             # <<<<<<<<<<<<<<
 *             keyword_args.append(p_test(s))
 *             starstar_seen = True
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":569
 *         elif s.sy == '**':
 *             s.next()
 *             keyword_args.append(p_test(s))             # <<<<<<<<<<<<<<
 *             starstar_seen = True
 *         else:
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_keyword_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":570
 *             s.next()
 *             keyword_args.append(p_test(s))
 *             starstar_seen = True             # <<<<<<<<<<<<<<
 *         else:
 *             arg = p_namedexpr_test(s)
*/
      __pyx_v_starstar_seen = 1;

      /* "Cython/Compiler/Parsing.py":567
 *             positional_args.append(p_test(s))
 *             last_was_tuple_unpack = True
 *         elif s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             keyword_args.append(p_test(s))
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":572
 *             starstar_seen = True
 *         else:
 *             arg = p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 *             if s.sy == '=':
 *                 s.next()
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":573
 *         else:
 *             arg = p_namedexpr_test(s)
 *             if s.sy == '=':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 if not arg.is_name:
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 573, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":574
 *             arg = p_namedexpr_test(s)
 *             if s.sy == '=':
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 if not arg.is_name:
 *                     s.error("Expected an identifier before '='",
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":575
 *             if s.sy == '=':
 *                 s.next()
 *                 if not arg.is_name:             # <<<<<<<<<<<<<<
 *                     s.error("Expected an identifier before '='",
 *                             pos=arg.pos)
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = (!__pyx_t_4);
        if (__pyx_t_8) {

          /* "Cython/Compiler/Parsing.py":576
 *                 s.next()
 *                 if not arg.is_name:
 *                     s.error("Expected an identifier before '='",             # <<<<<<<<<<<<<<
 *                             pos=arg.pos)
 *                 encoded_name = s.context.intern_ustring(arg.name)
*/
          __pyx_t_6 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_6);

          /* "Cython/Compiler/Parsing.py":577
 *                 if not arg.is_name:
 *                     s.error("Expected an identifier before '='",
 *                             pos=arg.pos)             # <<<<<<<<<<<<<<
 *                 encoded_name = s.context.intern_ustring(arg.name)
 *                 keyword = ExprNodes.IdentifierStringNode(
*/
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 577, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Expected_an_identifier_before};
            __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 576, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_5, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 576, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":575
 *             if s.sy == '=':
 *                 s.next()
 *                 if not arg.is_name:             # <<<<<<<<<<<<<<
 *                     s.error("Expected an identifier before '='",
 *                             pos=arg.pos)
*/
        }

        /* "Cython/Compiler/Parsing.py":578
 *                     s.error("Expected an identifier before '='",
 *                             pos=arg.pos)
 *                 encoded_name = s.context.intern_ustring(arg.name)             # <<<<<<<<<<<<<<
 *                 keyword = ExprNodes.IdentifierStringNode(
 *                     arg.pos, value=encoded_name)
*/
        __pyx_t_2 = __pyx_v_s->context;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 578, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 578, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_encoded_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":579
 *                             pos=arg.pos)
 *                 encoded_name = s.context.intern_ustring(arg.name)
 *                 keyword = ExprNodes.IdentifierStringNode(             # <<<<<<<<<<<<<<
 *                     arg.pos, value=encoded_name)
 *                 arg = p_test(s)
*/
        __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_5);

        /* "Cython/Compiler/Parsing.py":580
 *                 encoded_name = s.context.intern_ustring(arg.name)
 *                 keyword = ExprNodes.IdentifierStringNode(
 *                     arg.pos, value=encoded_name)             # <<<<<<<<<<<<<<
 *                 arg = p_test(s)
 *                 keyword_args.append((keyword, arg))
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 580, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_2};
          __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 579, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_encoded_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 579, __pyx_L1_error)
          __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IdentifierStringNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 579, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_keyword, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":581
 *                 keyword = ExprNodes.IdentifierStringNode(
 *                     arg.pos, value=encoded_name)
 *                 arg = p_test(s)             # <<<<<<<<<<<<<<
 *                 keyword_args.append((keyword, arg))
 *             else:
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_arg, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":582
 *                     arg.pos, value=encoded_name)
 *                 arg = p_test(s)
 *                 keyword_args.append((keyword, arg))             # <<<<<<<<<<<<<<
 *             else:
 *                 if keyword_args:
*/
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_keyword);
        __Pyx_GIVEREF(__pyx_v_keyword);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_keyword) != (0)) __PYX_ERR(0, 582, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_GIVEREF(__pyx_v_arg);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_arg) != (0)) __PYX_ERR(0, 582, __pyx_L1_error);
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_keyword_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 582, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":573
 *         else:
 *             arg = p_namedexpr_test(s)
 *             if s.sy == '=':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 if not arg.is_name:
*/
        goto __pyx_L7;
      }

      /* "Cython/Compiler/Parsing.py":584
 *                 keyword_args.append((keyword, arg))
 *             else:
 *                 if keyword_args:             # <<<<<<<<<<<<<<
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)
 *                 if positional_args and not last_was_tuple_unpack:
*/
      /*else*/ {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_keyword_args);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 584, __pyx_L1_error)
          __pyx_t_8 = (__pyx_temp != 0);
        }

        if (__pyx_t_8) {

          /* "Cython/Compiler/Parsing.py":585
 *             else:
 *                 if keyword_args:
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)             # <<<<<<<<<<<<<<
 *                 if positional_args and not last_was_tuple_unpack:
 *                     positional_args[-1].append(arg)
*/
          __pyx_t_6 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Non_keyword_arg_following_keywor};
            __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 585, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_2, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 585, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 585, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":584
 *                 keyword_args.append((keyword, arg))
 *             else:
 *                 if keyword_args:             # <<<<<<<<<<<<<<
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)
 *                 if positional_args and not last_was_tuple_unpack:
*/
        }

        /* "Cython/Compiler/Parsing.py":586
 *                 if keyword_args:
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)
 *                 if positional_args and not last_was_tuple_unpack:             # <<<<<<<<<<<<<<
 *                     positional_args[-1].append(arg)
 *                 else:
*/
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_positional_args);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 586, __pyx_L1_error)
          __pyx_t_4 = (__pyx_temp != 0);
        }

        if (__pyx_t_4) {
        } else {
          __pyx_t_8 = __pyx_t_4;
          goto __pyx_L11_bool_binop_done;
        }
        __pyx_t_4 = (!__pyx_v_last_was_tuple_unpack);
        __pyx_t_8 = __pyx_t_4;
        __pyx_L11_bool_binop_done:;
        if (__pyx_t_8) {

          /* "Cython/Compiler/Parsing.py":587
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)
 *                 if positional_args and not last_was_tuple_unpack:
 *                     positional_args[-1].append(arg)             # <<<<<<<<<<<<<<
 *                 else:
 *                     positional_args.append([arg])
*/
          __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_positional_args, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_arg); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 587, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":586
 *                 if keyword_args:
 *                     s.error("Non-keyword arg following keyword arg", pos=arg.pos)
 *                 if positional_args and not last_was_tuple_unpack:             # <<<<<<<<<<<<<<
 *                     positional_args[-1].append(arg)
 *                 else:
*/
          goto __pyx_L10;
        }

        /* "Cython/Compiler/Parsing.py":589
 *                     positional_args[-1].append(arg)
 *                 else:
 *                     positional_args.append([arg])             # <<<<<<<<<<<<<<
 *                 last_was_tuple_unpack = False
 *         if s.sy != ',':
*/
        /*else*/ {
          __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_v_arg);
          __Pyx_GIVEREF(__pyx_v_arg);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_arg) != (0)) __PYX_ERR(0, 589, __pyx_L1_error);
          __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_positional_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 589, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L10:;

        /* "Cython/Compiler/Parsing.py":590
 *                 else:
 *                     positional_args.append([arg])
 *                 last_was_tuple_unpack = False             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
        __pyx_v_last_was_tuple_unpack = 0;
      }
      __pyx_L7:;
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":591
 *                     positional_args.append([arg])
 *                 last_was_tuple_unpack = False
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 591, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":592
 *                 last_was_tuple_unpack = False
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":591
 *                     positional_args.append([arg])
 *                 last_was_tuple_unpack = False
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":593
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *     if s.sy in ('for', 'async') and allow_genexp:
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":595
 *         s.next()
 * 
 *     if s.sy in ('for', 'async') and allow_genexp:             # <<<<<<<<<<<<<<
 *         if not keyword_args and not last_was_tuple_unpack:
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_9 = __pyx_v_s->sy;
  __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 595, __pyx_L1_error)
  if (!__pyx_t_10) {
  } else {
    __pyx_t_4 = __pyx_t_10;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 595, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_10;
  __pyx_L17_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_10 = __pyx_t_4;
  if (__pyx_t_10) {
  } else {
    __pyx_t_8 = __pyx_t_10;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_8 = __pyx_v_allow_genexp;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":596
 * 
 *     if s.sy in ('for', 'async') and allow_genexp:
 *         if not keyword_args and not last_was_tuple_unpack:             # <<<<<<<<<<<<<<
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_keyword_args);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 596, __pyx_L1_error)
      __pyx_t_10 = (__pyx_temp != 0);
    }

    __pyx_t_4 = (!__pyx_t_10);
    if (__pyx_t_4) {
    } else {
      __pyx_t_8 = __pyx_t_4;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_4 = (!__pyx_v_last_was_tuple_unpack);
    __pyx_t_8 = __pyx_t_4;
    __pyx_L20_bool_binop_done:;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":597
 *     if s.sy in ('for', 'async') and allow_genexp:
 *         if not keyword_args and not last_was_tuple_unpack:
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:             # <<<<<<<<<<<<<<
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
 *     s.expect(')')
*/
      __pyx_t_11 = __Pyx_PyList_GET_SIZE(__pyx_v_positional_args); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 597, __pyx_L1_error)
      __pyx_t_4 = (__pyx_t_11 == 1);
      if (__pyx_t_4) {
      } else {
        __pyx_t_8 = __pyx_t_4;
        goto __pyx_L23_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_positional_args, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 597, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_4 = (__pyx_t_11 == 1);
      __pyx_t_8 = __pyx_t_4;
      __pyx_L23_bool_binop_done:;
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":598
 *         if not keyword_args and not last_was_tuple_unpack:
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]             # <<<<<<<<<<<<<<
 *     s.expect(')')
 *     return positional_args or [[]], keyword_args
*/
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_positional_args, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_genexp(__pyx_v_s, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 598, __pyx_L1_error);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_5) != (0)) __PYX_ERR(0, 598, __pyx_L1_error);
        __pyx_t_5 = 0;
        __Pyx_DECREF_SET(__pyx_v_positional_args, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":597
 *     if s.sy in ('for', 'async') and allow_genexp:
 *         if not keyword_args and not last_was_tuple_unpack:
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:             # <<<<<<<<<<<<<<
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
 *     s.expect(')')
*/
      }

      /* "Cython/Compiler/Parsing.py":596
 * 
 *     if s.sy in ('for', 'async') and allow_genexp:
 *         if not keyword_args and not last_was_tuple_unpack:             # <<<<<<<<<<<<<<
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
*/
    }

    /* "Cython/Compiler/Parsing.py":595
 *         s.next()
 * 
 *     if s.sy in ('for', 'async') and allow_genexp:             # <<<<<<<<<<<<<<
 *         if not keyword_args and not last_was_tuple_unpack:
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
*/
  }

  /* "Cython/Compiler/Parsing.py":599
 *             if len(positional_args) == 1 and len(positional_args[0]) == 1:
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
 *     s.expect(')')             # <<<<<<<<<<<<<<
 *     return positional_args or [[]], keyword_args
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":600
 *                 positional_args = [[p_genexp(s, positional_args[0][0])]]
 *     s.expect(')')
 *     return positional_args or [[]], keyword_args             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_positional_args); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 600, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __Pyx_INCREF(__pyx_v_positional_args);
    __pyx_t_1 = __pyx_v_positional_args;
    goto __pyx_L25_bool_binop_done;
  }
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_5) != (0)) __PYX_ERR(0, 600, __pyx_L1_error);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_1 = __pyx_t_2;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_L25_bool_binop_done:;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 600, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_keyword_args);
  __Pyx_GIVEREF(__pyx_v_keyword_args);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_keyword_args) != (0)) __PYX_ERR(0, 600, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":552
 * #             star_expr )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call_parse_args(s: PyrexScanner, allow_genexp: cython.bint = True) -> tuple:
 *     # s.sy == '('
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_call_parse_args", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_encoded_name);
  __Pyx_XDECREF(__pyx_v_keyword);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":603
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call_build_packed_args(pos, positional_args, keyword_args) -> tuple:
 *     keyword_dict = None
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call_build_packed_args(PyObject *__pyx_v_pos, PyObject *__pyx_v_positional_args, PyObject *__pyx_v_keyword_args) {
  PyObject *__pyx_v_keyword_dict = NULL;
  PyObject *__pyx_v_subtuples = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_v_kwargs = NULL;
  PyObject *__pyx_v_dict_items = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_7genexpr__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_call_build_packed_args", 0);

  /* "Cython/Compiler/Parsing.py":605
 * @cython.cfunc
 * def p_call_build_packed_args(pos, positional_args, keyword_args) -> tuple:
 *     keyword_dict = None             # <<<<<<<<<<<<<<
 * 
 *     subtuples = [
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_keyword_dict = Py_None;

  /* "Cython/Compiler/Parsing.py":607
 *     keyword_dict = None
 * 
 *     subtuples = [             # <<<<<<<<<<<<<<
 *         ExprNodes.TupleNode(pos, args=arg) if isinstance(arg, list) else ExprNodes.AsTupleNode(pos, arg=arg)
 *         for arg in positional_args
*/
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":609
 *     subtuples = [
 *         ExprNodes.TupleNode(pos, args=arg) if isinstance(arg, list) else ExprNodes.AsTupleNode(pos, arg=arg)
 *         for arg in positional_args             # <<<<<<<<<<<<<<
 *     ]
 *     # TODO: implement a faster way to join tuples than creating each one and adding them
*/
    if (likely(PyList_CheckExact(__pyx_v_positional_args)) || PyTuple_CheckExact(__pyx_v_positional_args)) {
      __pyx_t_2 = __pyx_v_positional_args; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_positional_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 609, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 609, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 609, __pyx_L5_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_3;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 609, __pyx_L5_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3));
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3);
          #endif
          ++__pyx_t_3;
        }
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 609, __pyx_L5_error)
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 609, __pyx_L5_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_arg, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":608
 * 
 *     subtuples = [
 *         ExprNodes.TupleNode(pos, args=arg) if isinstance(arg, list) else ExprNodes.AsTupleNode(pos, arg=arg)             # <<<<<<<<<<<<<<
 *         for arg in positional_args
 *     ]
*/
      __pyx_t_6 = PyList_Check(__pyx_7genexpr__pyx_v_arg); 
      if (__pyx_t_6) {
        __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos};
          __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 608, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_7genexpr__pyx_v_arg, __pyx_t_10, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 608, __pyx_L5_error)
          __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 608, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {
        __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_10, __pyx_v_pos};
          __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 608, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_7genexpr__pyx_v_arg, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 608, __pyx_L5_error)
          __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AsTupleNode, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 608, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 607, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":609
 *     subtuples = [
 *         ExprNodes.TupleNode(pos, args=arg) if isinstance(arg, list) else ExprNodes.AsTupleNode(pos, arg=arg)
 *         for arg in positional_args             # <<<<<<<<<<<<<<
 *     ]
 *     # TODO: implement a faster way to join tuples than creating each one and adding them
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_arg); __pyx_7genexpr__pyx_v_arg = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_arg); __pyx_7genexpr__pyx_v_arg = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_subtuples = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":612
 *     ]
 *     # TODO: implement a faster way to join tuples than creating each one and adding them
 *     arg_tuple = reduce(partial(ExprNodes.binop_node, pos, '+'), subtuples)             # <<<<<<<<<<<<<<
 * 
 *     if keyword_args:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_reduce);
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_reduce; 
  __pyx_t_8 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_partial);
  __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_partial; 
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_binop_node); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_9 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
    __pyx_t_9 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_t_11, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u__14};
    __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_9, (4-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 612, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __pyx_t_9 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_9 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_7, __pyx_v_subtuples};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_arg_tuple = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":614
 *     arg_tuple = reduce(partial(ExprNodes.binop_node, pos, '+'), subtuples)
 * 
 *     if keyword_args:             # <<<<<<<<<<<<<<
 *         kwargs = []
 *         dict_items = []
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_keyword_args); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 614, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":615
 * 
 *     if keyword_args:
 *         kwargs = []             # <<<<<<<<<<<<<<
 *         dict_items = []
 *         for item in keyword_args:
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_kwargs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":616
 *     if keyword_args:
 *         kwargs = []
 *         dict_items = []             # <<<<<<<<<<<<<<
 *         for item in keyword_args:
 *             if isinstance(item, tuple):
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_dict_items = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":617
 *         kwargs = []
 *         dict_items = []
 *         for item in keyword_args:             # <<<<<<<<<<<<<<
 *             if isinstance(item, tuple):
 *                 key, value = item
*/
    if (likely(PyList_CheckExact(__pyx_v_keyword_args)) || PyTuple_CheckExact(__pyx_v_keyword_args)) {
      __pyx_t_1 = __pyx_v_keyword_args; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_keyword_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_3;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
            #endif
            if (__pyx_t_3 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3));
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3);
          #endif
          ++__pyx_t_3;
        }
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 617, __pyx_L1_error)
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_1);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 617, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":618
 *         dict_items = []
 *         for item in keyword_args:
 *             if isinstance(item, tuple):             # <<<<<<<<<<<<<<
 *                 key, value = item
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))
*/
      __pyx_t_6 = PyTuple_Check(__pyx_v_item); 
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":619
 *         for item in keyword_args:
 *             if isinstance(item, tuple):
 *                 key, value = item             # <<<<<<<<<<<<<<
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))
 *             elif item.is_dict_literal:
*/
        if ((likely(PyTuple_CheckExact(__pyx_v_item))) || (PyList_CheckExact(__pyx_v_item))) {
          PyObject* sequence = __pyx_v_item;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 619, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_5);
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_7);
          } else {
            __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 619, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 619, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_7);
          }
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 619, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_5 = __pyx_t_12(__pyx_t_2); if (unlikely(!__pyx_t_5)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          index = 1; __pyx_t_7 = __pyx_t_12(__pyx_t_2); if (unlikely(!__pyx_t_7)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_2), 2) < (0)) __PYX_ERR(0, 619, __pyx_L1_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L15_unpacking_done;
          __pyx_L14_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 619, __pyx_L1_error)
          __pyx_L15_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":620
 *             if isinstance(item, tuple):
 *                 key, value = item
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))             # <<<<<<<<<<<<<<
 *             elif item.is_dict_literal:
 *                 # unpack "**{a:b}" directly
*/
        __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 620, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_5, NULL};
          __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 620, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_2, __pyx_t_10, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 620, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key, __pyx_v_key, __pyx_t_10, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 620, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_10, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 620, __pyx_L1_error)
          __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictItemNode, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 620, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_dict_items, __pyx_t_7); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 620, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":618
 *         dict_items = []
 *         for item in keyword_args:
 *             if isinstance(item, tuple):             # <<<<<<<<<<<<<<
 *                 key, value = item
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Parsing.py":621
 *                 key, value = item
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))
 *             elif item.is_dict_literal:             # <<<<<<<<<<<<<<
 *                 # unpack "**{a:b}" directly
 *                 dict_items.extend(item.key_value_pairs)
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_is_dict_literal); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":623
 *             elif item.is_dict_literal:
 *                 # unpack "**{a:b}" directly
 *                 dict_items.extend(item.key_value_pairs)             # <<<<<<<<<<<<<<
 *             else:
 *                 if dict_items:
*/
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_key_value_pairs); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 623, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = __Pyx_PyList_Extend(__pyx_v_dict_items, __pyx_t_7); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 623, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":621
 *                 key, value = item
 *                 dict_items.append(ExprNodes.DictItemNode(pos=key.pos, key=key, value=value))
 *             elif item.is_dict_literal:             # <<<<<<<<<<<<<<
 *                 # unpack "**{a:b}" directly
 *                 dict_items.extend(item.key_value_pairs)
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Parsing.py":625
 *                 dict_items.extend(item.key_value_pairs)
 *             else:
 *                 if dict_items:             # <<<<<<<<<<<<<<
 *                     kwargs.append(ExprNodes.DictNode(
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
*/
      /*else*/ {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dict_items);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 625, __pyx_L1_error)
          __pyx_t_6 = (__pyx_temp != 0);
        }

        if (__pyx_t_6) {

          /* "Cython/Compiler/Parsing.py":626
 *             else:
 *                 if dict_items:
 *                     kwargs.append(ExprNodes.DictNode(             # <<<<<<<<<<<<<<
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 *                     dict_items = []
*/
          __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
          __Pyx_INCREF(__pyx_t_10);

          /* "Cython/Compiler/Parsing.py":627
 *                 if dict_items:
 *                     kwargs.append(ExprNodes.DictNode(
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))             # <<<<<<<<<<<<<<
 *                     dict_items = []
 *                 kwargs.append(item)
*/
          __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_dict_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 627, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_9 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_10, __pyx_t_5};
            __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_v_dict_items, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 626, __pyx_L1_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_reject_duplicates, Py_True, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 626, __pyx_L1_error)
            __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 626, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          }

          /* "Cython/Compiler/Parsing.py":626
 *             else:
 *                 if dict_items:
 *                     kwargs.append(ExprNodes.DictNode(             # <<<<<<<<<<<<<<
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 *                     dict_items = []
*/
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_kwargs, __pyx_t_7); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 626, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "Cython/Compiler/Parsing.py":628
 *                     kwargs.append(ExprNodes.DictNode(
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 *                     dict_items = []             # <<<<<<<<<<<<<<
 *                 kwargs.append(item)
 * 
*/
          __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF_SET(__pyx_v_dict_items, ((PyObject*)__pyx_t_7));
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Parsing.py":625
 *                 dict_items.extend(item.key_value_pairs)
 *             else:
 *                 if dict_items:             # <<<<<<<<<<<<<<
 *                     kwargs.append(ExprNodes.DictNode(
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
*/
        }

        /* "Cython/Compiler/Parsing.py":629
 *                         dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 *                     dict_items = []
 *                 kwargs.append(item)             # <<<<<<<<<<<<<<
 * 
 *         if dict_items:
*/
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_kwargs, __pyx_v_item); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 629, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "Cython/Compiler/Parsing.py":617
 *         kwargs = []
 *         dict_items = []
 *         for item in keyword_args:             # <<<<<<<<<<<<<<
 *             if isinstance(item, tuple):
 *                 key, value = item
*/
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":631
 *                 kwargs.append(item)
 * 
 *         if dict_items:             # <<<<<<<<<<<<<<
 *             kwargs.append(ExprNodes.DictNode(
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dict_items);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 631, __pyx_L1_error)
      __pyx_t_6 = (__pyx_temp != 0);
    }

    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":632
 * 
 *         if dict_items:
 *             kwargs.append(ExprNodes.DictNode(             # <<<<<<<<<<<<<<
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 * 
*/
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_7);

      /* "Cython/Compiler/Parsing.py":633
 *         if dict_items:
 *             kwargs.append(ExprNodes.DictNode(
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))             # <<<<<<<<<<<<<<
 * 
 *         if kwargs:
*/
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_dict_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_v_dict_items, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 632, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_reject_duplicates, Py_True, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 632, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":632
 * 
 *         if dict_items:
 *             kwargs.append(ExprNodes.DictNode(             # <<<<<<<<<<<<<<
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 * 
*/
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_kwargs, __pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 632, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":631
 *                 kwargs.append(item)
 * 
 *         if dict_items:             # <<<<<<<<<<<<<<
 *             kwargs.append(ExprNodes.DictNode(
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
*/
    }

    /* "Cython/Compiler/Parsing.py":635
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 * 
 *         if kwargs:             # <<<<<<<<<<<<<<
 *             if len(kwargs) == 1 and kwargs[0].is_dict_literal:
 *                 # only simple keyword arguments found -> one dict
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_kwargs);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
      __pyx_t_6 = (__pyx_temp != 0);
    }

    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":636
 * 
 *         if kwargs:
 *             if len(kwargs) == 1 and kwargs[0].is_dict_literal:             # <<<<<<<<<<<<<<
 *                 # only simple keyword arguments found -> one dict
 *                 keyword_dict = kwargs[0]
*/
      __pyx_t_3 = __Pyx_PyList_GET_SIZE(__pyx_v_kwargs); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 636, __pyx_L1_error)
      __pyx_t_14 = (__pyx_t_3 == 1);
      if (__pyx_t_14) {
      } else {
        __pyx_t_6 = __pyx_t_14;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_kwargs, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_dict_literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 636, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_6 = __pyx_t_14;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":638
 *             if len(kwargs) == 1 and kwargs[0].is_dict_literal:
 *                 # only simple keyword arguments found -> one dict
 *                 keyword_dict = kwargs[0]             # <<<<<<<<<<<<<<
 *             else:
 *                 # at least one **kwargs
*/
        __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_kwargs, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_keyword_dict, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":636
 * 
 *         if kwargs:
 *             if len(kwargs) == 1 and kwargs[0].is_dict_literal:             # <<<<<<<<<<<<<<
 *                 # only simple keyword arguments found -> one dict
 *                 keyword_dict = kwargs[0]
*/
        goto __pyx_L20;
      }

      /* "Cython/Compiler/Parsing.py":641
 *             else:
 *                 # at least one **kwargs
 *                 keyword_dict = ExprNodes.MergedDictNode(pos, keyword_args=kwargs)             # <<<<<<<<<<<<<<
 * 
 *     return arg_tuple, keyword_dict
*/
      /*else*/ {
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_pos};
          __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 641, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_args, __pyx_v_kwargs, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 641, __pyx_L1_error)
          __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_MergedDictNode, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 641, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF_SET(__pyx_v_keyword_dict, __pyx_t_2);
        __pyx_t_2 = 0;
      }
      __pyx_L20:;

      /* "Cython/Compiler/Parsing.py":635
 *                 dict_items[0].pos, key_value_pairs=dict_items, reject_duplicates=True))
 * 
 *         if kwargs:             # <<<<<<<<<<<<<<
 *             if len(kwargs) == 1 and kwargs[0].is_dict_literal:
 *                 # only simple keyword arguments found -> one dict
*/
    }

    /* "Cython/Compiler/Parsing.py":614
 *     arg_tuple = reduce(partial(ExprNodes.binop_node, pos, '+'), subtuples)
 * 
 *     if keyword_args:             # <<<<<<<<<<<<<<
 *         kwargs = []
 *         dict_items = []
*/
  }

  /* "Cython/Compiler/Parsing.py":643
 *                 keyword_dict = ExprNodes.MergedDictNode(pos, keyword_args=kwargs)
 * 
 *     return arg_tuple, keyword_dict             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_arg_tuple);
  __Pyx_GIVEREF(__pyx_v_arg_tuple);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_arg_tuple) != (0)) __PYX_ERR(0, 643, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_keyword_dict);
  __Pyx_GIVEREF(__pyx_v_keyword_dict);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_keyword_dict) != (0)) __PYX_ERR(0, 643, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":603
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call_build_packed_args(pos, positional_args, keyword_args) -> tuple:
 *     keyword_dict = None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_call_build_packed_args", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_keyword_dict);
  __Pyx_XDECREF(__pyx_v_subtuples);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XDECREF(__pyx_v_dict_items);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":646
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call(s: PyrexScanner, function):
 *     # s.sy == '('
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_call(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_function) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_v_keyword_dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  size_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_call", 0);

  /* "Cython/Compiler/Parsing.py":649
 * def p_call(s: PyrexScanner, function):
 *     # s.sy == '('
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     positional_args, keyword_args = p_call_parse_args(s)
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":650
 *     # s.sy == '('
 *     pos = s.position()
 *     positional_args, keyword_args = p_call_parse_args(s)             # <<<<<<<<<<<<<<
 * 
 *     if not keyword_args and len(positional_args) == 1 and isinstance(positional_args[0], list):
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_parse_args(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 650, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 650, __pyx_L1_error)
  }
  __pyx_v_positional_args = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_keyword_args = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":652
 *     positional_args, keyword_args = p_call_parse_args(s)
 * 
 *     if not keyword_args and len(positional_args) == 1 and isinstance(positional_args[0], list):             # <<<<<<<<<<<<<<
 *         return ExprNodes.SimpleCallNode(pos, function=function, args=positional_args[0])
 *     else:
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_keyword_args); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 652, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = PyObject_Length(__pyx_v_positional_args); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 652, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 == 1);
  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_positional_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_Check(__pyx_t_1); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":653
 * 
 *     if not keyword_args and len(positional_args) == 1 and isinstance(positional_args[0], list):
 *         return ExprNodes.SimpleCallNode(pos, function=function, args=positional_args[0])             # <<<<<<<<<<<<<<
 *     else:
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_positional_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_function, __pyx_v_function, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 653, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_t_2, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 653, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SimpleCallNode, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":652
 *     positional_args, keyword_args = p_call_parse_args(s)
 * 
 *     if not keyword_args and len(positional_args) == 1 and isinstance(positional_args[0], list):             # <<<<<<<<<<<<<<
 *         return ExprNodes.SimpleCallNode(pos, function=function, args=positional_args[0])
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":655
 *         return ExprNodes.SimpleCallNode(pos, function=function, args=positional_args[0])
 *     else:
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)             # <<<<<<<<<<<<<<
 *         return ExprNodes.GeneralCallNode(
 *             pos, function=function, positional_args=arg_tuple, keyword_args=keyword_dict)
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_build_packed_args(__pyx_v_pos, __pyx_v_positional_args, __pyx_v_keyword_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 655, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_2);
      #else
      __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 655, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 655, __pyx_L1_error)
    }
    __pyx_v_arg_tuple = __pyx_t_9;
    __pyx_t_9 = 0;
    __pyx_v_keyword_dict = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":656
 *     else:
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
 *         return ExprNodes.GeneralCallNode(             # <<<<<<<<<<<<<<
 *             pos, function=function, positional_args=arg_tuple, keyword_args=keyword_dict)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":657
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
 *         return ExprNodes.GeneralCallNode(
 *             pos, function=function, positional_args=arg_tuple, keyword_args=keyword_dict)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_function, __pyx_v_function, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 656, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_positional_args, __pyx_v_arg_tuple, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 656, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_args, __pyx_v_keyword_dict, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 656, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_GeneralCallNode, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":646
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_call(s: PyrexScanner, function):
 *     # s.sy == '('
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XDECREF(__pyx_v_keyword_dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":664
 * #subscriptlist: subscript (',' subscript)* [',']
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_index(s: PyrexScanner, base):
 *     # s.sy == '['
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_index(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_subscripts = NULL;
  PyObject *__pyx_v_is_single_value = NULL;
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_stop = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_indexes = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_index", 0);

  /* "Cython/Compiler/Parsing.py":667
 * def p_index(s: PyrexScanner, base):
 *     # s.sy == '['
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     subscripts, is_single_value = p_subscript_list(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":668
 *     # s.sy == '['
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     subscripts, is_single_value = p_subscript_list(s)
 *     if is_single_value and len(subscripts[0]) == 2:
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":669
 *     pos = s.position()
 *     s.next()
 *     subscripts, is_single_value = p_subscript_list(s)             # <<<<<<<<<<<<<<
 *     if is_single_value and len(subscripts[0]) == 2:
 *         start, stop = subscripts[0]
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_subscript_list(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 669, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 669, __pyx_L1_error)
  }
  __pyx_v_subscripts = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_is_single_value = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":670
 *     s.next()
 *     subscripts, is_single_value = p_subscript_list(s)
 *     if is_single_value and len(subscripts[0]) == 2:             # <<<<<<<<<<<<<<
 *         start, stop = subscripts[0]
 *         result = ExprNodes.SliceIndexNode(pos,
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_is_single_value); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_subscripts, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_7 == 2);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":671
 *     subscripts, is_single_value = p_subscript_list(s)
 *     if is_single_value and len(subscripts[0]) == 2:
 *         start, stop = subscripts[0]             # <<<<<<<<<<<<<<
 *         result = ExprNodes.SliceIndexNode(pos,
 *             base = base, start = start, stop = stop)
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_subscripts, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 671, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_2);
      } else {
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 671, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_2);
      }
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
      index = 0; __pyx_t_4 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_4)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < (0)) __PYX_ERR(0, 671, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 671, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __pyx_v_start = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_stop = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":672
 *     if is_single_value and len(subscripts[0]) == 2:
 *         start, stop = subscripts[0]
 *         result = ExprNodes.SliceIndexNode(pos,             # <<<<<<<<<<<<<<
 *             base = base, start = start, stop = stop)
 *     else:
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":673
 *         start, stop = subscripts[0]
 *         result = ExprNodes.SliceIndexNode(pos,
 *             base = base, start = start, stop = stop)             # <<<<<<<<<<<<<<
 *     else:
 *         indexes = make_slice_nodes(pos, subscripts)
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 672, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_start, __pyx_v_start, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 672, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stop, __pyx_v_stop, __pyx_t_4, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 672, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SliceIndexNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":670
 *     s.next()
 *     subscripts, is_single_value = p_subscript_list(s)
 *     if is_single_value and len(subscripts[0]) == 2:             # <<<<<<<<<<<<<<
 *         start, stop = subscripts[0]
 *         result = ExprNodes.SliceIndexNode(pos,
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":675
 *             base = base, start = start, stop = stop)
 *     else:
 *         indexes = make_slice_nodes(pos, subscripts)             # <<<<<<<<<<<<<<
 *         if is_single_value:
 *             index = indexes[0]
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_make_slice_nodes(__pyx_v_pos, __pyx_v_subscripts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_indexes = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":676
 *     else:
 *         indexes = make_slice_nodes(pos, subscripts)
 *         if is_single_value:             # <<<<<<<<<<<<<<
 *             index = indexes[0]
 *         else:
*/
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_is_single_value); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 676, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":677
 *         indexes = make_slice_nodes(pos, subscripts)
 *         if is_single_value:
 *             index = indexes[0]             # <<<<<<<<<<<<<<
 *         else:
 *             index = ExprNodes.TupleNode(pos, args = indexes)
*/
      if (unlikely(__pyx_v_indexes == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 677, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_indexes, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_index = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":676
 *     else:
 *         indexes = make_slice_nodes(pos, subscripts)
 *         if is_single_value:             # <<<<<<<<<<<<<<
 *             index = indexes[0]
 *         else:
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/Parsing.py":679
 *             index = indexes[0]
 *         else:
 *             index = ExprNodes.TupleNode(pos, args = indexes)             # <<<<<<<<<<<<<<
 *         result = ExprNodes.IndexNode(pos,
 *             base = base, index = index)
*/
    /*else*/ {
      __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_indexes, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 679, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_index = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L8:;

    /* "Cython/Compiler/Parsing.py":680
 *         else:
 *             index = ExprNodes.TupleNode(pos, args = indexes)
 *         result = ExprNodes.IndexNode(pos,             # <<<<<<<<<<<<<<
 *             base = base, index = index)
 *     s.expect(']')
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":681
 *             index = ExprNodes.TupleNode(pos, args = indexes)
 *         result = ExprNodes.IndexNode(pos,
 *             base = base, index = index)             # <<<<<<<<<<<<<<
 *     s.expect(']')
 *     return result
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_index, __pyx_v_index, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 680, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IndexNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":682
 *         result = ExprNodes.IndexNode(pos,
 *             base = base, index = index)
 *     s.expect(']')             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":683
 *             base = base, index = index)
 *     s.expect(']')
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":664
 * #subscriptlist: subscript (',' subscript)* [',']
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_index(s: PyrexScanner, base):
 *     # s.sy == '['
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_subscripts);
  __Pyx_XDECREF(__pyx_v_is_single_value);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_indexes);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":686
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_subscript_list(s: PyrexScanner) -> tuple:
 *     is_single_value = True
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_subscript_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_v_is_single_value;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_subscript_list", 0);

  /* "Cython/Compiler/Parsing.py":688
 * @cython.cfunc
 * def p_subscript_list(s: PyrexScanner) -> tuple:
 *     is_single_value = True             # <<<<<<<<<<<<<<
 *     items = [p_subscript(s)]
 *     while s.sy == ',':
*/
  __pyx_v_is_single_value = 1;

  /* "Cython/Compiler/Parsing.py":689
 * def p_subscript_list(s: PyrexScanner) -> tuple:
 *     is_single_value = True
 *     items = [p_subscript(s)]             # <<<<<<<<<<<<<<
 *     while s.sy == ',':
 *         is_single_value = False
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_subscript(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 689, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_items = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":690
 *     is_single_value = True
 *     items = [p_subscript(s)]
 *     while s.sy == ',':             # <<<<<<<<<<<<<<
 *         is_single_value = False
 *         s.next()
*/
  while (1) {
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 690, __pyx_L1_error)
    if (!__pyx_t_3) break;

    /* "Cython/Compiler/Parsing.py":691
 *     items = [p_subscript(s)]
 *     while s.sy == ',':
 *         is_single_value = False             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ']':
*/
    __pyx_v_is_single_value = 0;

    /* "Cython/Compiler/Parsing.py":692
 *     while s.sy == ',':
 *         is_single_value = False
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == ']':
 *             break
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":693
 *         is_single_value = False
 *         s.next()
 *         if s.sy == ']':             # <<<<<<<<<<<<<<
 *             break
 *         items.append(p_subscript(s))
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__30, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 693, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":694
 *         s.next()
 *         if s.sy == ']':
 *             break             # <<<<<<<<<<<<<<
 *         items.append(p_subscript(s))
 *     return items, is_single_value
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":693
 *         is_single_value = False
 *         s.next()
 *         if s.sy == ']':             # <<<<<<<<<<<<<<
 *             break
 *         items.append(p_subscript(s))
*/
    }

    /* "Cython/Compiler/Parsing.py":695
 *         if s.sy == ']':
 *             break
 *         items.append(p_subscript(s))             # <<<<<<<<<<<<<<
 *     return items, is_single_value
 * 
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_subscript(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":696
 *             break
 *         items.append(p_subscript(s))
 *     return items, is_single_value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_is_single_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_items);
  __Pyx_GIVEREF(__pyx_v_items);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_items) != (0)) __PYX_ERR(0, 696, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 696, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":686
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_subscript_list(s: PyrexScanner) -> tuple:
 *     is_single_value = True
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_subscript_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":701
 * #subscript: '.' '.' '.' | test | [test] ':' [test] [':' [test]]
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_subscript(s: PyrexScanner) -> list:
 *     # Parse a subscript and return a list of
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_subscript(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_stop = NULL;
  PyObject *__pyx_v_step = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_subscript", 0);

  /* "Cython/Compiler/Parsing.py":706
 *     # 1, 2 or 3 ExprNodes, depending on how
 *     # many slice elements were encountered.
 *     start = p_slice_element(s, (':',))             # <<<<<<<<<<<<<<
 *     if s.sy != ':':
 *         return [start]
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_slice_element(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[6]); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":707
 *     # many slice elements were encountered.
 *     start = p_slice_element(s, (':',))
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         return [start]
 *     s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 707, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":708
 *     start = p_slice_element(s, (':',))
 *     if s.sy != ':':
 *         return [start]             # <<<<<<<<<<<<<<
 *     s.next()
 *     stop = p_slice_element(s, (':', ',', ']'))
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 708, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_start);
    __Pyx_GIVEREF(__pyx_v_start);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_start) != (0)) __PYX_ERR(0, 708, __pyx_L1_error);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":707
 *     # many slice elements were encountered.
 *     start = p_slice_element(s, (':',))
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         return [start]
 *     s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":709
 *     if s.sy != ':':
 *         return [start]
 *     s.next()             # <<<<<<<<<<<<<<
 *     stop = p_slice_element(s, (':', ',', ']'))
 *     if s.sy != ':':
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":710
 *         return [start]
 *     s.next()
 *     stop = p_slice_element(s, (':', ',', ']'))             # <<<<<<<<<<<<<<
 *     if s.sy != ':':
 *         return [start, stop]
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_slice_element(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[7]); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_stop = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":711
 *     s.next()
 *     stop = p_slice_element(s, (':', ',', ']'))
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         return [start, stop]
 *     s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 711, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":712
 *     stop = p_slice_element(s, (':', ',', ']'))
 *     if s.sy != ':':
 *         return [start, stop]             # <<<<<<<<<<<<<<
 *     s.next()
 *     step = p_slice_element(s, (':', ',', ']'))
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_start);
    __Pyx_GIVEREF(__pyx_v_start);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_start) != (0)) __PYX_ERR(0, 712, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_stop);
    __Pyx_GIVEREF(__pyx_v_stop);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_stop) != (0)) __PYX_ERR(0, 712, __pyx_L1_error);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":711
 *     s.next()
 *     stop = p_slice_element(s, (':', ',', ']'))
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         return [start, stop]
 *     s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":713
 *     if s.sy != ':':
 *         return [start, stop]
 *     s.next()             # <<<<<<<<<<<<<<
 *     step = p_slice_element(s, (':', ',', ']'))
 *     return [start, stop, step]
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":714
 *         return [start, stop]
 *     s.next()
 *     step = p_slice_element(s, (':', ',', ']'))             # <<<<<<<<<<<<<<
 *     return [start, stop, step]
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_slice_element(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[7]); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_step = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":715
 *     s.next()
 *     step = p_slice_element(s, (':', ',', ']'))
 *     return [start, stop, step]             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_GIVEREF(__pyx_v_start);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_start) != (0)) __PYX_ERR(0, 715, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_stop);
  __Pyx_GIVEREF(__pyx_v_stop);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_stop) != (0)) __PYX_ERR(0, 715, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_step);
  __Pyx_GIVEREF(__pyx_v_step);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_step) != (0)) __PYX_ERR(0, 715, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":701
 * #subscript: '.' '.' '.' | test | [test] ':' [test] [':' [test]]
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_subscript(s: PyrexScanner) -> list:
 *     # Parse a subscript and return a list of
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_subscript", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_step);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":718
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_slice_element(s: PyrexScanner, follow_set):
 *     # Simple expression which may be missing iff
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_slice_element(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_follow_set) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_slice_element", 0);

  /* "Cython/Compiler/Parsing.py":722
 *     # Simple expression which may be missing iff
 *     # it is followed by something in follow_set.
 *     if s.sy not in follow_set:             # <<<<<<<<<<<<<<
 *         return p_test(s)
 *     else:
*/
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_follow_set, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 722, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":723
 *     # it is followed by something in follow_set.
 *     if s.sy not in follow_set:
 *         return p_test(s)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 723, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":722
 *     # Simple expression which may be missing iff
 *     # it is followed by something in follow_set.
 *     if s.sy not in follow_set:             # <<<<<<<<<<<<<<
 *         return p_test(s)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":725
 *         return p_test(s)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":718
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_slice_element(s: PyrexScanner, follow_set):
 *     # Simple expression which may be missing iff
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_slice_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":728
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def expect_ellipsis(s: PyrexScanner):
 *     s.expect('...')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_expect_ellipsis(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expect_ellipsis", 0);

  /* "Cython/Compiler/Parsing.py":730
 * @cython.cfunc
 * def expect_ellipsis(s: PyrexScanner):
 *     s.expect('...')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__31};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 730, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":728
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def expect_ellipsis(s: PyrexScanner):
 *     s.expect('...')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.expect_ellipsis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":733
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def make_slice_nodes(pos, subscripts) -> list:
 *     # Convert a list of subscripts as returned
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_make_slice_nodes(PyObject *__pyx_v_pos, PyObject *__pyx_v_subscripts) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_subscript = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_slice_nodes", 0);

  /* "Cython/Compiler/Parsing.py":739
 *     # creating SliceNodes for elements with 2 or
 *     # more components.
 *     result = []             # <<<<<<<<<<<<<<
 *     for subscript in subscripts:
 *         if len(subscript) == 1:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":740
 *     # more components.
 *     result = []
 *     for subscript in subscripts:             # <<<<<<<<<<<<<<
 *         if len(subscript) == 1:
 *             result.append(subscript[0])
*/
  if (likely(PyList_CheckExact(__pyx_v_subscripts)) || PyTuple_CheckExact(__pyx_v_subscripts)) {
    __pyx_t_1 = __pyx_v_subscripts; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_subscripts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 740, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 740, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 740, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_subscript, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":741
 *     result = []
 *     for subscript in subscripts:
 *         if len(subscript) == 1:             # <<<<<<<<<<<<<<
 *             result.append(subscript[0])
 *         else:
*/
    __pyx_t_5 = PyObject_Length(__pyx_v_subscript); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 741, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 == 1);
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":742
 *     for subscript in subscripts:
 *         if len(subscript) == 1:
 *             result.append(subscript[0])             # <<<<<<<<<<<<<<
 *         else:
 *             result.append(make_slice_node(pos, *subscript))
*/
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_subscript, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 742, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 742, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/Parsing.py":741
 *     result = []
 *     for subscript in subscripts:
 *         if len(subscript) == 1:             # <<<<<<<<<<<<<<
 *             result.append(subscript[0])
 *         else:
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":744
 *             result.append(subscript[0])
 *         else:
 *             result.append(make_slice_node(pos, *subscript))             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_make_slice_node); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 744, __pyx_L1_error);
      __pyx_t_9 = __Pyx_PySequence_Tuple(__pyx_v_subscript); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_9); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":740
 *     # more components.
 *     result = []
 *     for subscript in subscripts:             # <<<<<<<<<<<<<<
 *         if len(subscript) == 1:
 *             result.append(subscript[0])
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":745
 *         else:
 *             result.append(make_slice_node(pos, *subscript))
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":733
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def make_slice_nodes(pos, subscripts) -> list:
 *     # Convert a list of subscripts as returned
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.make_slice_nodes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_subscript);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_1make_slice_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_make_slice_node(PyObject *__pyx_v_pos, PyObject *__pyx_v_start, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":749
 * 
 * @cython.ccall
 * def make_slice_node(pos, start, stop = None, step = None):             # <<<<<<<<<<<<<<
 *     if not start:
 *         start = ExprNodes.NoneNode(pos)
*/
  PyObject *__pyx_v_stop = ((PyObject *)Py_None);
  PyObject *__pyx_v_step = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_slice_node", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_stop = __pyx_optional_args->stop;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_step = __pyx_optional_args->step;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_INCREF(__pyx_v_stop);
  __Pyx_INCREF(__pyx_v_step);

  /* "Cython/Compiler/Parsing.py":750
 * @cython.ccall
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:             # <<<<<<<<<<<<<<
 *         start = ExprNodes.NoneNode(pos)
 *     if not stop:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_start); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 750, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":751
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
 *         start = ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *     if not stop:
 *         stop = ExprNodes.NoneNode(pos)
*/
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":750
 * @cython.ccall
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:             # <<<<<<<<<<<<<<
 *         start = ExprNodes.NoneNode(pos)
 *     if not stop:
*/
  }

  /* "Cython/Compiler/Parsing.py":752
 *     if not start:
 *         start = ExprNodes.NoneNode(pos)
 *     if not stop:             # <<<<<<<<<<<<<<
 *         stop = ExprNodes.NoneNode(pos)
 *     if not step:
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 752, __pyx_L1_error)
  __pyx_t_1 = (!__pyx_t_2);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":753
 *         start = ExprNodes.NoneNode(pos)
 *     if not stop:
 *         stop = ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *     if not step:
 *         step = ExprNodes.NoneNode(pos)
*/
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":752
 *     if not start:
 *         start = ExprNodes.NoneNode(pos)
 *     if not stop:             # <<<<<<<<<<<<<<
 *         stop = ExprNodes.NoneNode(pos)
 *     if not step:
*/
  }

  /* "Cython/Compiler/Parsing.py":754
 *     if not stop:
 *         stop = ExprNodes.NoneNode(pos)
 *     if not step:             # <<<<<<<<<<<<<<
 *         step = ExprNodes.NoneNode(pos)
 *     return ExprNodes.SliceNode(pos,
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_step); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 754, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":755
 *         stop = ExprNodes.NoneNode(pos)
 *     if not step:
 *         step = ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *     return ExprNodes.SliceNode(pos,
 *         start = start, stop = stop, step = step)
*/
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 755, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_step, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":754
 *     if not stop:
 *         stop = ExprNodes.NoneNode(pos)
 *     if not step:             # <<<<<<<<<<<<<<
 *         step = ExprNodes.NoneNode(pos)
 *     return ExprNodes.SliceNode(pos,
*/
  }

  /* "Cython/Compiler/Parsing.py":756
 *     if not step:
 *         step = ExprNodes.NoneNode(pos)
 *     return ExprNodes.SliceNode(pos,             # <<<<<<<<<<<<<<
 *         start = start, stop = stop, step = step)
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":757
 *         step = ExprNodes.NoneNode(pos)
 *     return ExprNodes.SliceNode(pos,
 *         start = start, stop = stop, step = step)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_start, __pyx_v_start, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 756, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stop, __pyx_v_stop, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 756, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_step, __pyx_v_step, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 756, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SliceNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.make_slice_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_step);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_1make_slice_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_1make_slice_node = {"make_slice_node", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_1make_slice_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_1make_slice_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_pos = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_stop = 0;
  PyObject *__pyx_v_step = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_slice_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pos,&__pyx_mstate_global->__pyx_n_u_start,&__pyx_mstate_global->__pyx_n_u_stop,&__pyx_mstate_global->__pyx_n_u_step,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 748, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "make_slice_node", 0) < (0)) __PYX_ERR(0, 748, __pyx_L3_error)

      /* "Cython/Compiler/Parsing.py":749
 * 
 * @cython.ccall
 * def make_slice_node(pos, start, stop = None, step = None):             # <<<<<<<<<<<<<<
 *     if not start:
 *         start = ExprNodes.NoneNode(pos)
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("make_slice_node", 0, 2, 4, i); __PYX_ERR(0, 748, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 748, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 748, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 748, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_pos = values[0];
    __pyx_v_start = values[1];
    __pyx_v_stop = values[2];
    __pyx_v_step = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_slice_node", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 748, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.make_slice_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_make_slice_node(__pyx_self, __pyx_v_pos, __pyx_v_start, __pyx_v_stop, __pyx_v_step);

  /* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_make_slice_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_pos, PyObject *__pyx_v_start, PyObject *__pyx_v_stop, PyObject *__pyx_v_step) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_slice_node", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.stop = __pyx_v_stop;
  __pyx_t_2.step = __pyx_v_step;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_make_slice_node(__pyx_v_pos, __pyx_v_start, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.make_slice_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":762
 * #atom: '(' [yield_expr|testlist_comp] ')' | '[' [listmaker] ']' | '{' [dict_or_set_maker] '}' | '`' testlist '`' | NAME | NUMBER | STRING+
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_atom", 0);

  /* "Cython/Compiler/Parsing.py":764
 * @cython.cfunc
 * def p_atom(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     sy = s.sy
 *     if sy == '(':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":765
 * def p_atom(s: PyrexScanner):
 *     pos = s.position()
 *     sy = s.sy             # <<<<<<<<<<<<<<
 *     if sy == '(':
 *         s.next()
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_sy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":766
 *     pos = s.position()
 *     sy = s.sy
 *     if sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ')':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 766, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":767
 *     sy = s.sy
 *     if sy == '(':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == ')':
 *             result = ExprNodes.TupleNode(pos, args = [])
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":768
 *     if sy == '(':
 *         s.next()
 *         if s.sy == ')':             # <<<<<<<<<<<<<<
 *             result = ExprNodes.TupleNode(pos, args = [])
 *         elif s.sy == 'yield':
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 768, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":769
 *         s.next()
 *         if s.sy == ')':
 *             result = ExprNodes.TupleNode(pos, args = [])             # <<<<<<<<<<<<<<
 *         elif s.sy == 'yield':
 *             result = p_yield_expression(s)
*/
      __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 769, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":768
 *     if sy == '(':
 *         s.next()
 *         if s.sy == ')':             # <<<<<<<<<<<<<<
 *             result = ExprNodes.TupleNode(pos, args = [])
 *         elif s.sy == 'yield':
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":770
 *         if s.sy == ')':
 *             result = ExprNodes.TupleNode(pos, args = [])
 *         elif s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             result = p_yield_expression(s)
 *         else:
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_yield, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 770, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":771
 *             result = ExprNodes.TupleNode(pos, args = [])
 *         elif s.sy == 'yield':
 *             result = p_yield_expression(s)             # <<<<<<<<<<<<<<
 *         else:
 *             result = p_testlist_comp(s)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":770
 *         if s.sy == ')':
 *             result = ExprNodes.TupleNode(pos, args = [])
 *         elif s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             result = p_yield_expression(s)
 *         else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":773
 *             result = p_yield_expression(s)
 *         else:
 *             result = p_testlist_comp(s)             # <<<<<<<<<<<<<<
 *         s.expect(')')
 *         return result
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist_comp(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 773, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":774
 *         else:
 *             result = p_testlist_comp(s)
 *         s.expect(')')             # <<<<<<<<<<<<<<
 *         return result
 *     elif sy == '[':
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__24};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":775
 *             result = p_testlist_comp(s)
 *         s.expect(')')
 *         return result             # <<<<<<<<<<<<<<
 *     elif sy == '[':
 *         return p_list_maker(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":766
 *     pos = s.position()
 *     sy = s.sy
 *     if sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ')':
*/
  }

  /* "Cython/Compiler/Parsing.py":776
 *         s.expect(')')
 *         return result
 *     elif sy == '[':             # <<<<<<<<<<<<<<
 *         return p_list_maker(s)
 *     elif sy == '{':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 776, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":777
 *         return result
 *     elif sy == '[':
 *         return p_list_maker(s)             # <<<<<<<<<<<<<<
 *     elif sy == '{':
 *         return p_dict_or_set_maker(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_list_maker(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":776
 *         s.expect(')')
 *         return result
 *     elif sy == '[':             # <<<<<<<<<<<<<<
 *         return p_list_maker(s)
 *     elif sy == '{':
*/
  }

  /* "Cython/Compiler/Parsing.py":778
 *     elif sy == '[':
 *         return p_list_maker(s)
 *     elif sy == '{':             # <<<<<<<<<<<<<<
 *         return p_dict_or_set_maker(s)
 *     elif sy == '`':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__32, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 778, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":779
 *         return p_list_maker(s)
 *     elif sy == '{':
 *         return p_dict_or_set_maker(s)             # <<<<<<<<<<<<<<
 *     elif sy == '`':
 *         return p_backquote_expr(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_dict_or_set_maker(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":778
 *     elif sy == '[':
 *         return p_list_maker(s)
 *     elif sy == '{':             # <<<<<<<<<<<<<<
 *         return p_dict_or_set_maker(s)
 *     elif sy == '`':
*/
  }

  /* "Cython/Compiler/Parsing.py":780
 *     elif sy == '{':
 *         return p_dict_or_set_maker(s)
 *     elif sy == '`':             # <<<<<<<<<<<<<<
 *         return p_backquote_expr(s)
 *     elif sy == '...':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__33, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 780, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":781
 *         return p_dict_or_set_maker(s)
 *     elif sy == '`':
 *         return p_backquote_expr(s)             # <<<<<<<<<<<<<<
 *     elif sy == '...':
 *         expect_ellipsis(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_backquote_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":780
 *     elif sy == '{':
 *         return p_dict_or_set_maker(s)
 *     elif sy == '`':             # <<<<<<<<<<<<<<
 *         return p_backquote_expr(s)
 *     elif sy == '...':
*/
  }

  /* "Cython/Compiler/Parsing.py":782
 *     elif sy == '`':
 *         return p_backquote_expr(s)
 *     elif sy == '...':             # <<<<<<<<<<<<<<
 *         expect_ellipsis(s)
 *         return ExprNodes.EllipsisNode(pos)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__31, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 782, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":783
 *         return p_backquote_expr(s)
 *     elif sy == '...':
 *         expect_ellipsis(s)             # <<<<<<<<<<<<<<
 *         return ExprNodes.EllipsisNode(pos)
 *     elif sy == 'INT':
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_expect_ellipsis(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":784
 *     elif sy == '...':
 *         expect_ellipsis(s)
 *         return ExprNodes.EllipsisNode(pos)             # <<<<<<<<<<<<<<
 *     elif sy == 'INT':
 *         return p_int_literal(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_EllipsisNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":782
 *     elif sy == '`':
 *         return p_backquote_expr(s)
 *     elif sy == '...':             # <<<<<<<<<<<<<<
 *         expect_ellipsis(s)
 *         return ExprNodes.EllipsisNode(pos)
*/
  }

  /* "Cython/Compiler/Parsing.py":785
 *         expect_ellipsis(s)
 *         return ExprNodes.EllipsisNode(pos)
 *     elif sy == 'INT':             # <<<<<<<<<<<<<<
 *         return p_int_literal(s)
 *     elif sy == 'FLOAT':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_INT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 785, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":786
 *         return ExprNodes.EllipsisNode(pos)
 *     elif sy == 'INT':
 *         return p_int_literal(s)             # <<<<<<<<<<<<<<
 *     elif sy == 'FLOAT':
 *         value = s.systring
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_int_literal(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":785
 *         expect_ellipsis(s)
 *         return ExprNodes.EllipsisNode(pos)
 *     elif sy == 'INT':             # <<<<<<<<<<<<<<
 *         return p_int_literal(s)
 *     elif sy == 'FLOAT':
*/
  }

  /* "Cython/Compiler/Parsing.py":787
 *     elif sy == 'INT':
 *         return p_int_literal(s)
 *     elif sy == 'FLOAT':             # <<<<<<<<<<<<<<
 *         value = s.systring
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_FLOAT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 787, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":788
 *         return p_int_literal(s)
 *     elif sy == 'FLOAT':
 *         value = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.FloatNode(pos, value = value)
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":789
 *     elif sy == 'FLOAT':
 *         value = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.FloatNode(pos, value = value)
 *     elif sy == 'IMAG':
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 789, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":790
 *         value = s.systring
 *         s.next()
 *         return ExprNodes.FloatNode(pos, value = value)             # <<<<<<<<<<<<<<
 *     elif sy == 'IMAG':
 *         value = s.systring[:-1]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 790, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FloatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":787
 *     elif sy == 'INT':
 *         return p_int_literal(s)
 *     elif sy == 'FLOAT':             # <<<<<<<<<<<<<<
 *         value = s.systring
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":791
 *         s.next()
 *         return ExprNodes.FloatNode(pos, value = value)
 *     elif sy == 'IMAG':             # <<<<<<<<<<<<<<
 *         value = s.systring[:-1]
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_IMAG, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 791, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":792
 *         return ExprNodes.FloatNode(pos, value = value)
 *     elif sy == 'IMAG':
 *         value = s.systring[:-1]             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.ImagNode(pos, value = value)
*/
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_s->systring, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":793
 *     elif sy == 'IMAG':
 *         value = s.systring[:-1]
 *         s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.ImagNode(pos, value = value)
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":794
 *         value = s.systring[:-1]
 *         s.next()
 *         return ExprNodes.ImagNode(pos, value = value)             # <<<<<<<<<<<<<<
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':
 *         return p_atom_string(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 794, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImagNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":791
 *         s.next()
 *         return ExprNodes.FloatNode(pos, value = value)
 *     elif sy == 'IMAG':             # <<<<<<<<<<<<<<
 *         value = s.systring[:-1]
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":795
 *         s.next()
 *         return ExprNodes.ImagNode(pos, value = value)
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':             # <<<<<<<<<<<<<<
 *         return p_atom_string(s)
 *     elif sy == 'IDENT':
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 795, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_BEGIN_FT_STRING, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 795, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":796
 *         return ExprNodes.ImagNode(pos, value = value)
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':
 *         return p_atom_string(s)             # <<<<<<<<<<<<<<
 *     elif sy == 'IDENT':
 *         result = p_atom_ident_constants(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom_string(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":795
 *         s.next()
 *         return ExprNodes.ImagNode(pos, value = value)
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':             # <<<<<<<<<<<<<<
 *         return p_atom_string(s)
 *     elif sy == 'IDENT':
*/
  }

  /* "Cython/Compiler/Parsing.py":797
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':
 *         return p_atom_string(s)
 *     elif sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         result = p_atom_ident_constants(s)
 *         if result is None:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 797, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":798
 *         return p_atom_string(s)
 *     elif sy == 'IDENT':
 *         result = p_atom_ident_constants(s)             # <<<<<<<<<<<<<<
 *         if result is None:
 *             result = p_name(s, s.systring)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom_ident_constants(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":799
 *     elif sy == 'IDENT':
 *         result = p_atom_ident_constants(s)
 *         if result is None:             # <<<<<<<<<<<<<<
 *             result = p_name(s, s.systring)
 *             s.next()
*/
    __pyx_t_2 = (__pyx_v_result == Py_None);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":800
 *         result = p_atom_ident_constants(s)
 *         if result is None:
 *             result = p_name(s, s.systring)             # <<<<<<<<<<<<<<
 *             s.next()
 *         return result
*/
      __pyx_t_1 = __pyx_v_s->systring;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":801
 *         if result is None:
 *             result = p_name(s, s.systring)
 *             s.next()             # <<<<<<<<<<<<<<
 *         return result
 *     else:
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 801, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":799
 *     elif sy == 'IDENT':
 *         result = p_atom_ident_constants(s)
 *         if result is None:             # <<<<<<<<<<<<<<
 *             result = p_name(s, s.systring)
 *             s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":802
 *             result = p_name(s, s.systring)
 *             s.next()
 *         return result             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("Expected an identifier or literal")
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":797
 *     elif sy == 'BEGIN_STRING' or sy == 'BEGIN_FT_STRING':
 *         return p_atom_string(s)
 *     elif sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         result = p_atom_ident_constants(s)
 *         if result is None:
*/
  }

  /* "Cython/Compiler/Parsing.py":804
 *         return result
 *     else:
 *         s.error("Expected an identifier or literal")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_Expected_an_identifier_or_litera};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "Cython/Compiler/Parsing.py":762
 * #atom: '(' [yield_expr|testlist_comp] ')' | '[' [listmaker] ']' | '{' [dict_or_set_maker] '}' | '`' testlist '`' | NAME | NUMBER | STRING+
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_atom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":807
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom_string(s: PyrexScanner):
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom_string(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_bytes_value = NULL;
  PyObject *__pyx_v_unicode_value = NULL;
  Py_UCS4 __pyx_v_kind_char;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  size_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  PyObject *__pyx_t_9[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_atom_string", 0);

  /* "Cython/Compiler/Parsing.py":810
 * def p_atom_string(s: PyrexScanner):
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     kind, bytes_value, unicode_value = p_cat_string_literal(s)
 *     if not kind:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":811
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_cat_string_literal(s)             # <<<<<<<<<<<<<<
 *     if not kind:
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cat_string_literal(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 811, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 811, __pyx_L1_error)
  }
  __pyx_v_kind = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_bytes_value = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_unicode_value = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":812
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_cat_string_literal(s)
 *     if not kind:             # <<<<<<<<<<<<<<
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     kind_char: cython.Py_UCS4 = kind
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_kind); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":813
 *     kind, bytes_value, unicode_value = p_cat_string_literal(s)
 *     if not kind:
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)             # <<<<<<<<<<<<<<
 *     kind_char: cython.Py_UCS4 = kind
 *     if kind_char == 'c':
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_unicode_value, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 813, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bytes_value, __pyx_v_bytes_value, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 813, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":812
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_cat_string_literal(s)
 *     if not kind:             # <<<<<<<<<<<<<<
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     kind_char: cython.Py_UCS4 = kind
*/
  }

  /* "Cython/Compiler/Parsing.py":814
 *     if not kind:
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     kind_char: cython.Py_UCS4 = kind             # <<<<<<<<<<<<<<
 *     if kind_char == 'c':
 *         return ExprNodes.CharNode(pos, value=bytes_value)
*/
  __pyx_t_8 = __Pyx_PyObject_AsPy_UCS4(__pyx_v_kind); if (unlikely((__pyx_t_8 == (Py_UCS4)-1) && PyErr_Occurred())) __PYX_ERR(0, 814, __pyx_L1_error)
  __pyx_v_kind_char = __pyx_t_8;

  /* "Cython/Compiler/Parsing.py":815
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     kind_char: cython.Py_UCS4 = kind
 *     if kind_char == 'c':             # <<<<<<<<<<<<<<
 *         return ExprNodes.CharNode(pos, value=bytes_value)
 *     elif kind_char == 'u':
*/
  switch (__pyx_v_kind_char) {
    case 99:

    /* "Cython/Compiler/Parsing.py":816
 *     kind_char: cython.Py_UCS4 = kind
 *     if kind_char == 'c':
 *         return ExprNodes.CharNode(pos, value=bytes_value)             # <<<<<<<<<<<<<<
 *     elif kind_char == 'u':
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_bytes_value, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 816, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CharNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":815
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     kind_char: cython.Py_UCS4 = kind
 *     if kind_char == 'c':             # <<<<<<<<<<<<<<
 *         return ExprNodes.CharNode(pos, value=bytes_value)
 *     elif kind_char == 'u':
*/
    break;
    case 0x75:

    /* "Cython/Compiler/Parsing.py":818
 *         return ExprNodes.CharNode(pos, value=bytes_value)
 *     elif kind_char == 'u':
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)             # <<<<<<<<<<<<<<
 *     elif kind_char == 'b':
 *         return ExprNodes.BytesNode(pos, value=bytes_value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_unicode_value, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 818, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bytes_value, __pyx_v_bytes_value, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 818, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":817
 *     if kind_char == 'c':
 *         return ExprNodes.CharNode(pos, value=bytes_value)
 *     elif kind_char == 'u':             # <<<<<<<<<<<<<<
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     elif kind_char == 'b':
*/
    break;
    case 98:

    /* "Cython/Compiler/Parsing.py":820
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     elif kind_char == 'b':
 *         return ExprNodes.BytesNode(pos, value=bytes_value)             # <<<<<<<<<<<<<<
 *     elif kind_char == 'f':
 *         return ExprNodes.JoinedStrNode(pos, values=unicode_value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_bytes_value, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 820, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BytesNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":819
 *     elif kind_char == 'u':
 *         return ExprNodes.UnicodeNode(pos, value=unicode_value, bytes_value=bytes_value)
 *     elif kind_char == 'b':             # <<<<<<<<<<<<<<
 *         return ExprNodes.BytesNode(pos, value=bytes_value)
 *     elif kind_char == 'f':
*/
    break;
    case 0x66:

    /* "Cython/Compiler/Parsing.py":822
 *         return ExprNodes.BytesNode(pos, value=bytes_value)
 *     elif kind_char == 'f':
 *         return ExprNodes.JoinedStrNode(pos, values=unicode_value)             # <<<<<<<<<<<<<<
 *     elif kind_char == 't':
 *         # TODO
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_values, __pyx_v_unicode_value, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 822, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_JoinedStrNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":821
 *     elif kind_char == 'b':
 *         return ExprNodes.BytesNode(pos, value=bytes_value)
 *     elif kind_char == 'f':             # <<<<<<<<<<<<<<
 *         return ExprNodes.JoinedStrNode(pos, values=unicode_value)
 *     elif kind_char == 't':
*/
    break;
    case 0x74:

    /* "Cython/Compiler/Parsing.py":825
 *     elif kind_char == 't':
 *         # TODO
 *         return ExprNodes.TemplateStringNode(pos, values=unicode_value)             # <<<<<<<<<<<<<<
 *     else:
 *         # This is actually prevented by the scanner (Lexicon.py).
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_values, __pyx_v_unicode_value, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 825, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TemplateStringNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":823
 *     elif kind_char == 'f':
 *         return ExprNodes.JoinedStrNode(pos, values=unicode_value)
 *     elif kind_char == 't':             # <<<<<<<<<<<<<<
 *         # TODO
 *         return ExprNodes.TemplateStringNode(pos, values=unicode_value)
*/
    break;
    default:

    /* "Cython/Compiler/Parsing.py":828
 *     else:
 *         # This is actually prevented by the scanner (Lexicon.py).
 *         s.error(f"invalid string kind '{kind}'")             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_kind, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_invalid_string_kind;
    __pyx_t_9[1] = __pyx_t_3;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__34;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_9, 3, 21 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    break;
  }

  /* "Cython/Compiler/Parsing.py":807
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom_string(s: PyrexScanner):
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_atom_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_bytes_value);
  __Pyx_XDECREF(__pyx_v_unicode_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":831
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom_ident_constants(s: PyrexScanner):
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_atom_ident_constants(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_atom_ident_constants", 0);

  /* "Cython/Compiler/Parsing.py":838
 *     """
 *     # s.sy == 'IDENT'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     name = s.systring
 *     if name == "None":
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":839
 *     # s.sy == 'IDENT'
 *     pos = s.position()
 *     name = s.systring             # <<<<<<<<<<<<<<
 *     if name == "None":
 *         result = ExprNodes.NoneNode(pos)
*/
  __pyx_t_1 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":840
 *     pos = s.position()
 *     name = s.systring
 *     if name == "None":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.NoneNode(pos)
 *     elif name == "True":
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_None, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 840, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":841
 *     name = s.systring
 *     if name == "None":
 *         result = ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *     elif name == "True":
 *         result = ExprNodes.BoolNode(pos, value=True)
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":840
 *     pos = s.position()
 *     name = s.systring
 *     if name == "None":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.NoneNode(pos)
 *     elif name == "True":
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":842
 *     if name == "None":
 *         result = ExprNodes.NoneNode(pos)
 *     elif name == "True":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.BoolNode(pos, value=True)
 *     elif name == "False":
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_True, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 842, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":843
 *         result = ExprNodes.NoneNode(pos)
 *     elif name == "True":
 *         result = ExprNodes.BoolNode(pos, value=True)             # <<<<<<<<<<<<<<
 *     elif name == "False":
 *         result = ExprNodes.BoolNode(pos, value=False)
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, Py_True, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 843, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BoolNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":842
 *     if name == "None":
 *         result = ExprNodes.NoneNode(pos)
 *     elif name == "True":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.BoolNode(pos, value=True)
 *     elif name == "False":
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":844
 *     elif name == "True":
 *         result = ExprNodes.BoolNode(pos, value=True)
 *     elif name == "False":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.BoolNode(pos, value=False)
 *     elif name == "NULL" and not s.in_python_file:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_False, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 844, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":845
 *         result = ExprNodes.BoolNode(pos, value=True)
 *     elif name == "False":
 *         result = ExprNodes.BoolNode(pos, value=False)             # <<<<<<<<<<<<<<
 *     elif name == "NULL" and not s.in_python_file:
 *         result = ExprNodes.NullNode(pos)
*/
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, Py_False, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 845, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BoolNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":844
 *     elif name == "True":
 *         result = ExprNodes.BoolNode(pos, value=True)
 *     elif name == "False":             # <<<<<<<<<<<<<<
 *         result = ExprNodes.BoolNode(pos, value=False)
 *     elif name == "NULL" and not s.in_python_file:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":846
 *     elif name == "False":
 *         result = ExprNodes.BoolNode(pos, value=False)
 *     elif name == "NULL" and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         result = ExprNodes.NullNode(pos)
 *     else:
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_NULL, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 846, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (!__pyx_v_s->in_python_file);
  __pyx_t_2 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":847
 *         result = ExprNodes.BoolNode(pos, value=False)
 *     elif name == "NULL" and not s.in_python_file:
 *         result = ExprNodes.NullNode(pos)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NullNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 847, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":846
 *     elif name == "False":
 *         result = ExprNodes.BoolNode(pos, value=False)
 *     elif name == "NULL" and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         result = ExprNodes.NullNode(pos)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":849
 *         result = ExprNodes.NullNode(pos)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 *     s.next()
 *     return result
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":850
 *     else:
 *         return None
 *     s.next()             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":851
 *         return None
 *     s.next()
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":831
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_atom_ident_constants(s: PyrexScanner):
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_atom_ident_constants", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":854
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_int_literal(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_int_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_unsigned = NULL;
  PyObject *__pyx_v_longness = NULL;
  PyObject *__pyx_v_is_c_literal = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_int_literal", 0);

  /* "Cython/Compiler/Parsing.py":856
 * @cython.cfunc
 * def p_int_literal(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     value: str = cython.cast(str, s.systring)
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":857
 * def p_int_literal(s: PyrexScanner):
 *     pos = s.position()
 *     value: str = cython.cast(str, s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     unsigned = ""
*/
  __pyx_t_1 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_value = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":858
 *     pos = s.position()
 *     value: str = cython.cast(str, s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     unsigned = ""
 *     longness = ""
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":859
 *     value: str = cython.cast(str, s.systring)
 *     s.next()
 *     unsigned = ""             # <<<<<<<<<<<<<<
 *     longness = ""
 *     while value[-1] in "UuLl":
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
  __pyx_v_unsigned = __pyx_mstate_global->__pyx_kp_u__35;

  /* "Cython/Compiler/Parsing.py":860
 *     s.next()
 *     unsigned = ""
 *     longness = ""             # <<<<<<<<<<<<<<
 *     while value[-1] in "UuLl":
 *         if value[-1] in "Ll":
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
  __pyx_v_longness = __pyx_mstate_global->__pyx_kp_u__35;

  /* "Cython/Compiler/Parsing.py":861
 *     unsigned = ""
 *     longness = ""
 *     while value[-1] in "UuLl":             # <<<<<<<<<<<<<<
 *         if value[-1] in "Ll":
 *             longness += "L"
*/
  while (1) {
    __pyx_t_5 = __Pyx_GetItemInt_Unicode(__pyx_v_value, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(__pyx_t_5 == (Py_UCS4)-1)) __PYX_ERR(0, 861, __pyx_L1_error)
    switch (__pyx_t_5) {
      case 76:
      case 85:
      case 0x6C:
      case 0x75:
      __pyx_t_4 = 1;
      break;
      default:
      __pyx_t_4 = 0;
      break;
    }
    __pyx_t_6 = __pyx_t_4;
    if (!__pyx_t_6) break;

    /* "Cython/Compiler/Parsing.py":862
 *     longness = ""
 *     while value[-1] in "UuLl":
 *         if value[-1] in "Ll":             # <<<<<<<<<<<<<<
 *             longness += "L"
 *         else:
*/
    __pyx_t_5 = __Pyx_GetItemInt_Unicode(__pyx_v_value, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(__pyx_t_5 == (Py_UCS4)-1)) __PYX_ERR(0, 862, __pyx_L1_error)
    switch (__pyx_t_5) {
      case 76:
      case 0x6C:

      /* "Cython/Compiler/Parsing.py":863
 *     while value[-1] in "UuLl":
 *         if value[-1] in "Ll":
 *             longness += "L"             # <<<<<<<<<<<<<<
 *         else:
 *             unsigned += "U"
*/
      __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_v_longness, __pyx_mstate_global->__pyx_n_u_L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_longness, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":862
 *     longness = ""
 *     while value[-1] in "UuLl":
 *         if value[-1] in "Ll":             # <<<<<<<<<<<<<<
 *             longness += "L"
 *         else:
*/
      break;
      default:

      /* "Cython/Compiler/Parsing.py":865
 *             longness += "L"
 *         else:
 *             unsigned += "U"             # <<<<<<<<<<<<<<
 *         value = value[:-1]
 *     # '3L' is ambiguous in Py2 but not in Py3.  '3U' and '3LL' are
*/
      __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_v_unsigned, __pyx_mstate_global->__pyx_n_u_U); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_unsigned, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      break;
    }

    /* "Cython/Compiler/Parsing.py":866
 *         else:
 *             unsigned += "U"
 *         value = value[:-1]             # <<<<<<<<<<<<<<
 *     # '3L' is ambiguous in Py2 but not in Py3.  '3U' and '3LL' are
 *     # illegal in Py2 Python files.  All suffixes are illegal in Py3
*/
    if (unlikely(__pyx_v_value == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 866, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_value, 0, -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 866, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_value, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":870
 *     # illegal in Py2 Python files.  All suffixes are illegal in Py3
 *     # Python files.
 *     is_c_literal = None             # <<<<<<<<<<<<<<
 *     if unsigned:
 *         is_c_literal = True
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_is_c_literal = Py_None;

  /* "Cython/Compiler/Parsing.py":871
 *     # Python files.
 *     is_c_literal = None
 *     if unsigned:             # <<<<<<<<<<<<<<
 *         is_c_literal = True
 *     elif longness:
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_unsigned);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 871, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":872
 *     is_c_literal = None
 *     if unsigned:
 *         is_c_literal = True             # <<<<<<<<<<<<<<
 *     elif longness:
 *         if longness == 'LL' or s.context.language_level >= 3:
*/
    __Pyx_INCREF(Py_True);
    __Pyx_DECREF_SET(__pyx_v_is_c_literal, Py_True);

    /* "Cython/Compiler/Parsing.py":871
 *     # Python files.
 *     is_c_literal = None
 *     if unsigned:             # <<<<<<<<<<<<<<
 *         is_c_literal = True
 *     elif longness:
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/Parsing.py":873
 *     if unsigned:
 *         is_c_literal = True
 *     elif longness:             # <<<<<<<<<<<<<<
 *         if longness == 'LL' or s.context.language_level >= 3:
 *             is_c_literal = True
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_longness);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 873, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":874
 *         is_c_literal = True
 *     elif longness:
 *         if longness == 'LL' or s.context.language_level >= 3:             # <<<<<<<<<<<<<<
 *             is_c_literal = True
 *     if s.in_python_file:
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_longness, __pyx_mstate_global->__pyx_n_u_LL, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 874, __pyx_L1_error)
    if (!__pyx_t_4) {
    } else {
      __pyx_t_6 = __pyx_t_4;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 874, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 874, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __pyx_t_4;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":875
 *     elif longness:
 *         if longness == 'LL' or s.context.language_level >= 3:
 *             is_c_literal = True             # <<<<<<<<<<<<<<
 *     if s.in_python_file:
 *         if is_c_literal:
*/
      __Pyx_INCREF(Py_True);
      __Pyx_DECREF_SET(__pyx_v_is_c_literal, Py_True);

      /* "Cython/Compiler/Parsing.py":874
 *         is_c_literal = True
 *     elif longness:
 *         if longness == 'LL' or s.context.language_level >= 3:             # <<<<<<<<<<<<<<
 *             is_c_literal = True
 *     if s.in_python_file:
*/
    }

    /* "Cython/Compiler/Parsing.py":873
 *     if unsigned:
 *         is_c_literal = True
 *     elif longness:             # <<<<<<<<<<<<<<
 *         if longness == 'LL' or s.context.language_level >= 3:
 *             is_c_literal = True
*/
  }
  __pyx_L5:;

  /* "Cython/Compiler/Parsing.py":876
 *         if longness == 'LL' or s.context.language_level >= 3:
 *             is_c_literal = True
 *     if s.in_python_file:             # <<<<<<<<<<<<<<
 *         if is_c_literal:
 *             error(pos, "illegal integer literal syntax in Python source file")
*/
  if (__pyx_v_s->in_python_file) {

    /* "Cython/Compiler/Parsing.py":877
 *             is_c_literal = True
 *     if s.in_python_file:
 *         if is_c_literal:             # <<<<<<<<<<<<<<
 *             error(pos, "illegal integer literal syntax in Python source file")
 *         is_c_literal = False
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_is_c_literal); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 877, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":878
 *     if s.in_python_file:
 *         if is_c_literal:
 *             error(pos, "illegal integer literal syntax in Python source file")             # <<<<<<<<<<<<<<
 *         is_c_literal = False
 *     return ExprNodes.IntNode(pos,
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_illegal_integer_literal_syntax_i};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 878, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":877
 *             is_c_literal = True
 *     if s.in_python_file:
 *         if is_c_literal:             # <<<<<<<<<<<<<<
 *             error(pos, "illegal integer literal syntax in Python source file")
 *         is_c_literal = False
*/
    }

    /* "Cython/Compiler/Parsing.py":879
 *         if is_c_literal:
 *             error(pos, "illegal integer literal syntax in Python source file")
 *         is_c_literal = False             # <<<<<<<<<<<<<<
 *     return ExprNodes.IntNode(pos,
 *                              is_c_literal = is_c_literal,
*/
    __Pyx_INCREF(Py_False);
    __Pyx_DECREF_SET(__pyx_v_is_c_literal, Py_False);

    /* "Cython/Compiler/Parsing.py":876
 *         if longness == 'LL' or s.context.language_level >= 3:
 *             is_c_literal = True
 *     if s.in_python_file:             # <<<<<<<<<<<<<<
 *         if is_c_literal:
 *             error(pos, "illegal integer literal syntax in Python source file")
*/
  }

  /* "Cython/Compiler/Parsing.py":880
 *             error(pos, "illegal integer literal syntax in Python source file")
 *         is_c_literal = False
 *     return ExprNodes.IntNode(pos,             # <<<<<<<<<<<<<<
 *                              is_c_literal = is_c_literal,
 *                              value = value,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":884
 *                              value = value,
 *                              unsigned = unsigned,
 *                              longness = longness)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_c_literal, __pyx_v_is_c_literal, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 880, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 880, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_unsigned, __pyx_v_unsigned, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 880, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_longness, __pyx_v_longness, __pyx_t_1, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 880, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IntNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":854
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_int_literal(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_int_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_unsigned);
  __Pyx_XDECREF(__pyx_v_longness);
  __Pyx_XDECREF(__pyx_v_is_c_literal);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":887
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_name(s: PyrexScanner, name):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_name", 0);

  /* "Cython/Compiler/Parsing.py":889
 * @cython.cfunc
 * def p_name(s: PyrexScanner, name):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if not s.compile_time_expr and name in s.compile_time_env:
 *         value = s.compile_time_env.lookup_here(name)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":890
 * def p_name(s: PyrexScanner, name):
 *     pos = s.position()
 *     if not s.compile_time_expr and name in s.compile_time_env:             # <<<<<<<<<<<<<<
 *         value = s.compile_time_env.lookup_here(name)
 *         node = wrap_compile_time_constant(pos, value)
*/
  __pyx_t_3 = (!__pyx_v_s->compile_time_expr);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, ((PyObject *)__pyx_v_s->compile_time_env), Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 890, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":891
 *     pos = s.position()
 *     if not s.compile_time_expr and name in s.compile_time_env:
 *         value = s.compile_time_env.lookup_here(name)             # <<<<<<<<<<<<<<
 *         node = wrap_compile_time_constant(pos, value)
 *         if node is not None:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s->compile_time_env);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_name};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup_here, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":892
 *     if not s.compile_time_expr and name in s.compile_time_env:
 *         value = s.compile_time_env.lookup_here(name)
 *         node = wrap_compile_time_constant(pos, value)             # <<<<<<<<<<<<<<
 *         if node is not None:
 *             return node
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_wrap_compile_time_constant(__pyx_v_pos, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":893
 *         value = s.compile_time_env.lookup_here(name)
 *         node = wrap_compile_time_constant(pos, value)
 *         if node is not None:             # <<<<<<<<<<<<<<
 *             return node
 *     return ExprNodes.NameNode(pos, name=name)
*/
    __pyx_t_2 = (__pyx_v_node != Py_None);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":894
 *         node = wrap_compile_time_constant(pos, value)
 *         if node is not None:
 *             return node             # <<<<<<<<<<<<<<
 *     return ExprNodes.NameNode(pos, name=name)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":893
 *         value = s.compile_time_env.lookup_here(name)
 *         node = wrap_compile_time_constant(pos, value)
 *         if node is not None:             # <<<<<<<<<<<<<<
 *             return node
 *     return ExprNodes.NameNode(pos, name=name)
*/
    }

    /* "Cython/Compiler/Parsing.py":890
 * def p_name(s: PyrexScanner, name):
 *     pos = s.position()
 *     if not s.compile_time_expr and name in s.compile_time_env:             # <<<<<<<<<<<<<<
 *         value = s.compile_time_env.lookup_here(name)
 *         node = wrap_compile_time_constant(pos, value)
*/
  }

  /* "Cython/Compiler/Parsing.py":895
 *         if node is not None:
 *             return node
 *     return ExprNodes.NameNode(pos, name=name)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 895, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NameNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":887
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_name(s: PyrexScanner, name):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":898
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def wrap_compile_time_constant(pos, value):
 *     if value is None:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_wrap_compile_time_constant(PyObject *__pyx_v_pos, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_bvalue = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrap_compile_time_constant", 0);

  /* "Cython/Compiler/Parsing.py":900
 * @cython.cfunc
 * def wrap_compile_time_constant(pos, value):
 *     if value is None:             # <<<<<<<<<<<<<<
 *         return ExprNodes.NoneNode(pos)
 *     elif value is Ellipsis:
*/
  __pyx_t_1 = (__pyx_v_value == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":901
 * def wrap_compile_time_constant(pos, value):
 *     if value is None:
 *         return ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *     elif value is Ellipsis:
 *         return ExprNodes.EllipsisNode(pos)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 901, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":900
 * @cython.cfunc
 * def wrap_compile_time_constant(pos, value):
 *     if value is None:             # <<<<<<<<<<<<<<
 *         return ExprNodes.NoneNode(pos)
 *     elif value is Ellipsis:
*/
  }

  /* "Cython/Compiler/Parsing.py":902
 *     if value is None:
 *         return ExprNodes.NoneNode(pos)
 *     elif value is Ellipsis:             # <<<<<<<<<<<<<<
 *         return ExprNodes.EllipsisNode(pos)
 *     elif isinstance(value, bool):
*/
  __pyx_t_1 = (__pyx_v_value == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":903
 *         return ExprNodes.NoneNode(pos)
 *     elif value is Ellipsis:
 *         return ExprNodes.EllipsisNode(pos)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, bool):
 *         return ExprNodes.BoolNode(pos, value=value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_EllipsisNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":902
 *     if value is None:
 *         return ExprNodes.NoneNode(pos)
 *     elif value is Ellipsis:             # <<<<<<<<<<<<<<
 *         return ExprNodes.EllipsisNode(pos)
 *     elif isinstance(value, bool):
*/
  }

  /* "Cython/Compiler/Parsing.py":904
 *     elif value is Ellipsis:
 *         return ExprNodes.EllipsisNode(pos)
 *     elif isinstance(value, bool):             # <<<<<<<<<<<<<<
 *         return ExprNodes.BoolNode(pos, value=value)
 *     elif isinstance(value, int):
*/
  __pyx_t_1 = PyBool_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":905
 *         return ExprNodes.EllipsisNode(pos)
 *     elif isinstance(value, bool):
 *         return ExprNodes.BoolNode(pos, value=value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, int):
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 905, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BoolNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":904
 *     elif value is Ellipsis:
 *         return ExprNodes.EllipsisNode(pos)
 *     elif isinstance(value, bool):             # <<<<<<<<<<<<<<
 *         return ExprNodes.BoolNode(pos, value=value)
 *     elif isinstance(value, int):
*/
  }

  /* "Cython/Compiler/Parsing.py":906
 *     elif isinstance(value, bool):
 *         return ExprNodes.BoolNode(pos, value=value)
 *     elif isinstance(value, int):             # <<<<<<<<<<<<<<
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, float):
*/
  __pyx_t_1 = PyLong_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":907
 *         return ExprNodes.BoolNode(pos, value=value)
 *     elif isinstance(value, int):
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, float):
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = PyObject_Repr(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_3, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 907, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_v_value, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 907, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IntNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":906
 *     elif isinstance(value, bool):
 *         return ExprNodes.BoolNode(pos, value=value)
 *     elif isinstance(value, int):             # <<<<<<<<<<<<<<
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, float):
*/
  }

  /* "Cython/Compiler/Parsing.py":908
 *     elif isinstance(value, int):
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, float):             # <<<<<<<<<<<<<<
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, complex):
*/
  __pyx_t_1 = PyFloat_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":909
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, float):
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, complex):
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = PyObject_Repr(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_3, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 909, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 909, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FloatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":908
 *     elif isinstance(value, int):
 *         return ExprNodes.IntNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, float):             # <<<<<<<<<<<<<<
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, complex):
*/
  }

  /* "Cython/Compiler/Parsing.py":910
 *     elif isinstance(value, float):
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, complex):             # <<<<<<<<<<<<<<
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))
 *         if value.real:
*/
  __pyx_t_1 = PyComplex_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":911
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, complex):
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))             # <<<<<<<<<<<<<<
 *         if value.real:
 *             # FIXME: should we care about -0.0 ?
*/
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_imag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_Repr(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_imag); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = 1;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_mstate_global->__pyx_float_0_0, __pyx_t_8};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyComplex_Type), __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_6, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 911, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_t_3, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 911, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImagNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 911, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":912
 *     elif isinstance(value, complex):
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))
 *         if value.real:             # <<<<<<<<<<<<<<
 *             # FIXME: should we care about -0.0 ?
 *             # probably not worth using the '-' operator for negative imag values
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_real); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":915
 *             # FIXME: should we care about -0.0 ?
 *             # probably not worth using the '-' operator for negative imag values
 *             node = ExprNodes.binop_node(             # <<<<<<<<<<<<<<
 *                 pos, '+', ExprNodes.FloatNode(pos, value=repr(value.real), constant_result=value.real), node,
 *                 constant_result=value)
*/
      __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_8);

      /* "Cython/Compiler/Parsing.py":916
 *             # probably not worth using the '-' operator for negative imag values
 *             node = ExprNodes.binop_node(
 *                 pos, '+', ExprNodes.FloatNode(pos, value=repr(value.real), constant_result=value.real), node,             # <<<<<<<<<<<<<<
 *                 constant_result=value)
 *         return node
*/
      __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_real); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyObject_Repr(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_real); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_6, __pyx_v_pos};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_7, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 916, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_t_5, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 916, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FloatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }

      /* "Cython/Compiler/Parsing.py":917
 *             node = ExprNodes.binop_node(
 *                 pos, '+', ExprNodes.FloatNode(pos, value=repr(value.real), constant_result=value.real), node,
 *                 constant_result=value)             # <<<<<<<<<<<<<<
 *         return node
 *     elif isinstance(value, str):
*/
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[5 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u__14, __pyx_t_3, __pyx_v_node};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_v_value, __pyx_t_9, __pyx_callargs+5, 0) < (0)) __PYX_ERR(0, 915, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_4, (5-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":912
 *     elif isinstance(value, complex):
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))
 *         if value.real:             # <<<<<<<<<<<<<<
 *             # FIXME: should we care about -0.0 ?
 *             # probably not worth using the '-' operator for negative imag values
*/
    }

    /* "Cython/Compiler/Parsing.py":918
 *                 pos, '+', ExprNodes.FloatNode(pos, value=repr(value.real), constant_result=value.real), node,
 *                 constant_result=value)
 *         return node             # <<<<<<<<<<<<<<
 *     elif isinstance(value, str):
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":910
 *     elif isinstance(value, float):
 *         return ExprNodes.FloatNode(pos, value=repr(value), constant_result=value)
 *     elif isinstance(value, complex):             # <<<<<<<<<<<<<<
 *         node = ExprNodes.ImagNode(pos, value=repr(value.imag), constant_result=complex(0.0, value.imag))
 *         if value.real:
*/
  }

  /* "Cython/Compiler/Parsing.py":919
 *                 constant_result=value)
 *         return node
 *     elif isinstance(value, str):             # <<<<<<<<<<<<<<
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
 *     elif isinstance(value, bytes):
*/
  __pyx_t_1 = PyUnicode_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":920
 *         return node
 *     elif isinstance(value, str):
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))             # <<<<<<<<<<<<<<
 *     elif isinstance(value, bytes):
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_8 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_8);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_value};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 920, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 920, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_3, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 920, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 920, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":919
 *                 constant_result=value)
 *         return node
 *     elif isinstance(value, str):             # <<<<<<<<<<<<<<
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
 *     elif isinstance(value, bytes):
*/
  }

  /* "Cython/Compiler/Parsing.py":921
 *     elif isinstance(value, str):
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
 *     elif isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
*/
  __pyx_t_1 = PyBytes_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":922
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
 *     elif isinstance(value, bytes):
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one             # <<<<<<<<<<<<<<
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
 *     elif isinstance(value, tuple):
*/
    __pyx_t_5 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_bytes_literal);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_bytes_literal; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_value, __pyx_mstate_global->__pyx_n_u_ascii};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 922, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_bvalue = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":923
 *     elif isinstance(value, bytes):
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)             # <<<<<<<<<<<<<<
 *     elif isinstance(value, tuple):
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 923, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_bvalue, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 923, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_constant_result, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 923, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BytesNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 923, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":921
 *     elif isinstance(value, str):
 *         return ExprNodes.UnicodeNode(pos, value=EncodedString(value))
 *     elif isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
*/
  }

  /* "Cython/Compiler/Parsing.py":924
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
 *     elif isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]
 *         if None in args:
*/
  __pyx_t_1 = PyTuple_Check(__pyx_v_value); 
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":925
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
 *     elif isinstance(value, tuple):
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]             # <<<<<<<<<<<<<<
 *         if None in args:
 *             # error already reported
*/
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 925, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (likely(PyList_CheckExact(__pyx_v_value)) || PyTuple_CheckExact(__pyx_v_value)) {
        __pyx_t_5 = __pyx_v_value; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_10 = 0;
        __pyx_t_11 = NULL;
      } else {
        __pyx_t_10 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 925, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 925, __pyx_L7_error)
      }
      for (;;) {
        if (likely(!__pyx_t_11)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 925, __pyx_L7_error)
              #endif
              if (__pyx_t_10 >= __pyx_temp) break;
            }
            __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_10;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 925, __pyx_L7_error)
              #endif
              if (__pyx_t_10 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_10));
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_10);
            #endif
            ++__pyx_t_10;
          }
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L7_error)
        } else {
          __pyx_t_3 = __pyx_t_11(__pyx_t_5);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 925, __pyx_L7_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_arg, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_wrap_compile_time_constant(__pyx_v_pos, __pyx_8genexpr1__pyx_v_arg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 925, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_arg); __pyx_8genexpr1__pyx_v_arg = 0;
      goto __pyx_L11_exit_scope;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_arg); __pyx_8genexpr1__pyx_v_arg = 0;
      goto __pyx_L1_error;
      __pyx_L11_exit_scope:;
    } /* exit inner scope */
    __pyx_v_args = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":926
 *     elif isinstance(value, tuple):
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]
 *         if None in args:             # <<<<<<<<<<<<<<
 *             # error already reported
 *             return None
*/
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(Py_None, __pyx_v_args, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 926, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":928
 *         if None in args:
 *             # error already reported
 *             return None             # <<<<<<<<<<<<<<
 *         return ExprNodes.TupleNode(pos, args=args)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":926
 *     elif isinstance(value, tuple):
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]
 *         if None in args:             # <<<<<<<<<<<<<<
 *             # error already reported
 *             return None
*/
    }

    /* "Cython/Compiler/Parsing.py":929
 *             # error already reported
 *             return None
 *         return ExprNodes.TupleNode(pos, args=args)             # <<<<<<<<<<<<<<
 * 
 *     error(pos, "Invalid type for compile-time constant: %r (type %s)"
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 929, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":924
 *         bvalue = bytes_literal(value, 'ascii')  # actually: unknown encoding, but BytesLiteral requires one
 *         return ExprNodes.BytesNode(pos, value=bvalue, constant_result=value)
 *     elif isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *         args = [wrap_compile_time_constant(pos, arg) for arg in value]
 *         if None in args:
*/
  }

  /* "Cython/Compiler/Parsing.py":931
 *         return ExprNodes.TupleNode(pos, args=args)
 * 
 *     error(pos, "Invalid type for compile-time constant: %r (type %s)"             # <<<<<<<<<<<<<<
 *                % (value, value.__class__.__name__))
 *     return None
*/
  __pyx_t_3 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 

  /* "Cython/Compiler/Parsing.py":932
 * 
 *     error(pos, "Invalid type for compile-time constant: %r (type %s)"
 *                % (value, value.__class__.__name__))             # <<<<<<<<<<<<<<
 *     return None
 * 
*/
  __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_value), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_Invalid_type_for_compile_time_co;
  __pyx_t_12[1] = __pyx_t_9;
  __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u_type;
  __pyx_t_12[3] = __pyx_t_8;
  __pyx_t_12[4] = __pyx_mstate_global->__pyx_kp_u__24;

  /* "Cython/Compiler/Parsing.py":931
 *         return ExprNodes.TupleNode(pos, args=args)
 * 
 *     error(pos, "Invalid type for compile-time constant: %r (type %s)"             # <<<<<<<<<<<<<<
 *                % (value, value.__class__.__name__))
 *     return None
*/
  __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_12, 5, 40 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 931, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":933
 *     error(pos, "Invalid type for compile-time constant: %r (type %s)"
 *                % (value, value.__class__.__name__))
 *     return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":898
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def wrap_compile_time_constant(pos, value):
 *     if value is None:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.wrap_compile_time_constant", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_bvalue);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":936
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cat_string_literal(s: PyrexScanner) -> tuple:
 *     # A sequence of one or more adjacent string literals.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cat_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_bytes_value = NULL;
  PyObject *__pyx_v_unicode_value = NULL;
  PyObject *__pyx_v_bstrings = NULL;
  PyObject *__pyx_v_ustrings = NULL;
  PyObject *__pyx_v_positions = NULL;
  PyObject *__pyx_v_next_kind = NULL;
  PyObject *__pyx_v_next_bytes_value = NULL;
  PyObject *__pyx_v_next_unicode_value = NULL;
  PyObject *__pyx_v_u = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_u = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *(*__pyx_t_15)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cat_string_literal", 0);

  /* "Cython/Compiler/Parsing.py":941
 *     # Returns (kind, bytes_value, unicode_value)
 *     # where kind in ('b', 'c', 'u', 'f', 't', '')
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     kind, bytes_value, unicode_value = p_string_literal(s)
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":942
 *     # where kind in ('b', 'c', 'u', 'f', 't', '')
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s)             # <<<<<<<<<<<<<<
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):
 *         return kind, bytes_value, unicode_value
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 942, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 942, __pyx_L1_error)
  }
  __pyx_v_kind = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_bytes_value = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_unicode_value = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":943
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s)
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):             # <<<<<<<<<<<<<<
 *         return kind, bytes_value, unicode_value
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 943, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 943, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_FT_STRING, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 943, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":944
 *     kind, bytes_value, unicode_value = p_string_literal(s)
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):
 *         return kind, bytes_value, unicode_value             # <<<<<<<<<<<<<<
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]
 *     bytes_value = unicode_value = None
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_kind);
    __Pyx_GIVEREF(__pyx_v_kind);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_kind) != (0)) __PYX_ERR(0, 944, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_bytes_value);
    __Pyx_GIVEREF(__pyx_v_bytes_value);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_bytes_value) != (0)) __PYX_ERR(0, 944, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_unicode_value);
    __Pyx_GIVEREF(__pyx_v_unicode_value);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_unicode_value) != (0)) __PYX_ERR(0, 944, __pyx_L1_error);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":943
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s)
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):             # <<<<<<<<<<<<<<
 *         return kind, bytes_value, unicode_value
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]
*/
  }

  /* "Cython/Compiler/Parsing.py":945
 *     if kind == 'c' or (s.sy != 'BEGIN_STRING' and s.sy != 'BEGIN_FT_STRING'):
 *         return kind, bytes_value, unicode_value
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]             # <<<<<<<<<<<<<<
 *     bytes_value = unicode_value = None
 *     while s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING':
*/
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_bytes_value);
  __Pyx_GIVEREF(__pyx_v_bytes_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_bytes_value) != (0)) __PYX_ERR(0, 945, __pyx_L1_error);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_unicode_value);
  __Pyx_GIVEREF(__pyx_v_unicode_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_unicode_value) != (0)) __PYX_ERR(0, 945, __pyx_L1_error);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 945, __pyx_L1_error);
  __pyx_v_bstrings = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_ustrings = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_v_positions = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":946
 *         return kind, bytes_value, unicode_value
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]
 *     bytes_value = unicode_value = None             # <<<<<<<<<<<<<<
 *     while s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING':
 *         pos = s.position()
*/
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF_SET(__pyx_v_bytes_value, Py_None);
  __Pyx_INCREF(Py_None);
  __Pyx_DECREF_SET(__pyx_v_unicode_value, Py_None);

  /* "Cython/Compiler/Parsing.py":947
 *     bstrings, ustrings, positions = [bytes_value], [unicode_value], [pos]
 *     bytes_value = unicode_value = None
 *     while s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)
*/
  while (1) {
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 947, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_FT_STRING, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 947, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_6;
    __pyx_L9_bool_binop_done:;
    if (!__pyx_t_5) break;

    /* "Cython/Compiler/Parsing.py":948
 *     bytes_value = unicode_value = None
 *     while s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)
 *         if next_kind == 'c':
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":949
 *     while s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING':
 *         pos = s.position()
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)             # <<<<<<<<<<<<<<
 *         if next_kind == 'c':
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (likely(__pyx_t_3 != Py_None)) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 949, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_2);
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 949, __pyx_L1_error)
    }
    __Pyx_XDECREF_SET(__pyx_v_next_kind, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_next_bytes_value, __pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_next_unicode_value, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":950
 *         pos = s.position()
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)
 *         if next_kind == 'c':             # <<<<<<<<<<<<<<
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
 *             continue
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_next_kind, __pyx_mstate_global->__pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 950, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":951
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)
 *         if next_kind == 'c':
 *             error(pos, "Cannot concatenate char literal with another string or char literal")             # <<<<<<<<<<<<<<
 *             continue
 *         elif next_kind != kind:
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Cannot_concatenate_char_literal};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":952
 *         if next_kind == 'c':
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
 *             continue             # <<<<<<<<<<<<<<
 *         elif next_kind != kind:
 *             # concatenating f strings and normal strings is allowed and leads to an f string
*/
      goto __pyx_L7_continue;

      /* "Cython/Compiler/Parsing.py":950
 *         pos = s.position()
 *         next_kind, next_bytes_value, next_unicode_value = p_string_literal(s)
 *         if next_kind == 'c':             # <<<<<<<<<<<<<<
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
 *             continue
*/
    }

    /* "Cython/Compiler/Parsing.py":953
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
 *             continue
 *         elif next_kind != kind:             # <<<<<<<<<<<<<<
 *             # concatenating f strings and normal strings is allowed and leads to an f string
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):
*/
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_next_kind, __pyx_v_kind, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 953, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 953, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":955
 *         elif next_kind != kind:
 *             # concatenating f strings and normal strings is allowed and leads to an f string
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):             # <<<<<<<<<<<<<<
 *                 kind = 'f'
 *             elif kind == 't' or next_kind == 't':
*/
      __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PySet_Add(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_f) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      if (PySet_Add(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_u) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_f) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__35) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PySet_Add(__pyx_t_2, __pyx_v_kind) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      if (PySet_Add(__pyx_t_2, __pyx_v_next_kind) < (0)) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) {
      } else {
        __pyx_t_5 = __pyx_t_6;
        goto __pyx_L13_bool_binop_done;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 955, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __pyx_t_6;
      __pyx_L13_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __pyx_t_5;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":956
 *             # concatenating f strings and normal strings is allowed and leads to an f string
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):
 *                 kind = 'f'             # <<<<<<<<<<<<<<
 *             elif kind == 't' or next_kind == 't':
 *                 error(pos, "cannot mix t-string literals with string or bytes literals")
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_f);
        __Pyx_DECREF_SET(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_f);

        /* "Cython/Compiler/Parsing.py":955
 *         elif next_kind != kind:
 *             # concatenating f strings and normal strings is allowed and leads to an f string
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):             # <<<<<<<<<<<<<<
 *                 kind = 'f'
 *             elif kind == 't' or next_kind == 't':
*/
        goto __pyx_L12;
      }

      /* "Cython/Compiler/Parsing.py":957
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):
 *                 kind = 'f'
 *             elif kind == 't' or next_kind == 't':             # <<<<<<<<<<<<<<
 *                 error(pos, "cannot mix t-string literals with string or bytes literals")
 *                 continue
*/
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_t, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 957, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_6 = __pyx_t_5;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_next_kind, __pyx_mstate_global->__pyx_n_u_t, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 957, __pyx_L1_error)
      __pyx_t_6 = __pyx_t_5;
      __pyx_L15_bool_binop_done:;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":958
 *                 kind = 'f'
 *             elif kind == 't' or next_kind == 't':
 *                 error(pos, "cannot mix t-string literals with string or bytes literals")             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
*/
        __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_cannot_mix_t_string_literals_wit};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":959
 *             elif kind == 't' or next_kind == 't':
 *                 error(pos, "cannot mix t-string literals with string or bytes literals")
 *                 continue             # <<<<<<<<<<<<<<
 *             else:
 *                 error(pos, "Cannot mix string literals of different types, expected %s'', got %s''" % (
*/
        goto __pyx_L7_continue;

        /* "Cython/Compiler/Parsing.py":957
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):
 *                 kind = 'f'
 *             elif kind == 't' or next_kind == 't':             # <<<<<<<<<<<<<<
 *                 error(pos, "cannot mix t-string literals with string or bytes literals")
 *                 continue
*/
      }

      /* "Cython/Compiler/Parsing.py":961
 *                 continue
 *             else:
 *                 error(pos, "Cannot mix string literals of different types, expected %s'', got %s''" % (             # <<<<<<<<<<<<<<
 *                     kind, next_kind))
 *                 continue
*/
      /*else*/ {
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 

        /* "Cython/Compiler/Parsing.py":962
 *             else:
 *                 error(pos, "Cannot mix string literals of different types, expected %s'', got %s''" % (
 *                     kind, next_kind))             # <<<<<<<<<<<<<<
 *                 continue
 *         bstrings.append(next_bytes_value)
*/
        __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_kind), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_next_kind), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 962, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Cannot_mix_string_literals_of_di;
        __pyx_t_9[1] = __pyx_t_4;
        __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_got;
        __pyx_t_9[3] = __pyx_t_8;
        __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__36;

        /* "Cython/Compiler/Parsing.py":961
 *                 continue
 *             else:
 *                 error(pos, "Cannot mix string literals of different types, expected %s'', got %s''" % (             # <<<<<<<<<<<<<<
 *                     kind, next_kind))
 *                 continue
*/
        __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 56 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 961, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_t_10};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 961, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":963
 *                 error(pos, "Cannot mix string literals of different types, expected %s'', got %s''" % (
 *                     kind, next_kind))
 *                 continue             # <<<<<<<<<<<<<<
 *         bstrings.append(next_bytes_value)
 *         ustrings.append(next_unicode_value)
*/
        goto __pyx_L7_continue;
      }
      __pyx_L12:;

      /* "Cython/Compiler/Parsing.py":953
 *             error(pos, "Cannot concatenate char literal with another string or char literal")
 *             continue
 *         elif next_kind != kind:             # <<<<<<<<<<<<<<
 *             # concatenating f strings and normal strings is allowed and leads to an f string
 *             if {kind, next_kind} in ({'f', 'u'}, {'f', ''}):
*/
    }

    /* "Cython/Compiler/Parsing.py":964
 *                     kind, next_kind))
 *                 continue
 *         bstrings.append(next_bytes_value)             # <<<<<<<<<<<<<<
 *         ustrings.append(next_unicode_value)
 *         positions.append(pos)
*/
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_bstrings, __pyx_v_next_bytes_value); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 964, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":965
 *                 continue
 *         bstrings.append(next_bytes_value)
 *         ustrings.append(next_unicode_value)             # <<<<<<<<<<<<<<
 *         positions.append(pos)
 *     # join and rewrap the partial literals
*/
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_ustrings, __pyx_v_next_unicode_value); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 965, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":966
 *         bstrings.append(next_bytes_value)
 *         ustrings.append(next_unicode_value)
 *         positions.append(pos)             # <<<<<<<<<<<<<<
 *     # join and rewrap the partial literals
 *     if kind in ('b', 'c', '') or kind == 'u' and None not in bstrings:
*/
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_positions, __pyx_v_pos); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 966, __pyx_L1_error)
    __pyx_L7_continue:;
  }

  /* "Cython/Compiler/Parsing.py":968
 *         positions.append(pos)
 *     # join and rewrap the partial literals
 *     if kind in ('b', 'c', '') or kind == 'u' and None not in bstrings:             # <<<<<<<<<<<<<<
 *         # Py3 enforced unicode literals are parsed as bytes/unicode combination
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)
*/
  __Pyx_INCREF(__pyx_v_kind);
  __pyx_t_3 = __pyx_v_kind;
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_b, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  if (!__pyx_t_12) {
  } else {
    __pyx_t_5 = __pyx_t_12;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  if (!__pyx_t_12) {
  } else {
    __pyx_t_5 = __pyx_t_12;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_12;
  __pyx_L20_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_12 = __pyx_t_5;
  if (!__pyx_t_12) {
  } else {
    __pyx_t_6 = __pyx_t_12;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  if (__pyx_t_12) {
  } else {
    __pyx_t_6 = __pyx_t_12;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_12 = (__Pyx_PySequence_ContainsTF(Py_None, __pyx_v_bstrings, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_12;
  __pyx_L18_bool_binop_done:;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":970
 *     if kind in ('b', 'c', '') or kind == 'u' and None not in bstrings:
 *         # Py3 enforced unicode literals are parsed as bytes/unicode combination
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)             # <<<<<<<<<<<<<<
 *     if kind in ('u', ''):
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
*/
    __pyx_t_1 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_bytes_literal);
    __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_bytes_literal; 
    __pyx_t_2 = __Pyx_PyBytes_Join(__pyx_mstate_global->__pyx_kp_b__35, __pyx_v_bstrings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_t_2, __pyx_v_s->source_encoding};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 970, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_bytes_value, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":968
 *         positions.append(pos)
 *     # join and rewrap the partial literals
 *     if kind in ('b', 'c', '') or kind == 'u' and None not in bstrings:             # <<<<<<<<<<<<<<
 *         # Py3 enforced unicode literals are parsed as bytes/unicode combination
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)
*/
  }

  /* "Cython/Compiler/Parsing.py":971
 *         # Py3 enforced unicode literals are parsed as bytes/unicode combination
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)
 *     if kind in ('u', ''):             # <<<<<<<<<<<<<<
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
 *     if kind == 'f':
*/
  __Pyx_INCREF(__pyx_v_kind);
  __pyx_t_3 = __pyx_v_kind;
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 971, __pyx_L1_error)
  if (!__pyx_t_12) {
  } else {
    __pyx_t_6 = __pyx_t_12;
    goto __pyx_L25_bool_binop_done;
  }
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 971, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_12;
  __pyx_L25_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_12 = __pyx_t_6;
  if (__pyx_t_12) {

    /* "Cython/Compiler/Parsing.py":972
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)
 *     if kind in ('u', ''):
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))             # <<<<<<<<<<<<<<
 *     if kind == 'f':
 *         unicode_value = []
*/
    __pyx_t_10 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 972, __pyx_L29_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __pyx_v_ustrings; __Pyx_INCREF(__pyx_t_8);
      __pyx_t_13 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 972, __pyx_L29_error)
          #endif
          if (__pyx_t_13 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_8, __pyx_t_13, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_13;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 972, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_u, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_12 = (__pyx_8genexpr2__pyx_v_u != Py_None);
        if (__pyx_t_12) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr2__pyx_v_u))) __PYX_ERR(0, 972, __pyx_L29_error)
        }
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_u); __pyx_8genexpr2__pyx_v_u = 0;
      goto __pyx_L34_exit_scope;
      __pyx_L29_error:;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_u); __pyx_8genexpr2__pyx_v_u = 0;
      goto __pyx_L1_error;
      __pyx_L34_exit_scope:;
    } /* exit inner scope */
    __pyx_t_8 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__35, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_10);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_8};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 972, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_unicode_value, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":971
 *         # Py3 enforced unicode literals are parsed as bytes/unicode combination
 *         bytes_value = bytes_literal(b''.join(bstrings), s.source_encoding)
 *     if kind in ('u', ''):             # <<<<<<<<<<<<<<
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
 *     if kind == 'f':
*/
  }

  /* "Cython/Compiler/Parsing.py":973
 *     if kind in ('u', ''):
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
 *     if kind == 'f':             # <<<<<<<<<<<<<<
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):
*/
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_f, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 973, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "Cython/Compiler/Parsing.py":974
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
 *     if kind == 'f':
 *         unicode_value = []             # <<<<<<<<<<<<<<
 *         for u, pos in zip(ustrings, positions):
 *             if isinstance(u, list):
*/
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_unicode_value, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":975
 *     if kind == 'f':
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):             # <<<<<<<<<<<<<<
 *             if isinstance(u, list):
 *                 unicode_value += u
*/
    __pyx_t_2 = NULL;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_ustrings, __pyx_v_positions};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_zip, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
    } else {
      __pyx_t_13 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 975, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_14)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 975, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_13, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_13;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 975, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_13));
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_13);
          #endif
          ++__pyx_t_13;
        }
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 975, __pyx_L1_error)
      } else {
        __pyx_t_3 = __pyx_t_14(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 975, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_3);
      if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
        PyObject* sequence = __pyx_t_3;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 975, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_10);
        } else {
          __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 975, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 975, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_10);
        }
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_15 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
        index = 0; __pyx_t_8 = __pyx_t_15(__pyx_t_1); if (unlikely(!__pyx_t_8)) goto __pyx_L38_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        index = 1; __pyx_t_10 = __pyx_t_15(__pyx_t_1); if (unlikely(!__pyx_t_10)) goto __pyx_L38_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_1), 2) < (0)) __PYX_ERR(0, 975, __pyx_L1_error)
        __pyx_t_15 = NULL;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L39_unpacking_done;
        __pyx_L38_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_15 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 975, __pyx_L1_error)
        __pyx_L39_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_u, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "Cython/Compiler/Parsing.py":976
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):
 *             if isinstance(u, list):             # <<<<<<<<<<<<<<
 *                 unicode_value += u
 *             else:
*/
      __pyx_t_12 = PyList_Check(__pyx_v_u); 
      if (__pyx_t_12) {

        /* "Cython/Compiler/Parsing.py":977
 *         for u, pos in zip(ustrings, positions):
 *             if isinstance(u, list):
 *                 unicode_value += u             # <<<<<<<<<<<<<<
 *             else:
 *                 # non-f-string concatenated into the f-string
*/
        __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_unicode_value, __pyx_v_u); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 977, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF_SET(__pyx_v_unicode_value, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":976
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):
 *             if isinstance(u, list):             # <<<<<<<<<<<<<<
 *                 unicode_value += u
 *             else:
*/
        goto __pyx_L40;
      }

      /* "Cython/Compiler/Parsing.py":980
 *             else:
 *                 # non-f-string concatenated into the f-string
 *                 unicode_value.append(ExprNodes.UnicodeNode(pos, value=EncodedString(u)))             # <<<<<<<<<<<<<<
 *     if kind == 't':
 *         unicode_value = []
*/
      /*else*/ {
        __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
        __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_u};
          __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 980, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_10, __pyx_v_pos};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 980, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_8, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 980, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 980, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_t_11 = __Pyx_PyObject_Append(__pyx_v_unicode_value, __pyx_t_3); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 980, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_L40:;

      /* "Cython/Compiler/Parsing.py":975
 *     if kind == 'f':
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):             # <<<<<<<<<<<<<<
 *             if isinstance(u, list):
 *                 unicode_value += u
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":973
 *     if kind in ('u', ''):
 *         unicode_value = EncodedString(''.join([u for u in ustrings if u is not None]))
 *     if kind == 'f':             # <<<<<<<<<<<<<<
 *         unicode_value = []
 *         for u, pos in zip(ustrings, positions):
*/
  }

  /* "Cython/Compiler/Parsing.py":981
 *                 # non-f-string concatenated into the f-string
 *                 unicode_value.append(ExprNodes.UnicodeNode(pos, value=EncodedString(u)))
 *     if kind == 't':             # <<<<<<<<<<<<<<
 *         unicode_value = []
 *         for u in ustrings:
*/
  __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_t, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 981, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "Cython/Compiler/Parsing.py":982
 *                 unicode_value.append(ExprNodes.UnicodeNode(pos, value=EncodedString(u)))
 *     if kind == 't':
 *         unicode_value = []             # <<<<<<<<<<<<<<
 *         for u in ustrings:
 *             unicode_value.extend(u)
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_unicode_value, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":983
 *     if kind == 't':
 *         unicode_value = []
 *         for u in ustrings:             # <<<<<<<<<<<<<<
 *             unicode_value.extend(u)
 *     return kind, bytes_value, unicode_value
*/
    __pyx_t_2 = __pyx_v_ustrings; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_13 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 983, __pyx_L1_error)
        #endif
        if (__pyx_t_13 >= __pyx_temp) break;
      }
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_13, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_13;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 983, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_u, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":984
 *         unicode_value = []
 *         for u in ustrings:
 *             unicode_value.extend(u)             # <<<<<<<<<<<<<<
 *     return kind, bytes_value, unicode_value
 * 
*/
      __pyx_t_4 = __pyx_v_unicode_value;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_u};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_extend, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 984, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":983
 *     if kind == 't':
 *         unicode_value = []
 *         for u in ustrings:             # <<<<<<<<<<<<<<
 *             unicode_value.extend(u)
 *     return kind, bytes_value, unicode_value
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":981
 *                 # non-f-string concatenated into the f-string
 *                 unicode_value.append(ExprNodes.UnicodeNode(pos, value=EncodedString(u)))
 *     if kind == 't':             # <<<<<<<<<<<<<<
 *         unicode_value = []
 *         for u in ustrings:
*/
  }

  /* "Cython/Compiler/Parsing.py":985
 *         for u in ustrings:
 *             unicode_value.extend(u)
 *     return kind, bytes_value, unicode_value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_kind);
  __Pyx_GIVEREF(__pyx_v_kind);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_kind) != (0)) __PYX_ERR(0, 985, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_bytes_value);
  __Pyx_GIVEREF(__pyx_v_bytes_value);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_bytes_value) != (0)) __PYX_ERR(0, 985, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_unicode_value);
  __Pyx_GIVEREF(__pyx_v_unicode_value);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_unicode_value) != (0)) __PYX_ERR(0, 985, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":936
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cat_string_literal(s: PyrexScanner) -> tuple:
 *     # A sequence of one or more adjacent string literals.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cat_string_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_bytes_value);
  __Pyx_XDECREF(__pyx_v_unicode_value);
  __Pyx_XDECREF(__pyx_v_bstrings);
  __Pyx_XDECREF(__pyx_v_ustrings);
  __Pyx_XDECREF(__pyx_v_positions);
  __Pyx_XDECREF(__pyx_v_next_kind);
  __Pyx_XDECREF(__pyx_v_next_bytes_value);
  __Pyx_XDECREF(__pyx_v_next_unicode_value);
  __Pyx_XDECREF(__pyx_v_u);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_u);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":988
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_opt_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_opt_string_literal *__pyx_optional_args) {
  PyObject *__pyx_v_required_type = ((PyObject*)__pyx_mstate_global->__pyx_n_u_u);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_bytes_value = NULL;
  PyObject *__pyx_v_unicode_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_opt_string_literal", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_required_type = __pyx_optional_args->required_type;
    }
  }

  /* "Cython/Compiler/Parsing.py":990
 * @cython.cfunc
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         return None
 *     pos = s.position()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 990, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":991
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':
 *         return None             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":990
 * @cython.cfunc
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         return None
 *     pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":992
 *     if s.sy != 'BEGIN_STRING':
 *         return None
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
 *     if required_type == 'u':
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pos = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":993
 *         return None
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)             # <<<<<<<<<<<<<<
 *     if required_type == 'u':
 *         if kind == 'f':
*/
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.kind_override = __pyx_v_required_type;
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(__pyx_t_2 != Py_None)) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 993, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_6);
    #else
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 993, __pyx_L1_error)
  }
  __pyx_v_kind = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_bytes_value = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_unicode_value = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "Cython/Compiler/Parsing.py":994
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
 *     if required_type == 'u':             # <<<<<<<<<<<<<<
 *         if kind == 'f':
 *             s.error("f-string not allowed here", pos)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_required_type, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 994, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":995
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
 *     if required_type == 'u':
 *         if kind == 'f':             # <<<<<<<<<<<<<<
 *             s.error("f-string not allowed here", pos)
 *         return unicode_value
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_f, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 995, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":996
 *     if required_type == 'u':
 *         if kind == 'f':
 *             s.error("f-string not allowed here", pos)             # <<<<<<<<<<<<<<
 *         return unicode_value
 *     elif required_type == 'b':
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_f_string_not_allowed_here, __pyx_v_pos};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 996, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":995
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
 *     if required_type == 'u':
 *         if kind == 'f':             # <<<<<<<<<<<<<<
 *             s.error("f-string not allowed here", pos)
 *         return unicode_value
*/
    }

    /* "Cython/Compiler/Parsing.py":997
 *         if kind == 'f':
 *             s.error("f-string not allowed here", pos)
 *         return unicode_value             # <<<<<<<<<<<<<<
 *     elif required_type == 'b':
 *         return bytes_value
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_unicode_value);
    __pyx_r = __pyx_v_unicode_value;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":994
 *     pos = s.position()
 *     kind, bytes_value, unicode_value = p_string_literal(s, required_type)
 *     if required_type == 'u':             # <<<<<<<<<<<<<<
 *         if kind == 'f':
 *             s.error("f-string not allowed here", pos)
*/
  }

  /* "Cython/Compiler/Parsing.py":998
 *             s.error("f-string not allowed here", pos)
 *         return unicode_value
 *     elif required_type == 'b':             # <<<<<<<<<<<<<<
 *         return bytes_value
 *     else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_required_type, __pyx_mstate_global->__pyx_n_u_b, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 998, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":999
 *         return unicode_value
 *     elif required_type == 'b':
 *         return bytes_value             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("internal parser configuration error")
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_bytes_value);
    __pyx_r = __pyx_v_bytes_value;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":998
 *             s.error("f-string not allowed here", pos)
 *         return unicode_value
 *     elif required_type == 'b':             # <<<<<<<<<<<<<<
 *         return bytes_value
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":1001
 *         return bytes_value
 *     else:
 *         s.error("internal parser configuration error")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_internal_parser_configuration_er};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1001, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":988
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_opt_string_literal(s: PyrexScanner, required_type: str = 'u'):
 *     if s.sy != 'BEGIN_STRING':
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_opt_string_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_bytes_value);
  __Pyx_XDECREF(__pyx_v_unicode_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1004
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def check_for_non_ascii_characters(string) -> cython.bint:
 *     s = cython.cast(str, string)  # EncodedString
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_check_for_non_ascii_characters(PyObject *__pyx_v_string) {
  PyObject *__pyx_v_s = NULL;
  Py_UCS4 __pyx_v_c;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  void *__pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_for_non_ascii_characters", 0);

  /* "Cython/Compiler/Parsing.py":1006
 * @cython.cfunc
 * def check_for_non_ascii_characters(string) -> cython.bint:
 *     s = cython.cast(str, string)  # EncodedString             # <<<<<<<<<<<<<<
 *     for c in s:
 *         if c >= '\x80':
*/
  __pyx_t_1 = __pyx_v_string;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_s = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1007
 * def check_for_non_ascii_characters(string) -> cython.bint:
 *     s = cython.cast(str, string)  # EncodedString
 *     for c in s:             # <<<<<<<<<<<<<<
 *         if c >= '\x80':
 *             return True
*/
  if (unlikely(__pyx_v_s == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(0, 1007, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_s);
  __pyx_t_2 = __pyx_v_s;
  __pyx_t_7 = __Pyx_init_unicode_iteration(__pyx_t_2, (&__pyx_t_4), (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1007, __pyx_L1_error)
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_4; __pyx_t_8++) {
    __pyx_t_3 = __pyx_t_8;
    __pyx_v_c = __Pyx_PyUnicode_READ(__pyx_t_6, __pyx_t_5, __pyx_t_3);

    /* "Cython/Compiler/Parsing.py":1008
 *     s = cython.cast(str, string)  # EncodedString
 *     for c in s:
 *         if c >= '\x80':             # <<<<<<<<<<<<<<
 *             return True
 *     return False
*/
    __pyx_t_9 = (__pyx_v_c >= 0x80);
    if (__pyx_t_9) {

      /* "Cython/Compiler/Parsing.py":1009
 *     for c in s:
 *         if c >= '\x80':
 *             return True             # <<<<<<<<<<<<<<
 *     return False
 * 
*/
      __pyx_r = 1;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1008
 *     s = cython.cast(str, string)  # EncodedString
 *     for c in s:
 *         if c >= '\x80':             # <<<<<<<<<<<<<<
 *             return True
 *     return False
*/
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1010
 *         if c >= '\x80':
 *             return True
 *     return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1004
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def check_for_non_ascii_characters(string) -> cython.bint:
 *     s = cython.cast(str, string)  # EncodedString
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.check_for_non_ascii_characters", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1013
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_string_literal_shared_read(
 *         s: PyrexScanner, pos, chars, kind,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_string_literal_shared_read(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_chars, PyObject *__pyx_v_kind, int __pyx_v_is_raw) {
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_systr = NULL;
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_is_python3_source;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_string_literal_shared_read", 0);

  /* "Cython/Compiler/Parsing.py":1021
 *     If passed an escape sequence returns an empty string.
 *     """
 *     sy = s.sy             # <<<<<<<<<<<<<<
 *     systr = s.systring
 *     result = systr
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_sy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1022
 *     """
 *     sy = s.sy
 *     systr = s.systring             # <<<<<<<<<<<<<<
 *     result = systr
 *     is_python3_source: cython.bint = s.context.language_level >= 3
*/
  __pyx_t_1 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_systr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1023
 *     sy = s.sy
 *     systr = s.systring
 *     result = systr             # <<<<<<<<<<<<<<
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     # print "p_string_literal: sy =", sy, repr(s.systring) ###
*/
  __Pyx_INCREF(__pyx_v_systr);
  __pyx_v_result = __pyx_v_systr;

  /* "Cython/Compiler/Parsing.py":1024
 *     systr = s.systring
 *     result = systr
 *     is_python3_source: cython.bint = s.context.language_level >= 3             # <<<<<<<<<<<<<<
 *     # print "p_string_literal: sy =", sy, repr(s.systring) ###
 *     if sy == 'CHARS':
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_is_python3_source = __pyx_t_3;

  /* "Cython/Compiler/Parsing.py":1026
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     # print "p_string_literal: sy =", sy, repr(s.systring) ###
 *     if sy == 'CHARS':             # <<<<<<<<<<<<<<
 *         chars.append(systr)
 *     elif sy == 'ESCAPE':
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_CHARS, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1026, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1027
 *     # print "p_string_literal: sy =", sy, repr(s.systring) ###
 *     if sy == 'CHARS':
 *         chars.append(systr)             # <<<<<<<<<<<<<<
 *     elif sy == 'ESCAPE':
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
*/
    __pyx_t_4 = __Pyx_PyObject_Append(__pyx_v_chars, __pyx_v_systr); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1027, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":1026
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     # print "p_string_literal: sy =", sy, repr(s.systring) ###
 *     if sy == 'CHARS':             # <<<<<<<<<<<<<<
 *         chars.append(systr)
 *     elif sy == 'ESCAPE':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1028
 *     if sy == 'CHARS':
 *         chars.append(systr)
 *     elif sy == 'ESCAPE':             # <<<<<<<<<<<<<<
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
 *         if is_raw and (is_python3_source or kind != 'u' or len(systr) < 2 or systr[1] not in 'Uu'):
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_ESCAPE, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1028, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1030
 *     elif sy == 'ESCAPE':
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
 *         if is_raw and (is_python3_source or kind != 'u' or len(systr) < 2 or systr[1] not in 'Uu'):             # <<<<<<<<<<<<<<
 *             chars.append(systr)
 *         else:
*/
    if (__pyx_v_is_raw) {
    } else {
      __pyx_t_3 = __pyx_v_is_raw;
      goto __pyx_L5_bool_binop_done;
    }
    if (!__pyx_v_is_python3_source) {
    } else {
      __pyx_t_3 = __pyx_v_is_python3_source;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_u, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1030, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_6 = PyObject_Length(__pyx_v_systr); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1030, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 < 2);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_systr, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1030, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Uu, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1030, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":1031
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
 *         if is_raw and (is_python3_source or kind != 'u' or len(systr) < 2 or systr[1] not in 'Uu'):
 *             chars.append(systr)             # <<<<<<<<<<<<<<
 *         else:
 *             result = ""
*/
      __pyx_t_4 = __Pyx_PyObject_Append(__pyx_v_chars, __pyx_v_systr); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1031, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":1030
 *     elif sy == 'ESCAPE':
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
 *         if is_raw and (is_python3_source or kind != 'u' or len(systr) < 2 or systr[1] not in 'Uu'):             # <<<<<<<<<<<<<<
 *             chars.append(systr)
 *         else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":1033
 *             chars.append(systr)
 *         else:
 *             result = ""             # <<<<<<<<<<<<<<
 *             _append_escape_sequence(kind, chars, systr, s)
 *     elif sy == 'NEWLINE':
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_mstate_global->__pyx_kp_u__35);

      /* "Cython/Compiler/Parsing.py":1034
 *         else:
 *             result = ""
 *             _append_escape_sequence(kind, chars, systr, s)             # <<<<<<<<<<<<<<
 *     elif sy == 'NEWLINE':
 *         chars.append('\n')
*/
      __pyx_t_2 = __pyx_v_systr;
      __Pyx_INCREF(__pyx_t_2);
      if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 1034, __pyx_L1_error)
      if (unlikely(__pyx_t_2 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
        __PYX_ERR(0, 1034, __pyx_L1_error)
      }
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing__append_escape_sequence(__pyx_v_kind, __pyx_v_chars, ((PyObject*)__pyx_t_2), __pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1034, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":1028
 *     if sy == 'CHARS':
 *         chars.append(systr)
 *     elif sy == 'ESCAPE':             # <<<<<<<<<<<<<<
 *         # in Py2, 'ur' raw unicode strings resolve unicode escapes but nothing else
 *         if is_raw and (is_python3_source or kind != 'u' or len(systr) < 2 or systr[1] not in 'Uu'):
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1035
 *             result = ""
 *             _append_escape_sequence(kind, chars, systr, s)
 *     elif sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *         chars.append('\n')
 *     elif sy == 'EOF':
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1035, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1036
 *             _append_escape_sequence(kind, chars, systr, s)
 *     elif sy == 'NEWLINE':
 *         chars.append('\n')             # <<<<<<<<<<<<<<
 *     elif sy == 'EOF':
 *         s.error("Unclosed string literal", pos=pos)
*/
    __pyx_t_4 = __Pyx_PyObject_Append(__pyx_v_chars, __pyx_mstate_global->__pyx_kp_u__37); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1036, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":1035
 *             result = ""
 *             _append_escape_sequence(kind, chars, systr, s)
 *     elif sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *         chars.append('\n')
 *     elif sy == 'EOF':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1037
 *     elif sy == 'NEWLINE':
 *         chars.append('\n')
 *     elif sy == 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Unclosed string literal", pos=pos)
 *     else:
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1037, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1038
 *         chars.append('\n')
 *     elif sy == 'EOF':
 *         s.error("Unclosed string literal", pos=pos)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Unclosed_string_literal};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1038, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1038, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1038, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1037
 *     elif sy == 'NEWLINE':
 *         chars.append('\n')
 *     elif sy == 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Unclosed string literal", pos=pos)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1040
 *         s.error("Unclosed string literal", pos=pos)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1041
 *     else:
 *         return None
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cython.cfunc
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1013
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_string_literal_shared_read(
 *         s: PyrexScanner, pos, chars, kind,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_string_literal_shared_read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_systr);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1043
 *     return result
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _validate_kind_string(pos, systring: str) -> str:
 *     kind_string = systring.rstrip('"\'').lower()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__validate_kind_string(PyObject *__pyx_v_pos, PyObject *__pyx_v_systring) {
  PyObject *__pyx_v_kind_string = NULL;
  PyObject *__pyx_v_unique_string_prefixes = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_validate_kind_string", 0);

  /* "Cython/Compiler/Parsing.py":1045
 * @cython.cfunc
 * def _validate_kind_string(pos, systring: str) -> str:
 *     kind_string = systring.rstrip('"\'').lower()             # <<<<<<<<<<<<<<
 *     if len(kind_string) <= 1 or (len(kind_string) == 2 and kind_string in "rbrurfrtr"):
 *         return kind_string
*/
  __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__rstrip, __pyx_v_systring, __pyx_mstate_global->__pyx_kp_u__38); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_kind_string = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1046
 * def _validate_kind_string(pos, systring: str) -> str:
 *     kind_string = systring.rstrip('"\'').lower()
 *     if len(kind_string) <= 1 or (len(kind_string) == 2 and kind_string in "rbrurfrtr"):             # <<<<<<<<<<<<<<
 *         return kind_string
 *     # Otherwise an error of some sort
*/
  __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_kind_string); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1046, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 <= 1);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_kind_string); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1046, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 == 2);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_ContainsTF(__pyx_v_kind_string, __pyx_mstate_global->__pyx_n_u_rbrurfrtr, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1046, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1047
 *     kind_string = systring.rstrip('"\'').lower()
 *     if len(kind_string) <= 1 or (len(kind_string) == 2 and kind_string in "rbrurfrtr"):
 *         return kind_string             # <<<<<<<<<<<<<<
 *     # Otherwise an error of some sort
 *     unique_string_prefixes = set(kind_string)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_kind_string);
    __pyx_r = __pyx_v_kind_string;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1046
 * def _validate_kind_string(pos, systring: str) -> str:
 *     kind_string = systring.rstrip('"\'').lower()
 *     if len(kind_string) <= 1 or (len(kind_string) == 2 and kind_string in "rbrurfrtr"):             # <<<<<<<<<<<<<<
 *         return kind_string
 *     # Otherwise an error of some sort
*/
  }

  /* "Cython/Compiler/Parsing.py":1049
 *         return kind_string
 *     # Otherwise an error of some sort
 *     unique_string_prefixes = set(kind_string)             # <<<<<<<<<<<<<<
 *     if len(unique_string_prefixes) != len(kind_string):
 *         error(pos, 'Duplicate string prefix character')
*/
  __pyx_t_1 = PySet_New(__pyx_v_kind_string); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_unique_string_prefixes = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1050
 *     # Otherwise an error of some sort
 *     unique_string_prefixes = set(kind_string)
 *     if len(unique_string_prefixes) != len(kind_string):             # <<<<<<<<<<<<<<
 *         error(pos, 'Duplicate string prefix character')
 *     unique_string_prefixes.discard('r')
*/
  __pyx_t_6 = PyObject_Length(__pyx_v_unique_string_prefixes); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1050, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_kind_string); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1050, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != __pyx_t_8);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1051
 *     unique_string_prefixes = set(kind_string)
 *     if len(unique_string_prefixes) != len(kind_string):
 *         error(pos, 'Duplicate string prefix character')             # <<<<<<<<<<<<<<
 *     unique_string_prefixes.discard('r')
 *     unique_string_prefixes = sorted(unique_string_prefixes)
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Duplicate_string_prefix_characte};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1050
 *     # Otherwise an error of some sort
 *     unique_string_prefixes = set(kind_string)
 *     if len(unique_string_prefixes) != len(kind_string):             # <<<<<<<<<<<<<<
 *         error(pos, 'Duplicate string prefix character')
 *     unique_string_prefixes.discard('r')
*/
  }

  /* "Cython/Compiler/Parsing.py":1052
 *     if len(unique_string_prefixes) != len(kind_string):
 *         error(pos, 'Duplicate string prefix character')
 *     unique_string_prefixes.discard('r')             # <<<<<<<<<<<<<<
 *     unique_string_prefixes = sorted(unique_string_prefixes)
 *     if len(unique_string_prefixes) >= 2:
*/
  __pyx_t_2 = __pyx_v_unique_string_prefixes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_r};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_discard, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1053
 *         error(pos, 'Duplicate string prefix character')
 *     unique_string_prefixes.discard('r')
 *     unique_string_prefixes = sorted(unique_string_prefixes)             # <<<<<<<<<<<<<<
 *     if len(unique_string_prefixes) >= 2:
 *         error(pos, f'String prefixes {unique_string_prefixes[0]} and {unique_string_prefixes[1]} cannot be combined')
*/
  __pyx_t_1 = PySequence_List(__pyx_v_unique_string_prefixes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyList_Sort(__pyx_t_1) < 0))) __PYX_ERR(0, 1053, __pyx_L1_error)
  __Pyx_DECREF_SET(__pyx_v_unique_string_prefixes, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1054
 *     unique_string_prefixes.discard('r')
 *     unique_string_prefixes = sorted(unique_string_prefixes)
 *     if len(unique_string_prefixes) >= 2:             # <<<<<<<<<<<<<<
 *         error(pos, f'String prefixes {unique_string_prefixes[0]} and {unique_string_prefixes[1]} cannot be combined')
 *     else:
*/
  __pyx_t_8 = PyObject_Length(__pyx_v_unique_string_prefixes); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1054, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_8 >= 2);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1055
 *     unique_string_prefixes = sorted(unique_string_prefixes)
 *     if len(unique_string_prefixes) >= 2:
 *         error(pos, f'String prefixes {unique_string_prefixes[0]} and {unique_string_prefixes[1]} cannot be combined')             # <<<<<<<<<<<<<<
 *     else:
 *         error(pos, f'Invalid string prefix {kind_string}')
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_unique_string_prefixes, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_t_9, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_unique_string_prefixes, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyObject_FormatSimple(__pyx_t_9, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_String_prefixes;
    __pyx_t_12[1] = __pyx_t_10;
    __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u_and_2;
    __pyx_t_12[3] = __pyx_t_11;
    __pyx_t_12[4] = __pyx_mstate_global->__pyx_kp_u_cannot_be_combined;
    __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_12, 5, 16 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10) + 5 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11) + 19, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1055, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1054
 *     unique_string_prefixes.discard('r')
 *     unique_string_prefixes = sorted(unique_string_prefixes)
 *     if len(unique_string_prefixes) >= 2:             # <<<<<<<<<<<<<<
 *         error(pos, f'String prefixes {unique_string_prefixes[0]} and {unique_string_prefixes[1]} cannot be combined')
 *     else:
*/
    goto __pyx_L8;
  }

  /* "Cython/Compiler/Parsing.py":1057
 *         error(pos, f'String prefixes {unique_string_prefixes[0]} and {unique_string_prefixes[1]} cannot be combined')
 *     else:
 *         error(pos, f'Invalid string prefix {kind_string}')             # <<<<<<<<<<<<<<
 *     return ''
 * 
*/
  /*else*/ {
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_string_prefix, __pyx_v_kind_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1057, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L8:;

  /* "Cython/Compiler/Parsing.py":1058
 *     else:
 *         error(pos, f'Invalid string prefix {kind_string}')
 *     return ''             # <<<<<<<<<<<<<<
 * 
 * @cython.cfunc
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
  __pyx_r = __pyx_mstate_global->__pyx_kp_u__35;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1043
 *     return result
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _validate_kind_string(pos, systring: str) -> str:
 *     kind_string = systring.rstrip('"\'').lower()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing._validate_kind_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kind_string);
  __Pyx_XDECREF(__pyx_v_unique_string_prefixes);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1060
 *     return ''
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_string_literal(s: PyrexScanner, kind_override=None) -> tuple:
 *     # A single string or char literal.  Returns (kind, bvalue, uvalue)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":1061
 * 
 * @cython.cfunc
 * def p_string_literal(s: PyrexScanner, kind_override=None) -> tuple:             # <<<<<<<<<<<<<<
 *     # A single string or char literal.  Returns (kind, bvalue, uvalue)
 *     # where kind in ('b', 'c', 'u', 'f', '').  The 'bvalue' is the source
*/
  PyObject *__pyx_v_kind_override = ((PyObject *)Py_None);
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_is_python3_source;
  int __pyx_v_has_non_ascii_literal_characters;
  PyObject *__pyx_v_kind_string = NULL;
  int __pyx_v_is_raw;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_chars = NULL;
  PyObject *__pyx_v_handled_chars = NULL;
  PyObject *__pyx_v_unicode_value = NULL;
  PyObject *__pyx_v_bytes_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_string_literal", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_kind_override = __pyx_optional_args->kind_override;
    }
  }

  /* "Cython/Compiler/Parsing.py":1070
 *     # strings and f-string expressions that make up the f-string.
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
 *     if s.sy == 'BEGIN_FT_STRING':             # <<<<<<<<<<<<<<
 *         assert kind_override is None
 *         return p_ft_string_literal(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_FT_STRING, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1070, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":1071
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
 *     if s.sy == 'BEGIN_FT_STRING':
 *         assert kind_override is None             # <<<<<<<<<<<<<<
 *         return p_ft_string_literal(s)
 *     pos = s.position()
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_kind_override == Py_None);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 1071, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 1071, __pyx_L1_error)
    #endif

    /* "Cython/Compiler/Parsing.py":1072
 *     if s.sy == 'BEGIN_FT_STRING':
 *         assert kind_override is None
 *         return p_ft_string_literal(s)             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     is_python3_source: cython.bint = s.context.language_level >= 3
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_literal(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1072, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1070
 *     # strings and f-string expressions that make up the f-string.
 *     # s.sy == 'BEGIN_STRING' or s.sy == 'BEGIN_FT_STRING'
 *     if s.sy == 'BEGIN_FT_STRING':             # <<<<<<<<<<<<<<
 *         assert kind_override is None
 *         return p_ft_string_literal(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":1073
 *         assert kind_override is None
 *         return p_ft_string_literal(s)
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     has_non_ascii_literal_characters = False
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pos = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1074
 *         return p_ft_string_literal(s)
 *     pos = s.position()
 *     is_python3_source: cython.bint = s.context.language_level >= 3             # <<<<<<<<<<<<<<
 *     has_non_ascii_literal_characters = False
 *     kind_string = _validate_kind_string(pos, s.systring)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_is_python3_source = __pyx_t_1;

  /* "Cython/Compiler/Parsing.py":1075
 *     pos = s.position()
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     has_non_ascii_literal_characters = False             # <<<<<<<<<<<<<<
 *     kind_string = _validate_kind_string(pos, s.systring)
 * 
*/
  __pyx_v_has_non_ascii_literal_characters = 0;

  /* "Cython/Compiler/Parsing.py":1076
 *     is_python3_source: cython.bint = s.context.language_level >= 3
 *     has_non_ascii_literal_characters = False
 *     kind_string = _validate_kind_string(pos, s.systring)             # <<<<<<<<<<<<<<
 * 
 *     is_raw: cython.bint = 'r' in kind_string
*/
  __pyx_t_3 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_3);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 1076, __pyx_L1_error)
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 1076, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing__validate_kind_string(__pyx_v_pos, ((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_kind_string = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1078
 *     kind_string = _validate_kind_string(pos, s.systring)
 * 
 *     is_raw: cython.bint = 'r' in kind_string             # <<<<<<<<<<<<<<
 * 
 *     if 'c' in kind_string:
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1078, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_r, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1078, __pyx_L1_error)
  __pyx_v_is_raw = __pyx_t_1;

  /* "Cython/Compiler/Parsing.py":1080
 *     is_raw: cython.bint = 'r' in kind_string
 * 
 *     if 'c' in kind_string:             # <<<<<<<<<<<<<<
 *         # this should never happen, since the lexer does not allow combining c
 *         # with other prefix characters
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1080, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_c, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1080, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":1083
 *         # this should never happen, since the lexer does not allow combining c
 *         # with other prefix characters
 *         if len(kind_string) != 1:             # <<<<<<<<<<<<<<
 *             error(pos, 'Invalid string prefix for character literal')
 *         kind = 'c'
*/
    if (unlikely(__pyx_v_kind_string == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 1083, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_kind_string); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1083, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_4 != 1);
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":1084
 *         # with other prefix characters
 *         if len(kind_string) != 1:
 *             error(pos, 'Invalid string prefix for character literal')             # <<<<<<<<<<<<<<
 *         kind = 'c'
 *     elif 'b' in kind_string:
*/
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Invalid_string_prefix_for_charac};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1084, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":1083
 *         # this should never happen, since the lexer does not allow combining c
 *         # with other prefix characters
 *         if len(kind_string) != 1:             # <<<<<<<<<<<<<<
 *             error(pos, 'Invalid string prefix for character literal')
 *         kind = 'c'
*/
    }

    /* "Cython/Compiler/Parsing.py":1085
 *         if len(kind_string) != 1:
 *             error(pos, 'Invalid string prefix for character literal')
 *         kind = 'c'             # <<<<<<<<<<<<<<
 *     elif 'b' in kind_string:
 *         kind = 'b'
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_c);
    __pyx_v_kind = __pyx_mstate_global->__pyx_n_u_c;

    /* "Cython/Compiler/Parsing.py":1080
 *     is_raw: cython.bint = 'r' in kind_string
 * 
 *     if 'c' in kind_string:             # <<<<<<<<<<<<<<
 *         # this should never happen, since the lexer does not allow combining c
 *         # with other prefix characters
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1086
 *             error(pos, 'Invalid string prefix for character literal')
 *         kind = 'c'
 *     elif 'b' in kind_string:             # <<<<<<<<<<<<<<
 *         kind = 'b'
 *     elif 'u' in kind_string:
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1086, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_b, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1086, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":1087
 *         kind = 'c'
 *     elif 'b' in kind_string:
 *         kind = 'b'             # <<<<<<<<<<<<<<
 *     elif 'u' in kind_string:
 *         kind = 'u'
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_b);
    __pyx_v_kind = __pyx_mstate_global->__pyx_n_u_b;

    /* "Cython/Compiler/Parsing.py":1086
 *             error(pos, 'Invalid string prefix for character literal')
 *         kind = 'c'
 *     elif 'b' in kind_string:             # <<<<<<<<<<<<<<
 *         kind = 'b'
 *     elif 'u' in kind_string:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1088
 *     elif 'b' in kind_string:
 *         kind = 'b'
 *     elif 'u' in kind_string:             # <<<<<<<<<<<<<<
 *         kind = 'u'
 *     else:
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1088, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_u, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1088, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":1089
 *         kind = 'b'
 *     elif 'u' in kind_string:
 *         kind = 'u'             # <<<<<<<<<<<<<<
 *     else:
 *         kind = ''
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_u);
    __pyx_v_kind = __pyx_mstate_global->__pyx_n_u_u;

    /* "Cython/Compiler/Parsing.py":1088
 *     elif 'b' in kind_string:
 *         kind = 'b'
 *     elif 'u' in kind_string:             # <<<<<<<<<<<<<<
 *         kind = 'u'
 *     else:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1091
 *         kind = 'u'
 *     else:
 *         kind = ''             # <<<<<<<<<<<<<<
 * 
 *     if kind == '' and kind_override is None and Future.unicode_literals in s.context.future_directives:
*/
  /*else*/ {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
    __pyx_v_kind = __pyx_mstate_global->__pyx_kp_u__35;
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":1093
 *         kind = ''
 * 
 *     if kind == '' and kind_override is None and Future.unicode_literals in s.context.future_directives:             # <<<<<<<<<<<<<<
 *         chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         kind = 'u'
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1093, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_1 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_7 = (__pyx_v_kind_override == Py_None);
  if (__pyx_t_7) {
  } else {
    __pyx_t_1 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_unicode_literals); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":1094
 * 
 *     if kind == '' and kind_override is None and Future.unicode_literals in s.context.future_directives:
 *         chars = StringEncoding.StrLiteralBuilder(s.source_encoding)             # <<<<<<<<<<<<<<
 *         kind = 'u'
 *     else:
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_s->source_encoding};
      __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_StrLiteralBuilder, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1094, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_v_chars = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1095
 *     if kind == '' and kind_override is None and Future.unicode_literals in s.context.future_directives:
 *         chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         kind = 'u'             # <<<<<<<<<<<<<<
 *     else:
 *         if kind_override is not None and kind_override in 'ub':
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_u);
    __Pyx_DECREF_SET(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_u);

    /* "Cython/Compiler/Parsing.py":1093
 *         kind = ''
 * 
 *     if kind == '' and kind_override is None and Future.unicode_literals in s.context.future_directives:             # <<<<<<<<<<<<<<
 *         chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         kind = 'u'
*/
    goto __pyx_L6;
  }

  /* "Cython/Compiler/Parsing.py":1097
 *         kind = 'u'
 *     else:
 *         if kind_override is not None and kind_override in 'ub':             # <<<<<<<<<<<<<<
 *             kind = kind_override
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
*/
  /*else*/ {
    __pyx_t_7 = (__pyx_v_kind_override != Py_None);
    if (__pyx_t_7) {
    } else {
      __pyx_t_1 = __pyx_t_7;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_ContainsTF(__pyx_v_kind_override, __pyx_mstate_global->__pyx_n_u_ub, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1097, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_7;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":1098
 *     else:
 *         if kind_override is not None and kind_override in 'ub':
 *             kind = kind_override             # <<<<<<<<<<<<<<
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
 *             chars = StringEncoding.UnicodeLiteralBuilder()
*/
      __Pyx_INCREF(__pyx_v_kind_override);
      __Pyx_DECREF_SET(__pyx_v_kind, __pyx_v_kind_override);

      /* "Cython/Compiler/Parsing.py":1097
 *         kind = 'u'
 *     else:
 *         if kind_override is not None and kind_override in 'ub':             # <<<<<<<<<<<<<<
 *             kind = kind_override
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
*/
    }

    /* "Cython/Compiler/Parsing.py":1099
 *         if kind_override is not None and kind_override in 'ub':
 *             kind = kind_override
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later             # <<<<<<<<<<<<<<
 *             chars = StringEncoding.UnicodeLiteralBuilder()
 *         elif kind == '':
*/
    __Pyx_INCREF(__pyx_v_kind);
    __pyx_t_5 = __pyx_v_kind;
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1099, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_1 = __pyx_t_7;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_f, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1099, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_7;
    __pyx_L14_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __pyx_t_1;
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1100
 *             kind = kind_override
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
 *             chars = StringEncoding.UnicodeLiteralBuilder()             # <<<<<<<<<<<<<<
 *         elif kind == '':
 *             chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeLiteralBuilder, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1100, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_v_chars = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":1099
 *         if kind_override is not None and kind_override in 'ub':
 *             kind = kind_override
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later             # <<<<<<<<<<<<<<
 *             chars = StringEncoding.UnicodeLiteralBuilder()
 *         elif kind == '':
*/
      goto __pyx_L13;
    }

    /* "Cython/Compiler/Parsing.py":1101
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
 *             chars = StringEncoding.UnicodeLiteralBuilder()
 *         elif kind == '':             # <<<<<<<<<<<<<<
 *             chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         else:
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1101, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1102
 *             chars = StringEncoding.UnicodeLiteralBuilder()
 *         elif kind == '':
 *             chars = StringEncoding.StrLiteralBuilder(s.source_encoding)             # <<<<<<<<<<<<<<
 *         else:
 *             chars = StringEncoding.BytesLiteralBuilder(s.source_encoding)
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_s->source_encoding};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_StrLiteralBuilder, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1102, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_v_chars = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":1101
 *         if kind in ('u', 'f'):  # f-strings are scanned exactly like Unicode literals, but are parsed further later
 *             chars = StringEncoding.UnicodeLiteralBuilder()
 *         elif kind == '':             # <<<<<<<<<<<<<<
 *             chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         else:
*/
      goto __pyx_L13;
    }

    /* "Cython/Compiler/Parsing.py":1104
 *             chars = StringEncoding.StrLiteralBuilder(s.source_encoding)
 *         else:
 *             chars = StringEncoding.BytesLiteralBuilder(s.source_encoding)             # <<<<<<<<<<<<<<
 * 
 *     while 1:
*/
    /*else*/ {
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_s->source_encoding};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_BytesLiteralBuilder, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_v_chars = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    __pyx_L13:;
  }
  __pyx_L6:;

  /* "Cython/Compiler/Parsing.py":1106
 *             chars = StringEncoding.BytesLiteralBuilder(s.source_encoding)
 * 
 *     while 1:             # <<<<<<<<<<<<<<
 *         s.next()
 *         handled_chars = p_string_literal_shared_read(
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":1107
 * 
 *     while 1:
 *         s.next()             # <<<<<<<<<<<<<<
 *         handled_chars = p_string_literal_shared_read(
 *             s, pos, chars, kind,
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1108
 *     while 1:
 *         s.next()
 *         handled_chars = p_string_literal_shared_read(             # <<<<<<<<<<<<<<
 *             s, pos, chars, kind,
 *             is_raw=is_raw)
*/
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal_shared_read(__pyx_v_s, __pyx_v_pos, __pyx_v_chars, __pyx_v_kind, __pyx_v_is_raw); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_handled_chars, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1111
 *             s, pos, chars, kind,
 *             is_raw=is_raw)
 *         if handled_chars is not None:             # <<<<<<<<<<<<<<
 *             if (not has_non_ascii_literal_characters and
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
*/
    __pyx_t_7 = (__pyx_v_handled_chars != Py_None);
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1112
 *             is_raw=is_raw)
 *         if handled_chars is not None:
 *             if (not has_non_ascii_literal_characters and             # <<<<<<<<<<<<<<
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
*/
      __pyx_t_1 = (!__pyx_v_has_non_ascii_literal_characters);
      if (__pyx_t_1) {
      } else {
        __pyx_t_7 = __pyx_t_1;
        goto __pyx_L20_bool_binop_done;
      }

      /* "Cython/Compiler/Parsing.py":1113
 *         if handled_chars is not None:
 *             if (not has_non_ascii_literal_characters and
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):             # <<<<<<<<<<<<<<
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
 *             continue
*/
      if (__pyx_v_is_python3_source) {
      } else {
        __pyx_t_7 = __pyx_v_is_python3_source;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_unicode_literals); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_t_1;
      __pyx_L20_bool_binop_done:;

      /* "Cython/Compiler/Parsing.py":1112
 *             is_raw=is_raw)
 *         if handled_chars is not None:
 *             if (not has_non_ascii_literal_characters and             # <<<<<<<<<<<<<<
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
*/
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1114
 *             if (not has_non_ascii_literal_characters and
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)             # <<<<<<<<<<<<<<
 *             continue
 *         if s.sy == 'END_STRING':
*/
        __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_check_for_non_ascii_characters(__pyx_v_handled_chars); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1114, __pyx_L1_error)
        __pyx_v_has_non_ascii_literal_characters = __pyx_t_7;

        /* "Cython/Compiler/Parsing.py":1112
 *             is_raw=is_raw)
 *         if handled_chars is not None:
 *             if (not has_non_ascii_literal_characters and             # <<<<<<<<<<<<<<
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
*/
      }

      /* "Cython/Compiler/Parsing.py":1115
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
 *             continue             # <<<<<<<<<<<<<<
 *         if s.sy == 'END_STRING':
 *             break
*/
      goto __pyx_L16_continue;

      /* "Cython/Compiler/Parsing.py":1111
 *             s, pos, chars, kind,
 *             is_raw=is_raw)
 *         if handled_chars is not None:             # <<<<<<<<<<<<<<
 *             if (not has_non_ascii_literal_characters and
 *                     is_python3_source and Future.unicode_literals in s.context.future_directives):
*/
    }

    /* "Cython/Compiler/Parsing.py":1116
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
 *             continue
 *         if s.sy == 'END_STRING':             # <<<<<<<<<<<<<<
 *             break
 *         else:
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_END_STRING, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1116, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1117
 *             continue
 *         if s.sy == 'END_STRING':
 *             break             # <<<<<<<<<<<<<<
 *         else:
 *             s.error("Unexpected token %r:%r in string literal" % (
*/
      goto __pyx_L17_break;

      /* "Cython/Compiler/Parsing.py":1116
 *                 has_non_ascii_literal_characters = check_for_non_ascii_characters(handled_chars)
 *             continue
 *         if s.sy == 'END_STRING':             # <<<<<<<<<<<<<<
 *             break
 *         else:
*/
    }

    /* "Cython/Compiler/Parsing.py":1119
 *             break
 *         else:
 *             s.error("Unexpected token %r:%r in string literal" % (             # <<<<<<<<<<<<<<
 *                 s.sy, s.systring))
 * 
*/
    /*else*/ {
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);

      /* "Cython/Compiler/Parsing.py":1120
 *         else:
 *             s.error("Unexpected token %r:%r in string literal" % (
 *                 s.sy, s.systring))             # <<<<<<<<<<<<<<
 * 
 *     if kind == 'c':
*/
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s->sy), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s->systring), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Unexpected_token;
      __pyx_t_9[1] = __pyx_t_3;
      __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__3;
      __pyx_t_9[3] = __pyx_t_8;
      __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u_in_string_literal;

      /* "Cython/Compiler/Parsing.py":1119
 *             break
 *         else:
 *             s.error("Unexpected token %r:%r in string literal" % (             # <<<<<<<<<<<<<<
 *                 s.sy, s.systring))
 * 
*/
      __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 18, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L16_continue:;
  }
  __pyx_L17_break:;

  /* "Cython/Compiler/Parsing.py":1122
 *                 s.sy, s.systring))
 * 
 *     if kind == 'c':             # <<<<<<<<<<<<<<
 *         unicode_value = None
 *         bytes_value = chars.getchar()
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1122, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1123
 * 
 *     if kind == 'c':
 *         unicode_value = None             # <<<<<<<<<<<<<<
 *         bytes_value = chars.getchar()
 *         if len(bytes_value) != 1:
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_unicode_value = Py_None;

    /* "Cython/Compiler/Parsing.py":1124
 *     if kind == 'c':
 *         unicode_value = None
 *         bytes_value = chars.getchar()             # <<<<<<<<<<<<<<
 *         if len(bytes_value) != 1:
 *             error(pos, "invalid character literal: %r" % bytes_value)
*/
    __pyx_t_10 = __pyx_v_chars;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getchar, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_bytes_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":1125
 *         unicode_value = None
 *         bytes_value = chars.getchar()
 *         if len(bytes_value) != 1:             # <<<<<<<<<<<<<<
 *             error(pos, "invalid character literal: %r" % bytes_value)
 *     else:
*/
    __pyx_t_4 = PyObject_Length(__pyx_v_bytes_value); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1125, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_4 != 1);
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1126
 *         bytes_value = chars.getchar()
 *         if len(bytes_value) != 1:
 *             error(pos, "invalid character literal: %r" % bytes_value)             # <<<<<<<<<<<<<<
 *     else:
 *         bytes_value, unicode_value = chars.getstrings()
*/
      __pyx_t_10 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_invalid_character_literal_r, __pyx_v_bytes_value); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_pos, __pyx_t_8};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1126, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":1125
 *         unicode_value = None
 *         bytes_value = chars.getchar()
 *         if len(bytes_value) != 1:             # <<<<<<<<<<<<<<
 *             error(pos, "invalid character literal: %r" % bytes_value)
 *     else:
*/
    }

    /* "Cython/Compiler/Parsing.py":1122
 *                 s.sy, s.systring))
 * 
 *     if kind == 'c':             # <<<<<<<<<<<<<<
 *         unicode_value = None
 *         bytes_value = chars.getchar()
*/
    goto __pyx_L24;
  }

  /* "Cython/Compiler/Parsing.py":1128
 *             error(pos, "invalid character literal: %r" % bytes_value)
 *     else:
 *         bytes_value, unicode_value = chars.getstrings()             # <<<<<<<<<<<<<<
 *         if (has_non_ascii_literal_characters
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
*/
  /*else*/ {
    __pyx_t_5 = __pyx_v_chars;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getstrings, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1128, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1128, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_8);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1128, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1128, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_8);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1128, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1128, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_10 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1128, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
      index = 0; __pyx_t_5 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_5)) goto __pyx_L26_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L26_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 2) < (0)) __PYX_ERR(0, 1128, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L27_unpacking_done;
      __pyx_L26_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1128, __pyx_L1_error)
      __pyx_L27_unpacking_done:;
    }
    __pyx_v_bytes_value = __pyx_t_5;
    __pyx_t_5 = 0;
    __pyx_v_unicode_value = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "Cython/Compiler/Parsing.py":1129
 *     else:
 *         bytes_value, unicode_value = chars.getstrings()
 *         if (has_non_ascii_literal_characters             # <<<<<<<<<<<<<<
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
 *             # Python 3 forbids literal non-ASCII characters in byte strings
*/
    if (__pyx_v_has_non_ascii_literal_characters) {
    } else {
      __pyx_t_7 = __pyx_v_has_non_ascii_literal_characters;
      goto __pyx_L29_bool_binop_done;
    }

    /* "Cython/Compiler/Parsing.py":1130
 *         bytes_value, unicode_value = chars.getstrings()
 *         if (has_non_ascii_literal_characters
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):             # <<<<<<<<<<<<<<
 *             # Python 3 forbids literal non-ASCII characters in byte strings
 *             if kind == 'b':
*/
    if (__pyx_v_is_python3_source) {
    } else {
      __pyx_t_7 = __pyx_v_is_python3_source;
      goto __pyx_L29_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_unicode_literals); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_8, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1130, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __pyx_t_1;
    __pyx_L29_bool_binop_done:;

    /* "Cython/Compiler/Parsing.py":1129
 *     else:
 *         bytes_value, unicode_value = chars.getstrings()
 *         if (has_non_ascii_literal_characters             # <<<<<<<<<<<<<<
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
 *             # Python 3 forbids literal non-ASCII characters in byte strings
*/
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1132
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
 *             # Python 3 forbids literal non-ASCII characters in byte strings
 *             if kind == 'b':             # <<<<<<<<<<<<<<
 *                 s.error("bytes can only contain ASCII literal characters.", pos=pos)
 *             bytes_value = None
*/
      __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_b, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1132, __pyx_L1_error)
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1133
 *             # Python 3 forbids literal non-ASCII characters in byte strings
 *             if kind == 'b':
 *                 s.error("bytes can only contain ASCII literal characters.", pos=pos)             # <<<<<<<<<<<<<<
 *             bytes_value = None
 *     s.next()
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_bytes_can_only_contain_ASCII_lit};
          __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __pyx_t_8 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/Parsing.py":1132
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
 *             # Python 3 forbids literal non-ASCII characters in byte strings
 *             if kind == 'b':             # <<<<<<<<<<<<<<
 *                 s.error("bytes can only contain ASCII literal characters.", pos=pos)
 *             bytes_value = None
*/
      }

      /* "Cython/Compiler/Parsing.py":1134
 *             if kind == 'b':
 *                 s.error("bytes can only contain ASCII literal characters.", pos=pos)
 *             bytes_value = None             # <<<<<<<<<<<<<<
 *     s.next()
 *     return (kind, bytes_value, unicode_value)
*/
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_bytes_value, Py_None);

      /* "Cython/Compiler/Parsing.py":1129
 *     else:
 *         bytes_value, unicode_value = chars.getstrings()
 *         if (has_non_ascii_literal_characters             # <<<<<<<<<<<<<<
 *                 and is_python3_source and Future.unicode_literals in s.context.future_directives):
 *             # Python 3 forbids literal non-ASCII characters in byte strings
*/
    }
  }
  __pyx_L24:;

  /* "Cython/Compiler/Parsing.py":1135
 *                 s.error("bytes can only contain ASCII literal characters.", pos=pos)
 *             bytes_value = None
 *     s.next()             # <<<<<<<<<<<<<<
 *     return (kind, bytes_value, unicode_value)
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "Cython/Compiler/Parsing.py":1136
 *             bytes_value = None
 *     s.next()
 *     return (kind, bytes_value, unicode_value)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_kind);
  __Pyx_GIVEREF(__pyx_v_kind);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_kind) != (0)) __PYX_ERR(0, 1136, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_bytes_value);
  __Pyx_GIVEREF(__pyx_v_bytes_value);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_bytes_value) != (0)) __PYX_ERR(0, 1136, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_unicode_value);
  __Pyx_GIVEREF(__pyx_v_unicode_value);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_v_unicode_value) != (0)) __PYX_ERR(0, 1136, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1060
 *     return ''
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_string_literal(s: PyrexScanner, kind_override=None) -> tuple:
 *     # A single string or char literal.  Returns (kind, bvalue, uvalue)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_string_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind_string);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_chars);
  __Pyx_XDECREF(__pyx_v_handled_chars);
  __Pyx_XDECREF(__pyx_v_unicode_value);
  __Pyx_XDECREF(__pyx_v_bytes_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1139
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_read_ft_string_expression(s: PyrexScanner) -> str:
 *     strings = []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_read_ft_string_expression(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_strings = NULL;
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_read_ft_string_expression", 0);

  /* "Cython/Compiler/Parsing.py":1141
 * @cython.cfunc
 * def p_read_ft_string_expression(s: PyrexScanner) -> str:
 *     strings = []             # <<<<<<<<<<<<<<
 *     while True:
 *         s.next()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_strings = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1142
 * def p_read_ft_string_expression(s: PyrexScanner) -> str:
 *     strings = []
 *     while True:             # <<<<<<<<<<<<<<
 *         s.next()
 *         sy = s.sy
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":1143
 *     strings = []
 *     while True:
 *         s.next()             # <<<<<<<<<<<<<<
 *         sy = s.sy
 *         if sy in ["END_FT_STRING_EXPR",
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1143, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1144
 *     while True:
 *         s.next()
 *         sy = s.sy             # <<<<<<<<<<<<<<
 *         if sy in ["END_FT_STRING_EXPR",
 *                     # probably an error, but handle it elsewhere
*/
    __pyx_t_1 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_sy, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1145
 *         s.next()
 *         sy = s.sy
 *         if sy in ["END_FT_STRING_EXPR",             # <<<<<<<<<<<<<<
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:
*/
    __Pyx_INCREF(__pyx_v_sy);
    __pyx_t_4 = __pyx_v_sy;
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_END_FT_STRING_EXPR, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }

    /* "Cython/Compiler/Parsing.py":1147
 *         if sy in ["END_FT_STRING_EXPR",
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:             # <<<<<<<<<<<<<<
 *             if sy == "END_FT_STRING_EXPR":
 *                 s.next()
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, Py_None, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":1145
 *         s.next()
 *         sy = s.sy
 *         if sy in ["END_FT_STRING_EXPR",             # <<<<<<<<<<<<<<
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:
*/
    __pyx_t_6 = __pyx_t_5;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":1148
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:
 *             if sy == "END_FT_STRING_EXPR":             # <<<<<<<<<<<<<<
 *                 s.next()
 *             return ''.join(strings)
*/
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_END_FT_STRING_EXPR, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1148, __pyx_L1_error)
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":1149
 *                    "EOF", None]:
 *             if sy == "END_FT_STRING_EXPR":
 *                 s.next()             # <<<<<<<<<<<<<<
 *             return ''.join(strings)
 *         strings.append(s.systring)
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1149, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1148
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:
 *             if sy == "END_FT_STRING_EXPR":             # <<<<<<<<<<<<<<
 *                 s.next()
 *             return ''.join(strings)
*/
      }

      /* "Cython/Compiler/Parsing.py":1150
 *             if sy == "END_FT_STRING_EXPR":
 *                 s.next()
 *             return ''.join(strings)             # <<<<<<<<<<<<<<
 *         strings.append(s.systring)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__35, __pyx_v_strings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1145
 *         s.next()
 *         sy = s.sy
 *         if sy in ["END_FT_STRING_EXPR",             # <<<<<<<<<<<<<<
 *                     # probably an error, but handle it elsewhere
 *                    "EOF", None]:
*/
    }

    /* "Cython/Compiler/Parsing.py":1151
 *                 s.next()
 *             return ''.join(strings)
 *         strings.append(s.systring)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_strings, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1151, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":1139
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_read_ft_string_expression(s: PyrexScanner) -> str:
 *     strings = []
*/

  /* function exit code */
  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_read_ft_string_expression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_strings);
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1154
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_replacement_field(s: PyrexScanner,
 *                                 is_raw: cython.bint, is_single_quoted: cython.bint,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_replacement_field(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_is_raw, int __pyx_v_is_single_quoted, Py_UCS4 __pyx_v_tf_string_kind) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_conversion_char = NULL;
  PyObject *__pyx_v_format_spec = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_t_string_expression = NULL;
  int __pyx_v_self_documenting;
  PyObject *__pyx_v_bracket_pos = NULL;
  PyObject *__pyx_v_expr_pos = NULL;
  PyObject *__pyx_v_expr_string = NULL;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_original_scanner = NULL;
  PyObject *__pyx_v_previous_pos = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_format_spec_contents = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8[3];
  PyObject *__pyx_t_9 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_yield_expression __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  PyObject *__pyx_t_17[4];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ft_string_replacement_field", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_s);

  /* "Cython/Compiler/Parsing.py":1158
 *                                 is_raw: cython.bint, is_single_quoted: cython.bint,
 *                                 tf_string_kind: cython.Py_UCS4) -> list:
 *     result = []             # <<<<<<<<<<<<<<
 *     conversion_char = format_spec = expr = None
 *     t_string_expression = None
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1159
 *                                 tf_string_kind: cython.Py_UCS4) -> list:
 *     result = []
 *     conversion_char = format_spec = expr = None             # <<<<<<<<<<<<<<
 *     t_string_expression = None
 *     self_documenting = False
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_conversion_char = Py_None;
  __Pyx_INCREF(Py_None);
  __pyx_v_format_spec = Py_None;
  __Pyx_INCREF(Py_None);
  __pyx_v_expr = Py_None;

  /* "Cython/Compiler/Parsing.py":1160
 *     result = []
 *     conversion_char = format_spec = expr = None
 *     t_string_expression = None             # <<<<<<<<<<<<<<
 *     self_documenting = False
 * 
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_t_string_expression = Py_None;

  /* "Cython/Compiler/Parsing.py":1161
 *     conversion_char = format_spec = expr = None
 *     t_string_expression = None
 *     self_documenting = False             # <<<<<<<<<<<<<<
 * 
 *     bracket_pos = s.position()
*/
  __pyx_v_self_documenting = 0;

  /* "Cython/Compiler/Parsing.py":1163
 *     self_documenting = False
 * 
 *     bracket_pos = s.position()             # <<<<<<<<<<<<<<
 *     expr_pos = (bracket_pos[0], bracket_pos[1], bracket_pos[2]+1)
 *     expr_string = p_read_ft_string_expression(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bracket_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1164
 * 
 *     bracket_pos = s.position()
 *     expr_pos = (bracket_pos[0], bracket_pos[1], bracket_pos[2]+1)             # <<<<<<<<<<<<<<
 *     expr_string = p_read_ft_string_expression(s)
 *     if not expr_string.strip():
*/
  if (unlikely(__pyx_v_bracket_pos == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1164, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_bracket_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_bracket_pos == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1164, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_bracket_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_bracket_pos == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1164, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_bracket_pos, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_t_3, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1164, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 1164, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_4) != (0)) __PYX_ERR(0, 1164, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_v_expr_pos = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1165
 *     bracket_pos = s.position()
 *     expr_pos = (bracket_pos[0], bracket_pos[1], bracket_pos[2]+1)
 *     expr_string = p_read_ft_string_expression(s)             # <<<<<<<<<<<<<<
 *     if not expr_string.strip():
 *         error(bracket_pos,
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_read_ft_string_expression(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_expr_string = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1166
 *     expr_pos = (bracket_pos[0], bracket_pos[1], bracket_pos[2]+1)
 *     expr_string = p_read_ft_string_expression(s)
 *     if not expr_string.strip():             # <<<<<<<<<<<<<<
 *         error(bracket_pos,
 *               f"empty expression not allowed in {tf_string_kind}-string")
*/
  __pyx_t_4 = __pyx_v_expr_string;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = (!__pyx_t_6);
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1167
 *     expr_string = p_read_ft_string_expression(s)
 *     if not expr_string.strip():
 *         error(bracket_pos,             # <<<<<<<<<<<<<<
 *               f"empty expression not allowed in {tf_string_kind}-string")
 *         result = []
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 

    /* "Cython/Compiler/Parsing.py":1168
 *     if not expr_string.strip():
 *         error(bracket_pos,
 *               f"empty expression not allowed in {tf_string_kind}-string")             # <<<<<<<<<<<<<<
 *         result = []
 *     else:
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_tf_string_kind); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_empty_expression_not_allowed_in;
    __pyx_t_8[1] = __pyx_t_1;
    __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_string;
    __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_8, 3, 32 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 7, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1));
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_bracket_pos, __pyx_t_9};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1169
 *         error(bracket_pos,
 *               f"empty expression not allowed in {tf_string_kind}-string")
 *         result = []             # <<<<<<<<<<<<<<
 *     else:
 *         original_scanner = s
*/
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1166
 *     expr_pos = (bracket_pos[0], bracket_pos[1], bracket_pos[2]+1)
 *     expr_string = p_read_ft_string_expression(s)
 *     if not expr_string.strip():             # <<<<<<<<<<<<<<
 *         error(bracket_pos,
 *               f"empty expression not allowed in {tf_string_kind}-string")
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1171
 *         result = []
 *     else:
 *         original_scanner = s             # <<<<<<<<<<<<<<
 *         s = PyrexScanner(
 *             StringIO(expr_string),
*/
  /*else*/ {
    __Pyx_INCREF((PyObject *)__pyx_v_s);
    __pyx_v_original_scanner = __pyx_v_s;

    /* "Cython/Compiler/Parsing.py":1172
 *     else:
 *         original_scanner = s
 *         s = PyrexScanner(             # <<<<<<<<<<<<<<
 *             StringIO(expr_string),
 *             bracket_pos[0],
*/
    __pyx_t_2 = NULL;

    /* "Cython/Compiler/Parsing.py":1173
 *         original_scanner = s
 *         s = PyrexScanner(
 *             StringIO(expr_string),             # <<<<<<<<<<<<<<
 *             bracket_pos[0],
 *             parent_scanner=s,
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_StringIO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_expr_string};
      __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    }

    /* "Cython/Compiler/Parsing.py":1174
 *         s = PyrexScanner(
 *             StringIO(expr_string),
 *             bracket_pos[0],             # <<<<<<<<<<<<<<
 *             parent_scanner=s,
 *             source_encoding=s.source_encoding,
*/
    if (unlikely(__pyx_v_bracket_pos == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1174, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_bracket_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":1177
 *             parent_scanner=s,
 *             source_encoding=s.source_encoding,
 *             initial_pos=expr_pos             # <<<<<<<<<<<<<<
 *         )
 *         s.bracket_nesting_level += 1
*/
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_t_9, __pyx_t_1};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_parent_scanner, ((PyObject *)__pyx_v_s), __pyx_t_4, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 1172, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_source_encoding, __pyx_v_s->source_encoding, __pyx_t_4, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 1172, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_initial_pos, __pyx_v_expr_pos, __pyx_t_4, __pyx_callargs+3, 2) < (0)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_s, ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1179
 *             initial_pos=expr_pos
 *         )
 *         s.bracket_nesting_level += 1             # <<<<<<<<<<<<<<
 *         if s.sy == "INDENT":
 *             s.next()
*/
    __pyx_v_s->bracket_nesting_level = (__pyx_v_s->bracket_nesting_level + 1);

    /* "Cython/Compiler/Parsing.py":1180
 *         )
 *         s.bracket_nesting_level += 1
 *         if s.sy == "INDENT":             # <<<<<<<<<<<<<<
 *             s.next()
 *         if s.sy == 'yield':
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_INDENT, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1180, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1181
 *         s.bracket_nesting_level += 1
 *         if s.sy == "INDENT":
 *             s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == 'yield':
 *             expr = p_yield_expression(
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1181, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1180
 *         )
 *         s.bracket_nesting_level += 1
 *         if s.sy == "INDENT":             # <<<<<<<<<<<<<<
 *             s.next()
 *         if s.sy == 'yield':
*/
    }

    /* "Cython/Compiler/Parsing.py":1182
 *         if s.sy == "INDENT":
 *             s.next()
 *         if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             expr = p_yield_expression(
 *                 s,
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_yield, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1182, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1185
 *             expr = p_yield_expression(
 *                 s,
 *                 statement_terminators=statement_terminators | {':', '}', '!'})             # <<<<<<<<<<<<<<
 *         else:
 *             expr = p_testlist_star_expr(s)
*/
      __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PySet_Add(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__3) < (0)) __PYX_ERR(0, 1185, __pyx_L1_error)
      if (PySet_Add(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__39) < (0)) __PYX_ERR(0, 1185, __pyx_L1_error)
      if (PySet_Add(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__40) < (0)) __PYX_ERR(0, 1185, __pyx_L1_error)
      __pyx_t_4 = PyNumber_Or(__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyFrozenSet_CheckExact(__pyx_t_4)) || __Pyx_RaiseUnexpectedTypeError("frozenset", __pyx_t_4))) __PYX_ERR(0, 1185, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":1183
 *             s.next()
 *         if s.sy == 'yield':
 *             expr = p_yield_expression(             # <<<<<<<<<<<<<<
 *                 s,
 *                 statement_terminators=statement_terminators | {':', '}', '!'})
*/
      __pyx_t_10.__pyx_n = 1;
      __pyx_t_10.statement_terminators = ((PyObject*)__pyx_t_4);
      __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1182
 *         if s.sy == "INDENT":
 *             s.next()
 *         if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             expr = p_yield_expression(
 *                 s,
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":1187
 *                 statement_terminators=statement_terminators | {':', '}', '!'})
 *         else:
 *             expr = p_testlist_star_expr(s)             # <<<<<<<<<<<<<<
 * 
 *         if s.sy == "=":
*/
    /*else*/ {
      __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist_star_expr(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":1189
 *             expr = p_testlist_star_expr(s)
 * 
 *         if s.sy == "=":             # <<<<<<<<<<<<<<
 *             self_documenting = True
 *             s.next()
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1189, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1190
 * 
 *         if s.sy == "=":
 *             self_documenting = True             # <<<<<<<<<<<<<<
 *             s.next()
 * 
*/
      __pyx_v_self_documenting = 1;

      /* "Cython/Compiler/Parsing.py":1191
 *         if s.sy == "=":
 *             self_documenting = True
 *             s.next()             # <<<<<<<<<<<<<<
 * 
 *         if s.sy == "!":
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1189
 *             expr = p_testlist_star_expr(s)
 * 
 *         if s.sy == "=":             # <<<<<<<<<<<<<<
 *             self_documenting = True
 *             s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":1193
 *             s.next()
 * 
 *         if s.sy == "!":             # <<<<<<<<<<<<<<
 *             # format conversion
 *             previous_pos = s.position()
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__40, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1193, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1195
 *         if s.sy == "!":
 *             # format conversion
 *             previous_pos = s.position()             # <<<<<<<<<<<<<<
 *             s.next()
 *             conversion_char = s.systring
*/
      __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_previous_pos = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1196
 *             # format conversion
 *             previous_pos = s.position()
 *             s.next()             # <<<<<<<<<<<<<<
 *             conversion_char = s.systring
 *             # validate the conversion char
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1197
 *             previous_pos = s.position()
 *             s.next()
 *             conversion_char = s.systring             # <<<<<<<<<<<<<<
 *             # validate the conversion char
 *             if conversion_char in ['}', ':', '']:
*/
      __pyx_t_3 = __pyx_v_s->systring;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_conversion_char, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1199
 *             conversion_char = s.systring
 *             # validate the conversion char
 *             if conversion_char in ['}', ':', '']:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "missing conversion character")
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):
*/
      __Pyx_INCREF(__pyx_v_conversion_char);
      __pyx_t_3 = __pyx_v_conversion_char;
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1199, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_7 = __pyx_t_6;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1199, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_7 = __pyx_t_6;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1199, __pyx_L1_error)
      __pyx_t_7 = __pyx_t_6;
      __pyx_L9_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __pyx_t_7;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":1200
 *             # validate the conversion char
 *             if conversion_char in ['}', ':', '']:
 *                 error(s.position(), "missing conversion character")             # <<<<<<<<<<<<<<
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
*/
        __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_9 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_9, __pyx_mstate_global->__pyx_kp_u_missing_conversion_character};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1200, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1199
 *             conversion_char = s.systring
 *             # validate the conversion char
 *             if conversion_char in ['}', ':', '']:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "missing conversion character")
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):
*/
        goto __pyx_L8;
      }

      /* "Cython/Compiler/Parsing.py":1201
 *             if conversion_char in ['}', ':', '']:
 *                 error(s.position(), "missing conversion character")
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):             # <<<<<<<<<<<<<<
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
 *                 s.next()
*/
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_FormattedValueNode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __pyx_t_9;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_conversion_char};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_find_conversion_func, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1201, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1201, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = (!__pyx_t_6);
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1202
 *                 error(s.position(), "missing conversion character")
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)             # <<<<<<<<<<<<<<
 *                 s.next()
 *             elif s.position()[2] != (previous_pos[2] + 1):
*/
        __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1202, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_invalid_conversion_character_s, __pyx_v_conversion_char); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1202, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_4, __pyx_t_2};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1203
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
 *                 s.next()             # <<<<<<<<<<<<<<
 *             elif s.position()[2] != (previous_pos[2] + 1):
 *                 error(s.position(), "f-string: conversion type must come right after the exclamation mark")
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1201
 *             if conversion_char in ['}', ':', '']:
 *                 error(s.position(), "missing conversion character")
 *             elif not ExprNodes.FormattedValueNode.find_conversion_func(conversion_char):             # <<<<<<<<<<<<<<
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
 *                 s.next()
*/
        goto __pyx_L8;
      }

      /* "Cython/Compiler/Parsing.py":1204
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
 *                 s.next()
 *             elif s.position()[2] != (previous_pos[2] + 1):             # <<<<<<<<<<<<<<
 *                 error(s.position(), "f-string: conversion type must come right after the exclamation mark")
 *                 s.next()
*/
      __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__pyx_t_3 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 1204, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_t_3, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(__pyx_v_previous_pos == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 1204, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_previous_pos, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyLong_AddObjC(__pyx_t_3, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1205
 *                 s.next()
 *             elif s.position()[2] != (previous_pos[2] + 1):
 *                 error(s.position(), "f-string: conversion type must come right after the exclamation mark")             # <<<<<<<<<<<<<<
 *                 s.next()
 *             else:
*/
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1205, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, __pyx_mstate_global->__pyx_kp_u_f_string_conversion_type_must_co};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1206
 *             elif s.position()[2] != (previous_pos[2] + 1):
 *                 error(s.position(), "f-string: conversion type must come right after the exclamation mark")
 *                 s.next()             # <<<<<<<<<<<<<<
 *             else:
 *                 s.next()
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1206, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1204
 *                 error(s.position(), "invalid conversion character '%s'" % conversion_char)
 *                 s.next()
 *             elif s.position()[2] != (previous_pos[2] + 1):             # <<<<<<<<<<<<<<
 *                 error(s.position(), "f-string: conversion type must come right after the exclamation mark")
 *                 s.next()
*/
        goto __pyx_L8;
      }

      /* "Cython/Compiler/Parsing.py":1208
 *                 s.next()
 *             else:
 *                 s.next()             # <<<<<<<<<<<<<<
 * 
 *         if self_documenting or tf_string_kind == 't':
*/
      /*else*/ {
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1208, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_L8:;

      /* "Cython/Compiler/Parsing.py":1193
 *             s.next()
 * 
 *         if s.sy == "!":             # <<<<<<<<<<<<<<
 *             # format conversion
 *             previous_pos = s.position()
*/
    }

    /* "Cython/Compiler/Parsing.py":1210
 *                 s.next()
 * 
 *         if self_documenting or tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *             if conversion_char is not None:
 *                 expr_string, _ = expr_string.rsplit('!', 1)
*/
    if (!__pyx_v_self_documenting) {
    } else {
      __pyx_t_7 = __pyx_v_self_documenting;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_tf_string_kind == 0x74);
    __pyx_t_7 = __pyx_t_6;
    __pyx_L13_bool_binop_done:;
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1211
 * 
 *         if self_documenting or tf_string_kind == 't':
 *             if conversion_char is not None:             # <<<<<<<<<<<<<<
 *                 expr_string, _ = expr_string.rsplit('!', 1)
 *             if tf_string_kind == 't':
*/
      __pyx_t_7 = (__pyx_v_conversion_char != Py_None);
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1212
 *         if self_documenting or tf_string_kind == 't':
 *             if conversion_char is not None:
 *                 expr_string, _ = expr_string.rsplit('!', 1)             # <<<<<<<<<<<<<<
 *             if tf_string_kind == 't':
 *                 t_string_expression = ExprNodes.UnicodeNode(
*/
        __pyx_t_3 = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__rsplit, __pyx_v_expr_string, __pyx_mstate_global->__pyx_kp_u__40, __pyx_mstate_global->__pyx_int_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1212, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (1) {
          PyObject* sequence = __pyx_t_3;
          Py_ssize_t size = __Pyx_PyList_GET_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1212, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1212, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_4);
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1212, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_expr_string, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_v__ = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "Cython/Compiler/Parsing.py":1211
 * 
 *         if self_documenting or tf_string_kind == 't':
 *             if conversion_char is not None:             # <<<<<<<<<<<<<<
 *                 expr_string, _ = expr_string.rsplit('!', 1)
 *             if tf_string_kind == 't':
*/
      }

      /* "Cython/Compiler/Parsing.py":1213
 *             if conversion_char is not None:
 *                 expr_string, _ = expr_string.rsplit('!', 1)
 *             if tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *                 t_string_expression = ExprNodes.UnicodeNode(
 *                     pos=expr_pos,
*/
      __pyx_t_7 = (__pyx_v_tf_string_kind == 0x74);
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":1214
 *                 expr_string, _ = expr_string.rsplit('!', 1)
 *             if tf_string_kind == 't':
 *                 t_string_expression = ExprNodes.UnicodeNode(             # <<<<<<<<<<<<<<
 *                     pos=expr_pos,
 *                     value=StringEncoding.EncodedString(expr_string.rstrip().rstrip('=').rstrip())
*/
        __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_4);

        /* "Cython/Compiler/Parsing.py":1216
 *                 t_string_expression = ExprNodes.UnicodeNode(
 *                     pos=expr_pos,
 *                     value=StringEncoding.EncodedString(expr_string.rstrip().rstrip('=').rstrip())             # <<<<<<<<<<<<<<
 *                 )
 *             if self_documenting:
*/
        __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_15 = __pyx_v_expr_string;
        __Pyx_INCREF(__pyx_t_15);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
          __pyx_t_14 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1216, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
        }
        __pyx_t_13 = __pyx_t_14;
        __Pyx_INCREF(__pyx_t_13);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_mstate_global->__pyx_kp_u__29};
          __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1216, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
        }
        __pyx_t_11 = __pyx_t_12;
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1216, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_EncodedString, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1216, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, NULL};
          __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1214, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_expr_pos, __pyx_t_9, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1214, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_1, __pyx_t_9, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1214, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1214, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF_SET(__pyx_v_t_string_expression, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1213
 *             if conversion_char is not None:
 *                 expr_string, _ = expr_string.rsplit('!', 1)
 *             if tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *                 t_string_expression = ExprNodes.UnicodeNode(
 *                     pos=expr_pos,
*/
      }

      /* "Cython/Compiler/Parsing.py":1218
 *                     value=StringEncoding.EncodedString(expr_string.rstrip().rstrip('=').rstrip())
 *                 )
 *             if self_documenting:             # <<<<<<<<<<<<<<
 *                 result.append(
 *                     ExprNodes.UnicodeNode(
*/
      if (__pyx_v_self_documenting) {

        /* "Cython/Compiler/Parsing.py":1220
 *             if self_documenting:
 *                 result.append(
 *                     ExprNodes.UnicodeNode(             # <<<<<<<<<<<<<<
 *                         pos=expr_pos,
 *                         value=StringEncoding.EncodedString(expr_string)
*/
        __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_9);

        /* "Cython/Compiler/Parsing.py":1222
 *                     ExprNodes.UnicodeNode(
 *                         pos=expr_pos,
 *                         value=StringEncoding.EncodedString(expr_string)             # <<<<<<<<<<<<<<
 *                     )
 *                 )
*/
        __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_expr_string};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_EncodedString, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1222, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, NULL};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1220, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_expr_pos, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1220, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_1, __pyx_t_4, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1220, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1220, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }

        /* "Cython/Compiler/Parsing.py":1219
 *                 )
 *             if self_documenting:
 *                 result.append(             # <<<<<<<<<<<<<<
 *                     ExprNodes.UnicodeNode(
 *                         pos=expr_pos,
*/
        __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_3); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 1219, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":1218
 *                     value=StringEncoding.EncodedString(expr_string.rstrip().rstrip('=').rstrip())
 *                 )
 *             if self_documenting:             # <<<<<<<<<<<<<<
 *                 result.append(
 *                     ExprNodes.UnicodeNode(
*/
      }

      /* "Cython/Compiler/Parsing.py":1210
 *                 s.next()
 * 
 *         if self_documenting or tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *             if conversion_char is not None:
 *                 expr_string, _ = expr_string.rsplit('!', 1)
*/
    }

    /* "Cython/Compiler/Parsing.py":1227
 * 
 *         # Validate that the expression string has actually ended
 *         while s.sy == "NEWLINE" or s.sy == "DEDENT":             # <<<<<<<<<<<<<<
 *             s.next()
 *         if s.sy != "EOF":
*/
    while (1) {
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1227, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_7 = __pyx_t_6;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1227, __pyx_L1_error)
      __pyx_t_7 = __pyx_t_6;
      __pyx_L20_bool_binop_done:;
      if (!__pyx_t_7) break;

      /* "Cython/Compiler/Parsing.py":1228
 *         # Validate that the expression string has actually ended
 *         while s.sy == "NEWLINE" or s.sy == "DEDENT":
 *             s.next()             # <<<<<<<<<<<<<<
 *         if s.sy != "EOF":
 *             error(
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1228, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "Cython/Compiler/Parsing.py":1229
 *         while s.sy == "NEWLINE" or s.sy == "DEDENT":
 *             s.next()
 *         if s.sy != "EOF":             # <<<<<<<<<<<<<<
 *             error(
 *                 s.position(),
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1229, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":1230
 *             s.next()
 *         if s.sy != "EOF":
 *             error(             # <<<<<<<<<<<<<<
 *                 s.position(),
 *                 f"Unexpected characters after {tf_string_kind}-string expression: {s.systring}")
*/
      __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 

      /* "Cython/Compiler/Parsing.py":1231
 *         if s.sy != "EOF":
 *             error(
 *                 s.position(),             # <<<<<<<<<<<<<<
 *                 f"Unexpected characters after {tf_string_kind}-string expression: {s.systring}")
 * 
*/
      __pyx_t_9 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);

      /* "Cython/Compiler/Parsing.py":1232
 *             error(
 *                 s.position(),
 *                 f"Unexpected characters after {tf_string_kind}-string expression: {s.systring}")             # <<<<<<<<<<<<<<
 * 
 *         s = original_scanner
*/
      __pyx_t_2 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_tf_string_kind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_12 = __Pyx_PyObject_FormatSimple(__pyx_v_s->systring, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_17[0] = __pyx_mstate_global->__pyx_kp_u_Unexpected_characters_after;
      __pyx_t_17[1] = __pyx_t_2;
      __pyx_t_17[2] = __pyx_mstate_global->__pyx_kp_u_string_expression;
      __pyx_t_17[3] = __pyx_t_12;
      __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_17, 4, 28 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 20 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_12), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_12));
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_9, __pyx_t_11};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1230, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":1229
 *         while s.sy == "NEWLINE" or s.sy == "DEDENT":
 *             s.next()
 *         if s.sy != "EOF":             # <<<<<<<<<<<<<<
 *             error(
 *                 s.position(),
*/
    }

    /* "Cython/Compiler/Parsing.py":1234
 *                 f"Unexpected characters after {tf_string_kind}-string expression: {s.systring}")
 * 
 *         s = original_scanner             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == ":":
*/
    __Pyx_INCREF((PyObject *)__pyx_v_original_scanner);
    __Pyx_DECREF_SET(__pyx_v_s, __pyx_v_original_scanner);
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1236
 *         s = original_scanner
 * 
 *     if s.sy == ":":             # <<<<<<<<<<<<<<
 *         # full format spec
 *         pos = s.position()
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1236, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1238
 *     if s.sy == ":":
 *         # full format spec
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         # Contents of format spec are handled closer to an f-string than a t-string
 *         # (even for t-strings).
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pos = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1241
 *         # Contents of format spec are handled closer to an f-string than a t-string
 *         # (even for t-strings).
 *         format_spec_contents = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=True, tf_string_kind='f')             # <<<<<<<<<<<<<<
 *         format_spec = ExprNodes.JoinedStrNode(
 *             pos,
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_middles(__pyx_v_s, __pyx_v_is_raw, __pyx_v_is_single_quoted, 1, 0x66); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_format_spec_contents = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1242
 *         # (even for t-strings).
 *         format_spec_contents = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=True, tf_string_kind='f')
 *         format_spec = ExprNodes.JoinedStrNode(             # <<<<<<<<<<<<<<
 *             pos,
 *             values=format_spec_contents
*/
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":1244
 *         format_spec = ExprNodes.JoinedStrNode(
 *             pos,
 *             values=format_spec_contents             # <<<<<<<<<<<<<<
 *         )
 *     if self_documenting and conversion_char is None and format_spec is None:
*/
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_pos};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_values, __pyx_v_format_spec_contents, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_JoinedStrNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_format_spec, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1236
 *         s = original_scanner
 * 
 *     if s.sy == ":":             # <<<<<<<<<<<<<<
 *         # full format spec
 *         pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":1246
 *             values=format_spec_contents
 *         )
 *     if self_documenting and conversion_char is None and format_spec is None:             # <<<<<<<<<<<<<<
 *         conversion_char = 'r'
 * 
*/
  if (__pyx_v_self_documenting) {
  } else {
    __pyx_t_7 = __pyx_v_self_documenting;
    goto __pyx_L25_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_conversion_char == Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_7 = __pyx_t_6;
    goto __pyx_L25_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_format_spec == Py_None);
  __pyx_t_7 = __pyx_t_6;
  __pyx_L25_bool_binop_done:;
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1247
 *         )
 *     if self_documenting and conversion_char is None and format_spec is None:
 *         conversion_char = 'r'             # <<<<<<<<<<<<<<
 * 
 *     if conversion_char is not None:
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_r);
    __Pyx_DECREF_SET(__pyx_v_conversion_char, __pyx_mstate_global->__pyx_n_u_r);

    /* "Cython/Compiler/Parsing.py":1246
 *             values=format_spec_contents
 *         )
 *     if self_documenting and conversion_char is None and format_spec is None:             # <<<<<<<<<<<<<<
 *         conversion_char = 'r'
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":1249
 *         conversion_char = 'r'
 * 
 *     if conversion_char is not None:             # <<<<<<<<<<<<<<
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':
*/
  __pyx_t_7 = (__pyx_v_conversion_char != Py_None);
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1250
 * 
 *     if conversion_char is not None:
 *         conversion_char = StringEncoding.EncodedString(conversion_char)             # <<<<<<<<<<<<<<
 *     if tf_string_kind == 't':
 *         result.append(ExprNodes.TStringInterpolationNode(
*/
    __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_conversion_char};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_EncodedString, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_conversion_char, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1249
 *         conversion_char = 'r'
 * 
 *     if conversion_char is not None:             # <<<<<<<<<<<<<<
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':
*/
  }

  /* "Cython/Compiler/Parsing.py":1251
 *     if conversion_char is not None:
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *         result.append(ExprNodes.TStringInterpolationNode(
 *             bracket_pos, value=expr, conversion_char=conversion_char,
*/
  __pyx_t_7 = (__pyx_v_tf_string_kind == 0x74);
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":1252
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':
 *         result.append(ExprNodes.TStringInterpolationNode(             # <<<<<<<<<<<<<<
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec, expression_str=t_string_expression
*/
    __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_11);

    /* "Cython/Compiler/Parsing.py":1254
 *         result.append(ExprNodes.TStringInterpolationNode(
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec, expression_str=t_string_expression             # <<<<<<<<<<<<<<
 *         ))
 *     else:
*/
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_11, __pyx_v_bracket_pos};
      __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1252, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_expr, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_conversion_char, __pyx_v_conversion_char, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_format_spec, __pyx_v_format_spec, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expression_str, __pyx_v_t_string_expression, __pyx_t_1, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TStringInterpolationNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1252, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }

    /* "Cython/Compiler/Parsing.py":1252
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':
 *         result.append(ExprNodes.TStringInterpolationNode(             # <<<<<<<<<<<<<<
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec, expression_str=t_string_expression
*/
    __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_3); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 1252, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1251
 *     if conversion_char is not None:
 *         conversion_char = StringEncoding.EncodedString(conversion_char)
 *     if tf_string_kind == 't':             # <<<<<<<<<<<<<<
 *         result.append(ExprNodes.TStringInterpolationNode(
 *             bracket_pos, value=expr, conversion_char=conversion_char,
*/
    goto __pyx_L29;
  }

  /* "Cython/Compiler/Parsing.py":1257
 *         ))
 *     else:
 *         result.append(ExprNodes.FormattedValueNode(             # <<<<<<<<<<<<<<
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":1259
 *         result.append(ExprNodes.FormattedValueNode(
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec             # <<<<<<<<<<<<<<
 *         ))
 *     return result
*/
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_1, __pyx_v_bracket_pos};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_expr, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1257, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_conversion_char, __pyx_v_conversion_char, __pyx_t_11, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1257, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_format_spec, __pyx_v_format_spec, __pyx_t_11, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1257, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FormattedValueNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }

    /* "Cython/Compiler/Parsing.py":1257
 *         ))
 *     else:
 *         result.append(ExprNodes.FormattedValueNode(             # <<<<<<<<<<<<<<
 *             bracket_pos, value=expr, conversion_char=conversion_char,
 *             format_spec=format_spec
*/
    __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_3); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 1257, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L29:;

  /* "Cython/Compiler/Parsing.py":1261
 *             format_spec=format_spec
 *         ))
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cython.cfunc
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1154
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_replacement_field(s: PyrexScanner,
 *                                 is_raw: cython.bint, is_single_quoted: cython.bint,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ft_string_replacement_field", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_conversion_char);
  __Pyx_XDECREF(__pyx_v_format_spec);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_t_string_expression);
  __Pyx_XDECREF(__pyx_v_bracket_pos);
  __Pyx_XDECREF(__pyx_v_expr_pos);
  __Pyx_XDECREF(__pyx_v_expr_string);
  __Pyx_XDECREF((PyObject *)__pyx_v_original_scanner);
  __Pyx_XDECREF(__pyx_v_previous_pos);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_format_spec_contents);
  __Pyx_XDECREF((PyObject *)__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1263
 *     return result
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_middles(s: PyrexScanner,
 *                         is_raw: cython.bint, is_single_quoted: cython.bint,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_middles(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_is_raw, int __pyx_v_is_single_quoted, int __pyx_v_is_format_string, Py_UCS4 __pyx_v_tf_string_kind) {
  PyObject *__pyx_v_middles = 0;
  PyObject *__pyx_v_builder = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_handled_chars = NULL;
  PyObject *__pyx_v_fields = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[7];
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ft_string_middles", 0);

  /* "Cython/Compiler/Parsing.py":1268
 *                         is_format_string: cython.bint,
 *                         tf_string_kind: cython.Py_UCS4) -> list:
 *     middles: list = []             # <<<<<<<<<<<<<<
 *     builder = StringEncoding.UnicodeLiteralBuilder()
 *     pos = s.position()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_middles = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1269
 *                         tf_string_kind: cython.Py_UCS4) -> list:
 *     middles: list = []
 *     builder = StringEncoding.UnicodeLiteralBuilder()             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     while True:
*/
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeLiteralBuilder, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_builder = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1270
 *     middles: list = []
 *     builder = StringEncoding.UnicodeLiteralBuilder()
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     while True:
 *         s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1271
 *     builder = StringEncoding.UnicodeLiteralBuilder()
 *     pos = s.position()
 *     while True:             # <<<<<<<<<<<<<<
 *         s.next()
 *         sy = s.sy
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":1272
 *     pos = s.position()
 *     while True:
 *         s.next()             # <<<<<<<<<<<<<<
 *         sy = s.sy
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1273
 *     while True:
 *         s.next()
 *         sy = s.sy             # <<<<<<<<<<<<<<
 * 
 *         handled_chars = p_string_literal_shared_read(
*/
    __pyx_t_1 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_sy, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1275
 *         sy = s.sy
 * 
 *         handled_chars = p_string_literal_shared_read(             # <<<<<<<<<<<<<<
 *             s, pos, builder, "u",
 *             is_raw=is_raw)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal_shared_read(__pyx_v_s, __pyx_v_pos, __pyx_v_builder, __pyx_mstate_global->__pyx_n_u_u, __pyx_v_is_raw); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_handled_chars, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1278
 *             s, pos, builder, "u",
 *             is_raw=is_raw)
 *         if handled_chars is not None:             # <<<<<<<<<<<<<<
 *             continue
 * 
*/
    __pyx_t_4 = (__pyx_v_handled_chars != Py_None);
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1279
 *             is_raw=is_raw)
 *         if handled_chars is not None:
 *             continue             # <<<<<<<<<<<<<<
 * 
 *         if builder.chars:
*/
      goto __pyx_L3_continue;

      /* "Cython/Compiler/Parsing.py":1278
 *             s, pos, builder, "u",
 *             is_raw=is_raw)
 *         if handled_chars is not None:             # <<<<<<<<<<<<<<
 *             continue
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":1281
 *             continue
 * 
 *         if builder.chars:             # <<<<<<<<<<<<<<
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))
 *             builder = StringEncoding.UnicodeLiteralBuilder()
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_builder, __pyx_mstate_global->__pyx_n_u_chars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1282
 * 
 *         if builder.chars:
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))             # <<<<<<<<<<<<<<
 *             builder = StringEncoding.UnicodeLiteralBuilder()
 *         if sy == "{":
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = __pyx_v_builder;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getstring, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1282, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1282, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1282, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1282, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_middles, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1282, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1283
 *         if builder.chars:
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))
 *             builder = StringEncoding.UnicodeLiteralBuilder()             # <<<<<<<<<<<<<<
 *         if sy == "{":
 *             fields = p_ft_string_replacement_field(
*/
      __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_UnicodeLiteralBuilder, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1283, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_builder, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1281
 *             continue
 * 
 *         if builder.chars:             # <<<<<<<<<<<<<<
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))
 *             builder = StringEncoding.UnicodeLiteralBuilder()
*/
    }

    /* "Cython/Compiler/Parsing.py":1284
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))
 *             builder = StringEncoding.UnicodeLiteralBuilder()
 *         if sy == "{":             # <<<<<<<<<<<<<<
 *             fields = p_ft_string_replacement_field(
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_kp_u__32, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1284, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1285
 *             builder = StringEncoding.UnicodeLiteralBuilder()
 *         if sy == "{":
 *             fields = p_ft_string_replacement_field(             # <<<<<<<<<<<<<<
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
 *             middles.extend(fields)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_replacement_field(__pyx_v_s, __pyx_v_is_raw, __pyx_v_is_single_quoted, __pyx_v_tf_string_kind); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_fields, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1287
 *             fields = p_ft_string_replacement_field(
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
 *             middles.extend(fields)             # <<<<<<<<<<<<<<
 *             if not s.sy == '}':
 *                 s.expected('}')
*/
      __pyx_t_7 = __Pyx_PyList_Extend(__pyx_v_middles, __pyx_v_fields); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1287, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":1288
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
 *             middles.extend(fields)
 *             if not s.sy == '}':             # <<<<<<<<<<<<<<
 *                 s.expected('}')
 *             continue
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1288, __pyx_L1_error)
      __pyx_t_8 = (!__pyx_t_4);
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1289
 *             middles.extend(fields)
 *             if not s.sy == '}':
 *                 s.expected('}')             # <<<<<<<<<<<<<<
 *             continue
 *         elif sy == "END_FT_STRING":
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__39};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1289, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1288
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
 *             middles.extend(fields)
 *             if not s.sy == '}':             # <<<<<<<<<<<<<<
 *                 s.expected('}')
 *             continue
*/
      }

      /* "Cython/Compiler/Parsing.py":1290
 *             if not s.sy == '}':
 *                 s.expected('}')
 *             continue             # <<<<<<<<<<<<<<
 *         elif sy == "END_FT_STRING":
 *             break
*/
      goto __pyx_L3_continue;

      /* "Cython/Compiler/Parsing.py":1284
 *             middles.append(ExprNodes.UnicodeNode(pos, value=builder.getstring()))
 *             builder = StringEncoding.UnicodeLiteralBuilder()
 *         if sy == "{":             # <<<<<<<<<<<<<<
 *             fields = p_ft_string_replacement_field(
 *                 s, is_raw, is_single_quoted, tf_string_kind=tf_string_kind)
*/
    }

    /* "Cython/Compiler/Parsing.py":1291
 *                 s.expected('}')
 *             continue
 *         elif sy == "END_FT_STRING":             # <<<<<<<<<<<<<<
 *             break
 *         elif s.sy == '}':
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_END_FT_STRING, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1291, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1292
 *             continue
 *         elif sy == "END_FT_STRING":
 *             break             # <<<<<<<<<<<<<<
 *         elif s.sy == '}':
 *             if is_format_string:
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":1291
 *                 s.expected('}')
 *             continue
 *         elif sy == "END_FT_STRING":             # <<<<<<<<<<<<<<
 *             break
 *         elif s.sy == '}':
*/
    }

    /* "Cython/Compiler/Parsing.py":1293
 *         elif sy == "END_FT_STRING":
 *             break
 *         elif s.sy == '}':             # <<<<<<<<<<<<<<
 *             if is_format_string:
 *                 break
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1293, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1294
 *             break
 *         elif s.sy == '}':
 *             if is_format_string:             # <<<<<<<<<<<<<<
 *                 break
 *             # otherwise it's an error, but the scanner has reported it
*/
      if (__pyx_v_is_format_string) {

        /* "Cython/Compiler/Parsing.py":1295
 *         elif s.sy == '}':
 *             if is_format_string:
 *                 break             # <<<<<<<<<<<<<<
 *             # otherwise it's an error, but the scanner has reported it
 *         else:
*/
        goto __pyx_L4_break;

        /* "Cython/Compiler/Parsing.py":1294
 *             break
 *         elif s.sy == '}':
 *             if is_format_string:             # <<<<<<<<<<<<<<
 *                 break
 *             # otherwise it's an error, but the scanner has reported it
*/
      }

      /* "Cython/Compiler/Parsing.py":1293
 *         elif sy == "END_FT_STRING":
 *             break
 *         elif s.sy == '}':             # <<<<<<<<<<<<<<
 *             if is_format_string:
 *                 break
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Parsing.py":1298
 *             # otherwise it's an error, but the scanner has reported it
 *         else:
 *             error(             # <<<<<<<<<<<<<<
 *                 s.position(),
 *                 "Unexpected token %r:%r in %s-string literal" % (
*/
    /*else*/ {
      __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 

      /* "Cython/Compiler/Parsing.py":1299
 *         else:
 *             error(
 *                 s.position(),             # <<<<<<<<<<<<<<
 *                 "Unexpected token %r:%r in %s-string literal" % (
 *                 s.sy, s.systring, tf_string_kind))
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "Cython/Compiler/Parsing.py":1301
 *                 s.position(),
 *                 "Unexpected token %r:%r in %s-string literal" % (
 *                 s.sy, s.systring, tf_string_kind))             # <<<<<<<<<<<<<<
 *     return middles
 * 
*/
      __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s->sy), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s->systring), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_tf_string_kind); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_Unexpected_token;
      __pyx_t_12[1] = __pyx_t_9;
      __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u__3;
      __pyx_t_12[3] = __pyx_t_10;
      __pyx_t_12[4] = __pyx_mstate_global->__pyx_kp_u_in_2;
      __pyx_t_12[5] = __pyx_t_11;
      __pyx_t_12[6] = __pyx_mstate_global->__pyx_kp_u_string_literal;

      /* "Cython/Compiler/Parsing.py":1300
 *             error(
 *                 s.position(),
 *                 "Unexpected token %r:%r in %s-string literal" % (             # <<<<<<<<<<<<<<
 *                 s.sy, s.systring, tf_string_kind))
 *     return middles
*/
      __pyx_t_13 = __Pyx_PyUnicode_Join(__pyx_t_12, 7, 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10) + 4 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11) + 15, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_2, __pyx_t_13};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L7:;
    __pyx_L3_continue:;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":1302
 *                 "Unexpected token %r:%r in %s-string literal" % (
 *                 s.sy, s.systring, tf_string_kind))
 *     return middles             # <<<<<<<<<<<<<<
 * 
 * @cython.cfunc
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_middles);
  __pyx_r = __pyx_v_middles;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1263
 *     return result
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_middles(s: PyrexScanner,
 *                         is_raw: cython.bint, is_single_quoted: cython.bint,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ft_string_middles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_middles);
  __Pyx_XDECREF(__pyx_v_builder);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_handled_chars);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1304
 *     return middles
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_literal(s: PyrexScanner) -> tuple:
 *     # s.sy == BEGIN_FT_STRING
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_literal(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_kind_string = NULL;
  Py_UCS4 __pyx_v_tf_string_kind;
  int __pyx_v_is_raw;
  PyObject *__pyx_v_quotes = NULL;
  int __pyx_v_is_single_quoted;
  PyObject *__pyx_v_middles = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_UCS4 __pyx_t_4;
  int __pyx_t_5;
  size_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ft_string_literal", 0);

  /* "Cython/Compiler/Parsing.py":1307
 * def p_ft_string_literal(s: PyrexScanner) -> tuple:
 *     # s.sy == BEGIN_FT_STRING
 *     kind_string = _validate_kind_string(s.position(), s.systring)             # <<<<<<<<<<<<<<
 *     tf_string_kind: cython.Py_UCS4 = 't' if 't' in kind_string else 'f'
 *     is_raw: cython.bint = 'r' in kind_string
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 1307, __pyx_L1_error)
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 1307, __pyx_L1_error)
  }
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing__validate_kind_string(__pyx_t_1, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_kind_string = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1308
 *     # s.sy == BEGIN_FT_STRING
 *     kind_string = _validate_kind_string(s.position(), s.systring)
 *     tf_string_kind: cython.Py_UCS4 = 't' if 't' in kind_string else 'f'             # <<<<<<<<<<<<<<
 *     is_raw: cython.bint = 'r' in kind_string
 *     quotes = s.systring.lstrip("rRbBuUfFtT")
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1308, __pyx_L1_error)
  }
  __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_t, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1308, __pyx_L1_error)
  if (__pyx_t_5) {
    __pyx_t_4 = 0x74;
  } else {
    __pyx_t_4 = 0x66;
  }
  __pyx_v_tf_string_kind = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":1309
 *     kind_string = _validate_kind_string(s.position(), s.systring)
 *     tf_string_kind: cython.Py_UCS4 = 't' if 't' in kind_string else 'f'
 *     is_raw: cython.bint = 'r' in kind_string             # <<<<<<<<<<<<<<
 *     quotes = s.systring.lstrip("rRbBuUfFtT")
 *     is_single_quoted: cython.bint = len(quotes) != 3
*/
  if (unlikely(__pyx_v_kind_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1309, __pyx_L1_error)
  }
  __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_r, __pyx_v_kind_string, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1309, __pyx_L1_error)
  __pyx_v_is_raw = __pyx_t_5;

  /* "Cython/Compiler/Parsing.py":1310
 *     tf_string_kind: cython.Py_UCS4 = 't' if 't' in kind_string else 'f'
 *     is_raw: cython.bint = 'r' in kind_string
 *     quotes = s.systring.lstrip("rRbBuUfFtT")             # <<<<<<<<<<<<<<
 *     is_single_quoted: cython.bint = len(quotes) != 3
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)
*/
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_rRbBuUfFtT};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_quotes = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1311
 *     is_raw: cython.bint = 'r' in kind_string
 *     quotes = s.systring.lstrip("rRbBuUfFtT")
 *     is_single_quoted: cython.bint = len(quotes) != 3             # <<<<<<<<<<<<<<
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)
 *     if s.sy != "END_FT_STRING":
*/
  __pyx_t_7 = PyObject_Length(__pyx_v_quotes); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1311, __pyx_L1_error)
  __pyx_v_is_single_quoted = (__pyx_t_7 != 3);

  /* "Cython/Compiler/Parsing.py":1312
 *     quotes = s.systring.lstrip("rRbBuUfFtT")
 *     is_single_quoted: cython.bint = len(quotes) != 3
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)             # <<<<<<<<<<<<<<
 *     if s.sy != "END_FT_STRING":
 *         s.expected(quotes)
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ft_string_middles(__pyx_v_s, __pyx_v_is_raw, __pyx_v_is_single_quoted, 0, __pyx_v_tf_string_kind); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_middles = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1313
 *     is_single_quoted: cython.bint = len(quotes) != 3
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)
 *     if s.sy != "END_FT_STRING":             # <<<<<<<<<<<<<<
 *         s.expected(quotes)
 *     s.next()
*/
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_END_FT_STRING, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1313, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1314
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)
 *     if s.sy != "END_FT_STRING":
 *         s.expected(quotes)             # <<<<<<<<<<<<<<
 *     s.next()
 *     return tf_string_kind, None, middles
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_quotes};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":1313
 *     is_single_quoted: cython.bint = len(quotes) != 3
 *     middles = p_ft_string_middles(s, is_raw, is_single_quoted, is_format_string=False, tf_string_kind=tf_string_kind)
 *     if s.sy != "END_FT_STRING":             # <<<<<<<<<<<<<<
 *         s.expected(quotes)
 *     s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":1315
 *     if s.sy != "END_FT_STRING":
 *         s.expected(quotes)
 *     s.next()             # <<<<<<<<<<<<<<
 *     return tf_string_kind, None, middles
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":1316
 *         s.expected(quotes)
 *     s.next()
 *     return tf_string_kind, None, middles             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_tf_string_kind); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 1316, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None) != (0)) __PYX_ERR(0, 1316, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_middles);
  __Pyx_GIVEREF(__pyx_v_middles);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_middles) != (0)) __PYX_ERR(0, 1316, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1304
 *     return middles
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ft_string_literal(s: PyrexScanner) -> tuple:
 *     # s.sy == BEGIN_FT_STRING
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ft_string_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kind_string);
  __Pyx_XDECREF(__pyx_v_quotes);
  __Pyx_XDECREF(__pyx_v_middles);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1319
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _append_escape_sequence(kind, builder, escape_sequence: str, s: PyrexScanner):
 *     if len(escape_sequence) < 2:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__append_escape_sequence(PyObject *__pyx_v_kind, PyObject *__pyx_v_builder, PyObject *__pyx_v_escape_sequence, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  Py_UCS4 __pyx_v_c;
  PyObject *__pyx_v_chrval = NULL;
  PyObject *__pyx_v_uchar = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  long __pyx_t_16;
  int __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_append_escape_sequence", 0);

  /* "Cython/Compiler/Parsing.py":1321
 * @cython.cfunc
 * def _append_escape_sequence(kind, builder, escape_sequence: str, s: PyrexScanner):
 *     if len(escape_sequence) < 2:             # <<<<<<<<<<<<<<
 *         builder.append("\\")  # invalid escape sequence, warned earlier
 *         return
*/
  __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_escape_sequence); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1321, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 < 2);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1322
 * def _append_escape_sequence(kind, builder, escape_sequence: str, s: PyrexScanner):
 *     if len(escape_sequence) < 2:
 *         builder.append("\\")  # invalid escape sequence, warned earlier             # <<<<<<<<<<<<<<
 *         return
 *     c = escape_sequence[1]
*/
    __pyx_t_3 = __Pyx_PyObject_Append(__pyx_v_builder, __pyx_mstate_global->__pyx_kp_u__41); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1322, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":1323
 *     if len(escape_sequence) < 2:
 *         builder.append("\\")  # invalid escape sequence, warned earlier
 *         return             # <<<<<<<<<<<<<<
 *     c = escape_sequence[1]
 *     if c in "01234567":
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1321
 * @cython.cfunc
 * def _append_escape_sequence(kind, builder, escape_sequence: str, s: PyrexScanner):
 *     if len(escape_sequence) < 2:             # <<<<<<<<<<<<<<
 *         builder.append("\\")  # invalid escape sequence, warned earlier
 *         return
*/
  }

  /* "Cython/Compiler/Parsing.py":1324
 *         builder.append("\\")  # invalid escape sequence, warned earlier
 *         return
 *     c = escape_sequence[1]             # <<<<<<<<<<<<<<
 *     if c in "01234567":
 *         builder.append_charval(int(escape_sequence[1:], 8))
*/
  __pyx_t_4 = __Pyx_GetItemInt_Unicode(__pyx_v_escape_sequence, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(__pyx_t_4 == (Py_UCS4)-1)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __pyx_v_c = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":1325
 *         return
 *     c = escape_sequence[1]
 *     if c in "01234567":             # <<<<<<<<<<<<<<
 *         builder.append_charval(int(escape_sequence[1:], 8))
 *     elif c in "'\"\\":
*/
  switch (__pyx_v_c) {
    case 48:
    case 49:
    case 50:
    case 51:
    case 52:
    case 53:
    case 54:
    case 55:
    __pyx_t_2 = 1;
    break;
    default:
    __pyx_t_2 = 0;
    break;
  }
  __pyx_t_5 = __pyx_t_2;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1326
 *     c = escape_sequence[1]
 *     if c in "01234567":
 *         builder.append_charval(int(escape_sequence[1:], 8))             # <<<<<<<<<<<<<<
 *     elif c in "'\"\\":
 *         builder.append(c)
*/
    __pyx_t_7 = __pyx_v_builder;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    __pyx_t_10 = __Pyx_PyUnicode_Substring(__pyx_v_escape_sequence, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = 1;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_10, __pyx_mstate_global->__pyx_int_8};
      __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)(&PyLong_Type), __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1326, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __pyx_t_11 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_append_charval, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1326, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":1325
 *         return
 *     c = escape_sequence[1]
 *     if c in "01234567":             # <<<<<<<<<<<<<<
 *         builder.append_charval(int(escape_sequence[1:], 8))
 *     elif c in "'\"\\":
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1327
 *     if c in "01234567":
 *         builder.append_charval(int(escape_sequence[1:], 8))
 *     elif c in "'\"\\":             # <<<<<<<<<<<<<<
 *         builder.append(c)
 *     elif c in "abfnrtv":
*/
  switch (__pyx_v_c) {
    case 34:
    case 39:
    case 92:
    __pyx_t_5 = 1;
    break;
    default:
    __pyx_t_5 = 0;
    break;
  }
  __pyx_t_2 = __pyx_t_5;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1328
 *         builder.append_charval(int(escape_sequence[1:], 8))
 *     elif c in "'\"\\":
 *         builder.append(c)             # <<<<<<<<<<<<<<
 *     elif c in "abfnrtv":
 *         builder.append(StringEncoding.char_from_escape_sequence(escape_sequence))
*/
    __pyx_t_6 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_Append(__pyx_v_builder, __pyx_t_6); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":1327
 *     if c in "01234567":
 *         builder.append_charval(int(escape_sequence[1:], 8))
 *     elif c in "'\"\\":             # <<<<<<<<<<<<<<
 *         builder.append(c)
 *     elif c in "abfnrtv":
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1329
 *     elif c in "'\"\\":
 *         builder.append(c)
 *     elif c in "abfnrtv":             # <<<<<<<<<<<<<<
 *         builder.append(StringEncoding.char_from_escape_sequence(escape_sequence))
 *     elif c == '\n':
*/
  switch (__pyx_v_c) {
    case 97:
    case 98:
    case 0x66:
    case 0x6E:
    case 0x72:
    case 0x74:
    case 0x76:
    __pyx_t_2 = 1;
    break;
    default:
    __pyx_t_2 = 0;
    break;
  }
  __pyx_t_5 = __pyx_t_2;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1330
 *         builder.append(c)
 *     elif c in "abfnrtv":
 *         builder.append(StringEncoding.char_from_escape_sequence(escape_sequence))             # <<<<<<<<<<<<<<
 *     elif c == '\n':
 *         pass  # line continuation
*/
    __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_11 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_escape_sequence};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_char_from_escape_sequence, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_3 = __Pyx_PyObject_Append(__pyx_v_builder, __pyx_t_6); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1330, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":1329
 *     elif c in "'\"\\":
 *         builder.append(c)
 *     elif c in "abfnrtv":             # <<<<<<<<<<<<<<
 *         builder.append(StringEncoding.char_from_escape_sequence(escape_sequence))
 *     elif c == '\n':
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1331
 *     elif c in "abfnrtv":
 *         builder.append(StringEncoding.char_from_escape_sequence(escape_sequence))
 *     elif c == '\n':             # <<<<<<<<<<<<<<
 *         pass  # line continuation
 *     elif c == 'x':  # \xXX
*/
  __pyx_t_5 = (__pyx_v_c == 10);
  if (__pyx_t_5) {
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1333
 *     elif c == '\n':
 *         pass  # line continuation
 *     elif c == 'x':  # \xXX             # <<<<<<<<<<<<<<
 *         if len(escape_sequence) == 4:
 *             builder.append_charval(int(escape_sequence[2:], 16))
*/
  __pyx_t_5 = (__pyx_v_c == 0x78);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1334
 *         pass  # line continuation
 *     elif c == 'x':  # \xXX
 *         if len(escape_sequence) == 4:             # <<<<<<<<<<<<<<
 *             builder.append_charval(int(escape_sequence[2:], 16))
 *         else:
*/
    __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_escape_sequence); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1334, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_1 == 4);
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":1335
 *     elif c == 'x':  # \xXX
 *         if len(escape_sequence) == 4:
 *             builder.append_charval(int(escape_sequence[2:], 16))             # <<<<<<<<<<<<<<
 *         else:
 *             s.error("Invalid hex escape '%s'" % escape_sequence, fatal=False)
*/
      __pyx_t_8 = __pyx_v_builder;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_9 = __Pyx_PyUnicode_Substring(__pyx_v_escape_sequence, 2, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1335, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = 1;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_9, __pyx_mstate_global->__pyx_int_16};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)(&PyLong_Type), __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_append_charval, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":1334
 *         pass  # line continuation
 *     elif c == 'x':  # \xXX
 *         if len(escape_sequence) == 4:             # <<<<<<<<<<<<<<
 *             builder.append_charval(int(escape_sequence[2:], 16))
 *         else:
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":1337
 *             builder.append_charval(int(escape_sequence[2:], 16))
 *         else:
 *             s.error("Invalid hex escape '%s'" % escape_sequence, fatal=False)             # <<<<<<<<<<<<<<
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}
 *         chrval = -1
*/
    /*else*/ {
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Invalid_hex_escape_s, __pyx_v_escape_sequence); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":1333
 *     elif c == '\n':
 *         pass  # line continuation
 *     elif c == 'x':  # \xXX             # <<<<<<<<<<<<<<
 *         if len(escape_sequence) == 4:
 *             builder.append_charval(int(escape_sequence[2:], 16))
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1338
 *         else:
 *             s.error("Invalid hex escape '%s'" % escape_sequence, fatal=False)
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}             # <<<<<<<<<<<<<<
 *         chrval = -1
 *         if c == 'N':
*/
  switch (__pyx_v_c) {
    case 78:
    case 85:
    case 0x75:
    __pyx_t_2 = 1;
    break;
    default:
    __pyx_t_2 = 0;
    break;
  }
  __pyx_t_12 = __pyx_t_2;
  if (__pyx_t_12) {
  } else {
    __pyx_t_5 = __pyx_t_12;
    goto __pyx_L6_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_kind);
  __pyx_t_6 = __pyx_v_kind;
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_12 = __pyx_t_2;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_f, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_12 = __pyx_t_2;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
  __pyx_t_12 = __pyx_t_2;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_2 = __pyx_t_12;
  __pyx_t_5 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1339
 *             s.error("Invalid hex escape '%s'" % escape_sequence, fatal=False)
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}
 *         chrval = -1             # <<<<<<<<<<<<<<
 *         if c == 'N':
 *             uchar = None
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_neg_1);
    __pyx_v_chrval = __pyx_mstate_global->__pyx_int_neg_1;

    /* "Cython/Compiler/Parsing.py":1340
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}
 *         chrval = -1
 *         if c == 'N':             # <<<<<<<<<<<<<<
 *             uchar = None
 *             try:
*/
    __pyx_t_5 = (__pyx_v_c == 78);
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":1341
 *         chrval = -1
 *         if c == 'N':
 *             uchar = None             # <<<<<<<<<<<<<<
 *             try:
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
*/
      __Pyx_INCREF(Py_None);
      __pyx_v_uchar = Py_None;

      /* "Cython/Compiler/Parsing.py":1342
 *         if c == 'N':
 *             uchar = None
 *             try:             # <<<<<<<<<<<<<<
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
 *                 chrval = ord(uchar)
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        /*try:*/ {

          /* "Cython/Compiler/Parsing.py":1343
 *             uchar = None
 *             try:
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])             # <<<<<<<<<<<<<<
 *                 chrval = ord(uchar)
 *             except KeyError:
*/
          __pyx_t_9 = NULL;
          __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar);
          __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar; 
          __pyx_t_7 = __Pyx_PyUnicode_Substring(__pyx_v_escape_sequence, 3, -1L); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1343, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_11 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
            assert(__pyx_t_9);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
            __pyx_t_11 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_7};
            __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1343, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_6);
          }
          __Pyx_DECREF_SET(__pyx_v_uchar, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "Cython/Compiler/Parsing.py":1344
 *             try:
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
 *                 chrval = ord(uchar)             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 s.error("Unknown Unicode character name %s" %
*/
          __pyx_t_16 = __Pyx_PyObject_Ord(__pyx_v_uchar); if (unlikely(__pyx_t_16 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(0, 1344, __pyx_L12_error)
          __pyx_t_6 = __Pyx_PyLong_From_long(__pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1344, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_PyInt_FromNumber(&__pyx_t_6, NULL, 0) < (0)) __PYX_ERR(0, 1344, __pyx_L12_error)
          __Pyx_DECREF_SET(__pyx_v_chrval, ((PyObject*)__pyx_t_6));
          __pyx_t_6 = 0;

          /* "Cython/Compiler/Parsing.py":1342
 *         if c == 'N':
 *             uchar = None
 *             try:             # <<<<<<<<<<<<<<
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
 *                 chrval = ord(uchar)
*/
        }
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L17_try_end;
        __pyx_L12_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "Cython/Compiler/Parsing.py":1345
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
 *                 chrval = ord(uchar)
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 s.error("Unknown Unicode character name %s" %
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
*/
        __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
        if (__pyx_t_17) {
          __Pyx_AddTraceback("Cython.Compiler.Parsing._append_escape_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_8, &__pyx_t_7) < 0) __PYX_ERR(0, 1345, __pyx_L14_except_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_7);

          /* "Cython/Compiler/Parsing.py":1346
 *                 chrval = ord(uchar)
 *             except KeyError:
 *                 s.error("Unknown Unicode character name %s" %             # <<<<<<<<<<<<<<
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
 *         elif len(escape_sequence) in (6, 10):
*/
          __pyx_t_10 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_10);

          /* "Cython/Compiler/Parsing.py":1347
 *             except KeyError:
 *                 s.error("Unknown Unicode character name %s" %
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)             # <<<<<<<<<<<<<<
 *         elif len(escape_sequence) in (6, 10):
 *             chrval = int(escape_sequence[2:], 16)
*/
          __pyx_t_20 = __Pyx_PyUnicode_Substring(__pyx_v_escape_sequence, 3, -1L); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1347, __pyx_L14_except_error)
          __Pyx_GOTREF(__pyx_t_20);
          __pyx_t_21 = PyObject_Repr(__pyx_t_20); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1347, __pyx_L14_except_error)
          __Pyx_GOTREF(__pyx_t_21);
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __pyx_t_19 = __pyx_t_21;
          __Pyx_INCREF(__pyx_t_19);
          __pyx_t_11 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_mstate_global->__pyx_n_u_u};
            __pyx_t_18 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
            if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1347, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_18);
          }

          /* "Cython/Compiler/Parsing.py":1346
 *                 chrval = ord(uchar)
 *             except KeyError:
 *                 s.error("Unknown Unicode character name %s" %             # <<<<<<<<<<<<<<
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
 *         elif len(escape_sequence) in (6, 10):
*/
          __pyx_t_21 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Unknown_Unicode_character_name_s, __pyx_t_18); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 1346, __pyx_L14_except_error)
          __Pyx_GOTREF(__pyx_t_21);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

          /* "Cython/Compiler/Parsing.py":1347
 *             except KeyError:
 *                 s.error("Unknown Unicode character name %s" %
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)             # <<<<<<<<<<<<<<
 *         elif len(escape_sequence) in (6, 10):
 *             chrval = int(escape_sequence[2:], 16)
*/
          __pyx_t_11 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_10, __pyx_t_21};
            __pyx_t_18 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1346, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_18);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_18, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1346, __pyx_L14_except_error)
            __pyx_t_9 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_18);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1346, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_9);
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L13_exception_handled;
        }
        goto __pyx_L14_except_error;

        /* "Cython/Compiler/Parsing.py":1342
 *         if c == 'N':
 *             uchar = None
 *             try:             # <<<<<<<<<<<<<<
 *                 uchar = lookup_unicodechar(escape_sequence[3:-1])
 *                 chrval = ord(uchar)
*/
        __pyx_L14_except_error:;
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
        goto __pyx_L1_error;
        __pyx_L13_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
        __pyx_L17_try_end:;
      }

      /* "Cython/Compiler/Parsing.py":1340
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}
 *         chrval = -1
 *         if c == 'N':             # <<<<<<<<<<<<<<
 *             uchar = None
 *             try:
*/
      goto __pyx_L11;
    }

    /* "Cython/Compiler/Parsing.py":1348
 *                 s.error("Unknown Unicode character name %s" %
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
 *         elif len(escape_sequence) in (6, 10):             # <<<<<<<<<<<<<<
 *             chrval = int(escape_sequence[2:], 16)
 *             if chrval > 1114111:  # sys.maxunicode:
*/
    __pyx_t_1 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_escape_sequence); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1348, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_1 == 6);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_5 = __pyx_t_2;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_t_1 == 10);
    __pyx_t_5 = __pyx_t_2;
    __pyx_L20_bool_binop_done:;
    __pyx_t_2 = __pyx_t_5;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1349
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
 *         elif len(escape_sequence) in (6, 10):
 *             chrval = int(escape_sequence[2:], 16)             # <<<<<<<<<<<<<<
 *             if chrval > 1114111:  # sys.maxunicode:
 *                 s.error("Invalid unicode escape '%s'" % escape_sequence)
*/
      __pyx_t_8 = NULL;
      __pyx_t_6 = __Pyx_PyUnicode_Substring(__pyx_v_escape_sequence, 2, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_11 = 1;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_6, __pyx_mstate_global->__pyx_int_16};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)(&PyLong_Type), __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1349, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF_SET(__pyx_v_chrval, ((PyObject*)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":1350
 *         elif len(escape_sequence) in (6, 10):
 *             chrval = int(escape_sequence[2:], 16)
 *             if chrval > 1114111:  # sys.maxunicode:             # <<<<<<<<<<<<<<
 *                 s.error("Invalid unicode escape '%s'" % escape_sequence)
 *                 chrval = -1
*/
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_chrval, __pyx_mstate_global->__pyx_int_1114111, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1350, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1350, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":1351
 *             chrval = int(escape_sequence[2:], 16)
 *             if chrval > 1114111:  # sys.maxunicode:
 *                 s.error("Invalid unicode escape '%s'" % escape_sequence)             # <<<<<<<<<<<<<<
 *                 chrval = -1
 *         else:
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_8 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Invalid_unicode_escape_s, __pyx_v_escape_sequence); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
          __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1351, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":1352
 *             if chrval > 1114111:  # sys.maxunicode:
 *                 s.error("Invalid unicode escape '%s'" % escape_sequence)
 *                 chrval = -1             # <<<<<<<<<<<<<<
 *         else:
 *             s.error("Invalid unicode escape '%s'" % escape_sequence, fatal=False)
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_int_neg_1);
        __Pyx_DECREF_SET(__pyx_v_chrval, __pyx_mstate_global->__pyx_int_neg_1);

        /* "Cython/Compiler/Parsing.py":1350
 *         elif len(escape_sequence) in (6, 10):
 *             chrval = int(escape_sequence[2:], 16)
 *             if chrval > 1114111:  # sys.maxunicode:             # <<<<<<<<<<<<<<
 *                 s.error("Invalid unicode escape '%s'" % escape_sequence)
 *                 chrval = -1
*/
      }

      /* "Cython/Compiler/Parsing.py":1348
 *                 s.error("Unknown Unicode character name %s" %
 *                         repr(escape_sequence[3:-1]).lstrip('u'), fatal=False)
 *         elif len(escape_sequence) in (6, 10):             # <<<<<<<<<<<<<<
 *             chrval = int(escape_sequence[2:], 16)
 *             if chrval > 1114111:  # sys.maxunicode:
*/
      goto __pyx_L11;
    }

    /* "Cython/Compiler/Parsing.py":1354
 *                 chrval = -1
 *         else:
 *             s.error("Invalid unicode escape '%s'" % escape_sequence, fatal=False)             # <<<<<<<<<<<<<<
 *         if chrval >= 0:
 *             builder.append_uescape(chrval, escape_sequence)
*/
    /*else*/ {
      __pyx_t_8 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_6 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Invalid_unicode_escape_s, __pyx_v_escape_sequence); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1354, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1354, __pyx_L1_error)
        __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1354, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_L11:;

    /* "Cython/Compiler/Parsing.py":1355
 *         else:
 *             s.error("Invalid unicode escape '%s'" % escape_sequence, fatal=False)
 *         if chrval >= 0:             # <<<<<<<<<<<<<<
 *             builder.append_uescape(chrval, escape_sequence)
 *     else:
*/
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_chrval, __pyx_mstate_global->__pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1355, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1355, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1356
 *             s.error("Invalid unicode escape '%s'" % escape_sequence, fatal=False)
 *         if chrval >= 0:
 *             builder.append_uescape(chrval, escape_sequence)             # <<<<<<<<<<<<<<
 *     else:
 *         builder.append(escape_sequence)
*/
      __pyx_t_9 = __pyx_v_builder;
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_chrval, __pyx_v_escape_sequence};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_append_uescape, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":1355
 *         else:
 *             s.error("Invalid unicode escape '%s'" % escape_sequence, fatal=False)
 *         if chrval >= 0:             # <<<<<<<<<<<<<<
 *             builder.append_uescape(chrval, escape_sequence)
 *     else:
*/
    }

    /* "Cython/Compiler/Parsing.py":1338
 *         else:
 *             s.error("Invalid hex escape '%s'" % escape_sequence, fatal=False)
 *     elif c in 'NUu' and kind in ('u', 'f', ''):  # \uxxxx, \Uxxxxxxxx, \N{...}             # <<<<<<<<<<<<<<
 *         chrval = -1
 *         if c == 'N':
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":1358
 *             builder.append_uescape(chrval, escape_sequence)
 *     else:
 *         builder.append(escape_sequence)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_Append(__pyx_v_builder, __pyx_v_escape_sequence); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1358, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":1319
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _append_escape_sequence(kind, builder, escape_sequence: str, s: PyrexScanner):
 *     if len(escape_sequence) < 2:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_AddTraceback("Cython.Compiler.Parsing._append_escape_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_chrval);
  __Pyx_XDECREF(__pyx_v_uchar);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1368
 * # comp_if       ::=     "if" test [comp_iter]
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_list_maker(s: PyrexScanner):
 *     # s.sy == '['
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_list_maker(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_append = NULL;
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_v_exprs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_list_maker", 0);

  /* "Cython/Compiler/Parsing.py":1371
 * def p_list_maker(s: PyrexScanner):
 *     # s.sy == '['
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy == ']':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1372
 *     # s.sy == '['
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy == ']':
 *         s.expect(']')
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1373
 *     pos = s.position()
 *     s.next()
 *     if s.sy == ']':             # <<<<<<<<<<<<<<
 *         s.expect(']')
 *         return ExprNodes.ListNode(pos, args=[])
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__30, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1373, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1374
 *     s.next()
 *     if s.sy == ']':
 *         s.expect(']')             # <<<<<<<<<<<<<<
 *         return ExprNodes.ListNode(pos, args=[])
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__30};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1375
 *     if s.sy == ']':
 *         s.expect(']')
 *         return ExprNodes.ListNode(pos, args=[])             # <<<<<<<<<<<<<<
 * 
 *     expr = p_namedexpr_test_or_starred_expr(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1375, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ListNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1373
 *     pos = s.position()
 *     s.next()
 *     if s.sy == ']':             # <<<<<<<<<<<<<<
 *         s.expect(']')
 *         return ExprNodes.ListNode(pos, args=[])
*/
  }

  /* "Cython/Compiler/Parsing.py":1377
 *         return ExprNodes.ListNode(pos, args=[])
 * 
 *     expr = p_namedexpr_test_or_starred_expr(s)             # <<<<<<<<<<<<<<
 *     if s.sy in ('for', 'async'):
 *         if expr.is_starred:
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1378
 * 
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         if expr.is_starred:
 *             s.error("iterable unpacking cannot be used in comprehension")
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_7 = __pyx_v_s->sy;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1378, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_4 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1378, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_8 = __pyx_t_4;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1379
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy in ('for', 'async'):
 *         if expr.is_starred:             # <<<<<<<<<<<<<<
 *             s.error("iterable unpacking cannot be used in comprehension")
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_is_starred); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1379, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1380
 *     if s.sy in ('for', 'async'):
 *         if expr.is_starred:
 *             s.error("iterable unpacking cannot be used in comprehension")             # <<<<<<<<<<<<<<
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)
 *         loop = p_comp_for(s, append)
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_iterable_unpacking_cannot_be_use};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1380, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1379
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy in ('for', 'async'):
 *         if expr.is_starred:             # <<<<<<<<<<<<<<
 *             s.error("iterable unpacking cannot be used in comprehension")
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)
*/
    }

    /* "Cython/Compiler/Parsing.py":1381
 *         if expr.is_starred:
 *             s.error("iterable unpacking cannot be used in comprehension")
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)             # <<<<<<<<<<<<<<
 *         loop = p_comp_for(s, append)
 *         s.expect(']')
*/
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_expr, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1381, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ComprehensionAppendNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_append = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1382
 *             s.error("iterable unpacking cannot be used in comprehension")
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)
 *         loop = p_comp_for(s, append)             # <<<<<<<<<<<<<<
 *         s.expect(']')
 *         return ExprNodes.ComprehensionNode(
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(__pyx_v_s, __pyx_v_append); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_loop = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1383
 *         append = ExprNodes.ComprehensionAppendNode(pos, expr=expr)
 *         loop = p_comp_for(s, append)
 *         s.expect(']')             # <<<<<<<<<<<<<<
 *         return ExprNodes.ComprehensionNode(
 *             pos, loop=loop, append=append, type=Builtin.list_type,
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__30};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1384
 *         loop = p_comp_for(s, append)
 *         s.expect(']')
 *         return ExprNodes.ComprehensionNode(             # <<<<<<<<<<<<<<
 *             pos, loop=loop, append=append, type=Builtin.list_type,
 *             # list comprehensions leak their loop variable in Py2
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);

    /* "Cython/Compiler/Parsing.py":1385
 *         s.expect(']')
 *         return ExprNodes.ComprehensionNode(
 *             pos, loop=loop, append=append, type=Builtin.list_type,             # <<<<<<<<<<<<<<
 *             # list comprehensions leak their loop variable in Py2
 *             has_local_scope=s.context.language_level >= 3)
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Builtin, __pyx_mstate_global->__pyx_n_u_list_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "Cython/Compiler/Parsing.py":1387
 *             pos, loop=loop, append=append, type=Builtin.list_type,
 *             # list comprehensions leak their loop variable in Py2
 *             has_local_scope=s.context.language_level >= 3)             # <<<<<<<<<<<<<<
 * 
 *     # (merged) list literal
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_2, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_loop, __pyx_v_loop, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1384, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_append, __pyx_v_append, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1384, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_type_2, __pyx_t_6, __pyx_t_2, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1384, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_has_local_scope, __pyx_t_9, __pyx_t_2, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 1384, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ComprehensionNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1378
 * 
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         if expr.is_starred:
 *             s.error("iterable unpacking cannot be used in comprehension")
*/
  }

  /* "Cython/Compiler/Parsing.py":1390
 * 
 *     # (merged) list literal
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
*/
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1390, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1391
 *     # (merged) list literal
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *     else:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1392
 *     if s.sy == ',':
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)             # <<<<<<<<<<<<<<
 *     else:
 *         exprs = [expr]
*/
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.expr = __pyx_v_expr;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1390
 * 
 *     # (merged) list literal
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
*/
    goto __pyx_L8;
  }

  /* "Cython/Compiler/Parsing.py":1394
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *     else:
 *         exprs = [expr]             # <<<<<<<<<<<<<<
 *     s.expect(']')
 *     return ExprNodes.ListNode(pos, args=exprs)
*/
  /*else*/ {
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_expr);
    __Pyx_GIVEREF(__pyx_v_expr);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 1394, __pyx_L1_error);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L8:;

  /* "Cython/Compiler/Parsing.py":1395
 *     else:
 *         exprs = [expr]
 *     s.expect(']')             # <<<<<<<<<<<<<<
 *     return ExprNodes.ListNode(pos, args=exprs)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1396
 *         exprs = [expr]
 *     s.expect(']')
 *     return ExprNodes.ListNode(pos, args=exprs)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_exprs, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ListNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1368
 * # comp_if       ::=     "if" test [comp_iter]
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_list_maker(s: PyrexScanner):
 *     # s.sy == '['
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_list_maker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_append);
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1399
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_iter(s: PyrexScanner, body):
 *     if s.sy in ('for', 'async'):
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_iter(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_body) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_comp_iter", 0);

  /* "Cython/Compiler/Parsing.py":1401
 * @cython.cfunc
 * def p_comp_iter(s: PyrexScanner, body):
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         return p_comp_for(s, body)
 *     elif s.sy == 'if':
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_1 = __pyx_v_s->sy;
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1401, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1401, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1402
 * def p_comp_iter(s: PyrexScanner, body):
 *     if s.sy in ('for', 'async'):
 *         return p_comp_for(s, body)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'if':
 *         return p_comp_if(s, body)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(__pyx_v_s, __pyx_v_body); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1401
 * @cython.cfunc
 * def p_comp_iter(s: PyrexScanner, body):
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         return p_comp_for(s, body)
 *     elif s.sy == 'if':
*/
  }

  /* "Cython/Compiler/Parsing.py":1403
 *     if s.sy in ('for', 'async'):
 *         return p_comp_for(s, body)
 *     elif s.sy == 'if':             # <<<<<<<<<<<<<<
 *         return p_comp_if(s, body)
 *     else:
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_if, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1403, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1404
 *         return p_comp_for(s, body)
 *     elif s.sy == 'if':
 *         return p_comp_if(s, body)             # <<<<<<<<<<<<<<
 *     else:
 *         # insert the 'append' operation into the loop
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_if(__pyx_v_s, __pyx_v_body); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1403
 *     if s.sy in ('for', 'async'):
 *         return p_comp_for(s, body)
 *     elif s.sy == 'if':             # <<<<<<<<<<<<<<
 *         return p_comp_if(s, body)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":1407
 *     else:
 *         # insert the 'append' operation into the loop
 *         return body             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_body);
    __pyx_r = __pyx_v_body;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1399
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_iter(s: PyrexScanner, body):
 *     if s.sy in ('for', 'async'):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_comp_iter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1410
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_for(s: PyrexScanner, body):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_body) {
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_is_async;
  PyObject *__pyx_v_kw = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_comp_for", 0);

  /* "Cython/Compiler/Parsing.py":1412
 * @cython.cfunc
 * def p_comp_for(s: PyrexScanner, body):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     # [async] for ...
 *     is_async = False
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1414
 *     pos = s.position()
 *     # [async] for ...
 *     is_async = False             # <<<<<<<<<<<<<<
 *     if s.sy == 'async':
 *         is_async = True
*/
  __pyx_v_is_async = 0;

  /* "Cython/Compiler/Parsing.py":1415
 *     # [async] for ...
 *     is_async = False
 *     if s.sy == 'async':             # <<<<<<<<<<<<<<
 *         is_async = True
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1415, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1416
 *     is_async = False
 *     if s.sy == 'async':
 *         is_async = True             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
    __pyx_v_is_async = 1;

    /* "Cython/Compiler/Parsing.py":1417
 *     if s.sy == 'async':
 *         is_async = True
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *     # s.sy == 'for'
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1415
 *     # [async] for ...
 *     is_async = False
 *     if s.sy == 'async':             # <<<<<<<<<<<<<<
 *         is_async = True
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":1420
 * 
 *     # s.sy == 'for'
 *     s.expect('for')             # <<<<<<<<<<<<<<
 *     kw = p_for_bounds(s, allow_testlist=False, is_async=is_async)
 *     kw.update(else_clause=None, body=p_comp_iter(s, body), is_async=is_async)
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_for};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1421
 *     # s.sy == 'for'
 *     s.expect('for')
 *     kw = p_for_bounds(s, allow_testlist=False, is_async=is_async)             # <<<<<<<<<<<<<<
 *     kw.update(else_clause=None, body=p_comp_iter(s, body), is_async=is_async)
 *     return Nodes.ForStatNode(pos, **kw)
*/
  __pyx_t_5.__pyx_n = 2;
  __pyx_t_5.allow_testlist = 0;
  __pyx_t_5.is_async = __pyx_v_is_async;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_bounds(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_kw = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1422
 *     s.expect('for')
 *     kw = p_for_bounds(s, allow_testlist=False, is_async=is_async)
 *     kw.update(else_clause=None, body=p_comp_iter(s, body), is_async=is_async)             # <<<<<<<<<<<<<<
 *     return Nodes.ForStatNode(pos, **kw)
 * 
*/
  __pyx_t_3 = __pyx_v_kw;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_iter(__pyx_v_s, __pyx_v_body); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_is_async); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, NULL};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, Py_None, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1422, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_6, __pyx_t_8, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1422, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_async, __pyx_t_7, __pyx_t_8, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1422, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1423
 *     kw = p_for_bounds(s, allow_testlist=False, is_async=is_async)
 *     kw.update(else_clause=None, body=p_comp_iter(s, body), is_async=is_async)
 *     return Nodes.ForStatNode(pos, **kw)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = NULL;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_ForStatNode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (unlikely(__pyx_v_kw == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 1423, __pyx_L1_error)
  }
  __pyx_t_6 = PyDict_Copy(__pyx_v_kw); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallDict((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1410
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_for(s: PyrexScanner, body):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_comp_for", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1426
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_if(s: PyrexScanner, body):
 *     # s.sy == 'if'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_comp_if(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_body) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_test = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_comp_if", 0);

  /* "Cython/Compiler/Parsing.py":1429
 * def p_comp_if(s: PyrexScanner, body):
 *     # s.sy == 'if'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     # Note that Python 3.9+ is actually more restrictive here and Cython now follows
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1430
 *     # s.sy == 'if'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     # Note that Python 3.9+ is actually more restrictive here and Cython now follows
 *     # the Python 3.9+ behaviour: https://github.com/python/cpython/issues/86014
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1436
 *     # but `[i for i in range(10) if lambda: i]` was allowed.
 *     # On Python >=3.9 they're both disallowed.
 *     test = p_or_test(s)             # <<<<<<<<<<<<<<
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_or_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_test = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1437
 *     # On Python >=3.9 they're both disallowed.
 *     test = p_or_test(s)
 *     return Nodes.IfStatNode(pos,             # <<<<<<<<<<<<<<
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,
 *                                          body = p_comp_iter(s, body))],
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":1438
 *     test = p_or_test(s)
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,             # <<<<<<<<<<<<<<
 *                                          body = p_comp_iter(s, body))],
 *         else_clause = None )
*/
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_5);

  /* "Cython/Compiler/Parsing.py":1439
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,
 *                                          body = p_comp_iter(s, body))],             # <<<<<<<<<<<<<<
 *         else_clause = None )
 * 
*/
  __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_iter(__pyx_v_s, __pyx_v_body); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_condition, __pyx_v_test, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1438, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_6, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IfClauseNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }

  /* "Cython/Compiler/Parsing.py":1438
 *     test = p_or_test(s)
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,             # <<<<<<<<<<<<<<
 *                                          body = p_comp_iter(s, body))],
 *         else_clause = None )
*/
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 1438, __pyx_L1_error);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":1440
 *         if_clauses = [Nodes.IfClauseNode(pos, condition = test,
 *                                          body = p_comp_iter(s, body))],
 *         else_clause = None )             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_if_clauses, __pyx_t_7, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1437, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, Py_None, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IfStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1426
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_comp_if(s: PyrexScanner, body):
 *     # s.sy == 'if'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_comp_if", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_test);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1449
 * #                   (comp_for | (',' (test | star_expr))* [','])) )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_dict_or_set_maker(s: PyrexScanner):
 *     # s.sy == '{'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_dict_or_set_maker(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_parts = NULL;
  int __pyx_v_target_type;
  int __pyx_v_last_was_simple_item;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_comprehension_type = NULL;
  PyObject *__pyx_v_append = NULL;
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_set_items = NULL;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_v_dict_items = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[5];
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_dict_or_set_maker", 0);

  /* "Cython/Compiler/Parsing.py":1452
 * def p_dict_or_set_maker(s: PyrexScanner):
 *     # s.sy == '{'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy == '}':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1453
 *     # s.sy == '{'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy == '}':
 *         s.next()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1454
 *     pos = s.position()
 *     s.next()
 *     if s.sy == '}':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.DictNode(pos, key_value_pairs=[])
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1454, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1455
 *     s.next()
 *     if s.sy == '}':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.DictNode(pos, key_value_pairs=[])
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1456
 *     if s.sy == '}':
 *         s.next()
 *         return ExprNodes.DictNode(pos, key_value_pairs=[])             # <<<<<<<<<<<<<<
 * 
 *     parts = []
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_t_5, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1456, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1454
 *     pos = s.position()
 *     s.next()
 *     if s.sy == '}':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.DictNode(pos, key_value_pairs=[])
*/
  }

  /* "Cython/Compiler/Parsing.py":1458
 *         return ExprNodes.DictNode(pos, key_value_pairs=[])
 * 
 *     parts = []             # <<<<<<<<<<<<<<
 *     target_type: cython.int = 0
 *     last_was_simple_item = False
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_parts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1459
 * 
 *     parts = []
 *     target_type: cython.int = 0             # <<<<<<<<<<<<<<
 *     last_was_simple_item = False
 *     while True:
*/
  __pyx_v_target_type = 0;

  /* "Cython/Compiler/Parsing.py":1460
 *     parts = []
 *     target_type: cython.int = 0
 *     last_was_simple_item = False             # <<<<<<<<<<<<<<
 *     while True:
 *         if s.sy in ('*', '**'):
*/
  __pyx_v_last_was_simple_item = 0;

  /* "Cython/Compiler/Parsing.py":1461
 *     target_type: cython.int = 0
 *     last_was_simple_item = False
 *     while True:             # <<<<<<<<<<<<<<
 *         if s.sy in ('*', '**'):
 *             # merged set/dict literal
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":1462
 *     last_was_simple_item = False
 *     while True:
 *         if s.sy in ('*', '**'):             # <<<<<<<<<<<<<<
 *             # merged set/dict literal
 *             if target_type == 0:
*/
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_7 = __pyx_v_s->sy;
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1462, __pyx_L1_error)
    if (!__pyx_t_8) {
    } else {
      __pyx_t_4 = __pyx_t_8;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1462, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_8;
    __pyx_L7_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = __pyx_t_4;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1464
 *         if s.sy in ('*', '**'):
 *             # merged set/dict literal
 *             if target_type == 0:             # <<<<<<<<<<<<<<
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):
*/
      __pyx_t_8 = (__pyx_v_target_type == 0);
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1465
 *             # merged set/dict literal
 *             if target_type == 0:
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'             # <<<<<<<<<<<<<<
 *             elif target_type != len(s.sy):
 *                 s.error("unexpected %sitem found in %s literal" % (
*/
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1465, __pyx_L1_error)
        if (__pyx_t_8) {
          __pyx_t_9 = 1;
        } else {
          __pyx_t_9 = 2;
        }
        __pyx_v_target_type = __pyx_t_9;

        /* "Cython/Compiler/Parsing.py":1464
 *         if s.sy in ('*', '**'):
 *             # merged set/dict literal
 *             if target_type == 0:             # <<<<<<<<<<<<<<
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):
*/
        goto __pyx_L9;
      }

      /* "Cython/Compiler/Parsing.py":1466
 *             if target_type == 0:
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):             # <<<<<<<<<<<<<<
 *                 s.error("unexpected %sitem found in %s literal" % (
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
*/
      __pyx_t_1 = __pyx_v_s->sy;
      __Pyx_INCREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 1466, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1466, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = (__pyx_v_target_type != __pyx_t_10);
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1467
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):
 *                 s.error("unexpected %sitem found in %s literal" % (             # <<<<<<<<<<<<<<
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
 *             s.next()
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);

        /* "Cython/Compiler/Parsing.py":1468
 *             elif target_type != len(s.sy):
 *                 s.error("unexpected %sitem found in %s literal" % (
 *                     s.sy, 'set' if target_type == 1 else 'dict'))             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == '*':
*/
        __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_v_s->sy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1468, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = (__pyx_v_target_type == 1);
        if (__pyx_t_8) {
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_set);
          __pyx_t_2 = __pyx_mstate_global->__pyx_n_u_set;
        } else {
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_dict_2);
          __pyx_t_2 = __pyx_mstate_global->__pyx_n_u_dict_2;
        }
        __pyx_t_11 = __Pyx_PyUnicode_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1468, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_unexpected;
        __pyx_t_12[1] = __pyx_t_5;
        __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u_item_found_in;
        __pyx_t_12[3] = __pyx_t_11;
        __pyx_t_12[4] = __pyx_mstate_global->__pyx_kp_u_literal;

        /* "Cython/Compiler/Parsing.py":1467
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):
 *                 s.error("unexpected %sitem found in %s literal" % (             # <<<<<<<<<<<<<<
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
 *             s.next()
*/
        __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_12, 5, 11 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 14 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11) + 8, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1467, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1466
 *             if target_type == 0:
 *                 target_type = 1 if s.sy == '*' else 2  # 'stars'
 *             elif target_type != len(s.sy):             # <<<<<<<<<<<<<<
 *                 s.error("unexpected %sitem found in %s literal" % (
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
*/
      }
      __pyx_L9:;

      /* "Cython/Compiler/Parsing.py":1469
 *                 s.error("unexpected %sitem found in %s literal" % (
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == '*':
 *                 s.error("expected expression, found '*'")
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1469, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1470
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
 *             s.next()
 *             if s.sy == '*':             # <<<<<<<<<<<<<<
 *                 s.error("expected expression, found '*'")
 *             item = p_starred_expr(s)
*/
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1470, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1471
 *             s.next()
 *             if s.sy == '*':
 *                 s.error("expected expression, found '*'")             # <<<<<<<<<<<<<<
 *             item = p_starred_expr(s)
 *             parts.append(item)
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_expected_expression_found};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1471, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1470
 *                     s.sy, 'set' if target_type == 1 else 'dict'))
 *             s.next()
 *             if s.sy == '*':             # <<<<<<<<<<<<<<
 *                 s.error("expected expression, found '*'")
 *             item = p_starred_expr(s)
*/
      }

      /* "Cython/Compiler/Parsing.py":1472
 *             if s.sy == '*':
 *                 s.error("expected expression, found '*'")
 *             item = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *             parts.append(item)
 *             last_was_simple_item = False
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1473
 *                 s.error("expected expression, found '*'")
 *             item = p_starred_expr(s)
 *             parts.append(item)             # <<<<<<<<<<<<<<
 *             last_was_simple_item = False
 *         else:
*/
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_v_item); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1473, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":1474
 *             item = p_starred_expr(s)
 *             parts.append(item)
 *             last_was_simple_item = False             # <<<<<<<<<<<<<<
 *         else:
 *             item = p_test(s)
*/
      __pyx_v_last_was_simple_item = 0;

      /* "Cython/Compiler/Parsing.py":1462
 *     last_was_simple_item = False
 *     while True:
 *         if s.sy in ('*', '**'):             # <<<<<<<<<<<<<<
 *             # merged set/dict literal
 *             if target_type == 0:
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":1476
 *             last_was_simple_item = False
 *         else:
 *             item = p_test(s)             # <<<<<<<<<<<<<<
 *             if target_type == 0:
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1477
 *         else:
 *             item = p_test(s)
 *             if target_type == 0:             # <<<<<<<<<<<<<<
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set
 *             if target_type == 2:
*/
      __pyx_t_8 = (__pyx_v_target_type == 0);
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1478
 *             item = p_test(s)
 *             if target_type == 0:
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set             # <<<<<<<<<<<<<<
 *             if target_type == 2:
 *                 # dict literal
*/
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1478, __pyx_L1_error)
        if (__pyx_t_8) {
          __pyx_t_9 = 2;
        } else {
          __pyx_t_9 = 1;
        }
        __pyx_v_target_type = __pyx_t_9;

        /* "Cython/Compiler/Parsing.py":1477
 *         else:
 *             item = p_test(s)
 *             if target_type == 0:             # <<<<<<<<<<<<<<
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set
 *             if target_type == 2:
*/
      }

      /* "Cython/Compiler/Parsing.py":1479
 *             if target_type == 0:
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set
 *             if target_type == 2:             # <<<<<<<<<<<<<<
 *                 # dict literal
 *                 s.expect(':')
*/
      __pyx_t_8 = (__pyx_v_target_type == 2);
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1481
 *             if target_type == 2:
 *                 # dict literal
 *                 s.expect(':')             # <<<<<<<<<<<<<<
 *                 key = item
 *                 value = p_test(s)
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__3};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1481, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1482
 *                 # dict literal
 *                 s.expect(':')
 *                 key = item             # <<<<<<<<<<<<<<
 *                 value = p_test(s)
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)
*/
        __Pyx_INCREF(__pyx_v_item);
        __Pyx_XDECREF_SET(__pyx_v_key, __pyx_v_item);

        /* "Cython/Compiler/Parsing.py":1483
 *                 s.expect(':')
 *                 key = item
 *                 value = p_test(s)             # <<<<<<<<<<<<<<
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)
 *             if last_was_simple_item:
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1484
 *                 key = item
 *                 value = p_test(s)
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)             # <<<<<<<<<<<<<<
 *             if last_was_simple_item:
 *                 parts[-1].append(item)
*/
        __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_t_6};
          __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1484, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key, __pyx_v_key, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1484, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_11, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1484, __pyx_L1_error)
          __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictItemNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1484, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF_SET(__pyx_v_item, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1479
 *             if target_type == 0:
 *                 target_type = 2 if s.sy == ':' else 1  # dict vs. set
 *             if target_type == 2:             # <<<<<<<<<<<<<<
 *                 # dict literal
 *                 s.expect(':')
*/
      }

      /* "Cython/Compiler/Parsing.py":1485
 *                 value = p_test(s)
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)
 *             if last_was_simple_item:             # <<<<<<<<<<<<<<
 *                 parts[-1].append(item)
 *             else:
*/
      if (__pyx_v_last_was_simple_item) {

        /* "Cython/Compiler/Parsing.py":1486
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)
 *             if last_was_simple_item:
 *                 parts[-1].append(item)             # <<<<<<<<<<<<<<
 *             else:
 *                 parts.append([item])
*/
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_parts, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1486, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_13 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_item); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1486, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1485
 *                 value = p_test(s)
 *                 item = ExprNodes.DictItemNode(key.pos, key=key, value=value)
 *             if last_was_simple_item:             # <<<<<<<<<<<<<<
 *                 parts[-1].append(item)
 *             else:
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Parsing.py":1488
 *                 parts[-1].append(item)
 *             else:
 *                 parts.append([item])             # <<<<<<<<<<<<<<
 *                 last_was_simple_item = True
 * 
*/
      /*else*/ {
        __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_item);
        __Pyx_GIVEREF(__pyx_v_item);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_item) != (0)) __PYX_ERR(0, 1488, __pyx_L1_error);
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1488, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1489
 *             else:
 *                 parts.append([item])
 *                 last_was_simple_item = True             # <<<<<<<<<<<<<<
 * 
 *         if s.sy == ',':
*/
        __pyx_v_last_was_simple_item = 1;
      }
      __pyx_L13:;
    }
    __pyx_L6:;

    /* "Cython/Compiler/Parsing.py":1491
 *                 last_was_simple_item = True
 * 
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == '}':
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1491, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1492
 * 
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == '}':
 *                 break
*/
      __pyx_t_11 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1493
 *         if s.sy == ',':
 *             s.next()
 *             if s.sy == '}':             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1493, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":1494
 *             s.next()
 *             if s.sy == '}':
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             break
*/
        goto __pyx_L5_break;

        /* "Cython/Compiler/Parsing.py":1493
 *         if s.sy == ',':
 *             s.next()
 *             if s.sy == '}':             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
      }

      /* "Cython/Compiler/Parsing.py":1491
 *                 last_was_simple_item = True
 * 
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == '}':
*/
      goto __pyx_L14;
    }

    /* "Cython/Compiler/Parsing.py":1496
 *                 break
 *         else:
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if s.sy in ('for', 'async'):
*/
    /*else*/ {
      goto __pyx_L5_break;
    }
    __pyx_L14:;
  }
  __pyx_L5_break:;

  /* "Cython/Compiler/Parsing.py":1498
 *             break
 * 
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         # dict/set comprehension
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_7 = __pyx_v_s->sy;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1498, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_8 = __pyx_t_4;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1498, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_4;
  __pyx_L17_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = __pyx_t_8;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1500
 *     if s.sy in ('for', 'async'):
 *         # dict/set comprehension
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:             # <<<<<<<<<<<<<<
 *             item = parts[0][0]
 *             if target_type == 2:
*/
    __pyx_t_10 = __Pyx_PyList_GET_SIZE(__pyx_v_parts); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1500, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_10 == 1);
    if (__pyx_t_8) {
    } else {
      __pyx_t_4 = __pyx_t_8;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyList_Check(__pyx_t_1); 
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_4 = __pyx_t_8;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (__pyx_t_10 == 1);
    __pyx_t_4 = __pyx_t_8;
    __pyx_L20_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1501
 *         # dict/set comprehension
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:
 *             item = parts[0][0]             # <<<<<<<<<<<<<<
 *             if target_type == 2:
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)
*/
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":1502
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:
 *             item = parts[0][0]
 *             if target_type == 2:             # <<<<<<<<<<<<<<
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)
 *                 comprehension_type = Builtin.dict_type
*/
      __pyx_t_4 = (__pyx_v_target_type == 2);
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1503
 *             item = parts[0][0]
 *             if target_type == 2:
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)             # <<<<<<<<<<<<<<
 *                 comprehension_type = Builtin.dict_type
 *                 append = ExprNodes.DictComprehensionAppendNode(
*/
        #ifndef CYTHON_WITHOUT_ASSERTIONS
        if (unlikely(__pyx_assertions_enabled())) {
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_DictItemNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1503, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_4 = PyObject_IsInstance(__pyx_v_item, __pyx_t_11); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1503, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_4)) {
            __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), ((PyObject *)Py_TYPE(__pyx_v_item)), 0, 0);
            __PYX_ERR(0, 1503, __pyx_L1_error)
          }
        }
        #else
        if ((1)); else __PYX_ERR(0, 1503, __pyx_L1_error)
        #endif

        /* "Cython/Compiler/Parsing.py":1504
 *             if target_type == 2:
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)
 *                 comprehension_type = Builtin.dict_type             # <<<<<<<<<<<<<<
 *                 append = ExprNodes.DictComprehensionAppendNode(
 *                     item.pos, key_expr=item.key, value_expr=item.value)
*/
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Builtin, __pyx_mstate_global->__pyx_n_u_dict_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1504, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_v_comprehension_type = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":1505
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)
 *                 comprehension_type = Builtin.dict_type
 *                 append = ExprNodes.DictComprehensionAppendNode(             # <<<<<<<<<<<<<<
 *                     item.pos, key_expr=item.key, value_expr=item.value)
 *             else:
*/
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_1);

        /* "Cython/Compiler/Parsing.py":1506
 *                 comprehension_type = Builtin.dict_type
 *                 append = ExprNodes.DictComprehensionAppendNode(
 *                     item.pos, key_expr=item.key, value_expr=item.value)             # <<<<<<<<<<<<<<
 *             else:
 *                 comprehension_type = Builtin.set_type
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_t_6};
          __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_expr, __pyx_t_2, __pyx_t_14, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1505, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value_expr, __pyx_t_5, __pyx_t_14, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1505, __pyx_L1_error)
          __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictComprehensionAppendNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1505, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __pyx_v_append = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":1502
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:
 *             item = parts[0][0]
 *             if target_type == 2:             # <<<<<<<<<<<<<<
 *                 assert isinstance(item, ExprNodes.DictItemNode), type(item)
 *                 comprehension_type = Builtin.dict_type
*/
        goto __pyx_L23;
      }

      /* "Cython/Compiler/Parsing.py":1508
 *                     item.pos, key_expr=item.key, value_expr=item.value)
 *             else:
 *                 comprehension_type = Builtin.set_type             # <<<<<<<<<<<<<<
 *                 append = ExprNodes.ComprehensionAppendNode(item.pos, expr=item)
 *             loop = p_comp_for(s, append)
*/
      /*else*/ {
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Builtin, __pyx_mstate_global->__pyx_n_u_set_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1508, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_v_comprehension_type = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":1509
 *             else:
 *                 comprehension_type = Builtin.set_type
 *                 append = ExprNodes.ComprehensionAppendNode(item.pos, expr=item)             # <<<<<<<<<<<<<<
 *             loop = p_comp_for(s, append)
 *             s.expect('}')
*/
        __pyx_t_14 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_14);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1509, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_14, __pyx_t_5};
          __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1509, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_item, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1509, __pyx_L1_error)
          __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ComprehensionAppendNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1509, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __pyx_v_append = __pyx_t_11;
        __pyx_t_11 = 0;
      }
      __pyx_L23:;

      /* "Cython/Compiler/Parsing.py":1510
 *                 comprehension_type = Builtin.set_type
 *                 append = ExprNodes.ComprehensionAppendNode(item.pos, expr=item)
 *             loop = p_comp_for(s, append)             # <<<<<<<<<<<<<<
 *             s.expect('}')
 *             return ExprNodes.ComprehensionNode(pos, loop=loop, append=append, type=comprehension_type)
*/
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(__pyx_v_s, __pyx_v_append); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_v_loop = __pyx_t_11;
      __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":1511
 *                 append = ExprNodes.ComprehensionAppendNode(item.pos, expr=item)
 *             loop = p_comp_for(s, append)
 *             s.expect('}')             # <<<<<<<<<<<<<<
 *             return ExprNodes.ComprehensionNode(pos, loop=loop, append=append, type=comprehension_type)
 *         else:
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__39};
        __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1511, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":1512
 *             loop = p_comp_for(s, append)
 *             s.expect('}')
 *             return ExprNodes.ComprehensionNode(pos, loop=loop, append=append, type=comprehension_type)             # <<<<<<<<<<<<<<
 *         else:
 *             # syntax error, try to find a good error message
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_pos};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1512, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_loop, __pyx_v_loop, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1512, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_append, __pyx_v_append, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1512, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_type_2, __pyx_v_comprehension_type, __pyx_t_5, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1512, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ComprehensionNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1512, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1500
 *     if s.sy in ('for', 'async'):
 *         # dict/set comprehension
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:             # <<<<<<<<<<<<<<
 *             item = parts[0][0]
 *             if target_type == 2:
*/
    }

    /* "Cython/Compiler/Parsing.py":1515
 *         else:
 *             # syntax error, try to find a good error message
 *             if len(parts) == 1 and not isinstance(parts[0], list):             # <<<<<<<<<<<<<<
 *                 s.error("iterable unpacking cannot be used in comprehension")
 *             else:
*/
    /*else*/ {
      __pyx_t_10 = __Pyx_PyList_GET_SIZE(__pyx_v_parts); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1515, __pyx_L1_error)
      __pyx_t_8 = (__pyx_t_10 == 1);
      if (__pyx_t_8) {
      } else {
        __pyx_t_4 = __pyx_t_8;
        goto __pyx_L25_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_v_parts, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_8 = PyList_Check(__pyx_t_11); 
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_15 = (!__pyx_t_8);
      __pyx_t_4 = __pyx_t_15;
      __pyx_L25_bool_binop_done:;
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1516
 *             # syntax error, try to find a good error message
 *             if len(parts) == 1 and not isinstance(parts[0], list):
 *                 s.error("iterable unpacking cannot be used in comprehension")             # <<<<<<<<<<<<<<
 *             else:
 *                 # e.g. "{1,2,3 for ..."
*/
        __pyx_t_5 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_iterable_unpacking_cannot_be_use};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1516, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":1515
 *         else:
 *             # syntax error, try to find a good error message
 *             if len(parts) == 1 and not isinstance(parts[0], list):             # <<<<<<<<<<<<<<
 *                 s.error("iterable unpacking cannot be used in comprehension")
 *             else:
*/
        goto __pyx_L24;
      }

      /* "Cython/Compiler/Parsing.py":1519
 *             else:
 *                 # e.g. "{1,2,3 for ..."
 *                 s.expect('}')             # <<<<<<<<<<<<<<
 *             return ExprNodes.DictNode(pos, key_value_pairs=[])
 * 
*/
      /*else*/ {
        __pyx_t_5 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__39};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1519, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __pyx_L24:;

      /* "Cython/Compiler/Parsing.py":1520
 *                 # e.g. "{1,2,3 for ..."
 *                 s.expect('}')
 *             return ExprNodes.DictNode(pos, key_value_pairs=[])             # <<<<<<<<<<<<<<
 * 
 *     s.expect('}')
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
        __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1520, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_t_2, __pyx_t_14, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1520, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1520, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }

    /* "Cython/Compiler/Parsing.py":1498
 *             break
 * 
 *     if s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         # dict/set comprehension
 *         if len(parts) == 1 and isinstance(parts[0], list) and len(parts[0]) == 1:
*/
  }

  /* "Cython/Compiler/Parsing.py":1522
 *             return ExprNodes.DictNode(pos, key_value_pairs=[])
 * 
 *     s.expect('}')             # <<<<<<<<<<<<<<
 *     if target_type == 1:
 *         # (merged) set literal
*/
  __pyx_t_14 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_14);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_mstate_global->__pyx_kp_u__39};
    __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "Cython/Compiler/Parsing.py":1523
 * 
 *     s.expect('}')
 *     if target_type == 1:             # <<<<<<<<<<<<<<
 *         # (merged) set literal
 *         items = []
*/
  __pyx_t_4 = (__pyx_v_target_type == 1);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1525
 *     if target_type == 1:
 *         # (merged) set literal
 *         items = []             # <<<<<<<<<<<<<<
 *         set_items = []
 *         for part in parts:
*/
    __pyx_t_11 = PyList_New(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_v_items = ((PyObject*)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "Cython/Compiler/Parsing.py":1526
 *         # (merged) set literal
 *         items = []
 *         set_items = []             # <<<<<<<<<<<<<<
 *         for part in parts:
 *             if isinstance(part, list):
*/
    __pyx_t_11 = PyList_New(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_v_set_items = ((PyObject*)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "Cython/Compiler/Parsing.py":1527
 *         items = []
 *         set_items = []
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             if isinstance(part, list):
 *                 set_items.extend(part)
*/
    __pyx_t_11 = __pyx_v_parts; __Pyx_INCREF(__pyx_t_11);
    __pyx_t_10 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1527, __pyx_L1_error)
        #endif
        if (__pyx_t_10 >= __pyx_temp) break;
      }
      __pyx_t_14 = __Pyx_PyList_GetItemRefFast(__pyx_t_11, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_10;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "Cython/Compiler/Parsing.py":1528
 *         set_items = []
 *         for part in parts:
 *             if isinstance(part, list):             # <<<<<<<<<<<<<<
 *                 set_items.extend(part)
 *             else:
*/
      __pyx_t_4 = PyList_Check(__pyx_v_part); 
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1529
 *         for part in parts:
 *             if isinstance(part, list):
 *                 set_items.extend(part)             # <<<<<<<<<<<<<<
 *             else:
 *                 if set_items:
*/
        __pyx_t_13 = __Pyx_PyList_Extend(__pyx_v_set_items, __pyx_v_part); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1529, __pyx_L1_error)

        /* "Cython/Compiler/Parsing.py":1528
 *         set_items = []
 *         for part in parts:
 *             if isinstance(part, list):             # <<<<<<<<<<<<<<
 *                 set_items.extend(part)
 *             else:
*/
        goto __pyx_L30;
      }

      /* "Cython/Compiler/Parsing.py":1531
 *                 set_items.extend(part)
 *             else:
 *                 if set_items:             # <<<<<<<<<<<<<<
 *                     items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *                     set_items = []
*/
      /*else*/ {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_set_items);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1531, __pyx_L1_error)
          __pyx_t_4 = (__pyx_temp != 0);
        }

        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":1532
 *             else:
 *                 if set_items:
 *                     items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))             # <<<<<<<<<<<<<<
 *                     set_items = []
 *                 items.append(part)
*/
          __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_set_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_6};
            __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1532, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_set_items, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1532, __pyx_L1_error)
            __pyx_t_14 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SetNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1532, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
          }
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_14); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "Cython/Compiler/Parsing.py":1533
 *                 if set_items:
 *                     items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *                     set_items = []             # <<<<<<<<<<<<<<
 *                 items.append(part)
 *         if set_items:
*/
          __pyx_t_14 = PyList_New(0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF_SET(__pyx_v_set_items, ((PyObject*)__pyx_t_14));
          __pyx_t_14 = 0;

          /* "Cython/Compiler/Parsing.py":1531
 *                 set_items.extend(part)
 *             else:
 *                 if set_items:             # <<<<<<<<<<<<<<
 *                     items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *                     set_items = []
*/
        }

        /* "Cython/Compiler/Parsing.py":1534
 *                     items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *                     set_items = []
 *                 items.append(part)             # <<<<<<<<<<<<<<
 *         if set_items:
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
*/
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_v_part); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1534, __pyx_L1_error)
      }
      __pyx_L30:;

      /* "Cython/Compiler/Parsing.py":1527
 *         items = []
 *         set_items = []
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             if isinstance(part, list):
 *                 set_items.extend(part)
*/
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "Cython/Compiler/Parsing.py":1535
 *                     set_items = []
 *                 items.append(part)
 *         if set_items:             # <<<<<<<<<<<<<<
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *         if len(items) == 1 and items[0].is_set_literal:
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_set_items);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1535, __pyx_L1_error)
      __pyx_t_4 = (__pyx_temp != 0);
    }

    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1536
 *                 items.append(part)
 *         if set_items:
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))             # <<<<<<<<<<<<<<
 *         if len(items) == 1 and items[0].is_set_literal:
 *             return items[0]
*/
      __pyx_t_14 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_14);
      __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_set_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_14, __pyx_t_6};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1536, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_set_items, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1536, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SetNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1536, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_11); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":1535
 *                     set_items = []
 *                 items.append(part)
 *         if set_items:             # <<<<<<<<<<<<<<
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *         if len(items) == 1 and items[0].is_set_literal:
*/
    }

    /* "Cython/Compiler/Parsing.py":1537
 *         if set_items:
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *         if len(items) == 1 and items[0].is_set_literal:             # <<<<<<<<<<<<<<
 *             return items[0]
 *         return ExprNodes.MergedSequenceNode(pos, args=items, type=Builtin.set_type)
*/
    __pyx_t_10 = __Pyx_PyList_GET_SIZE(__pyx_v_items); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1537, __pyx_L1_error)
    __pyx_t_15 = (__pyx_t_10 == 1);
    if (__pyx_t_15) {
    } else {
      __pyx_t_4 = __pyx_t_15;
      goto __pyx_L35_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_v_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_is_set_literal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1537, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __pyx_t_15;
    __pyx_L35_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1538
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *         if len(items) == 1 and items[0].is_set_literal:
 *             return items[0]             # <<<<<<<<<<<<<<
 *         return ExprNodes.MergedSequenceNode(pos, args=items, type=Builtin.set_type)
 *     else:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1538, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1537
 *         if set_items:
 *             items.append(ExprNodes.SetNode(set_items[0].pos, args=set_items))
 *         if len(items) == 1 and items[0].is_set_literal:             # <<<<<<<<<<<<<<
 *             return items[0]
 *         return ExprNodes.MergedSequenceNode(pos, args=items, type=Builtin.set_type)
*/
    }

    /* "Cython/Compiler/Parsing.py":1539
 *         if len(items) == 1 and items[0].is_set_literal:
 *             return items[0]
 *         return ExprNodes.MergedSequenceNode(pos, args=items, type=Builtin.set_type)             # <<<<<<<<<<<<<<
 *     else:
 *         # (merged) dict literal
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Builtin, __pyx_mstate_global->__pyx_n_u_set_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_11, __pyx_v_pos};
      __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1539, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_items, __pyx_t_14, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1539, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_type_2, __pyx_t_6, __pyx_t_14, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1539, __pyx_L1_error)
      __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_MergedSequenceNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1539, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1523
 * 
 *     s.expect('}')
 *     if target_type == 1:             # <<<<<<<<<<<<<<
 *         # (merged) set literal
 *         items = []
*/
  }

  /* "Cython/Compiler/Parsing.py":1542
 *     else:
 *         # (merged) dict literal
 *         items = []             # <<<<<<<<<<<<<<
 *         dict_items = []
 *         for part in parts:
*/
  /*else*/ {
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_items = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1543
 *         # (merged) dict literal
 *         items = []
 *         dict_items = []             # <<<<<<<<<<<<<<
 *         for part in parts:
 *             if isinstance(part, list):
*/
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_dict_items = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1544
 *         items = []
 *         dict_items = []
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             if isinstance(part, list):
 *                 dict_items.extend(part)
*/
    __pyx_t_5 = __pyx_v_parts; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_10 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1544, __pyx_L1_error)
        #endif
        if (__pyx_t_10 >= __pyx_temp) break;
      }
      __pyx_t_14 = __Pyx_PyList_GetItemRefFast(__pyx_t_5, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_10;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1544, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "Cython/Compiler/Parsing.py":1545
 *         dict_items = []
 *         for part in parts:
 *             if isinstance(part, list):             # <<<<<<<<<<<<<<
 *                 dict_items.extend(part)
 *             else:
*/
      __pyx_t_4 = PyList_Check(__pyx_v_part); 
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1546
 *         for part in parts:
 *             if isinstance(part, list):
 *                 dict_items.extend(part)             # <<<<<<<<<<<<<<
 *             else:
 *                 if dict_items:
*/
        __pyx_t_13 = __Pyx_PyList_Extend(__pyx_v_dict_items, __pyx_v_part); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1546, __pyx_L1_error)

        /* "Cython/Compiler/Parsing.py":1545
 *         dict_items = []
 *         for part in parts:
 *             if isinstance(part, list):             # <<<<<<<<<<<<<<
 *                 dict_items.extend(part)
 *             else:
*/
        goto __pyx_L39;
      }

      /* "Cython/Compiler/Parsing.py":1548
 *                 dict_items.extend(part)
 *             else:
 *                 if dict_items:             # <<<<<<<<<<<<<<
 *                     items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *                     dict_items = []
*/
      /*else*/ {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dict_items);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1548, __pyx_L1_error)
          __pyx_t_4 = (__pyx_temp != 0);
        }

        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":1549
 *             else:
 *                 if dict_items:
 *                     items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))             # <<<<<<<<<<<<<<
 *                     dict_items = []
 *                 items.append(part)
*/
          __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_v_dict_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1549, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1549, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_t_2};
            __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1549, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_v_dict_items, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1549, __pyx_L1_error)
            __pyx_t_14 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1549, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
          }
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_14); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1549, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "Cython/Compiler/Parsing.py":1550
 *                 if dict_items:
 *                     items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *                     dict_items = []             # <<<<<<<<<<<<<<
 *                 items.append(part)
 *         if dict_items:
*/
          __pyx_t_14 = PyList_New(0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1550, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF_SET(__pyx_v_dict_items, ((PyObject*)__pyx_t_14));
          __pyx_t_14 = 0;

          /* "Cython/Compiler/Parsing.py":1548
 *                 dict_items.extend(part)
 *             else:
 *                 if dict_items:             # <<<<<<<<<<<<<<
 *                     items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *                     dict_items = []
*/
        }

        /* "Cython/Compiler/Parsing.py":1551
 *                     items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *                     dict_items = []
 *                 items.append(part)             # <<<<<<<<<<<<<<
 *         if dict_items:
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
*/
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_v_part); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1551, __pyx_L1_error)
      }
      __pyx_L39:;

      /* "Cython/Compiler/Parsing.py":1544
 *         items = []
 *         dict_items = []
 *         for part in parts:             # <<<<<<<<<<<<<<
 *             if isinstance(part, list):
 *                 dict_items.extend(part)
*/
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":1552
 *                     dict_items = []
 *                 items.append(part)
 *         if dict_items:             # <<<<<<<<<<<<<<
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *         if len(items) == 1 and items[0].is_dict_literal:
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dict_items);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1552, __pyx_L1_error)
      __pyx_t_4 = (__pyx_temp != 0);
    }

    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1553
 *                 items.append(part)
 *         if dict_items:
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))             # <<<<<<<<<<<<<<
 *         if len(items) == 1 and items[0].is_dict_literal:
 *             return items[0]
*/
      __pyx_t_14 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_14);
      __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_v_dict_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_14, __pyx_t_2};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_v_dict_items, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_5); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1553, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "Cython/Compiler/Parsing.py":1552
 *                     dict_items = []
 *                 items.append(part)
 *         if dict_items:             # <<<<<<<<<<<<<<
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *         if len(items) == 1 and items[0].is_dict_literal:
*/
    }

    /* "Cython/Compiler/Parsing.py":1554
 *         if dict_items:
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *         if len(items) == 1 and items[0].is_dict_literal:             # <<<<<<<<<<<<<<
 *             return items[0]
 *         return ExprNodes.MergedDictNode(pos, keyword_args=items, reject_duplicates=False)
*/
    __pyx_t_10 = __Pyx_PyList_GET_SIZE(__pyx_v_items); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1554, __pyx_L1_error)
    __pyx_t_15 = (__pyx_t_10 == 1);
    if (__pyx_t_15) {
    } else {
      __pyx_t_4 = __pyx_t_15;
      goto __pyx_L44_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_is_dict_literal); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1554, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_4 = __pyx_t_15;
    __pyx_L44_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1555
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *         if len(items) == 1 and items[0].is_dict_literal:
 *             return items[0]             # <<<<<<<<<<<<<<
 *         return ExprNodes.MergedDictNode(pos, keyword_args=items, reject_duplicates=False)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_11 = __Pyx_GetItemInt_List(__pyx_v_items, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1554
 *         if dict_items:
 *             items.append(ExprNodes.DictNode(dict_items[0].pos, key_value_pairs=dict_items))
 *         if len(items) == 1 and items[0].is_dict_literal:             # <<<<<<<<<<<<<<
 *             return items[0]
 *         return ExprNodes.MergedDictNode(pos, keyword_args=items, reject_duplicates=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":1556
 *         if len(items) == 1 and items[0].is_dict_literal:
 *             return items[0]
 *         return ExprNodes.MergedDictNode(pos, keyword_args=items, reject_duplicates=False)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_args, __pyx_v_items, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1556, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_reject_duplicates, Py_False, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_MergedDictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }
    __pyx_r = __pyx_t_11;
    __pyx_t_11 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1449
 * #                   (comp_for | (',' (test | star_expr))* [','])) )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_dict_or_set_maker(s: PyrexScanner):
 *     # s.sy == '{'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_dict_or_set_maker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_comprehension_type);
  __Pyx_XDECREF(__pyx_v_append);
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_set_items);
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XDECREF(__pyx_v_dict_items);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1560
 * 
 * # NOTE: no longer in Py3 :)
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_backquote_expr(s: PyrexScanner):
 *     # s.sy == '`'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_backquote_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_backquote_expr", 0);

  /* "Cython/Compiler/Parsing.py":1563
 * def p_backquote_expr(s: PyrexScanner):
 *     # s.sy == '`'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     args = [p_test(s)]
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1564
 *     # s.sy == '`'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     args = [p_test(s)]
 *     while s.sy == ',':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1565
 *     pos = s.position()
 *     s.next()
 *     args = [p_test(s)]             # <<<<<<<<<<<<<<
 *     while s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1565, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_args = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1566
 *     s.next()
 *     args = [p_test(s)]
 *     while s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         args.append(p_test(s))
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1566, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":1567
 *     args = [p_test(s)]
 *     while s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         args.append(p_test(s))
 *     s.expect('`')
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":1568
 *     while s.sy == ',':
 *         s.next()
 *         args.append(p_test(s))             # <<<<<<<<<<<<<<
 *     s.expect('`')
 *     if len(args) == 1:
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_args, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1568, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":1569
 *         s.next()
 *         args.append(p_test(s))
 *     s.expect('`')             # <<<<<<<<<<<<<<
 *     if len(args) == 1:
 *         arg = args[0]
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__33};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1570
 *         args.append(p_test(s))
 *     s.expect('`')
 *     if len(args) == 1:             # <<<<<<<<<<<<<<
 *         arg = args[0]
 *     else:
*/
  __pyx_t_6 = __Pyx_PyList_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1570, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_6 == 1);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1571
 *     s.expect('`')
 *     if len(args) == 1:
 *         arg = args[0]             # <<<<<<<<<<<<<<
 *     else:
 *         arg = ExprNodes.TupleNode(pos, args = args)
*/
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_arg = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":1570
 *         args.append(p_test(s))
 *     s.expect('`')
 *     if len(args) == 1:             # <<<<<<<<<<<<<<
 *         arg = args[0]
 *     else:
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/Parsing.py":1573
 *         arg = args[0]
 *     else:
 *         arg = ExprNodes.TupleNode(pos, args = args)             # <<<<<<<<<<<<<<
 *     return ExprNodes.BackquoteNode(pos, arg = arg)
 * 
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_pos};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_arg = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "Cython/Compiler/Parsing.py":1574
 *     else:
 *         arg = ExprNodes.TupleNode(pos, args = args)
 *     return ExprNodes.BackquoteNode(pos, arg = arg)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_v_arg, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1574, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_BackquoteNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1560
 * 
 * # NOTE: no longer in Py3 :)
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_backquote_expr(s: PyrexScanner):
 *     # s.sy == '`'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_backquote_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1577
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_expr_list *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":1578
 * 
 * @cython.cfunc
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:             # <<<<<<<<<<<<<<
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
*/
  PyObject *__pyx_v_expr = ((PyObject *)Py_None);
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_simple_expr_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_expr = __pyx_optional_args->expr;
    }
  }

  /* "Cython/Compiler/Parsing.py":1579
 * @cython.cfunc
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []             # <<<<<<<<<<<<<<
 *     while s.sy not in expr_terminators:
 *         exprs.append( p_test(s) )
*/
  __pyx_t_2 = (__pyx_v_expr != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_expr);
    __Pyx_GIVEREF(__pyx_v_expr);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 1579, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_exprs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1580
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:             # <<<<<<<<<<<<<<
 *         exprs.append( p_test(s) )
 *         if s.sy != ',':
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_expr_terminators, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1580, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":1581
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
 *         exprs.append( p_test(s) )             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
    if (unlikely(__pyx_v_exprs == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 1581, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1582
 *     while s.sy not in expr_terminators:
 *         exprs.append( p_test(s) )
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1582, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1583
 *         exprs.append( p_test(s) )
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     return exprs
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":1582
 *     while s.sy not in expr_terminators:
 *         exprs.append( p_test(s) )
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":1584
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     return exprs
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":1585
 *             break
 *         s.next()
 *     return exprs             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_exprs);
  __pyx_r = __pyx_v_exprs;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1577
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_simple_expr_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1588
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":1589
 * 
 * @cython.cfunc
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:             # <<<<<<<<<<<<<<
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
*/
  PyObject *__pyx_v_expr = ((PyObject *)Py_None);
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_test_or_starred_expr_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_expr = __pyx_optional_args->expr;
    }
  }

  /* "Cython/Compiler/Parsing.py":1590
 * @cython.cfunc
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []             # <<<<<<<<<<<<<<
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_test_or_starred_expr(s))
*/
  __pyx_t_2 = (__pyx_v_expr != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_expr);
    __Pyx_GIVEREF(__pyx_v_expr);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 1590, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_exprs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1591
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:             # <<<<<<<<<<<<<<
 *         exprs.append(p_test_or_starred_expr(s))
 *         if s.sy != ',':
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_expr_terminators, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1591, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":1592
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_test_or_starred_expr(s))             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
    if (unlikely(__pyx_v_exprs == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 1592, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1592, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1593
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_test_or_starred_expr(s))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1593, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1594
 *         exprs.append(p_test_or_starred_expr(s))
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     return exprs
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":1593
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_test_or_starred_expr(s))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":1595
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     return exprs
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":1596
 *             break
 *         s.next()
 *     return exprs             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_exprs);
  __pyx_r = __pyx_v_exprs;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1588
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_test_or_starred_expr_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1599
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":1600
 * 
 * @cython.cfunc
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:             # <<<<<<<<<<<<<<
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
*/
  PyObject *__pyx_v_expr = ((PyObject *)Py_None);
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_namedexpr_test_or_starred_expr_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_expr = __pyx_optional_args->expr;
    }
  }

  /* "Cython/Compiler/Parsing.py":1601
 * @cython.cfunc
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []             # <<<<<<<<<<<<<<
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))
*/
  __pyx_t_2 = (__pyx_v_expr != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_expr);
    __Pyx_GIVEREF(__pyx_v_expr);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 1601, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_exprs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1602
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:             # <<<<<<<<<<<<<<
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))
 *         if s.sy != ',':
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_expr_terminators, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1602, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":1603
 *     exprs: list = [expr] if expr is not None else []
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
    if (unlikely(__pyx_v_exprs == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 1603, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1603, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1604
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1604, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1605
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     return exprs
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":1604
 *     while s.sy not in expr_terminators:
 *         exprs.append(p_namedexpr_test_or_starred_expr(s))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":1606
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     return exprs
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":1607
 *             break
 *         s.next()
 *     return exprs             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_exprs);
  __pyx_r = __pyx_v_exprs;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1599
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_namedexpr_test_or_starred_expr_list(s: PyrexScanner, expr=None) -> list:
 *     exprs: list = [expr] if expr is not None else []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_namedexpr_test_or_starred_expr_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1612
 * #testlist: test (',' test)* [',']
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_exprs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_expr_list __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_testlist", 0);

  /* "Cython/Compiler/Parsing.py":1614
 * @cython.cfunc
 * def p_testlist(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_test(s)
 *     if s.sy == ',':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1615
 * def p_testlist(s: PyrexScanner):
 *     pos = s.position()
 *     expr = p_test(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1616
 *     pos = s.position()
 *     expr = p_test(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_simple_expr_list(s, expr)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1616, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1617
 *     expr = p_test(s)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         exprs = p_simple_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1618
 *     if s.sy == ',':
 *         s.next()
 *         exprs = p_simple_expr_list(s, expr)             # <<<<<<<<<<<<<<
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.expr = __pyx_v_expr;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_expr_list(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1619
 *         s.next()
 *         exprs = p_simple_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)             # <<<<<<<<<<<<<<
 *     else:
 *         return expr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_exprs, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1616
 *     pos = s.position()
 *     expr = p_test(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_simple_expr_list(s, expr)
*/
  }

  /* "Cython/Compiler/Parsing.py":1621
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
 *         return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_expr);
    __pyx_r = __pyx_v_expr;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1612
 * #testlist: test (',' test)* [',']
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_testlist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1626
 * # testlist_star_expr: (test|star_expr) ( comp_for | (',' (test|star_expr))* [','] )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist_star_expr(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist_star_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_exprs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_testlist_star_expr", 0);

  /* "Cython/Compiler/Parsing.py":1628
 * @cython.cfunc
 * def p_testlist_star_expr(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_test_or_starred_expr(s)
 *     if s.sy == ',':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1629
 * def p_testlist_star_expr(s: PyrexScanner):
 *     pos = s.position()
 *     expr = p_test_or_starred_expr(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1630
 *     pos = s.position()
 *     expr = p_test_or_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_test_or_starred_expr_list(s, expr)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1630, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1631
 *     expr = p_test_or_starred_expr(s)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         exprs = p_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1632
 *     if s.sy == ',':
 *         s.next()
 *         exprs = p_test_or_starred_expr_list(s, expr)             # <<<<<<<<<<<<<<
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.expr = __pyx_v_expr;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test_or_starred_expr_list(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1633
 *         s.next()
 *         exprs = p_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)             # <<<<<<<<<<<<<<
 *     else:
 *         return expr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_exprs, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1633, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1630
 *     pos = s.position()
 *     expr = p_test_or_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_test_or_starred_expr_list(s, expr)
*/
  }

  /* "Cython/Compiler/Parsing.py":1635
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
 *         return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_expr);
    __pyx_r = __pyx_v_expr;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1626
 * # testlist_star_expr: (test|star_expr) ( comp_for | (',' (test|star_expr))* [','] )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist_star_expr(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_testlist_star_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1640
 * # testlist_comp: (test|star_expr) ( comp_for | (',' (test|star_expr))* [','] )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist_comp(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_testlist_comp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_exprs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_testlist_comp", 0);

  /* "Cython/Compiler/Parsing.py":1642
 * @cython.cfunc
 * def p_testlist_comp(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy == ',':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1643
 * def p_testlist_comp(s: PyrexScanner):
 *     pos = s.position()
 *     expr = p_namedexpr_test_or_starred_expr(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1644
 *     pos = s.position()
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1644, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1645
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1646
 *     if s.sy == ',':
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)             # <<<<<<<<<<<<<<
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     elif s.sy in ('for', 'async'):
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.expr = __pyx_v_expr;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test_or_starred_expr_list(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1647
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)             # <<<<<<<<<<<<<<
 *     elif s.sy in ('for', 'async'):
 *         return p_genexp(s, expr)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_exprs, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1647, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1644
 *     pos = s.position()
 *     expr = p_namedexpr_test_or_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
*/
  }

  /* "Cython/Compiler/Parsing.py":1648
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     elif s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         return p_genexp(s, expr)
 *     else:
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_7 = __pyx_v_s->sy;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1648, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_2 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1648, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_8 = __pyx_t_2;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1649
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     elif s.sy in ('for', 'async'):
 *         return p_genexp(s, expr)             # <<<<<<<<<<<<<<
 *     else:
 *         return expr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_genexp(__pyx_v_s, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1648
 *         exprs = p_namedexpr_test_or_starred_expr_list(s, expr)
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     elif s.sy in ('for', 'async'):             # <<<<<<<<<<<<<<
 *         return p_genexp(s, expr)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":1651
 *         return p_genexp(s, expr)
 *     else:
 *         return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_expr);
    __pyx_r = __pyx_v_expr;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1640
 * # testlist_comp: (test|star_expr) ( comp_for | (',' (test|star_expr))* [','] )
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_testlist_comp(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_testlist_comp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1654
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_genexp(s: PyrexScanner, expr):
 *     # s.sy == 'async' | 'for'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_genexp(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_expr) {
  PyObject *__pyx_v_loop = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_genexp", 0);

  /* "Cython/Compiler/Parsing.py":1657
 * def p_genexp(s: PyrexScanner, expr):
 *     # s.sy == 'async' | 'for'
 *     loop = p_comp_for(s, Nodes.ExprStatNode(             # <<<<<<<<<<<<<<
 *         expr.pos, expr = ExprNodes.YieldExprNode(expr.pos, arg=expr)))
 *     return ExprNodes.GeneratorExpressionNode(expr.pos, loop=loop)
*/
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":1658
 *     # s.sy == 'async' | 'for'
 *     loop = p_comp_for(s, Nodes.ExprStatNode(
 *         expr.pos, expr = ExprNodes.YieldExprNode(expr.pos, arg=expr)))             # <<<<<<<<<<<<<<
 *     return ExprNodes.GeneratorExpressionNode(expr.pos, loop=loop)
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg, __pyx_v_expr, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1658, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_YieldExprNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_t_4, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExprStatNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }

  /* "Cython/Compiler/Parsing.py":1657
 * def p_genexp(s: PyrexScanner, expr):
 *     # s.sy == 'async' | 'for'
 *     loop = p_comp_for(s, Nodes.ExprStatNode(             # <<<<<<<<<<<<<<
 *         expr.pos, expr = ExprNodes.YieldExprNode(expr.pos, arg=expr)))
 *     return ExprNodes.GeneratorExpressionNode(expr.pos, loop=loop)
*/
  __pyx_t_8 = __pyx_f_6Cython_8Compiler_7Parsing_p_comp_for(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_loop = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "Cython/Compiler/Parsing.py":1659
 *     loop = p_comp_for(s, Nodes.ExprStatNode(
 *         expr.pos, expr = ExprNodes.YieldExprNode(expr.pos, arg=expr)))
 *     return ExprNodes.GeneratorExpressionNode(expr.pos, loop=loop)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_t_4};
    __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_loop, __pyx_v_loop, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1659, __pyx_L1_error)
    __pyx_t_8 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_GeneratorExpressionNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1654
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_genexp(s: PyrexScanner, expr):
 *     # s.sy == 'async' | 'for'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_genexp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1672
 * #-------------------------------------------------------
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_global_statement(s: PyrexScanner):
 *     # assume s.sy == 'global'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_global_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_global_statement", 0);

  /* "Cython/Compiler/Parsing.py":1675
 * def p_global_statement(s: PyrexScanner):
 *     # assume s.sy == 'global'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     names = p_ident_list(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1676
 *     # assume s.sy == 'global'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     names = p_ident_list(s)
 *     return Nodes.GlobalNode(pos, names = names)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1677
 *     pos = s.position()
 *     s.next()
 *     names = p_ident_list(s)             # <<<<<<<<<<<<<<
 *     return Nodes.GlobalNode(pos, names = names)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident_list(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_names = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1678
 *     s.next()
 *     names = p_ident_list(s)
 *     return Nodes.GlobalNode(pos, names = names)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_names, __pyx_v_names, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1678, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_GlobalNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1672
 * #-------------------------------------------------------
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_global_statement(s: PyrexScanner):
 *     # assume s.sy == 'global'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_global_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1681
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_nonlocal_statement(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_nonlocal_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_nonlocal_statement", 0);

  /* "Cython/Compiler/Parsing.py":1683
 * @cython.cfunc
 * def p_nonlocal_statement(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     names = p_ident_list(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1684
 * def p_nonlocal_statement(s: PyrexScanner):
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     names = p_ident_list(s)
 *     return Nodes.NonlocalNode(pos, names = names)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1685
 *     pos = s.position()
 *     s.next()
 *     names = p_ident_list(s)             # <<<<<<<<<<<<<<
 *     return Nodes.NonlocalNode(pos, names = names)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident_list(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_names = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1686
 *     s.next()
 *     names = p_ident_list(s)
 *     return Nodes.NonlocalNode(pos, names = names)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_names, __pyx_v_names, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1686, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NonlocalNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1681
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_nonlocal_statement(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_nonlocal_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1689
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_expression_or_assignment(s: PyrexScanner):
 *     expr = p_testlist_star_expr(s)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_expression_or_assignment(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_expr = NULL;
  int __pyx_v_has_annotation;
  PyObject *__pyx_v_expr_list = NULL;
  PyObject *__pyx_v_lhs = NULL;
  PyObject *__pyx_v_operator = NULL;
  PyObject *__pyx_v_rhs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_make_slice_node __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_expression_or_assignment", 0);

  /* "Cython/Compiler/Parsing.py":1691
 * @cython.cfunc
 * def p_expression_or_assignment(s: PyrexScanner):
 *     expr = p_testlist_star_expr(s)             # <<<<<<<<<<<<<<
 *     has_annotation = False
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist_star_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1692
 * def p_expression_or_assignment(s: PyrexScanner):
 *     expr = p_testlist_star_expr(s)
 *     has_annotation = False             # <<<<<<<<<<<<<<
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):
 *         has_annotation = True
*/
  __pyx_v_has_annotation = 0;

  /* "Cython/Compiler/Parsing.py":1693
 *     expr = p_testlist_star_expr(s)
 *     has_annotation = False
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):             # <<<<<<<<<<<<<<
 *         has_annotation = True
 *         s.next()
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1693, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_is_subscript); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_is_attribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1694
 *     has_annotation = False
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):
 *         has_annotation = True             # <<<<<<<<<<<<<<
 *         s.next()
 *         expr.annotation = p_annotation(s)
*/
    __pyx_v_has_annotation = 1;

    /* "Cython/Compiler/Parsing.py":1695
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):
 *         has_annotation = True
 *         s.next()             # <<<<<<<<<<<<<<
 *         expr.annotation = p_annotation(s)
 * 
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1696
 *         has_annotation = True
 *         s.next()
 *         expr.annotation = p_annotation(s)             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == '=' and expr.is_starred:
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_annotation(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_annotation, __pyx_t_1) < (0)) __PYX_ERR(0, 1696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1693
 *     expr = p_testlist_star_expr(s)
 *     has_annotation = False
 *     if s.sy == ':' and (expr.is_name or expr.is_subscript or expr.is_attribute):             # <<<<<<<<<<<<<<
 *         has_annotation = True
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":1698
 *         expr.annotation = p_annotation(s)
 * 
 *     if s.sy == '=' and expr.is_starred:             # <<<<<<<<<<<<<<
 *         # This is a common enough error to make when learning Cython to let
 *         # it fail as early as possible and give a very clear error message.
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1698, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_is_starred); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1701
 *         # This is a common enough error to make when learning Cython to let
 *         # it fail as early as possible and give a very clear error message.
 *         s.error("a starred assignment target must be in a list or tuple"             # <<<<<<<<<<<<<<
 *                 " - maybe you meant to use an index assignment: var[0] = ...",
 *                 pos=expr.pos)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);

    /* "Cython/Compiler/Parsing.py":1703
 *         s.error("a starred assignment target must be in a list or tuple"
 *                 " - maybe you meant to use an index assignment: var[0] = ...",
 *                 pos=expr.pos)             # <<<<<<<<<<<<<<
 * 
 *     expr_list = [expr]
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_a_starred_assignment_target_must};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_6, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1701, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1698
 *         expr.annotation = p_annotation(s)
 * 
 *     if s.sy == '=' and expr.is_starred:             # <<<<<<<<<<<<<<
 *         # This is a common enough error to make when learning Cython to let
 *         # it fail as early as possible and give a very clear error message.
*/
  }

  /* "Cython/Compiler/Parsing.py":1705
 *                 pos=expr.pos)
 * 
 *     expr_list = [expr]             # <<<<<<<<<<<<<<
 *     while s.sy == '=':
 *         s.next()
*/
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_v_expr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 1705, __pyx_L1_error);
  __pyx_v_expr_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1706
 * 
 *     expr_list = [expr]
 *     while s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'yield':
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1706, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":1707
 *     expr_list = [expr]
 *     while s.sy == '=':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == 'yield':
 *             expr = p_yield_expression(s)
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1708
 *     while s.sy == '=':
 *         s.next()
 *         if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             expr = p_yield_expression(s)
 *         else:
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_yield, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1708, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1709
 *         s.next()
 *         if s.sy == 'yield':
 *             expr = p_yield_expression(s)             # <<<<<<<<<<<<<<
 *         else:
 *             expr = p_testlist_star_expr(s)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1709, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1708
 *     while s.sy == '=':
 *         s.next()
 *         if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *             expr = p_yield_expression(s)
 *         else:
*/
      goto __pyx_L13;
    }

    /* "Cython/Compiler/Parsing.py":1711
 *             expr = p_yield_expression(s)
 *         else:
 *             expr = p_testlist_star_expr(s)             # <<<<<<<<<<<<<<
 *         expr_list.append(expr)
 *     if len(expr_list) == 1:
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist_star_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1711, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L13:;

    /* "Cython/Compiler/Parsing.py":1712
 *         else:
 *             expr = p_testlist_star_expr(s)
 *         expr_list.append(expr)             # <<<<<<<<<<<<<<
 *     if len(expr_list) == 1:
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
*/
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_expr_list, __pyx_v_expr); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1712, __pyx_L1_error)
  }

  /* "Cython/Compiler/Parsing.py":1713
 *             expr = p_testlist_star_expr(s)
 *         expr_list.append(expr)
 *     if len(expr_list) == 1:             # <<<<<<<<<<<<<<
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
 *             lhs = expr_list[0]
*/
  __pyx_t_9 = __Pyx_PyList_GET_SIZE(__pyx_v_expr_list); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1713, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_9 == 1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":1714
 *         expr_list.append(expr)
 *     if len(expr_list) == 1:
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):             # <<<<<<<<<<<<<<
 *             lhs = expr_list[0]
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):
*/
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_re;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__42, __pyx_v_s->sy};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_match, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1714, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1714, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":1715
 *     if len(expr_list) == 1:
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
 *             lhs = expr_list[0]             # <<<<<<<<<<<<<<
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):
 *                 # implementation requires IndexNode
*/
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_expr_list, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_lhs = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1716
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
 *             lhs = expr_list[0]
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):             # <<<<<<<<<<<<<<
 *                 # implementation requires IndexNode
 *                 lhs = ExprNodes.IndexNode(
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_SliceIndexNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1716, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyObject_IsInstance(__pyx_v_lhs, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1716, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":1718
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):
 *                 # implementation requires IndexNode
 *                 lhs = ExprNodes.IndexNode(             # <<<<<<<<<<<<<<
 *                     lhs.pos,
 *                     base=lhs.base,
*/
        __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_7);

        /* "Cython/Compiler/Parsing.py":1719
 *                 # implementation requires IndexNode
 *                 lhs = ExprNodes.IndexNode(
 *                     lhs.pos,             # <<<<<<<<<<<<<<
 *                     base=lhs.base,
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1719, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "Cython/Compiler/Parsing.py":1720
 *                 lhs = ExprNodes.IndexNode(
 *                     lhs.pos,
 *                     base=lhs.base,             # <<<<<<<<<<<<<<
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):
*/
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1720, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "Cython/Compiler/Parsing.py":1721
 *                     lhs.pos,
 *                     base=lhs.base,
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))             # <<<<<<<<<<<<<<
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):
 *                 error(lhs.pos, "Illegal operand for inplace operation.")
*/
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1721, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_start); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1721, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_stop); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1721, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_14.__pyx_n = 1;
        __pyx_t_14.stop = __pyx_t_12;
        __pyx_t_13 = __pyx_f_6Cython_8Compiler_7Parsing_make_slice_node(__pyx_t_10, __pyx_t_11, 0, &__pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1721, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1718, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_t_4, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1718, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_index, __pyx_t_13, __pyx_t_12, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1718, __pyx_L1_error)
          __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IndexNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1718, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF_SET(__pyx_v_lhs, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1716
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
 *             lhs = expr_list[0]
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):             # <<<<<<<<<<<<<<
 *                 # implementation requires IndexNode
 *                 lhs = ExprNodes.IndexNode(
*/
        goto __pyx_L16;
      }

      /* "Cython/Compiler/Parsing.py":1722
 *                     base=lhs.base,
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):             # <<<<<<<<<<<<<<
 *                 error(lhs.pos, "Illegal operand for inplace operation.")
 *             operator = s.sy[:-1]
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_AttributeNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_IndexNode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_NameNode); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_3 = PyObject_IsInstance(__pyx_v_lhs, __pyx_t_1); 
      if (!__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_3 = PyObject_IsInstance(__pyx_v_lhs, __pyx_t_12); 
      if (!__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_3 = PyObject_IsInstance(__pyx_v_lhs, __pyx_t_13); 
      __pyx_t_2 = __pyx_t_3;
      __pyx_L17_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = (!__pyx_t_2);
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":1723
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):
 *                 error(lhs.pos, "Illegal operand for inplace operation.")             # <<<<<<<<<<<<<<
 *             operator = s.sy[:-1]
 *             s.next()
*/
        __pyx_t_12 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_13 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1723, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
          assert(__pyx_t_12);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Illegal_operand_for_inplace_oper};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1723, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1722
 *                     base=lhs.base,
 *                     index=make_slice_node(lhs.pos, lhs.start, lhs.stop))
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):             # <<<<<<<<<<<<<<
 *                 error(lhs.pos, "Illegal operand for inplace operation.")
 *             operator = s.sy[:-1]
*/
      }
      __pyx_L16:;

      /* "Cython/Compiler/Parsing.py":1724
 *             elif not isinstance(lhs, (ExprNodes.AttributeNode, ExprNodes.IndexNode, ExprNodes.NameNode)):
 *                 error(lhs.pos, "Illegal operand for inplace operation.")
 *             operator = s.sy[:-1]             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == 'yield':
*/
      if (unlikely(__pyx_v_s->sy == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 1724, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_PyUnicode_Substring(__pyx_v_s->sy, 0, -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1724, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_operator = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1725
 *                 error(lhs.pos, "Illegal operand for inplace operation.")
 *             operator = s.sy[:-1]
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == 'yield':
 *                 rhs = p_yield_expression(s)
*/
      __pyx_t_13 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_13);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1725, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1726
 *             operator = s.sy[:-1]
 *             s.next()
 *             if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *                 rhs = p_yield_expression(s)
 *             else:
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_yield, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1726, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":1727
 *             s.next()
 *             if s.sy == 'yield':
 *                 rhs = p_yield_expression(s)             # <<<<<<<<<<<<<<
 *             else:
 *                 rhs = p_testlist(s)
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_expression(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1727, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_rhs = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1726
 *             operator = s.sy[:-1]
 *             s.next()
 *             if s.sy == 'yield':             # <<<<<<<<<<<<<<
 *                 rhs = p_yield_expression(s)
 *             else:
*/
        goto __pyx_L20;
      }

      /* "Cython/Compiler/Parsing.py":1729
 *                 rhs = p_yield_expression(s)
 *             else:
 *                 rhs = p_testlist(s)             # <<<<<<<<<<<<<<
 *             return Nodes.InPlaceAssignmentNode(lhs.pos, operator=operator, lhs=lhs, rhs=rhs)
 *         expr = expr_list[0]
*/
      /*else*/ {
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_rhs = __pyx_t_1;
        __pyx_t_1 = 0;
      }
      __pyx_L20:;

      /* "Cython/Compiler/Parsing.py":1730
 *             else:
 *                 rhs = p_testlist(s)
 *             return Nodes.InPlaceAssignmentNode(lhs.pos, operator=operator, lhs=lhs, rhs=rhs)             # <<<<<<<<<<<<<<
 *         expr = expr_list[0]
 *         return Nodes.ExprStatNode(expr.pos, expr=expr)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_13 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_13);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_lhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_13, __pyx_t_4};
        __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1730, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operator, __pyx_v_operator, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1730, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_lhs, __pyx_v_lhs, __pyx_t_12, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1730, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs, __pyx_v_rhs, __pyx_t_12, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1730, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_InPlaceAssignmentNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1730, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":1714
 *         expr_list.append(expr)
 *     if len(expr_list) == 1:
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):             # <<<<<<<<<<<<<<
 *             lhs = expr_list[0]
 *             if isinstance(lhs, ExprNodes.SliceIndexNode):
*/
    }

    /* "Cython/Compiler/Parsing.py":1731
 *                 rhs = p_testlist(s)
 *             return Nodes.InPlaceAssignmentNode(lhs.pos, operator=operator, lhs=lhs, rhs=rhs)
 *         expr = expr_list[0]             # <<<<<<<<<<<<<<
 *         return Nodes.ExprStatNode(expr.pos, expr=expr)
 * 
*/
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_expr_list, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1732
 *             return Nodes.InPlaceAssignmentNode(lhs.pos, operator=operator, lhs=lhs, rhs=rhs)
 *         expr = expr_list[0]
 *         return Nodes.ExprStatNode(expr.pos, expr=expr)             # <<<<<<<<<<<<<<
 * 
 *     rhs = expr_list[-1]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_12 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_12);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_12, __pyx_t_4};
      __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_expr, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1732, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExprStatNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1713
 *             expr = p_testlist_star_expr(s)
 *         expr_list.append(expr)
 *     if len(expr_list) == 1:             # <<<<<<<<<<<<<<
 *         if re.match(r"([-+*[inserted by cython to avoid comment closer]/%^&|]|<<|>>|\*\*|//|@)=", s.sy):
 *             lhs = expr_list[0]
*/
  }

  /* "Cython/Compiler/Parsing.py":1734
 *         return Nodes.ExprStatNode(expr.pos, expr=expr)
 * 
 *     rhs = expr_list[-1]             # <<<<<<<<<<<<<<
 *     if len(expr_list) == 2:
 *         return Nodes.SingleAssignmentNode(rhs.pos, lhs=expr_list[0], rhs=rhs, first=has_annotation)
*/
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_expr_list, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rhs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1735
 * 
 *     rhs = expr_list[-1]
 *     if len(expr_list) == 2:             # <<<<<<<<<<<<<<
 *         return Nodes.SingleAssignmentNode(rhs.pos, lhs=expr_list[0], rhs=rhs, first=has_annotation)
 *     else:
*/
  __pyx_t_9 = __Pyx_PyList_GET_SIZE(__pyx_v_expr_list); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1735, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_9 == 2);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":1736
 *     rhs = expr_list[-1]
 *     if len(expr_list) == 2:
 *         return Nodes.SingleAssignmentNode(rhs.pos, lhs=expr_list[0], rhs=rhs, first=has_annotation)             # <<<<<<<<<<<<<<
 *     else:
 *         return Nodes.CascadedAssignmentNode(rhs.pos, lhs_list=expr_list[:-1], rhs=rhs)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_13 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_rhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_GetItemInt_List(__pyx_v_expr_list, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_has_annotation); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_13, __pyx_t_4};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_lhs, __pyx_t_12, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1736, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs, __pyx_v_rhs, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1736, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_first, __pyx_t_6, __pyx_t_7, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1736, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SingleAssignmentNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1735
 * 
 *     rhs = expr_list[-1]
 *     if len(expr_list) == 2:             # <<<<<<<<<<<<<<
 *         return Nodes.SingleAssignmentNode(rhs.pos, lhs=expr_list[0], rhs=rhs, first=has_annotation)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":1738
 *         return Nodes.SingleAssignmentNode(rhs.pos, lhs=expr_list[0], rhs=rhs, first=has_annotation)
 *     else:
 *         return Nodes.CascadedAssignmentNode(rhs.pos, lhs_list=expr_list[:-1], rhs=rhs)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_rhs, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = __Pyx_PyList_GetSlice(__pyx_v_expr_list, 0, -1L); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_7, __pyx_t_6};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_lhs_list, __pyx_t_12, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1738, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs, __pyx_v_rhs, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1738, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CascadedAssignmentNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1689
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_expression_or_assignment(s: PyrexScanner):
 *     expr = p_testlist_star_expr(s)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_expression_or_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_expr_list);
  __Pyx_XDECREF(__pyx_v_lhs);
  __Pyx_XDECREF(__pyx_v_operator);
  __Pyx_XDECREF(__pyx_v_rhs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1741
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_print_statement(s: PyrexScanner):
 *     # s.sy == 'print'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_print_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_ends_with_comma;
  PyObject *__pyx_v_stream = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_print_statement", 0);

  /* "Cython/Compiler/Parsing.py":1744
 * def p_print_statement(s: PyrexScanner):
 *     # s.sy == 'print'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     ends_with_comma: cython.bint = False
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1745
 *     # s.sy == 'print'
 *     pos = s.position()
 *     ends_with_comma: cython.bint = False             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy == '>>':
*/
  __pyx_v_ends_with_comma = 0;

  /* "Cython/Compiler/Parsing.py":1746
 *     pos = s.position()
 *     ends_with_comma: cython.bint = False
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy == '>>':
 *         s.next()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1747
 *     ends_with_comma: cython.bint = False
 *     s.next()
 *     if s.sy == '>>':             # <<<<<<<<<<<<<<
 *         s.next()
 *         stream = p_test(s)
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__13, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1747, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1748
 *     s.next()
 *     if s.sy == '>>':
 *         s.next()             # <<<<<<<<<<<<<<
 *         stream = p_test(s)
 *         if s.sy == ',':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1749
 *     if s.sy == '>>':
 *         s.next()
 *         stream = p_test(s)             # <<<<<<<<<<<<<<
 *         if s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_stream = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1750
 *         s.next()
 *         stream = p_test(s)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             ends_with_comma = s.sy in ('NEWLINE', 'EOF')
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1750, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1751
 *         stream = p_test(s)
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             ends_with_comma = s.sy in ('NEWLINE', 'EOF')
 *     else:
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1751, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1752
 *         if s.sy == ',':
 *             s.next()
 *             ends_with_comma = s.sy in ('NEWLINE', 'EOF')             # <<<<<<<<<<<<<<
 *     else:
 *         stream = None
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_5 = __pyx_v_s->sy;
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1752, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L5_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1752, __pyx_L1_error)
      __pyx_t_4 = __pyx_t_6;
      __pyx_L5_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_ends_with_comma = __pyx_t_4;

      /* "Cython/Compiler/Parsing.py":1750
 *         s.next()
 *         stream = p_test(s)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             ends_with_comma = s.sy in ('NEWLINE', 'EOF')
*/
    }

    /* "Cython/Compiler/Parsing.py":1747
 *     ends_with_comma: cython.bint = False
 *     s.next()
 *     if s.sy == '>>':             # <<<<<<<<<<<<<<
 *         s.next()
 *         stream = p_test(s)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1754
 *             ends_with_comma = s.sy in ('NEWLINE', 'EOF')
 *     else:
 *         stream = None             # <<<<<<<<<<<<<<
 *     args = []
 *     if s.sy not in ('NEWLINE', 'EOF'):
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_stream = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1755
 *     else:
 *         stream = None
 *     args = []             # <<<<<<<<<<<<<<
 *     if s.sy not in ('NEWLINE', 'EOF'):
 *         args.append(p_test(s))
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1756
 *         stream = None
 *     args = []
 *     if s.sy not in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *         args.append(p_test(s))
 *         while s.sy == ',':
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_5 = __pyx_v_s->sy;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1756, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1756, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __pyx_t_4;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":1757
 *     args = []
 *     if s.sy not in ('NEWLINE', 'EOF'):
 *         args.append(p_test(s))             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1757, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1758
 *     if s.sy not in ('NEWLINE', 'EOF'):
 *         args.append(p_test(s))
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):
*/
    while (1) {
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1758, __pyx_L1_error)
      if (!__pyx_t_6) break;

      /* "Cython/Compiler/Parsing.py":1759
 *         args.append(p_test(s))
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 ends_with_comma = True
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1759, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1760
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *                 ends_with_comma = True
 *                 break
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_5 = __pyx_v_s->sy;
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1760, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __pyx_t_6 = __pyx_t_4;
        goto __pyx_L13_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1760, __pyx_L1_error)
      __pyx_t_6 = __pyx_t_4;
      __pyx_L13_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_4 = __pyx_t_6;
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1761
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 ends_with_comma = True             # <<<<<<<<<<<<<<
 *                 break
 *             args.append(p_test(s))
*/
        __pyx_v_ends_with_comma = 1;

        /* "Cython/Compiler/Parsing.py":1762
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 ends_with_comma = True
 *                 break             # <<<<<<<<<<<<<<
 *             args.append(p_test(s))
 *     arg_tuple = ExprNodes.TupleNode(pos, args=args)
*/
        goto __pyx_L11_break;

        /* "Cython/Compiler/Parsing.py":1760
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *                 ends_with_comma = True
 *                 break
*/
      }

      /* "Cython/Compiler/Parsing.py":1763
 *                 ends_with_comma = True
 *                 break
 *             args.append(p_test(s))             # <<<<<<<<<<<<<<
 *     arg_tuple = ExprNodes.TupleNode(pos, args=args)
 *     return Nodes.PrintStatNode(pos,
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 1763, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L11_break:;

    /* "Cython/Compiler/Parsing.py":1756
 *         stream = None
 *     args = []
 *     if s.sy not in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *         args.append(p_test(s))
 *         while s.sy == ',':
*/
  }

  /* "Cython/Compiler/Parsing.py":1764
 *                 break
 *             args.append(p_test(s))
 *     arg_tuple = ExprNodes.TupleNode(pos, args=args)             # <<<<<<<<<<<<<<
 *     return Nodes.PrintStatNode(pos,
 *         arg_tuple=arg_tuple, stream=stream,
*/
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_arg_tuple = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1765
 *             args.append(p_test(s))
 *     arg_tuple = ExprNodes.TupleNode(pos, args=args)
 *     return Nodes.PrintStatNode(pos,             # <<<<<<<<<<<<<<
 *         arg_tuple=arg_tuple, stream=stream,
 *         append_newline=not ends_with_comma)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_8);

  /* "Cython/Compiler/Parsing.py":1767
 *     return Nodes.PrintStatNode(pos,
 *         arg_tuple=arg_tuple, stream=stream,
 *         append_newline=not ends_with_comma)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyBool_FromLong((!__pyx_v_ends_with_comma)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_arg_tuple, __pyx_v_arg_tuple, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1765, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stream, __pyx_v_stream, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1765, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_append_newline, __pyx_t_2, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1765, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_PrintStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1741
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_print_statement(s: PyrexScanner):
 *     # s.sy == 'print'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_print_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_stream);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1770
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_exec_statement(s: PyrexScanner):
 *     # s.sy == 'exec'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_exec_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_code = NULL;
  int __pyx_v_tuple_variant;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_exec_statement", 0);

  /* "Cython/Compiler/Parsing.py":1773
 * def p_exec_statement(s: PyrexScanner):
 *     # s.sy == 'exec'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     code = p_bit_expr(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1774
 *     # s.sy == 'exec'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     code = p_bit_expr(s)
 *     if isinstance(code, ExprNodes.TupleNode):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1775
 *     pos = s.position()
 *     s.next()
 *     code = p_bit_expr(s)             # <<<<<<<<<<<<<<
 *     if isinstance(code, ExprNodes.TupleNode):
 *         # Py3 compatibility syntax
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_code = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1776
 *     s.next()
 *     code = p_bit_expr(s)
 *     if isinstance(code, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *         # Py3 compatibility syntax
 *         tuple_variant = True
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_TupleNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_code, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 1776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1778
 *     if isinstance(code, ExprNodes.TupleNode):
 *         # Py3 compatibility syntax
 *         tuple_variant = True             # <<<<<<<<<<<<<<
 *         args = code.args
 *         if len(args) not in (2, 3):
*/
    __pyx_v_tuple_variant = 1;

    /* "Cython/Compiler/Parsing.py":1779
 *         # Py3 compatibility syntax
 *         tuple_variant = True
 *         args = code.args             # <<<<<<<<<<<<<<
 *         if len(args) not in (2, 3):
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_args = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1780
 *         tuple_variant = True
 *         args = code.args
 *         if len(args) not in (2, 3):             # <<<<<<<<<<<<<<
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),
 *                     pos=pos, fatal=False)
*/
    __pyx_t_5 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1780, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 2);
    if (__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_t_5 != 3);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;
    __pyx_t_6 = __pyx_t_4;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":1781
 *         args = code.args
 *         if len(args) not in (2, 3):
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),             # <<<<<<<<<<<<<<
 *                     pos=pos, fatal=False)
 *             args = [code]
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1781, __pyx_L1_error)
      __pyx_t_7 = PyLong_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_expected_tuple_of_length_2_or_3, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":1782
 *         if len(args) not in (2, 3):
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),
 *                     pos=pos, fatal=False)             # <<<<<<<<<<<<<<
 *             args = [code]
 *     else:
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1781, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1781, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1781, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1781, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1783
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),
 *                     pos=pos, fatal=False)
 *             args = [code]             # <<<<<<<<<<<<<<
 *     else:
 *         tuple_variant = False
*/
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1783, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_code);
      __Pyx_GIVEREF(__pyx_v_code);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_code) != (0)) __PYX_ERR(0, 1783, __pyx_L1_error);
      __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1780
 *         tuple_variant = True
 *         args = code.args
 *         if len(args) not in (2, 3):             # <<<<<<<<<<<<<<
 *             s.error("expected tuple of length 2 or 3, got length %d" % len(args),
 *                     pos=pos, fatal=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":1776
 *     s.next()
 *     code = p_bit_expr(s)
 *     if isinstance(code, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *         # Py3 compatibility syntax
 *         tuple_variant = True
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1785
 *             args = [code]
 *     else:
 *         tuple_variant = False             # <<<<<<<<<<<<<<
 *         args = [code]
 *     if s.sy == 'in':
*/
  /*else*/ {
    __pyx_v_tuple_variant = 0;

    /* "Cython/Compiler/Parsing.py":1786
 *     else:
 *         tuple_variant = False
 *         args = [code]             # <<<<<<<<<<<<<<
 *     if s.sy == 'in':
 *         if tuple_variant:
*/
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1786, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_code);
    __Pyx_GIVEREF(__pyx_v_code);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_code) != (0)) __PYX_ERR(0, 1786, __pyx_L1_error);
    __pyx_v_args = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1787
 *         tuple_variant = False
 *         args = [code]
 *     if s.sy == 'in':             # <<<<<<<<<<<<<<
 *         if tuple_variant:
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_in, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1787, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":1788
 *         args = [code]
 *     if s.sy == 'in':
 *         if tuple_variant:             # <<<<<<<<<<<<<<
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
 *                     fatal=False)
*/
    if (__pyx_v_tuple_variant) {

      /* "Cython/Compiler/Parsing.py":1789
 *     if s.sy == 'in':
 *         if tuple_variant:
 *             s.error("tuple variant of exec does not support additional 'in' arguments",             # <<<<<<<<<<<<<<
 *                     fatal=False)
 *         s.next()
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);

      /* "Cython/Compiler/Parsing.py":1790
 *         if tuple_variant:
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
 *                     fatal=False)             # <<<<<<<<<<<<<<
 *         s.next()
 *         args.append(p_test(s))
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_tuple_variant_of_exec_does_not_s};
        __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1789, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1789, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1789, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1788
 *         args = [code]
 *     if s.sy == 'in':
 *         if tuple_variant:             # <<<<<<<<<<<<<<
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
 *                     fatal=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":1791
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
 *                     fatal=False)
 *         s.next()             # <<<<<<<<<<<<<<
 *         args.append(p_test(s))
 *         if s.sy == ',':
*/
    __pyx_t_8 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1792
 *                     fatal=False)
 *         s.next()
 *         args.append(p_test(s))             # <<<<<<<<<<<<<<
 *         if s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_Append(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1792, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1793
 *         s.next()
 *         args.append(p_test(s))
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.append(p_test(s))
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1793, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":1794
 *         args.append(p_test(s))
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             args.append(p_test(s))
 *     return Nodes.ExecStatNode(pos, args=args)
*/
      __pyx_t_8 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1794, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1795
 *         if s.sy == ',':
 *             s.next()
 *             args.append(p_test(s))             # <<<<<<<<<<<<<<
 *     return Nodes.ExecStatNode(pos, args=args)
 * 
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1795, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1795, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1793
 *         s.next()
 *         args.append(p_test(s))
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.append(p_test(s))
*/
    }

    /* "Cython/Compiler/Parsing.py":1787
 *         tuple_variant = False
 *         args = [code]
 *     if s.sy == 'in':             # <<<<<<<<<<<<<<
 *         if tuple_variant:
 *             s.error("tuple variant of exec does not support additional 'in' arguments",
*/
  }

  /* "Cython/Compiler/Parsing.py":1796
 *             s.next()
 *             args.append(p_test(s))
 *     return Nodes.ExecStatNode(pos, args=args)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExecStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1770
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_exec_statement(s: PyrexScanner):
 *     # s.sy == 'exec'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_exec_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1799
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_del_statement(s: PyrexScanner):
 *     # s.sy == 'del'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_del_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_del_statement", 0);

  /* "Cython/Compiler/Parsing.py":1802
 * def p_del_statement(s: PyrexScanner):
 *     # s.sy == 'del'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     # FIXME: 'exprlist' in Python
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1803
 *     # s.sy == 'del'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     # FIXME: 'exprlist' in Python
 *     args = p_simple_expr_list(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1805
 *     s.next()
 *     # FIXME: 'exprlist' in Python
 *     args = p_simple_expr_list(s)             # <<<<<<<<<<<<<<
 *     return Nodes.DelStatNode(pos, args = args)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_expr_list(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1806
 *     # FIXME: 'exprlist' in Python
 *     args = p_simple_expr_list(s)
 *     return Nodes.DelStatNode(pos, args = args)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1806, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DelStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1799
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_del_statement(s: PyrexScanner):
 *     # s.sy == 'del'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_del_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1809
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_pass_statement *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":1810
 * 
 * @cython.cfunc
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     s.expect('pass')
*/
  int __pyx_v_with_newline = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_pass_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_with_newline = __pyx_optional_args->with_newline;
    }
  }

  /* "Cython/Compiler/Parsing.py":1811
 * @cython.cfunc
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.expect('pass')
 *     if with_newline:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1812
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):
 *     pos = s.position()
 *     s.expect('pass')             # <<<<<<<<<<<<<<
 *     if with_newline:
 *         s.expect_newline("Expected a newline", ignore_semicolon=True)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pass};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1813
 *     pos = s.position()
 *     s.expect('pass')
 *     if with_newline:             # <<<<<<<<<<<<<<
 *         s.expect_newline("Expected a newline", ignore_semicolon=True)
 *     return Nodes.PassStatNode(pos)
*/
  if (__pyx_v_with_newline) {

    /* "Cython/Compiler/Parsing.py":1814
 *     s.expect('pass')
 *     if with_newline:
 *         s.expect_newline("Expected a newline", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *     return Nodes.PassStatNode(pos)
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1814, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1813
 *     pos = s.position()
 *     s.expect('pass')
 *     if with_newline:             # <<<<<<<<<<<<<<
 *         s.expect_newline("Expected a newline", ignore_semicolon=True)
 *     return Nodes.PassStatNode(pos)
*/
  }

  /* "Cython/Compiler/Parsing.py":1815
 *     if with_newline:
 *         s.expect_newline("Expected a newline", ignore_semicolon=True)
 *     return Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1809
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pass_statement(s: PyrexScanner, with_newline: cython.bint = False):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_pass_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1818
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_break_statement(s: PyrexScanner):
 *     # s.sy == 'break'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_break_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_break_statement", 0);

  /* "Cython/Compiler/Parsing.py":1821
 * def p_break_statement(s: PyrexScanner):
 *     # s.sy == 'break'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     return Nodes.BreakStatNode(pos)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1822
 *     # s.sy == 'break'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     return Nodes.BreakStatNode(pos)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1823
 *     pos = s.position()
 *     s.next()
 *     return Nodes.BreakStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_BreakStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1818
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_break_statement(s: PyrexScanner):
 *     # s.sy == 'break'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_break_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1826
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_continue_statement(s: PyrexScanner):
 *     # s.sy == 'continue'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_continue_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_continue_statement", 0);

  /* "Cython/Compiler/Parsing.py":1829
 * def p_continue_statement(s: PyrexScanner):
 *     # s.sy == 'continue'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     return Nodes.ContinueStatNode(pos)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1830
 *     # s.sy == 'continue'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     return Nodes.ContinueStatNode(pos)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1831
 *     pos = s.position()
 *     s.next()
 *     return Nodes.ContinueStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_ContinueStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1826
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_continue_statement(s: PyrexScanner):
 *     # s.sy == 'continue'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_continue_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1834
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_return_statement(s: PyrexScanner):
 *     # s.sy == 'return'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_return_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_return_statement", 0);

  /* "Cython/Compiler/Parsing.py":1837
 * def p_return_statement(s: PyrexScanner):
 *     # s.sy == 'return'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy not in statement_terminators:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1838
 *     # s.sy == 'return'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy not in statement_terminators:
 *         value = p_testlist(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1839
 *     pos = s.position()
 *     s.next()
 *     if s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         value = p_testlist(s)
 *     else:
*/
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_statement_terminators, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1839, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1840
 *     s.next()
 *     if s.sy not in statement_terminators:
 *         value = p_testlist(s)             # <<<<<<<<<<<<<<
 *     else:
 *         value = None
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1839
 *     pos = s.position()
 *     s.next()
 *     if s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         value = p_testlist(s)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1842
 *         value = p_testlist(s)
 *     else:
 *         value = None             # <<<<<<<<<<<<<<
 *     return Nodes.ReturnStatNode(pos, value = value)
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_value = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1843
 *     else:
 *         value = None
 *     return Nodes.ReturnStatNode(pos, value = value)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ReturnStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1834
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_return_statement(s: PyrexScanner):
 *     # s.sy == 'return'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_return_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1846
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_raise_statement(s: PyrexScanner):
 *     # s.sy == 'raise'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_raise_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_exc_type = NULL;
  PyObject *__pyx_v_exc_value = NULL;
  PyObject *__pyx_v_exc_tb = NULL;
  PyObject *__pyx_v_cause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_raise_statement", 0);

  /* "Cython/Compiler/Parsing.py":1849
 * def p_raise_statement(s: PyrexScanner):
 *     # s.sy == 'raise'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     exc_type = None
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1850
 *     # s.sy == 'raise'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     exc_type = None
 *     exc_value = None
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1851
 *     pos = s.position()
 *     s.next()
 *     exc_type = None             # <<<<<<<<<<<<<<
 *     exc_value = None
 *     exc_tb = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_type = Py_None;

  /* "Cython/Compiler/Parsing.py":1852
 *     s.next()
 *     exc_type = None
 *     exc_value = None             # <<<<<<<<<<<<<<
 *     exc_tb = None
 *     cause = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_value = Py_None;

  /* "Cython/Compiler/Parsing.py":1853
 *     exc_type = None
 *     exc_value = None
 *     exc_tb = None             # <<<<<<<<<<<<<<
 *     cause = None
 *     if s.sy not in statement_terminators:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_tb = Py_None;

  /* "Cython/Compiler/Parsing.py":1854
 *     exc_value = None
 *     exc_tb = None
 *     cause = None             # <<<<<<<<<<<<<<
 *     if s.sy not in statement_terminators:
 *         exc_type = p_test(s)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_cause = Py_None;

  /* "Cython/Compiler/Parsing.py":1855
 *     exc_tb = None
 *     cause = None
 *     if s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         exc_type = p_test(s)
 *         if s.sy == ',':
*/
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_statement_terminators, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1855, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1856
 *     cause = None
 *     if s.sy not in statement_terminators:
 *         exc_type = p_test(s)             # <<<<<<<<<<<<<<
 *         if s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_exc_type, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1857
 *     if s.sy not in statement_terminators:
 *         exc_type = p_test(s)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             exc_value = p_test(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1857, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1858
 *         exc_type = p_test(s)
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             exc_value = p_test(s)
 *             if s.sy == ',':
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1858, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1859
 *         if s.sy == ',':
 *             s.next()
 *             exc_value = p_test(s)             # <<<<<<<<<<<<<<
 *             if s.sy == ',':
 *                 s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_exc_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1860
 *             s.next()
 *             exc_value = p_test(s)
 *             if s.sy == ',':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 exc_tb = p_test(s)
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1860, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":1861
 *             exc_value = p_test(s)
 *             if s.sy == ',':
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 exc_tb = p_test(s)
 *         elif s.sy == 'from':
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1861, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1862
 *             if s.sy == ',':
 *                 s.next()
 *                 exc_tb = p_test(s)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'from':
 *             s.next()
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1862, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_exc_tb, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1860
 *             s.next()
 *             exc_value = p_test(s)
 *             if s.sy == ',':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 exc_tb = p_test(s)
*/
      }

      /* "Cython/Compiler/Parsing.py":1857
 *     if s.sy not in statement_terminators:
 *         exc_type = p_test(s)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             exc_value = p_test(s)
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":1863
 *                 s.next()
 *                 exc_tb = p_test(s)
 *         elif s.sy == 'from':             # <<<<<<<<<<<<<<
 *             s.next()
 *             cause = p_test(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_from, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1863, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1864
 *                 exc_tb = p_test(s)
 *         elif s.sy == 'from':
 *             s.next()             # <<<<<<<<<<<<<<
 *             cause = p_test(s)
 *     if exc_type or exc_value or exc_tb:
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1865
 *         elif s.sy == 'from':
 *             s.next()
 *             cause = p_test(s)             # <<<<<<<<<<<<<<
 *     if exc_type or exc_value or exc_tb:
 *         return Nodes.RaiseStatNode(pos,
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_cause, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1863
 *                 s.next()
 *                 exc_tb = p_test(s)
 *         elif s.sy == 'from':             # <<<<<<<<<<<<<<
 *             s.next()
 *             cause = p_test(s)
*/
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":1855
 *     exc_tb = None
 *     cause = None
 *     if s.sy not in statement_terminators:             # <<<<<<<<<<<<<<
 *         exc_type = p_test(s)
 *         if s.sy == ',':
*/
  }

  /* "Cython/Compiler/Parsing.py":1866
 *             s.next()
 *             cause = p_test(s)
 *     if exc_type or exc_value or exc_tb:             # <<<<<<<<<<<<<<
 *         return Nodes.RaiseStatNode(pos,
 *             exc_type = exc_type,
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_exc_type); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1866, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_exc_value); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1866, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_exc_tb); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1866, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":1867
 *             cause = p_test(s)
 *     if exc_type or exc_value or exc_tb:
 *         return Nodes.RaiseStatNode(pos,             # <<<<<<<<<<<<<<
 *             exc_type = exc_type,
 *             exc_value = exc_value,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":1871
 *             exc_value = exc_value,
 *             exc_tb = exc_tb,
 *             cause = cause)             # <<<<<<<<<<<<<<
 *     else:
 *         return Nodes.ReraiseStatNode(pos)
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_type, __pyx_v_exc_type, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1867, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_value, __pyx_v_exc_value, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1867, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_tb, __pyx_v_exc_tb, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1867, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cause, __pyx_v_cause, __pyx_t_6, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_RaiseStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1866
 *             s.next()
 *             cause = p_test(s)
 *     if exc_type or exc_value or exc_tb:             # <<<<<<<<<<<<<<
 *         return Nodes.RaiseStatNode(pos,
 *             exc_type = exc_type,
*/
  }

  /* "Cython/Compiler/Parsing.py":1873
 *             cause = cause)
 *     else:
 *         return Nodes.ReraiseStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_ReraiseStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1846
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_raise_statement(s: PyrexScanner):
 *     # s.sy == 'raise'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_raise_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_exc_type);
  __Pyx_XDECREF(__pyx_v_exc_value);
  __Pyx_XDECREF(__pyx_v_exc_tb);
  __Pyx_XDECREF(__pyx_v_cause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1876
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_import_statement(s: PyrexScanner):
 *     # s.sy in ('import', 'cimport')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_import_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_stats = NULL;
  PyObject *__pyx_v_is_absolute = NULL;
  PyObject *__pyx_v_target_name = NULL;
  PyObject *__pyx_v_dotted_name = NULL;
  PyObject *__pyx_v_as_name = NULL;
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_import_statement", 0);

  /* "Cython/Compiler/Parsing.py":1879
 * def p_import_statement(s: PyrexScanner):
 *     # s.sy in ('import', 'cimport')
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     kind = s.sy
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1880
 *     # s.sy in ('import', 'cimport')
 *     pos = s.position()
 *     kind = s.sy             # <<<<<<<<<<<<<<
 *     s.next()
 *     items = [p_dotted_name(s, as_allowed=True)]
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_kind = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1881
 *     pos = s.position()
 *     kind = s.sy
 *     s.next()             # <<<<<<<<<<<<<<
 *     items = [p_dotted_name(s, as_allowed=True)]
 *     while s.sy == ',':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1882
 *     kind = s.sy
 *     s.next()
 *     items = [p_dotted_name(s, as_allowed=True)]             # <<<<<<<<<<<<<<
 *     while s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_dotted_name(__pyx_v_s, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1882, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_items = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1883
 *     s.next()
 *     items = [p_dotted_name(s, as_allowed=True)]
 *     while s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         items.append(p_dotted_name(s, as_allowed=True))
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1883, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":1884
 *     items = [p_dotted_name(s, as_allowed=True)]
 *     while s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         items.append(p_dotted_name(s, as_allowed=True))
 *     stats = []
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":1885
 *     while s.sy == ',':
 *         s.next()
 *         items.append(p_dotted_name(s, as_allowed=True))             # <<<<<<<<<<<<<<
 *     stats = []
 *     is_absolute = Future.absolute_import in s.context.future_directives
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_dotted_name(__pyx_v_s, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1885, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":1886
 *         s.next()
 *         items.append(p_dotted_name(s, as_allowed=True))
 *     stats = []             # <<<<<<<<<<<<<<
 *     is_absolute = Future.absolute_import in s.context.future_directives
 *     for pos, target_name, dotted_name, as_name in items:
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_stats = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1887
 *         items.append(p_dotted_name(s, as_allowed=True))
 *     stats = []
 *     is_absolute = Future.absolute_import in s.context.future_directives             # <<<<<<<<<<<<<<
 *     for pos, target_name, dotted_name, as_name in items:
 *         if kind == 'cimport':
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_absolute_import); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_is_absolute = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1888
 *     stats = []
 *     is_absolute = Future.absolute_import in s.context.future_directives
 *     for pos, target_name, dotted_name, as_name in items:             # <<<<<<<<<<<<<<
 *         if kind == 'cimport':
 *             stat = Nodes.CImportStatNode(
*/
  __pyx_t_1 = __pyx_v_items; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_6 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1888, __pyx_L1_error)
      #endif
      if (__pyx_t_6 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_6;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1888, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 4)) {
        if (size > 4) __Pyx_RaiseTooManyValuesError(4);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1888, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 2);
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_10 = PyTuple_GET_ITEM(sequence, 3);
        __Pyx_INCREF(__pyx_t_10);
      } else {
        __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1888, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1888, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1888, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_9);
        __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 3, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1888, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_10);
      }
      #else
      {
        Py_ssize_t i;
        PyObject** temps[4] = {&__pyx_t_7,&__pyx_t_8,&__pyx_t_9,&__pyx_t_10};
        for (i=0; i < 4; i++) {
          PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1888, __pyx_L1_error)
          __Pyx_GOTREF(item);
          *(temps[i]) = item;
        }
      }
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      PyObject** temps[4] = {&__pyx_t_7,&__pyx_t_8,&__pyx_t_9,&__pyx_t_10};
      __pyx_t_11 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
      for (index=0; index < 4; index++) {
        PyObject* item = __pyx_t_12(__pyx_t_11); if (unlikely(!item)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(item);
        *(temps[index]) = item;
      }
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 4) < (0)) __PYX_ERR(0, 1888, __pyx_L1_error)
      __pyx_t_12 = NULL;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L8_unpacking_done;
      __pyx_L7_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1888, __pyx_L1_error)
      __pyx_L8_unpacking_done:;
    }
    __Pyx_DECREF_SET(__pyx_v_pos, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_target_name, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_dotted_name, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_XDECREF_SET(__pyx_v_as_name, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1889
 *     is_absolute = Future.absolute_import in s.context.future_directives
 *     for pos, target_name, dotted_name, as_name in items:
 *         if kind == 'cimport':             # <<<<<<<<<<<<<<
 *             stat = Nodes.CImportStatNode(
 *                 pos,
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_cimport, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1889, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":1890
 *     for pos, target_name, dotted_name, as_name in items:
 *         if kind == 'cimport':
 *             stat = Nodes.CImportStatNode(             # <<<<<<<<<<<<<<
 *                 pos,
 *                 module_name=dotted_name,
*/
      __pyx_t_10 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_10);

      /* "Cython/Compiler/Parsing.py":1894
 *                 module_name=dotted_name,
 *                 as_name=as_name,
 *                 is_absolute=is_absolute)             # <<<<<<<<<<<<<<
 *         else:
 *             stat = Nodes.SingleAssignmentNode(
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_10, __pyx_v_pos};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1890, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_name, __pyx_v_dotted_name, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1890, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_as_name, __pyx_v_as_name, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1890, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_absolute, __pyx_v_is_absolute, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1890, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CImportStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1890, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":1889
 *     is_absolute = Future.absolute_import in s.context.future_directives
 *     for pos, target_name, dotted_name, as_name in items:
 *         if kind == 'cimport':             # <<<<<<<<<<<<<<
 *             stat = Nodes.CImportStatNode(
 *                 pos,
*/
      goto __pyx_L9;
    }

    /* "Cython/Compiler/Parsing.py":1896
 *                 is_absolute=is_absolute)
 *         else:
 *             stat = Nodes.SingleAssignmentNode(             # <<<<<<<<<<<<<<
 *                 pos,
 *                 lhs=ExprNodes.NameNode(pos, name=as_name or target_name),
*/
    /*else*/ {
      __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_9);

      /* "Cython/Compiler/Parsing.py":1898
 *             stat = Nodes.SingleAssignmentNode(
 *                 pos,
 *                 lhs=ExprNodes.NameNode(pos, name=as_name or target_name),             # <<<<<<<<<<<<<<
 *                 rhs=ExprNodes.ImportNode(
 *                     pos,
*/
      __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_as_name); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1898, __pyx_L1_error)
      if (!__pyx_t_4) {
      } else {
        __Pyx_INCREF(__pyx_v_as_name);
        __pyx_t_7 = __pyx_v_as_name;
        goto __pyx_L10_bool_binop_done;
      }
      __Pyx_INCREF(__pyx_v_target_name);
      __pyx_t_7 = __pyx_v_target_name;
      __pyx_L10_bool_binop_done:;
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_7, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __pyx_t_10 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NameNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }

      /* "Cython/Compiler/Parsing.py":1899
 *                 pos,
 *                 lhs=ExprNodes.NameNode(pos, name=as_name or target_name),
 *                 rhs=ExprNodes.ImportNode(             # <<<<<<<<<<<<<<
 *                     pos,
 *                     module_name=ExprNodes.IdentifierStringNode(pos, value=dotted_name),
*/
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_7);

      /* "Cython/Compiler/Parsing.py":1901
 *                 rhs=ExprNodes.ImportNode(
 *                     pos,
 *                     module_name=ExprNodes.IdentifierStringNode(pos, value=dotted_name),             # <<<<<<<<<<<<<<
 *                     is_import_as_name=bool(as_name),
 *                     level=0 if is_absolute else None,
*/
      __pyx_t_13 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_13);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_13, __pyx_v_pos};
        __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_dotted_name, __pyx_t_14, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1901, __pyx_L1_error)
        __pyx_t_8 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IdentifierStringNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
      }

      /* "Cython/Compiler/Parsing.py":1902
 *                     pos,
 *                     module_name=ExprNodes.IdentifierStringNode(pos, value=dotted_name),
 *                     is_import_as_name=bool(as_name),             # <<<<<<<<<<<<<<
 *                     level=0 if is_absolute else None,
 *                     imported_names=None))
*/
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_as_name); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1902, __pyx_L1_error)
      __pyx_t_14 = __Pyx_PyBool_FromLong((!(!__pyx_t_4))); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1902, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);

      /* "Cython/Compiler/Parsing.py":1903
 *                     module_name=ExprNodes.IdentifierStringNode(pos, value=dotted_name),
 *                     is_import_as_name=bool(as_name),
 *                     level=0 if is_absolute else None,             # <<<<<<<<<<<<<<
 *                     imported_names=None))
 *         stats.append(stat)
*/
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_is_absolute); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1903, __pyx_L1_error)
      if (__pyx_t_4) {
        __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
        __pyx_t_13 = __pyx_mstate_global->__pyx_int_0;
      } else {
        __Pyx_INCREF(Py_None);
        __pyx_t_13 = Py_None;
      }

      /* "Cython/Compiler/Parsing.py":1904
 *                     is_import_as_name=bool(as_name),
 *                     level=0 if is_absolute else None,
 *                     imported_names=None))             # <<<<<<<<<<<<<<
 *         stats.append(stat)
 *     return Nodes.StatListNode(pos, stats=stats)
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_7, __pyx_v_pos};
        __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_name, __pyx_t_8, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1899, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_import_as_name, __pyx_t_14, __pyx_t_15, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1899, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_t_13, __pyx_t_15, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1899, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_imported_names, Py_None, __pyx_t_15, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 1899, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImportNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_v_pos};
        __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_lhs, __pyx_t_10, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1896, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_rhs, __pyx_t_11, __pyx_t_15, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1896, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_SingleAssignmentNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_2);
      __pyx_t_2 = 0;
    }
    __pyx_L9:;

    /* "Cython/Compiler/Parsing.py":1905
 *                     level=0 if is_absolute else None,
 *                     imported_names=None))
 *         stats.append(stat)             # <<<<<<<<<<<<<<
 *     return Nodes.StatListNode(pos, stats=stats)
 * 
*/
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_stats, __pyx_v_stat); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 1905, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":1888
 *     stats = []
 *     is_absolute = Future.absolute_import in s.context.future_directives
 *     for pos, target_name, dotted_name, as_name in items:             # <<<<<<<<<<<<<<
 *         if kind == 'cimport':
 *             stat = Nodes.CImportStatNode(
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1906
 *                     imported_names=None))
 *         stats.append(stat)
 *     return Nodes.StatListNode(pos, stats=stats)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1906, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stats, __pyx_v_stats, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1906, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_StatListNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1906, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1876
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_import_statement(s: PyrexScanner):
 *     # s.sy in ('import', 'cimport')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_import_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_stats);
  __Pyx_XDECREF(__pyx_v_is_absolute);
  __Pyx_XDECREF(__pyx_v_target_name);
  __Pyx_XDECREF(__pyx_v_dotted_name);
  __Pyx_XDECREF(__pyx_v_as_name);
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1909
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_from_import_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     # s.sy == 'from'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_from_import_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_from_import_statement *__pyx_optional_args) {
  int __pyx_v_first_statement = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_level = NULL;
  PyObject *__pyx_v_dotted_name_pos = NULL;
  PyObject *__pyx_v_dotted_name = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_is_cimport = NULL;
  int __pyx_v_is_parenthesized;
  PyObject *__pyx_v_imported_names = NULL;
  PyObject *__pyx_v_name_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_as_name = NULL;
  PyObject *__pyx_v_directive = NULL;
  PyObject *__pyx_v_imported_name_strings = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_from_import_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_first_statement = __pyx_optional_args->first_statement;
    }
  }

  /* "Cython/Compiler/Parsing.py":1912
 * def p_from_import_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     # s.sy == 'from'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy in ('.', '...'):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1913
 *     # s.sy == 'from'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy in ('.', '...'):
 *         # count relative import level
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1914
 *     pos = s.position()
 *     s.next()
 *     if s.sy in ('.', '...'):             # <<<<<<<<<<<<<<
 *         # count relative import level
 *         level = 0
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_4 = __pyx_v_s->sy;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1914, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__31, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1914, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __pyx_t_5;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":1916
 *     if s.sy in ('.', '...'):
 *         # count relative import level
 *         level = 0             # <<<<<<<<<<<<<<
 *         while s.sy in ('.', '...'):
 *             level += len(s.sy)
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
    __pyx_v_level = __pyx_mstate_global->__pyx_int_0;

    /* "Cython/Compiler/Parsing.py":1917
 *         # count relative import level
 *         level = 0
 *         while s.sy in ('.', '...'):             # <<<<<<<<<<<<<<
 *             level += len(s.sy)
 *             s.next()
*/
    while (1) {
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_4 = __pyx_v_s->sy;
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1917, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_6 = __pyx_t_5;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__31, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1917, __pyx_L1_error)
      __pyx_t_6 = __pyx_t_5;
      __pyx_L8_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __pyx_t_6;
      if (!__pyx_t_5) break;

      /* "Cython/Compiler/Parsing.py":1918
 *         level = 0
 *         while s.sy in ('.', '...'):
 *             level += len(s.sy)             # <<<<<<<<<<<<<<
 *             s.next()
 *     else:
*/
      __pyx_t_1 = __pyx_v_s->sy;
      __Pyx_INCREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 1918, __pyx_L1_error)
      }
      __pyx_t_7 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1918, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyLong_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1918, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_level, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1918, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_level, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":1919
 *         while s.sy in ('.', '...'):
 *             level += len(s.sy)
 *             s.next()             # <<<<<<<<<<<<<<
 *     else:
 *         level = None
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1919, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "Cython/Compiler/Parsing.py":1914
 *     pos = s.position()
 *     s.next()
 *     if s.sy in ('.', '...'):             # <<<<<<<<<<<<<<
 *         # count relative import level
 *         level = 0
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":1921
 *             s.next()
 *     else:
 *         level = None             # <<<<<<<<<<<<<<
 *     if level is not None and s.sy in ('import', 'cimport'):
 *         # we are dealing with "from .. import foo, bar"
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_level = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":1922
 *     else:
 *         level = None
 *     if level is not None and s.sy in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         # we are dealing with "from .. import foo, bar"
 *         dotted_name_pos, dotted_name = s.position(), s.context.intern_ustring('')
*/
  __pyx_t_6 = (__pyx_v_level != Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L11_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_4 = __pyx_v_s->sy;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_import, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1922, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cimport, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1922, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_8;
  __pyx_L13_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __pyx_t_6;
  __pyx_t_5 = __pyx_t_8;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":1924
 *     if level is not None and s.sy in ('import', 'cimport'):
 *         # we are dealing with "from .. import foo, bar"
 *         dotted_name_pos, dotted_name = s.position(), s.context.intern_ustring('')             # <<<<<<<<<<<<<<
 *     else:
 *         if level is None and Future.absolute_import in s.context.future_directives:
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_mstate_global->__pyx_kp_u__35};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1924, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_dotted_name_pos = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_v_dotted_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":1922
 *     else:
 *         level = None
 *     if level is not None and s.sy in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         # we are dealing with "from .. import foo, bar"
 *         dotted_name_pos, dotted_name = s.position(), s.context.intern_ustring('')
*/
    goto __pyx_L10;
  }

  /* "Cython/Compiler/Parsing.py":1926
 *         dotted_name_pos, dotted_name = s.position(), s.context.intern_ustring('')
 *     else:
 *         if level is None and Future.absolute_import in s.context.future_directives:             # <<<<<<<<<<<<<<
 *             level = 0
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
*/
  /*else*/ {
    __pyx_t_8 = (__pyx_v_level == Py_None);
    if (__pyx_t_8) {
    } else {
      __pyx_t_5 = __pyx_t_8;
      goto __pyx_L16_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_mstate_global->__pyx_n_u_absolute_import); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1926, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = __pyx_t_8;
    __pyx_L16_bool_binop_done:;
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":1927
 *     else:
 *         if level is None and Future.absolute_import in s.context.future_directives:
 *             level = 0             # <<<<<<<<<<<<<<
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
 *     if s.sy not in ('import', 'cimport'):
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_level, __pyx_mstate_global->__pyx_int_0);

      /* "Cython/Compiler/Parsing.py":1926
 *         dotted_name_pos, dotted_name = s.position(), s.context.intern_ustring('')
 *     else:
 *         if level is None and Future.absolute_import in s.context.future_directives:             # <<<<<<<<<<<<<<
 *             level = 0
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":1928
 *         if level is None and Future.absolute_import in s.context.future_directives:
 *             level = 0
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)             # <<<<<<<<<<<<<<
 *     if s.sy not in ('import', 'cimport'):
 *         s.error("Expected 'import' or 'cimport'")
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_dotted_name(__pyx_v_s, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(__pyx_t_2 != Py_None)) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 4)) {
        if (size > 4) __Pyx_RaiseTooManyValuesError(4);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1928, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_10 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_11 = PyTuple_GET_ITEM(sequence, 3);
      __Pyx_INCREF(__pyx_t_11);
      #else
      {
        Py_ssize_t i;
        PyObject** temps[4] = {&__pyx_t_1,&__pyx_t_9,&__pyx_t_10,&__pyx_t_11};
        for (i=0; i < 4; i++) {
          PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 1928, __pyx_L1_error)
          __Pyx_GOTREF(item);
          *(temps[i]) = item;
        }
      }
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 1928, __pyx_L1_error)
    }
    __pyx_v_dotted_name_pos = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v__ = __pyx_t_9;
    __pyx_t_9 = 0;
    __pyx_v_dotted_name = __pyx_t_10;
    __pyx_t_10 = 0;
    __Pyx_DECREF_SET(__pyx_v__, __pyx_t_11);
    __pyx_t_11 = 0;
  }
  __pyx_L10:;

  /* "Cython/Compiler/Parsing.py":1929
 *             level = 0
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
 *     if s.sy not in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         s.error("Expected 'import' or 'cimport'")
 *     kind = s.sy
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_4 = __pyx_v_s->sy;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_import, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1929, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_5 = __pyx_t_8;
    goto __pyx_L19_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cimport, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1929, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_8;
  __pyx_L19_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __pyx_t_5;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1930
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
 *     if s.sy not in ('import', 'cimport'):
 *         s.error("Expected 'import' or 'cimport'")             # <<<<<<<<<<<<<<
 *     kind = s.sy
 *     s.next()
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_Expected_import_or_cimport};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1930, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":1929
 *             level = 0
 *         (dotted_name_pos, _, dotted_name, _) = p_dotted_name(s, as_allowed=False)
 *     if s.sy not in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         s.error("Expected 'import' or 'cimport'")
 *     kind = s.sy
*/
  }

  /* "Cython/Compiler/Parsing.py":1931
 *     if s.sy not in ('import', 'cimport'):
 *         s.error("Expected 'import' or 'cimport'")
 *     kind = s.sy             # <<<<<<<<<<<<<<
 *     s.next()
 * 
*/
  __pyx_t_2 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_kind = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1932
 *         s.error("Expected 'import' or 'cimport'")
 *     kind = s.sy
 *     s.next()             # <<<<<<<<<<<<<<
 * 
 *     is_cimport = kind == 'cimport'
*/
  __pyx_t_11 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_11);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1934
 *     s.next()
 * 
 *     is_cimport = kind == 'cimport'             # <<<<<<<<<<<<<<
 *     is_parenthesized = False
 *     if s.sy == '*':
*/
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_cimport, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1934, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_is_cimport = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1935
 * 
 *     is_cimport = kind == 'cimport'
 *     is_parenthesized = False             # <<<<<<<<<<<<<<
 *     if s.sy == '*':
 *         imported_names = [(s.position(), s.context.intern_ustring("*"), None)]
*/
  __pyx_v_is_parenthesized = 0;

  /* "Cython/Compiler/Parsing.py":1936
 *     is_cimport = kind == 'cimport'
 *     is_parenthesized = False
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         imported_names = [(s.position(), s.context.intern_ustring("*"), None)]
 *         s.next()
*/
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1936, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1937
 *     is_parenthesized = False
 *     if s.sy == '*':
 *         imported_names = [(s.position(), s.context.intern_ustring("*"), None)]             # <<<<<<<<<<<<<<
 *         s.next()
 *     else:
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u__6};
      __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1937, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }
    __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 1937, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_11);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_11) != (0)) __PYX_ERR(0, 1937, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 2, Py_None) != (0)) __PYX_ERR(0, 1937, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_11 = 0;
    __pyx_t_11 = PyList_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_10);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_11, 0, __pyx_t_10) != (0)) __PYX_ERR(0, 1937, __pyx_L1_error);
    __pyx_t_10 = 0;
    __pyx_v_imported_names = ((PyObject*)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "Cython/Compiler/Parsing.py":1938
 *     if s.sy == '*':
 *         imported_names = [(s.position(), s.context.intern_ustring("*"), None)]
 *         s.next()             # <<<<<<<<<<<<<<
 *     else:
 *         if s.sy == '(':
*/
    __pyx_t_10 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
      __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1938, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "Cython/Compiler/Parsing.py":1936
 *     is_cimport = kind == 'cimport'
 *     is_parenthesized = False
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         imported_names = [(s.position(), s.context.intern_ustring("*"), None)]
 *         s.next()
*/
    goto __pyx_L21;
  }

  /* "Cython/Compiler/Parsing.py":1940
 *         s.next()
 *     else:
 *         if s.sy == '(':             # <<<<<<<<<<<<<<
 *             is_parenthesized = True
 *             s.next()
*/
  /*else*/ {
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1940, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1941
 *     else:
 *         if s.sy == '(':
 *             is_parenthesized = True             # <<<<<<<<<<<<<<
 *             s.next()
 *         imported_names = [p_imported_name(s)]
*/
      __pyx_v_is_parenthesized = 1;

      /* "Cython/Compiler/Parsing.py":1942
 *         if s.sy == '(':
 *             is_parenthesized = True
 *             s.next()             # <<<<<<<<<<<<<<
 *         imported_names = [p_imported_name(s)]
 *     while s.sy == ',':
*/
      __pyx_t_10 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
        __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1942, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":1940
 *         s.next()
 *     else:
 *         if s.sy == '(':             # <<<<<<<<<<<<<<
 *             is_parenthesized = True
 *             s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":1943
 *             is_parenthesized = True
 *             s.next()
 *         imported_names = [p_imported_name(s)]             # <<<<<<<<<<<<<<
 *     while s.sy == ',':
 *         s.next()
*/
    __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_imported_name(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_11);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_t_11) != (0)) __PYX_ERR(0, 1943, __pyx_L1_error);
    __pyx_t_11 = 0;
    __pyx_v_imported_names = ((PyObject*)__pyx_t_10);
    __pyx_t_10 = 0;
  }
  __pyx_L21:;

  /* "Cython/Compiler/Parsing.py":1944
 *             s.next()
 *         imported_names = [p_imported_name(s)]
 *     while s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if is_parenthesized and s.sy == ')':
*/
  while (1) {
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
    if (!__pyx_t_8) break;

    /* "Cython/Compiler/Parsing.py":1945
 *         imported_names = [p_imported_name(s)]
 *     while s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if is_parenthesized and s.sy == ')':
 *             break
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1946
 *     while s.sy == ',':
 *         s.next()
 *         if is_parenthesized and s.sy == ')':             # <<<<<<<<<<<<<<
 *             break
 *         imported_names.append(p_imported_name(s))
*/
    if (__pyx_v_is_parenthesized) {
    } else {
      __pyx_t_8 = __pyx_v_is_parenthesized;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1946, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_5;
    __pyx_L26_bool_binop_done:;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1947
 *         s.next()
 *         if is_parenthesized and s.sy == ')':
 *             break             # <<<<<<<<<<<<<<
 *         imported_names.append(p_imported_name(s))
 *     if is_parenthesized:
*/
      goto __pyx_L24_break;

      /* "Cython/Compiler/Parsing.py":1946
 *     while s.sy == ',':
 *         s.next()
 *         if is_parenthesized and s.sy == ')':             # <<<<<<<<<<<<<<
 *             break
 *         imported_names.append(p_imported_name(s))
*/
    }

    /* "Cython/Compiler/Parsing.py":1948
 *         if is_parenthesized and s.sy == ')':
 *             break
 *         imported_names.append(p_imported_name(s))             # <<<<<<<<<<<<<<
 *     if is_parenthesized:
 *         s.expect(')')
*/
    __pyx_t_10 = __pyx_f_6Cython_8Compiler_7Parsing_p_imported_name(__pyx_v_s); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_imported_names, __pyx_t_10); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 1948, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __pyx_L24_break:;

  /* "Cython/Compiler/Parsing.py":1949
 *             break
 *         imported_names.append(p_imported_name(s))
 *     if is_parenthesized:             # <<<<<<<<<<<<<<
 *         s.expect(')')
 *     if dotted_name == '__future__':
*/
  if (__pyx_v_is_parenthesized) {

    /* "Cython/Compiler/Parsing.py":1950
 *         imported_names.append(p_imported_name(s))
 *     if is_parenthesized:
 *         s.expect(')')             # <<<<<<<<<<<<<<
 *     if dotted_name == '__future__':
 *         if not first_statement:
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u__24};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1949
 *             break
 *         imported_names.append(p_imported_name(s))
 *     if is_parenthesized:             # <<<<<<<<<<<<<<
 *         s.expect(')')
 *     if dotted_name == '__future__':
*/
  }

  /* "Cython/Compiler/Parsing.py":1951
 *     if is_parenthesized:
 *         s.expect(')')
 *     if dotted_name == '__future__':             # <<<<<<<<<<<<<<
 *         if not first_statement:
 *             s.error("from __future__ imports must occur at the beginning of the file")
*/
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_dotted_name, __pyx_mstate_global->__pyx_n_u_future, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1951, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1952
 *         s.expect(')')
 *     if dotted_name == '__future__':
 *         if not first_statement:             # <<<<<<<<<<<<<<
 *             s.error("from __future__ imports must occur at the beginning of the file")
 *         elif level:
*/
    __pyx_t_8 = (!__pyx_v_first_statement);
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1953
 *     if dotted_name == '__future__':
 *         if not first_statement:
 *             s.error("from __future__ imports must occur at the beginning of the file")             # <<<<<<<<<<<<<<
 *         elif level:
 *             s.error("invalid syntax")
*/
      __pyx_t_11 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_from___future___imports_must_occ};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1953, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "Cython/Compiler/Parsing.py":1952
 *         s.expect(')')
 *     if dotted_name == '__future__':
 *         if not first_statement:             # <<<<<<<<<<<<<<
 *             s.error("from __future__ imports must occur at the beginning of the file")
 *         elif level:
*/
      goto __pyx_L30;
    }

    /* "Cython/Compiler/Parsing.py":1954
 *         if not first_statement:
 *             s.error("from __future__ imports must occur at the beginning of the file")
 *         elif level:             # <<<<<<<<<<<<<<
 *             s.error("invalid syntax")
 *         else:
*/
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_level); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1954, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":1955
 *             s.error("from __future__ imports must occur at the beginning of the file")
 *         elif level:
 *             s.error("invalid syntax")             # <<<<<<<<<<<<<<
 *         else:
 *             for (name_pos, name, as_name) in imported_names:
*/
      __pyx_t_11 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_invalid_syntax};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1955, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "Cython/Compiler/Parsing.py":1954
 *         if not first_statement:
 *             s.error("from __future__ imports must occur at the beginning of the file")
 *         elif level:             # <<<<<<<<<<<<<<
 *             s.error("invalid syntax")
 *         else:
*/
      goto __pyx_L30;
    }

    /* "Cython/Compiler/Parsing.py":1957
 *             s.error("invalid syntax")
 *         else:
 *             for (name_pos, name, as_name) in imported_names:             # <<<<<<<<<<<<<<
 *                 if name == "braces":
 *                     s.error("not a chance", name_pos)
*/
    /*else*/ {
      __pyx_t_10 = __pyx_v_imported_names; __Pyx_INCREF(__pyx_t_10);
      __pyx_t_7 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1957, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        __pyx_t_11 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_7;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1957, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
          PyObject* sequence = __pyx_t_11;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1957, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2);
            __Pyx_INCREF(__pyx_t_1);
          } else {
            __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1957, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_2);
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1957, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1957, __pyx_L1_error)
            __Pyx_XGOTREF(__pyx_t_1);
          }
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1957, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1957, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1957, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_13 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1957, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
          index = 0; __pyx_t_2 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_2)) goto __pyx_L33_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          index = 1; __pyx_t_9 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_9)) goto __pyx_L33_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 2; __pyx_t_1 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_1)) goto __pyx_L33_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 3) < (0)) __PYX_ERR(0, 1957, __pyx_L1_error)
          __pyx_t_14 = NULL;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L34_unpacking_done;
          __pyx_L33_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_14 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1957, __pyx_L1_error)
          __pyx_L34_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_name_pos, __pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_v_as_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":1958
 *         else:
 *             for (name_pos, name, as_name) in imported_names:
 *                 if name == "braces":             # <<<<<<<<<<<<<<
 *                     s.error("not a chance", name_pos)
 *                     break
*/
        __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_braces, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1958, __pyx_L1_error)
        if (__pyx_t_8) {

          /* "Cython/Compiler/Parsing.py":1959
 *             for (name_pos, name, as_name) in imported_names:
 *                 if name == "braces":
 *                     s.error("not a chance", name_pos)             # <<<<<<<<<<<<<<
 *                     break
 *                 try:
*/
          __pyx_t_1 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_not_a_chance, __pyx_v_name_pos};
            __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1959, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":1960
 *                 if name == "braces":
 *                     s.error("not a chance", name_pos)
 *                     break             # <<<<<<<<<<<<<<
 *                 try:
 *                     directive = getattr(Future, name)
*/
          goto __pyx_L32_break;

          /* "Cython/Compiler/Parsing.py":1958
 *         else:
 *             for (name_pos, name, as_name) in imported_names:
 *                 if name == "braces":             # <<<<<<<<<<<<<<
 *                     s.error("not a chance", name_pos)
 *                     break
*/
        }

        /* "Cython/Compiler/Parsing.py":1961
 *                     s.error("not a chance", name_pos)
 *                     break
 *                 try:             # <<<<<<<<<<<<<<
 *                     directive = getattr(Future, name)
 *                 except AttributeError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          /*try:*/ {

            /* "Cython/Compiler/Parsing.py":1962
 *                     break
 *                 try:
 *                     directive = getattr(Future, name)             # <<<<<<<<<<<<<<
 *                 except AttributeError:
 *                     s.error("future feature %s is not defined" % name, name_pos)
*/
            __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_Future;
            __Pyx_INCREF(__pyx_t_11);
            __pyx_t_1 = __Pyx_GetAttr(__pyx_t_11, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1962, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF_SET(__pyx_v_directive, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "Cython/Compiler/Parsing.py":1961
 *                     s.error("not a chance", name_pos)
 *                     break
 *                 try:             # <<<<<<<<<<<<<<
 *                     directive = getattr(Future, name)
 *                 except AttributeError:
*/
          }
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          goto __pyx_L43_try_end;
          __pyx_L36_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "Cython/Compiler/Parsing.py":1963
 *                 try:
 *                     directive = getattr(Future, name)
 *                 except AttributeError:             # <<<<<<<<<<<<<<
 *                     s.error("future feature %s is not defined" % name, name_pos)
 *                     break
*/
          __pyx_t_18 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
          if (__pyx_t_18) {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_from_import_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_11, &__pyx_t_9) < 0) __PYX_ERR(0, 1963, __pyx_L38_except_error)
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_9);

            /* "Cython/Compiler/Parsing.py":1964
 *                     directive = getattr(Future, name)
 *                 except AttributeError:
 *                     s.error("future feature %s is not defined" % name, name_pos)             # <<<<<<<<<<<<<<
 *                     break
 *                 s.context.future_directives.add(directive)
*/
            __pyx_t_13 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_19 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_future_feature_s_is_not_defined, __pyx_v_name); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1964, __pyx_L38_except_error)
            __Pyx_GOTREF(__pyx_t_19);
            __pyx_t_3 = 0;
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_19, __pyx_v_name_pos};
              __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1964, __pyx_L38_except_error)
              __Pyx_GOTREF(__pyx_t_2);
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "Cython/Compiler/Parsing.py":1965
 *                 except AttributeError:
 *                     s.error("future feature %s is not defined" % name, name_pos)
 *                     break             # <<<<<<<<<<<<<<
 *                 s.context.future_directives.add(directive)
 *         return Nodes.PassStatNode(pos)
*/
            goto __pyx_L45_except_break;
            __pyx_L45_except_break:;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            goto __pyx_L41_try_break;
          }
          goto __pyx_L38_except_error;

          /* "Cython/Compiler/Parsing.py":1961
 *                     s.error("not a chance", name_pos)
 *                     break
 *                 try:             # <<<<<<<<<<<<<<
 *                     directive = getattr(Future, name)
 *                 except AttributeError:
*/
          __pyx_L38_except_error:;
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          goto __pyx_L1_error;
          __pyx_L41_try_break:;
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          goto __pyx_L32_break;
          __pyx_L43_try_end:;
        }

        /* "Cython/Compiler/Parsing.py":1966
 *                     s.error("future feature %s is not defined" % name, name_pos)
 *                     break
 *                 s.context.future_directives.add(directive)             # <<<<<<<<<<<<<<
 *         return Nodes.PassStatNode(pos)
 *     elif is_cimport:
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_11 = __pyx_t_1;
        __Pyx_INCREF(__pyx_t_11);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_directive};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1966, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "Cython/Compiler/Parsing.py":1957
 *             s.error("invalid syntax")
 *         else:
 *             for (name_pos, name, as_name) in imported_names:             # <<<<<<<<<<<<<<
 *                 if name == "braces":
 *                     s.error("not a chance", name_pos)
*/
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L46_for_end;
      __pyx_L32_break:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L46_for_end;
      __pyx_L46_for_end:;
    }
    __pyx_L30:;

    /* "Cython/Compiler/Parsing.py":1967
 *                     break
 *                 s.context.future_directives.add(directive)
 *         return Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 *     elif is_cimport:
 *         return Nodes.FromCImportStatNode(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1967, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1951
 *     if is_parenthesized:
 *         s.expect(')')
 *     if dotted_name == '__future__':             # <<<<<<<<<<<<<<
 *         if not first_statement:
 *             s.error("from __future__ imports must occur at the beginning of the file")
*/
  }

  /* "Cython/Compiler/Parsing.py":1968
 *                 s.context.future_directives.add(directive)
 *         return Nodes.PassStatNode(pos)
 *     elif is_cimport:             # <<<<<<<<<<<<<<
 *         return Nodes.FromCImportStatNode(
 *             pos, module_name=dotted_name,
*/
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_cimport); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1968, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":1969
 *         return Nodes.PassStatNode(pos)
 *     elif is_cimport:
 *         return Nodes.FromCImportStatNode(             # <<<<<<<<<<<<<<
 *             pos, module_name=dotted_name,
 *             relative_level=level,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);

    /* "Cython/Compiler/Parsing.py":1972
 *             pos, module_name=dotted_name,
 *             relative_level=level,
 *             imported_names=imported_names)             # <<<<<<<<<<<<<<
 *     else:
 *         imported_name_strings = []
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1969, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_name, __pyx_v_dotted_name, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1969, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_relative_level, __pyx_v_level, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1969, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_imported_names, __pyx_v_imported_names, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1969, __pyx_L1_error)
      __pyx_t_10 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FromCImportStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1969, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":1968
 *                 s.context.future_directives.add(directive)
 *         return Nodes.PassStatNode(pos)
 *     elif is_cimport:             # <<<<<<<<<<<<<<
 *         return Nodes.FromCImportStatNode(
 *             pos, module_name=dotted_name,
*/
  }

  /* "Cython/Compiler/Parsing.py":1974
 *             imported_names=imported_names)
 *     else:
 *         imported_name_strings = []             # <<<<<<<<<<<<<<
 *         items = []
 *         for (name_pos, name, as_name) in imported_names:
*/
  /*else*/ {
    __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_v_imported_name_strings = ((PyObject*)__pyx_t_10);
    __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1975
 *     else:
 *         imported_name_strings = []
 *         items = []             # <<<<<<<<<<<<<<
 *         for (name_pos, name, as_name) in imported_names:
 *             imported_name_strings.append(
*/
    __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_v_items = ((PyObject*)__pyx_t_10);
    __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1976
 *         imported_name_strings = []
 *         items = []
 *         for (name_pos, name, as_name) in imported_names:             # <<<<<<<<<<<<<<
 *             imported_name_strings.append(
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))
*/
    __pyx_t_10 = __pyx_v_imported_names; __Pyx_INCREF(__pyx_t_10);
    __pyx_t_7 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1976, __pyx_L1_error)
        #endif
        if (__pyx_t_7 >= __pyx_temp) break;
      }
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_7;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1976, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1976, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_11);
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 2);
          __Pyx_INCREF(__pyx_t_2);
        } else {
          __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1976, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_9);
          __pyx_t_11 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1976, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_11);
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1976, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
        }
        #else
        __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_11 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_19 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_19);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_19);
        index = 0; __pyx_t_9 = __pyx_t_14(__pyx_t_19); if (unlikely(!__pyx_t_9)) goto __pyx_L49_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_9);
        index = 1; __pyx_t_11 = __pyx_t_14(__pyx_t_19); if (unlikely(!__pyx_t_11)) goto __pyx_L49_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        index = 2; __pyx_t_2 = __pyx_t_14(__pyx_t_19); if (unlikely(!__pyx_t_2)) goto __pyx_L49_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_19), 3) < (0)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __pyx_t_14 = NULL;
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        goto __pyx_L50_unpacking_done;
        __pyx_L49_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __pyx_t_14 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1976, __pyx_L1_error)
        __pyx_L50_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_name_pos, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_as_name, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":1978
 *         for (name_pos, name, as_name) in imported_names:
 *             imported_name_strings.append(
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))             # <<<<<<<<<<<<<<
 *             items.append(
 *                 (name, ExprNodes.NameNode(name_pos, name=as_name or name)))
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_name_pos};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_name, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IdentifierStringNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":1977
 *         items = []
 *         for (name_pos, name, as_name) in imported_names:
 *             imported_name_strings.append(             # <<<<<<<<<<<<<<
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))
 *             items.append(
*/
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_imported_name_strings, __pyx_t_1); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 1977, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1980
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))
 *             items.append(
 *                 (name, ExprNodes.NameNode(name_pos, name=as_name or name)))             # <<<<<<<<<<<<<<
 *         return Nodes.FromImportStatNode(pos,
 *             module = ExprNodes.ImportNode(dotted_name_pos,
*/
      __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_as_name); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1980, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __Pyx_INCREF(__pyx_v_as_name);
        __pyx_t_2 = __pyx_v_as_name;
        goto __pyx_L51_bool_binop_done;
      }
      __Pyx_INCREF(__pyx_v_name);
      __pyx_t_2 = __pyx_v_name;
      __pyx_L51_bool_binop_done:;
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_v_name_pos};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_2, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1980, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NameNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_name);
      __Pyx_GIVEREF(__pyx_v_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_name) != (0)) __PYX_ERR(0, 1980, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 1980, __pyx_L1_error);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":1979
 *             imported_name_strings.append(
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))
 *             items.append(             # <<<<<<<<<<<<<<
 *                 (name, ExprNodes.NameNode(name_pos, name=as_name or name)))
 *         return Nodes.FromImportStatNode(pos,
*/
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_9); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 1979, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "Cython/Compiler/Parsing.py":1976
 *         imported_name_strings = []
 *         items = []
 *         for (name_pos, name, as_name) in imported_names:             # <<<<<<<<<<<<<<
 *             imported_name_strings.append(
 *                 ExprNodes.IdentifierStringNode(name_pos, value=name))
*/
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "Cython/Compiler/Parsing.py":1981
 *             items.append(
 *                 (name, ExprNodes.NameNode(name_pos, name=as_name or name)))
 *         return Nodes.FromImportStatNode(pos,             # <<<<<<<<<<<<<<
 *             module = ExprNodes.ImportNode(dotted_name_pos,
 *                 module_name = ExprNodes.IdentifierStringNode(pos, value = dotted_name),
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);

    /* "Cython/Compiler/Parsing.py":1982
 *                 (name, ExprNodes.NameNode(name_pos, name=as_name or name)))
 *         return Nodes.FromImportStatNode(pos,
 *             module = ExprNodes.ImportNode(dotted_name_pos,             # <<<<<<<<<<<<<<
 *                 module_name = ExprNodes.IdentifierStringNode(pos, value = dotted_name),
 *                 is_import_as_name = False,
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":1983
 *         return Nodes.FromImportStatNode(pos,
 *             module = ExprNodes.ImportNode(dotted_name_pos,
 *                 module_name = ExprNodes.IdentifierStringNode(pos, value = dotted_name),             # <<<<<<<<<<<<<<
 *                 is_import_as_name = False,
 *                 level = level,
*/
    __pyx_t_19 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_19);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_19, __pyx_v_pos};
      __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1983, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_dotted_name, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1983, __pyx_L1_error)
      __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IdentifierStringNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1983, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }

    /* "Cython/Compiler/Parsing.py":1986
 *                 is_import_as_name = False,
 *                 level = level,
 *                 imported_names = imported_name_strings),             # <<<<<<<<<<<<<<
 *             items = items)
 * 
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_2, __pyx_v_dotted_name_pos};
      __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_name, __pyx_t_11, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1982, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_import_as_name, Py_False, __pyx_t_13, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1982, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_v_level, __pyx_t_13, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 1982, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_imported_names, __pyx_v_imported_name_strings, __pyx_t_13, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImportNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "Cython/Compiler/Parsing.py":1987
 *                 level = level,
 *                 imported_names = imported_name_strings),
 *             items = items)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module, __pyx_t_1, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1981, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_items, __pyx_v_items, __pyx_t_13, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1981, __pyx_L1_error)
      __pyx_t_10 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FromImportStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":1909
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_from_import_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     # s.sy == 'from'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_from_import_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_level);
  __Pyx_XDECREF(__pyx_v_dotted_name_pos);
  __Pyx_XDECREF(__pyx_v_dotted_name);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_is_cimport);
  __Pyx_XDECREF(__pyx_v_imported_names);
  __Pyx_XDECREF(__pyx_v_name_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_as_name);
  __Pyx_XDECREF(__pyx_v_directive);
  __Pyx_XDECREF(__pyx_v_imported_name_strings);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1990
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_imported_name(s: PyrexScanner) -> tuple:
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_imported_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_as_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_imported_name", 0);

  /* "Cython/Compiler/Parsing.py":1992
 * @cython.cfunc
 * def p_imported_name(s: PyrexScanner) -> tuple:
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     as_name = p_as_name(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1993
 * def p_imported_name(s: PyrexScanner) -> tuple:
 *     pos = s.position()
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     as_name = p_as_name(s)
 *     return (pos, name, as_name)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1994
 *     pos = s.position()
 *     name = p_ident(s)
 *     as_name = p_as_name(s)             # <<<<<<<<<<<<<<
 *     return (pos, name, as_name)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_as_name(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_as_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":1995
 *     name = p_ident(s)
 *     as_name = p_as_name(s)
 *     return (pos, name, as_name)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 1995, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_name) != (0)) __PYX_ERR(0, 1995, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_as_name);
  __Pyx_GIVEREF(__pyx_v_as_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_as_name) != (0)) __PYX_ERR(0, 1995, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1990
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_imported_name(s: PyrexScanner) -> tuple:
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_imported_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_as_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":1998
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_dotted_name(s: PyrexScanner, as_allowed: cython.bint) -> tuple:
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_dotted_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_as_allowed) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_target_name = NULL;
  PyObject *__pyx_v_as_name = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_dotted_name", 0);

  /* "Cython/Compiler/Parsing.py":2000
 * @cython.cfunc
 * def p_dotted_name(s: PyrexScanner, as_allowed: cython.bint) -> tuple:
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     target_name = p_ident(s)
 *     as_name = None
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2001
 * def p_dotted_name(s: PyrexScanner, as_allowed: cython.bint) -> tuple:
 *     pos = s.position()
 *     target_name = p_ident(s)             # <<<<<<<<<<<<<<
 *     as_name = None
 *     names = [target_name]
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_target_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2002
 *     pos = s.position()
 *     target_name = p_ident(s)
 *     as_name = None             # <<<<<<<<<<<<<<
 *     names = [target_name]
 *     while s.sy == '.':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_as_name = Py_None;

  /* "Cython/Compiler/Parsing.py":2003
 *     target_name = p_ident(s)
 *     as_name = None
 *     names = [target_name]             # <<<<<<<<<<<<<<
 *     while s.sy == '.':
 *         s.next()
*/
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_target_name);
  __Pyx_GIVEREF(__pyx_v_target_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_target_name) != (0)) __PYX_ERR(0, 2003, __pyx_L1_error);
  __pyx_v_names = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2004
 *     as_name = None
 *     names = [target_name]
 *     while s.sy == '.':             # <<<<<<<<<<<<<<
 *         s.next()
 *         names.append(p_ident(s))
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2004, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":2005
 *     names = [target_name]
 *     while s.sy == '.':
 *         s.next()             # <<<<<<<<<<<<<<
 *         names.append(p_ident(s))
 *     if as_allowed:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2006
 *     while s.sy == '.':
 *         s.next()
 *         names.append(p_ident(s))             # <<<<<<<<<<<<<<
 *     if as_allowed:
 *         as_name = p_as_name(s)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_names, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2006, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2007
 *         s.next()
 *         names.append(p_ident(s))
 *     if as_allowed:             # <<<<<<<<<<<<<<
 *         as_name = p_as_name(s)
 *     return (pos, target_name, s.context.intern_ustring('.'.join(names)), as_name)
*/
  if (__pyx_v_as_allowed) {

    /* "Cython/Compiler/Parsing.py":2008
 *         names.append(p_ident(s))
 *     if as_allowed:
 *         as_name = p_as_name(s)             # <<<<<<<<<<<<<<
 *     return (pos, target_name, s.context.intern_ustring('.'.join(names)), as_name)
 * 
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_as_name(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_as_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2007
 *         s.next()
 *         names.append(p_ident(s))
 *     if as_allowed:             # <<<<<<<<<<<<<<
 *         as_name = p_as_name(s)
 *     return (pos, target_name, s.context.intern_ustring('.'.join(names)), as_name)
*/
  }

  /* "Cython/Compiler/Parsing.py":2009
 *     if as_allowed:
 *         as_name = p_as_name(s)
 *     return (pos, target_name, s.context.intern_ustring('.'.join(names)), as_name)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_s->context;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_6 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__27, __pyx_v_names); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_pos);
  __Pyx_GIVEREF(__pyx_v_pos);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_pos) != (0)) __PYX_ERR(0, 2009, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_target_name);
  __Pyx_GIVEREF(__pyx_v_target_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_target_name) != (0)) __PYX_ERR(0, 2009, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 2009, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_as_name);
  __Pyx_GIVEREF(__pyx_v_as_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_v_as_name) != (0)) __PYX_ERR(0, 2009, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":1998
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_dotted_name(s: PyrexScanner, as_allowed: cython.bint) -> tuple:
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_dotted_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_target_name);
  __Pyx_XDECREF(__pyx_v_as_name);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2012
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_as_name(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'as':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_as_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_as_name", 0);

  /* "Cython/Compiler/Parsing.py":2014
 * @cython.cfunc
 * def p_as_name(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_ident(s)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2014, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2014, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2015
 * def p_as_name(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return p_ident(s)
 *     else:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2016
 *     if s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()
 *         return p_ident(s)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2014
 * @cython.cfunc
 * def p_as_name(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_ident(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":2018
 *         return p_ident(s)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2012
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_as_name(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'as':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_as_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2021
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_assert_statement(s: PyrexScanner):
 *     # s.sy == 'assert'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_assert_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_cond = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_assert_statement", 0);

  /* "Cython/Compiler/Parsing.py":2024
 * def p_assert_statement(s: PyrexScanner):
 *     # s.sy == 'assert'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     cond = p_test(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2025
 *     # s.sy == 'assert'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     cond = p_test(s)
 *     if s.sy == ',':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2026
 *     pos = s.position()
 *     s.next()
 *     cond = p_test(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cond = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2027
 *     s.next()
 *     cond = p_test(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         value = p_test(s)
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2027, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2028
 *     cond = p_test(s)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         value = p_test(s)
 *     else:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2028, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2029
 *     if s.sy == ',':
 *         s.next()
 *         value = p_test(s)             # <<<<<<<<<<<<<<
 *     else:
 *         value = None
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2027
 *     s.next()
 *     cond = p_test(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         value = p_test(s)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2031
 *         value = p_test(s)
 *     else:
 *         value = None             # <<<<<<<<<<<<<<
 *     return Nodes.AssertStatNode(pos, condition=cond, value=value)
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_value = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2032
 *     else:
 *         value = None
 *     return Nodes.AssertStatNode(pos, condition=cond, value=value)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2032, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_condition, __pyx_v_cond, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2032, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2032, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AssertStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2032, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2021
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_assert_statement(s: PyrexScanner):
 *     # s.sy == 'assert'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_assert_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_cond);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2035
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_if_statement(s: PyrexScanner):
 *     # s.sy == 'if'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_if_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_if_clauses = NULL;
  PyObject *__pyx_v_else_clause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_if_statement", 0);

  /* "Cython/Compiler/Parsing.py":2038
 * def p_if_statement(s: PyrexScanner):
 *     # s.sy == 'if'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     if_clauses = [p_if_clause(s)]
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2039
 *     # s.sy == 'if'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     if_clauses = [p_if_clause(s)]
 *     while s.sy == 'elif':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2040
 *     pos = s.position()
 *     s.next()
 *     if_clauses = [p_if_clause(s)]             # <<<<<<<<<<<<<<
 *     while s.sy == 'elif':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_if_clause(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 2040, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_if_clauses = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2041
 *     s.next()
 *     if_clauses = [p_if_clause(s)]
 *     while s.sy == 'elif':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if_clauses.append(p_if_clause(s))
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_elif, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2041, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":2042
 *     if_clauses = [p_if_clause(s)]
 *     while s.sy == 'elif':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if_clauses.append(p_if_clause(s))
 *     else_clause = p_else_clause(s)
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2042, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2043
 *     while s.sy == 'elif':
 *         s.next()
 *         if_clauses.append(p_if_clause(s))             # <<<<<<<<<<<<<<
 *     else_clause = p_else_clause(s)
 *     return Nodes.IfStatNode(pos,
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_if_clause(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_if_clauses, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2043, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2044
 *         s.next()
 *         if_clauses.append(p_if_clause(s))
 *     else_clause = p_else_clause(s)             # <<<<<<<<<<<<<<
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = if_clauses, else_clause = else_clause)
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_else_clause(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_else_clause = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2045
 *         if_clauses.append(p_if_clause(s))
 *     else_clause = p_else_clause(s)
 *     return Nodes.IfStatNode(pos,             # <<<<<<<<<<<<<<
 *         if_clauses = if_clauses, else_clause = else_clause)
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_1);

  /* "Cython/Compiler/Parsing.py":2046
 *     else_clause = p_else_clause(s)
 *     return Nodes.IfStatNode(pos,
 *         if_clauses = if_clauses, else_clause = else_clause)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_if_clauses, __pyx_v_if_clauses, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2045, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, __pyx_v_else_clause, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2045, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IfStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2035
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_if_statement(s: PyrexScanner):
 *     # s.sy == 'if'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_if_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_if_clauses);
  __Pyx_XDECREF(__pyx_v_else_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2049
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_if_clause(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_if_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_test = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_if_clause", 0);

  /* "Cython/Compiler/Parsing.py":2051
 * @cython.cfunc
 * def p_if_clause(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2052
 * def p_if_clause(s: PyrexScanner):
 *     pos = s.position()
 *     test = p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     return Nodes.IfClauseNode(pos,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_test = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2053
 *     pos = s.position()
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     return Nodes.IfClauseNode(pos,
 *         condition = test, body = body)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2054
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)
 *     return Nodes.IfClauseNode(pos,             # <<<<<<<<<<<<<<
 *         condition = test, body = body)
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":2055
 *     body = p_suite(s)
 *     return Nodes.IfClauseNode(pos,
 *         condition = test, body = body)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_condition, __pyx_v_test, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2054, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2054, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IfClauseNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2049
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_if_clause(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_if_clause", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_test);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2058
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_else_clause(s: PyrexScanner):
 *     if s.sy == 'else':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_else_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_else_clause", 0);

  /* "Cython/Compiler/Parsing.py":2060
 * @cython.cfunc
 * def p_else_clause(s: PyrexScanner):
 *     if s.sy == 'else':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_suite(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2060, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2061
 * def p_else_clause(s: PyrexScanner):
 *     if s.sy == 'else':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return p_suite(s)
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2061, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2062
 *     if s.sy == 'else':
 *         s.next()
 *         return p_suite(s)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2060
 * @cython.cfunc
 * def p_else_clause(s: PyrexScanner):
 *     if s.sy == 'else':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_suite(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":2064
 *         return p_suite(s)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2058
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_else_clause(s: PyrexScanner):
 *     if s.sy == 'else':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_else_clause", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2067
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_while_statement(s: PyrexScanner):
 *     # s.sy == 'while'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_while_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_test = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_else_clause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_while_statement", 0);

  /* "Cython/Compiler/Parsing.py":2070
 * def p_while_statement(s: PyrexScanner):
 *     # s.sy == 'while'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     test = p_namedexpr_test(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2071
 *     # s.sy == 'while'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2071, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2072
 *     pos = s.position()
 *     s.next()
 *     test = p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_test = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2073
 *     s.next()
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     else_clause = p_else_clause(s)
 *     return Nodes.WhileStatNode(pos,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2074
 *     test = p_namedexpr_test(s)
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)             # <<<<<<<<<<<<<<
 *     return Nodes.WhileStatNode(pos,
 *         condition = test, body = body,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_else_clause(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_else_clause = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2075
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)
 *     return Nodes.WhileStatNode(pos,             # <<<<<<<<<<<<<<
 *         condition = test, body = body,
 *         else_clause = else_clause)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":2077
 *     return Nodes.WhileStatNode(pos,
 *         condition = test, body = body,
 *         else_clause = else_clause)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_condition, __pyx_v_test, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2075, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2075, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, __pyx_v_else_clause, __pyx_t_4, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2075, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_WhileStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2067
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_while_statement(s: PyrexScanner):
 *     # s.sy == 'while'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_while_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_test);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_else_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2080
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_statement(s: PyrexScanner, is_async: cython.bint = False):
 *     # s.sy == 'for'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_statement *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2081
 * 
 * @cython.cfunc
 * def p_for_statement(s: PyrexScanner, is_async: cython.bint = False):             # <<<<<<<<<<<<<<
 *     # s.sy == 'for'
 *     pos = s.position()
*/
  int __pyx_v_is_async = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kw = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_else_clause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_is_async = __pyx_optional_args->is_async;
    }
  }

  /* "Cython/Compiler/Parsing.py":2083
 * def p_for_statement(s: PyrexScanner, is_async: cython.bint = False):
 *     # s.sy == 'for'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     kw = p_for_bounds(s, allow_testlist=True, is_async=is_async)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2084
 *     # s.sy == 'for'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     kw = p_for_bounds(s, allow_testlist=True, is_async=is_async)
 *     body = p_suite(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2085
 *     pos = s.position()
 *     s.next()
 *     kw = p_for_bounds(s, allow_testlist=True, is_async=is_async)             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)
*/
  __pyx_t_4.__pyx_n = 2;
  __pyx_t_4.allow_testlist = 1;
  __pyx_t_4.is_async = __pyx_v_is_async;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_bounds(__pyx_v_s, &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_kw = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2086
 *     s.next()
 *     kw = p_for_bounds(s, allow_testlist=True, is_async=is_async)
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     else_clause = p_else_clause(s)
 *     kw.update(body=body, else_clause=else_clause, is_async=is_async)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2087
 *     kw = p_for_bounds(s, allow_testlist=True, is_async=is_async)
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)             # <<<<<<<<<<<<<<
 *     kw.update(body=body, else_clause=else_clause, is_async=is_async)
 *     return Nodes.ForStatNode(pos, **kw)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_else_clause(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_else_clause = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2088
 *     body = p_suite(s)
 *     else_clause = p_else_clause(s)
 *     kw.update(body=body, else_clause=else_clause, is_async=is_async)             # <<<<<<<<<<<<<<
 *     return Nodes.ForStatNode(pos, **kw)
 * 
*/
  __pyx_t_2 = __pyx_v_kw;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_is_async); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 2088, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, __pyx_v_else_clause, __pyx_t_6, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 2088, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_async, __pyx_t_5, __pyx_t_6, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_update, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2089
 *     else_clause = p_else_clause(s)
 *     kw.update(body=body, else_clause=else_clause, is_async=is_async)
 *     return Nodes.ForStatNode(pos, **kw)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = NULL;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_ForStatNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__pyx_v_kw == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 2089, __pyx_L1_error)
  }
  __pyx_t_2 = PyDict_Copy(__pyx_v_kw); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallDict((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2080
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_statement(s: PyrexScanner, is_async: cython.bint = False):
 *     # s.sy == 'for'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_else_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2092
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_bounds(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_bounds *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2093
 * 
 * @cython.cfunc
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:             # <<<<<<<<<<<<<<
 *     target = p_for_target(s)
 *     if s.sy == 'in':
*/
  int __pyx_v_allow_testlist = ((int)1);
  int __pyx_v_is_async = ((int)0);
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_iterator = NULL;
  PyObject *__pyx_v_bound1 = NULL;
  PyObject *__pyx_v_rel1 = NULL;
  PyObject *__pyx_v_name2_pos = NULL;
  PyObject *__pyx_v_name2 = NULL;
  PyObject *__pyx_v_rel2_pos = NULL;
  PyObject *__pyx_v_rel2 = NULL;
  PyObject *__pyx_v_bound2 = NULL;
  PyObject *__pyx_v_step = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_iterator __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_bounds", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_allow_testlist = __pyx_optional_args->allow_testlist;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_is_async = __pyx_optional_args->is_async;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":2094
 * @cython.cfunc
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)             # <<<<<<<<<<<<<<
 *     if s.sy == 'in':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_target(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_target = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2095
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)
 *     if s.sy == 'in':             # <<<<<<<<<<<<<<
 *         s.next()
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_in, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2095, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2096
 *     target = p_for_target(s)
 *     if s.sy == 'in':
 *         s.next()             # <<<<<<<<<<<<<<
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
 *         return dict(target=target, iterator=iterator)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2096, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2097
 *     if s.sy == 'in':
 *         s.next()
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)             # <<<<<<<<<<<<<<
 *         return dict(target=target, iterator=iterator)
 *     elif not s.in_python_file and not is_async:
*/
    __pyx_t_5.__pyx_n = 2;
    __pyx_t_5.allow_testlist = __pyx_v_allow_testlist;
    __pyx_t_5.is_async = __pyx_v_is_async;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_iterator(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_iterator = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2098
 *         s.next()
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
 *         return dict(target=target, iterator=iterator)             # <<<<<<<<<<<<<<
 *     elif not s.in_python_file and not is_async:
 *         if s.sy == 'from':
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_target, __pyx_v_target) < (0)) __PYX_ERR(0, 2098, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_iterator, __pyx_v_iterator) < (0)) __PYX_ERR(0, 2098, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2095
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)
 *     if s.sy == 'in':             # <<<<<<<<<<<<<<
 *         s.next()
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
*/
  }

  /* "Cython/Compiler/Parsing.py":2099
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
 *         return dict(target=target, iterator=iterator)
 *     elif not s.in_python_file and not is_async:             # <<<<<<<<<<<<<<
 *         if s.sy == 'from':
 *             s.next()
*/
  __pyx_t_6 = (!__pyx_v_s->in_python_file);
  if (__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (!__pyx_v_is_async);
  __pyx_t_2 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2100
 *         return dict(target=target, iterator=iterator)
 *     elif not s.in_python_file and not is_async:
 *         if s.sy == 'from':             # <<<<<<<<<<<<<<
 *             s.next()
 *             bound1 = p_bit_expr(s)
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_from, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2100, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2101
 *     elif not s.in_python_file and not is_async:
 *         if s.sy == 'from':
 *             s.next()             # <<<<<<<<<<<<<<
 *             bound1 = p_bit_expr(s)
 *         else:
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2101, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2102
 *         if s.sy == 'from':
 *             s.next()
 *             bound1 = p_bit_expr(s)             # <<<<<<<<<<<<<<
 *         else:
 *             # Support shorter "for a <= x < b" syntax
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_bound1 = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2100
 *         return dict(target=target, iterator=iterator)
 *     elif not s.in_python_file and not is_async:
 *         if s.sy == 'from':             # <<<<<<<<<<<<<<
 *             s.next()
 *             bound1 = p_bit_expr(s)
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":2105
 *         else:
 *             # Support shorter "for a <= x < b" syntax
 *             bound1, target = target, None             # <<<<<<<<<<<<<<
 *         rel1 = p_for_from_relation(s)
 *         name2_pos = s.position()
*/
    /*else*/ {
      __pyx_t_1 = __pyx_v_target;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = Py_None;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_bound1 = __pyx_t_1;
      __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L6:;

    /* "Cython/Compiler/Parsing.py":2106
 *             # Support shorter "for a <= x < b" syntax
 *             bound1, target = target, None
 *         rel1 = p_for_from_relation(s)             # <<<<<<<<<<<<<<
 *         name2_pos = s.position()
 *         name2 = p_ident(s)
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_from_relation(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_rel1 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2107
 *             bound1, target = target, None
 *         rel1 = p_for_from_relation(s)
 *         name2_pos = s.position()             # <<<<<<<<<<<<<<
 *         name2 = p_ident(s)
 *         rel2_pos = s.position()
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_name2_pos = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2108
 *         rel1 = p_for_from_relation(s)
 *         name2_pos = s.position()
 *         name2 = p_ident(s)             # <<<<<<<<<<<<<<
 *         rel2_pos = s.position()
 *         rel2 = p_for_from_relation(s)
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_name2 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2109
 *         name2_pos = s.position()
 *         name2 = p_ident(s)
 *         rel2_pos = s.position()             # <<<<<<<<<<<<<<
 *         rel2 = p_for_from_relation(s)
 *         bound2 = p_bit_expr(s)
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_rel2_pos = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2110
 *         name2 = p_ident(s)
 *         rel2_pos = s.position()
 *         rel2 = p_for_from_relation(s)             # <<<<<<<<<<<<<<
 *         bound2 = p_bit_expr(s)
 *         step = p_for_from_step(s)
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_from_relation(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_rel2 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2111
 *         rel2_pos = s.position()
 *         rel2 = p_for_from_relation(s)
 *         bound2 = p_bit_expr(s)             # <<<<<<<<<<<<<<
 *         step = p_for_from_step(s)
 *         if target is None:
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_bound2 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2112
 *         rel2 = p_for_from_relation(s)
 *         bound2 = p_bit_expr(s)
 *         step = p_for_from_step(s)             # <<<<<<<<<<<<<<
 *         if target is None:
 *             target = ExprNodes.NameNode(name2_pos, name = name2)
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_from_step(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_step = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2113
 *         bound2 = p_bit_expr(s)
 *         step = p_for_from_step(s)
 *         if target is None:             # <<<<<<<<<<<<<<
 *             target = ExprNodes.NameNode(name2_pos, name = name2)
 *         else:
*/
    __pyx_t_2 = (__pyx_v_target == Py_None);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2114
 *         step = p_for_from_step(s)
 *         if target is None:
 *             target = ExprNodes.NameNode(name2_pos, name = name2)             # <<<<<<<<<<<<<<
 *         else:
 *             if not target.is_name:
*/
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_name2_pos};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name2, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2114, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NameNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2113
 *         bound2 = p_bit_expr(s)
 *         step = p_for_from_step(s)
 *         if target is None:             # <<<<<<<<<<<<<<
 *             target = ExprNodes.NameNode(name2_pos, name = name2)
 *         else:
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Parsing.py":2116
 *             target = ExprNodes.NameNode(name2_pos, name = name2)
 *         else:
 *             if not target.is_name:             # <<<<<<<<<<<<<<
 *                 error(target.pos,
 *                     "Target of for-from statement must be a variable name")
*/
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2116, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = (!__pyx_t_2);
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":2117
 *         else:
 *             if not target.is_name:
 *                 error(target.pos,             # <<<<<<<<<<<<<<
 *                     "Target of for-from statement must be a variable name")
 *             elif name2 != target.name:
*/
        __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2117, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_8, __pyx_mstate_global->__pyx_kp_u_Target_of_for_from_statement_mus};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":2116
 *             target = ExprNodes.NameNode(name2_pos, name = name2)
 *         else:
 *             if not target.is_name:             # <<<<<<<<<<<<<<
 *                 error(target.pos,
 *                     "Target of for-from statement must be a variable name")
*/
        goto __pyx_L8;
      }

      /* "Cython/Compiler/Parsing.py":2119
 *                 error(target.pos,
 *                     "Target of for-from statement must be a variable name")
 *             elif name2 != target.name:             # <<<<<<<<<<<<<<
 *                 error(name2_pos,
 *                     "Variable name in for-from range does not match target")
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_target, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_name2, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2119, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2119, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":2120
 *                     "Target of for-from statement must be a variable name")
 *             elif name2 != target.name:
 *                 error(name2_pos,             # <<<<<<<<<<<<<<
 *                     "Variable name in for-from range does not match target")
 *         if rel1[0] != rel2[0]:
*/
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_name2_pos, __pyx_mstate_global->__pyx_kp_u_Variable_name_in_for_from_range};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2120, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2119
 *                 error(target.pos,
 *                     "Target of for-from statement must be a variable name")
 *             elif name2 != target.name:             # <<<<<<<<<<<<<<
 *                 error(name2_pos,
 *                     "Variable name in for-from range does not match target")
*/
      }
      __pyx_L8:;
    }
    __pyx_L7:;

    /* "Cython/Compiler/Parsing.py":2122
 *                 error(name2_pos,
 *                     "Variable name in for-from range does not match target")
 *         if rel1[0] != rel2[0]:             # <<<<<<<<<<<<<<
 *             error(rel2_pos,
 *                 "Relation directions in for-from do not match")
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_rel1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_rel2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_8, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2122, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2122, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":2123
 *                     "Variable name in for-from range does not match target")
 *         if rel1[0] != rel2[0]:
 *             error(rel2_pos,             # <<<<<<<<<<<<<<
 *                 "Relation directions in for-from do not match")
 *         return dict(target = target,
*/
      __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_rel2_pos, __pyx_mstate_global->__pyx_kp_u_Relation_directions_in_for_from};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2123, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2122
 *                 error(name2_pos,
 *                     "Variable name in for-from range does not match target")
 *         if rel1[0] != rel2[0]:             # <<<<<<<<<<<<<<
 *             error(rel2_pos,
 *                 "Relation directions in for-from do not match")
*/
    }

    /* "Cython/Compiler/Parsing.py":2125
 *             error(rel2_pos,
 *                 "Relation directions in for-from do not match")
 *         return dict(target = target,             # <<<<<<<<<<<<<<
 *                     bound1 = bound1,
 *                     relation1 = rel1,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_target, __pyx_v_target) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2126
 *                 "Relation directions in for-from do not match")
 *         return dict(target = target,
 *                     bound1 = bound1,             # <<<<<<<<<<<<<<
 *                     relation1 = rel1,
 *                     relation2 = rel2,
*/
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_bound1, __pyx_v_bound1) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2127
 *         return dict(target = target,
 *                     bound1 = bound1,
 *                     relation1 = rel1,             # <<<<<<<<<<<<<<
 *                     relation2 = rel2,
 *                     bound2 = bound2,
*/
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_relation1, __pyx_v_rel1) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2128
 *                     bound1 = bound1,
 *                     relation1 = rel1,
 *                     relation2 = rel2,             # <<<<<<<<<<<<<<
 *                     bound2 = bound2,
 *                     step = step,
*/
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_relation2, __pyx_v_rel2) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2129
 *                     relation1 = rel1,
 *                     relation2 = rel2,
 *                     bound2 = bound2,             # <<<<<<<<<<<<<<
 *                     step = step,
 *                     )
*/
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_bound2, __pyx_v_bound2) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2130
 *                     relation2 = rel2,
 *                     bound2 = bound2,
 *                     step = step,             # <<<<<<<<<<<<<<
 *                     )
 *     else:
*/
    if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_step, __pyx_v_step) < (0)) __PYX_ERR(0, 2125, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2099
 *         iterator = p_for_iterator(s, allow_testlist, is_async=is_async)
 *         return dict(target=target, iterator=iterator)
 *     elif not s.in_python_file and not is_async:             # <<<<<<<<<<<<<<
 *         if s.sy == 'from':
 *             s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":2133
 *                     )
 *     else:
 *         s.expect('in')             # <<<<<<<<<<<<<<
 *         return {}
 * 
*/
  /*else*/ {
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_in};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2134
 *     else:
 *         s.expect('in')
 *         return {}             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2092
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_bounds(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False) -> dict:
 *     target = p_for_target(s)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_iterator);
  __Pyx_XDECREF(__pyx_v_bound1);
  __Pyx_XDECREF(__pyx_v_rel1);
  __Pyx_XDECREF(__pyx_v_name2_pos);
  __Pyx_XDECREF(__pyx_v_name2);
  __Pyx_XDECREF(__pyx_v_rel2_pos);
  __Pyx_XDECREF(__pyx_v_rel2);
  __Pyx_XDECREF(__pyx_v_bound2);
  __Pyx_XDECREF(__pyx_v_step);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2137
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_from_relation(s: PyrexScanner):
 *     if s.sy in inequality_relations:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_from_relation(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_from_relation", 0);

  /* "Cython/Compiler/Parsing.py":2139
 * @cython.cfunc
 * def p_for_from_relation(s: PyrexScanner):
 *     if s.sy in inequality_relations:             # <<<<<<<<<<<<<<
 *         op = s.sy
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_inequality_relations, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2139, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2140
 * def p_for_from_relation(s: PyrexScanner):
 *     if s.sy in inequality_relations:
 *         op = s.sy             # <<<<<<<<<<<<<<
 *         s.next()
 *         return op
*/
    __pyx_t_2 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_op = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2141
 *     if s.sy in inequality_relations:
 *         op = s.sy
 *         s.next()             # <<<<<<<<<<<<<<
 *         return op
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2142
 *         op = s.sy
 *         s.next()
 *         return op             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("Expected one of '<', '<=', '>' '>='")
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_op);
    __pyx_r = __pyx_v_op;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2139
 * @cython.cfunc
 * def p_for_from_relation(s: PyrexScanner):
 *     if s.sy in inequality_relations:             # <<<<<<<<<<<<<<
 *         op = s.sy
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":2144
 *         return op
 *     else:
 *         s.error("Expected one of '<', '<=', '>' '>='")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_one_of};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2144, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2137
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_from_relation(s: PyrexScanner):
 *     if s.sy in inequality_relations:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_from_relation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2147
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_from_step(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'by':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_from_step(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_step = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_from_step", 0);

  /* "Cython/Compiler/Parsing.py":2149
 * @cython.cfunc
 * def p_for_from_step(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'by':             # <<<<<<<<<<<<<<
 *         s.next()
 *         step = p_bit_expr(s)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2149, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_by, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2149, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2150
 * def p_for_from_step(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'by':
 *         s.next()             # <<<<<<<<<<<<<<
 *         step = p_bit_expr(s)
 *         return step
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2151
 *     if s.sy == 'IDENT' and s.systring == 'by':
 *         s.next()
 *         step = p_bit_expr(s)             # <<<<<<<<<<<<<<
 *         return step
 *     else:
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_bit_expr(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_step = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2152
 *         s.next()
 *         step = p_bit_expr(s)
 *         return step             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_step);
    __pyx_r = __pyx_v_step;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2149
 * @cython.cfunc
 * def p_for_from_step(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'by':             # <<<<<<<<<<<<<<
 *         s.next()
 *         step = p_bit_expr(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":2154
 *         return step
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2147
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_from_step(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring == 'by':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_from_step", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_step);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2161
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_target(s: PyrexScanner, terminator: str):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_terminator) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_exprs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_target", 0);

  /* "Cython/Compiler/Parsing.py":2163
 * @cython.cfunc
 * def p_target(s: PyrexScanner, terminator: str):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_starred_expr(s)
 *     if s.sy == ',':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2164
 * def p_target(s: PyrexScanner, terminator: str):
 *     pos = s.position()
 *     expr = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2165
 *     pos = s.position()
 *     expr = p_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = [expr]
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2165, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2166
 *     expr = p_starred_expr(s)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         exprs = [expr]
 *         while s.sy != terminator:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2166, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2167
 *     if s.sy == ',':
 *         s.next()
 *         exprs = [expr]             # <<<<<<<<<<<<<<
 *         while s.sy != terminator:
 *             exprs.append(p_starred_expr(s))
*/
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_expr);
    __Pyx_GIVEREF(__pyx_v_expr);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr) != (0)) __PYX_ERR(0, 2167, __pyx_L1_error);
    __pyx_v_exprs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2168
 *         s.next()
 *         exprs = [expr]
 *         while s.sy != terminator:             # <<<<<<<<<<<<<<
 *             exprs.append(p_starred_expr(s))
 *             if s.sy != ',':
*/
    while (1) {
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_v_terminator, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2168, __pyx_L1_error)
      if (!__pyx_t_2) break;

      /* "Cython/Compiler/Parsing.py":2169
 *         exprs = [expr]
 *         while s.sy != terminator:
 *             exprs.append(p_starred_expr(s))             # <<<<<<<<<<<<<<
 *             if s.sy != ',':
 *                 break
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_exprs, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2170
 *         while s.sy != terminator:
 *             exprs.append(p_starred_expr(s))
 *             if s.sy != ',':             # <<<<<<<<<<<<<<
 *                 break
 *             s.next()
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2170, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2171
 *             exprs.append(p_starred_expr(s))
 *             if s.sy != ',':
 *                 break             # <<<<<<<<<<<<<<
 *             s.next()
 *         return ExprNodes.TupleNode(pos, args = exprs)
*/
        goto __pyx_L5_break;

        /* "Cython/Compiler/Parsing.py":2170
 *         while s.sy != terminator:
 *             exprs.append(p_starred_expr(s))
 *             if s.sy != ',':             # <<<<<<<<<<<<<<
 *                 break
 *             s.next()
*/
      }

      /* "Cython/Compiler/Parsing.py":2172
 *             if s.sy != ',':
 *                 break
 *             s.next()             # <<<<<<<<<<<<<<
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2172, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5_break:;

    /* "Cython/Compiler/Parsing.py":2173
 *                 break
 *             s.next()
 *         return ExprNodes.TupleNode(pos, args = exprs)             # <<<<<<<<<<<<<<
 *     else:
 *         return expr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_exprs, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2165
 *     pos = s.position()
 *     expr = p_starred_expr(s)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         exprs = [expr]
*/
  }

  /* "Cython/Compiler/Parsing.py":2175
 *         return ExprNodes.TupleNode(pos, args = exprs)
 *     else:
 *         return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_expr);
    __pyx_r = __pyx_v_expr;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2161
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_target(s: PyrexScanner, terminator: str):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_target", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_exprs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2178
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_target(s: PyrexScanner):
 *     return p_target(s, 'in')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_target", 0);

  /* "Cython/Compiler/Parsing.py":2180
 * @cython.cfunc
 * def p_for_target(s: PyrexScanner):
 *     return p_target(s, 'in')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_target(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_in); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2178
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_target(s: PyrexScanner):
 *     return p_target(s, 'in')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_target", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2183
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_for_iterator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_for_iterator *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2184
 * 
 * @cython.cfunc
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     if allow_testlist:
*/
  int __pyx_v_allow_testlist = ((int)1);
  int __pyx_v_is_async = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_for_iterator", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_allow_testlist = __pyx_optional_args->allow_testlist;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_is_async = __pyx_optional_args->is_async;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":2185
 * @cython.cfunc
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if allow_testlist:
 *         expr = p_testlist(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2186
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()
 *     if allow_testlist:             # <<<<<<<<<<<<<<
 *         expr = p_testlist(s)
 *     else:
*/
  if (__pyx_v_allow_testlist) {

    /* "Cython/Compiler/Parsing.py":2187
 *     pos = s.position()
 *     if allow_testlist:
 *         expr = p_testlist(s)             # <<<<<<<<<<<<<<
 *     else:
 *         expr = p_or_test(s)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_expr = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2186
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()
 *     if allow_testlist:             # <<<<<<<<<<<<<<
 *         expr = p_testlist(s)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2189
 *         expr = p_testlist(s)
 *     else:
 *         expr = p_or_test(s)             # <<<<<<<<<<<<<<
 *     return (ExprNodes.AsyncIteratorNode if is_async else ExprNodes.IteratorNode)(pos, sequence=expr)
 * 
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_or_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_expr = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2190
 *     else:
 *         expr = p_or_test(s)
 *     return (ExprNodes.AsyncIteratorNode if is_async else ExprNodes.IteratorNode)(pos, sequence=expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  if (__pyx_v_is_async) {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_AsyncIteratorNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_IteratorNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_sequence, __pyx_v_expr, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2190, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2183
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_for_iterator(s: PyrexScanner, allow_testlist: cython.bint = True, is_async: cython.bint = False):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_for_iterator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2193
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_try_statement(s: PyrexScanner):
 *     # s.sy == 'try'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_try_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_except_clauses = NULL;
  PyObject *__pyx_v_else_clause = NULL;
  PyObject *__pyx_v_finally_clause = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_try_statement", 0);

  /* "Cython/Compiler/Parsing.py":2196
 * def p_try_statement(s: PyrexScanner):
 *     # s.sy == 'try'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     body = p_suite(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2197
 *     # s.sy == 'try'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     except_clauses = []
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2198
 *     pos = s.position()
 *     s.next()
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     except_clauses = []
 *     else_clause = None
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2199
 *     s.next()
 *     body = p_suite(s)
 *     except_clauses = []             # <<<<<<<<<<<<<<
 *     else_clause = None
 *     if s.sy in ('except', 'else'):
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_except_clauses = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2200
 *     body = p_suite(s)
 *     except_clauses = []
 *     else_clause = None             # <<<<<<<<<<<<<<
 *     if s.sy in ('except', 'else'):
 *         while s.sy == 'except':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_else_clause = Py_None;

  /* "Cython/Compiler/Parsing.py":2201
 *     except_clauses = []
 *     else_clause = None
 *     if s.sy in ('except', 'else'):             # <<<<<<<<<<<<<<
 *         while s.sy == 'except':
 *             except_clauses.append(p_except_clause(s))
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_4 = __pyx_v_s->sy;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_except, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2201, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2201, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __pyx_t_5;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2202
 *     else_clause = None
 *     if s.sy in ('except', 'else'):
 *         while s.sy == 'except':             # <<<<<<<<<<<<<<
 *             except_clauses.append(p_except_clause(s))
 *         if s.sy == 'else':
*/
    while (1) {
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_except, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2202, __pyx_L1_error)
      if (!__pyx_t_6) break;

      /* "Cython/Compiler/Parsing.py":2203
 *     if s.sy in ('except', 'else'):
 *         while s.sy == 'except':
 *             except_clauses.append(p_except_clause(s))             # <<<<<<<<<<<<<<
 *         if s.sy == 'else':
 *             s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_except_clause(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_except_clauses, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2203, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "Cython/Compiler/Parsing.py":2204
 *         while s.sy == 'except':
 *             except_clauses.append(p_except_clause(s))
 *         if s.sy == 'else':             # <<<<<<<<<<<<<<
 *             s.next()
 *             else_clause = p_suite(s)
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_else, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2204, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":2205
 *             except_clauses.append(p_except_clause(s))
 *         if s.sy == 'else':
 *             s.next()             # <<<<<<<<<<<<<<
 *             else_clause = p_suite(s)
 *         body = Nodes.TryExceptStatNode(pos,
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2205, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2206
 *         if s.sy == 'else':
 *             s.next()
 *             else_clause = p_suite(s)             # <<<<<<<<<<<<<<
 *         body = Nodes.TryExceptStatNode(pos,
 *             body = body, except_clauses = except_clauses,
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_else_clause, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2204
 *         while s.sy == 'except':
 *             except_clauses.append(p_except_clause(s))
 *         if s.sy == 'else':             # <<<<<<<<<<<<<<
 *             s.next()
 *             else_clause = p_suite(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":2207
 *             s.next()
 *             else_clause = p_suite(s)
 *         body = Nodes.TryExceptStatNode(pos,             # <<<<<<<<<<<<<<
 *             body = body, except_clauses = except_clauses,
 *             else_clause = else_clause)
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":2209
 *         body = Nodes.TryExceptStatNode(pos,
 *             body = body, except_clauses = except_clauses,
 *             else_clause = else_clause)             # <<<<<<<<<<<<<<
 *         if s.sy != 'finally':
 *             return body
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2207, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_except_clauses, __pyx_v_except_clauses, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2207, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_else_clause, __pyx_v_else_clause, __pyx_t_8, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2207, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TryExceptStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_body, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2210
 *             body = body, except_clauses = except_clauses,
 *             else_clause = else_clause)
 *         if s.sy != 'finally':             # <<<<<<<<<<<<<<
 *             return body
 *         # try-except-finally is equivalent to nested try-except/try-finally
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_finally, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2210, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":2211
 *             else_clause = else_clause)
 *         if s.sy != 'finally':
 *             return body             # <<<<<<<<<<<<<<
 *         # try-except-finally is equivalent to nested try-except/try-finally
 *     if s.sy == 'finally':
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_body);
      __pyx_r = __pyx_v_body;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2210
 *             body = body, except_clauses = except_clauses,
 *             else_clause = else_clause)
 *         if s.sy != 'finally':             # <<<<<<<<<<<<<<
 *             return body
 *         # try-except-finally is equivalent to nested try-except/try-finally
*/
    }

    /* "Cython/Compiler/Parsing.py":2201
 *     except_clauses = []
 *     else_clause = None
 *     if s.sy in ('except', 'else'):             # <<<<<<<<<<<<<<
 *         while s.sy == 'except':
 *             except_clauses.append(p_except_clause(s))
*/
  }

  /* "Cython/Compiler/Parsing.py":2213
 *             return body
 *         # try-except-finally is equivalent to nested try-except/try-finally
 *     if s.sy == 'finally':             # <<<<<<<<<<<<<<
 *         s.next()
 *         finally_clause = p_suite(s)
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_finally, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2214
 *         # try-except-finally is equivalent to nested try-except/try-finally
 *     if s.sy == 'finally':
 *         s.next()             # <<<<<<<<<<<<<<
 *         finally_clause = p_suite(s)
 *         return Nodes.TryFinallyStatNode(pos,
*/
    __pyx_t_8 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2215
 *     if s.sy == 'finally':
 *         s.next()
 *         finally_clause = p_suite(s)             # <<<<<<<<<<<<<<
 *         return Nodes.TryFinallyStatNode(pos,
 *             body = body, finally_clause = finally_clause)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_finally_clause = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2216
 *         s.next()
 *         finally_clause = p_suite(s)
 *         return Nodes.TryFinallyStatNode(pos,             # <<<<<<<<<<<<<<
 *             body = body, finally_clause = finally_clause)
 *     else:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_8);

    /* "Cython/Compiler/Parsing.py":2217
 *         finally_clause = p_suite(s)
 *         return Nodes.TryFinallyStatNode(pos,
 *             body = body, finally_clause = finally_clause)             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("Expected 'except' or 'finally'")
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_8, __pyx_v_pos};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2216, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_finally_clause, __pyx_v_finally_clause, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2216, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TryFinallyStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2213
 *             return body
 *         # try-except-finally is equivalent to nested try-except/try-finally
 *     if s.sy == 'finally':             # <<<<<<<<<<<<<<
 *         s.next()
 *         finally_clause = p_suite(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":2219
 *             body = body, finally_clause = finally_clause)
 *     else:
 *         s.error("Expected 'except' or 'finally'")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Expected_except_or_finally};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2193
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_try_statement(s: PyrexScanner):
 *     # s.sy == 'try'
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_try_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_except_clauses);
  __Pyx_XDECREF(__pyx_v_else_clause);
  __Pyx_XDECREF(__pyx_v_finally_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2222
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_except_clause(s: PyrexScanner):
 *     # s.sy == 'except'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_except_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_exc_type = NULL;
  PyObject *__pyx_v_exc_value = NULL;
  int __pyx_v_is_except_as;
  PyObject *__pyx_v_pos2 = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_except_clause", 0);

  /* "Cython/Compiler/Parsing.py":2225
 * def p_except_clause(s: PyrexScanner):
 *     # s.sy == 'except'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     exc_type = None
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2226
 *     # s.sy == 'except'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     exc_type = None
 *     exc_value = None
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2227
 *     pos = s.position()
 *     s.next()
 *     exc_type = None             # <<<<<<<<<<<<<<
 *     exc_value = None
 *     is_except_as = False
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_type = Py_None;

  /* "Cython/Compiler/Parsing.py":2228
 *     s.next()
 *     exc_type = None
 *     exc_value = None             # <<<<<<<<<<<<<<
 *     is_except_as = False
 *     if s.sy != ':':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_value = Py_None;

  /* "Cython/Compiler/Parsing.py":2229
 *     exc_type = None
 *     exc_value = None
 *     is_except_as = False             # <<<<<<<<<<<<<<
 *     if s.sy != ':':
 *         exc_type = p_test(s)
*/
  __pyx_v_is_except_as = 0;

  /* "Cython/Compiler/Parsing.py":2230
 *     exc_value = None
 *     is_except_as = False
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         exc_type = p_test(s)
 *         # normalise into list of single exception tests
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2230, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2231
 *     is_except_as = False
 *     if s.sy != ':':
 *         exc_type = p_test(s)             # <<<<<<<<<<<<<<
 *         # normalise into list of single exception tests
 *         if isinstance(exc_type, ExprNodes.TupleNode):
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_exc_type, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2233
 *         exc_type = p_test(s)
 *         # normalise into list of single exception tests
 *         if isinstance(exc_type, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *             exc_type = exc_type.args
 *         else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_TupleNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_exc_type, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2233, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2234
 *         # normalise into list of single exception tests
 *         if isinstance(exc_type, ExprNodes.TupleNode):
 *             exc_type = exc_type.args             # <<<<<<<<<<<<<<
 *         else:
 *             exc_type = [exc_type]
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc_type, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_exc_type, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2233
 *         exc_type = p_test(s)
 *         # normalise into list of single exception tests
 *         if isinstance(exc_type, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *             exc_type = exc_type.args
 *         else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":2236
 *             exc_type = exc_type.args
 *         else:
 *             exc_type = [exc_type]             # <<<<<<<<<<<<<<
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'
 *                            and s.context.language_level == 2):
*/
    /*else*/ {
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_exc_type);
      __Pyx_GIVEREF(__pyx_v_exc_type);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_exc_type) != (0)) __PYX_ERR(0, 2236, __pyx_L1_error);
      __Pyx_DECREF_SET(__pyx_v_exc_type, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":2237
 *         else:
 *             exc_type = [exc_type]
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'             # <<<<<<<<<<<<<<
 *                            and s.context.language_level == 2):
 *             s.next()
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2237, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2237, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }

    /* "Cython/Compiler/Parsing.py":2238
 *             exc_type = [exc_type]
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'
 *                            and s.context.language_level == 2):             # <<<<<<<<<<<<<<
 *             s.next()
 *             exc_value = p_test(s)
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2237, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PyLong_BoolEqObjC(__pyx_t_1, __pyx_mstate_global->__pyx_int_2, 2, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __pyx_t_5;
    __pyx_L6_bool_binop_done:;

    /* "Cython/Compiler/Parsing.py":2237
 *         else:
 *             exc_type = [exc_type]
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'             # <<<<<<<<<<<<<<
 *                            and s.context.language_level == 2):
 *             s.next()
*/
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2239
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'
 *                            and s.context.language_level == 2):
 *             s.next()             # <<<<<<<<<<<<<<
 *             exc_value = p_test(s)
 *         elif s.sy == 'IDENT' and s.systring == 'as':
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2239, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2240
 *                            and s.context.language_level == 2):
 *             s.next()
 *             exc_value = p_test(s)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'IDENT' and s.systring == 'as':
 *             # Py3 syntax requires a name here
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_exc_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2237
 *         else:
 *             exc_type = [exc_type]
 *         if s.sy == ',' or (s.sy == 'IDENT' and s.systring == 'as'             # <<<<<<<<<<<<<<
 *                            and s.context.language_level == 2):
 *             s.next()
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":2241
 *             s.next()
 *             exc_value = p_test(s)
 *         elif s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *             # Py3 syntax requires a name here
 *             s.next()
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2241, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2241, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_5;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2243
 *         elif s.sy == 'IDENT' and s.systring == 'as':
 *             # Py3 syntax requires a name here
 *             s.next()             # <<<<<<<<<<<<<<
 *             pos2 = s.position()
 *             name = p_ident(s)
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2243, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2244
 *             # Py3 syntax requires a name here
 *             s.next()
 *             pos2 = s.position()             # <<<<<<<<<<<<<<
 *             name = p_ident(s)
 *             exc_value = ExprNodes.NameNode(pos2, name = name)
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_pos2 = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2245
 *             s.next()
 *             pos2 = s.position()
 *             name = p_ident(s)             # <<<<<<<<<<<<<<
 *             exc_value = ExprNodes.NameNode(pos2, name = name)
 *             is_except_as = True
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2246
 *             pos2 = s.position()
 *             name = p_ident(s)
 *             exc_value = ExprNodes.NameNode(pos2, name = name)             # <<<<<<<<<<<<<<
 *             is_except_as = True
 *     body = p_suite(s)
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos2};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2246, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2246, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_NameNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2246, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_exc_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2247
 *             name = p_ident(s)
 *             exc_value = ExprNodes.NameNode(pos2, name = name)
 *             is_except_as = True             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     return Nodes.ExceptClauseNode(pos,
*/
      __pyx_v_is_except_as = 1;

      /* "Cython/Compiler/Parsing.py":2241
 *             s.next()
 *             exc_value = p_test(s)
 *         elif s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *             # Py3 syntax requires a name here
 *             s.next()
*/
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":2230
 *     exc_value = None
 *     is_except_as = False
 *     if s.sy != ':':             # <<<<<<<<<<<<<<
 *         exc_type = p_test(s)
 *         # normalise into list of single exception tests
*/
  }

  /* "Cython/Compiler/Parsing.py":2248
 *             exc_value = ExprNodes.NameNode(pos2, name = name)
 *             is_except_as = True
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     return Nodes.ExceptClauseNode(pos,
 *         pattern = exc_type, target = exc_value,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_body = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2249
 *             is_except_as = True
 *     body = p_suite(s)
 *     return Nodes.ExceptClauseNode(pos,             # <<<<<<<<<<<<<<
 *         pattern = exc_type, target = exc_value,
 *         body = body, is_except_as=is_except_as)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_6);

  /* "Cython/Compiler/Parsing.py":2251
 *     return Nodes.ExceptClauseNode(pos,
 *         pattern = exc_type, target = exc_value,
 *         body = body, is_except_as=is_except_as)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_is_except_as); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pattern, __pyx_v_exc_type, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2249, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_target, __pyx_v_exc_value, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2249, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_7, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2249, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_except_as, __pyx_t_2, __pyx_t_7, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 2249, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExceptClauseNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2222
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_except_clause(s: PyrexScanner):
 *     # s.sy == 'except'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_except_clause", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_exc_type);
  __Pyx_XDECREF(__pyx_v_exc_value);
  __Pyx_XDECREF(__pyx_v_pos2);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2254
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_include_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_include_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_unicode_include_file_name = NULL;
  PyObject *__pyx_v_include_file_name = NULL;
  PyObject *__pyx_v_include_file_path = NULL;
  PyObject *__pyx_v_source_desc = NULL;
  PyObject *__pyx_v_f = NULL;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s2 = NULL;
  PyObject *__pyx_v_tree = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_include_statement", 0);

  /* "Cython/Compiler/Parsing.py":2256
 * @cython.cfunc
 * def p_include_statement(s: PyrexScanner, ctx):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()  # 'include'
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2257
 * def p_include_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
 *     s.next()  # 'include'             # <<<<<<<<<<<<<<
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]
 *     s.expect_newline("Syntax error in include statement")
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2258
 *     pos = s.position()
 *     s.next()  # 'include'
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]             # <<<<<<<<<<<<<<
 *     s.expect_newline("Syntax error in include statement")
 *     if s.compile_time_eval:
*/
  __pyx_t_4.__pyx_n = 1;
  __pyx_t_4.kind_override = __pyx_mstate_global->__pyx_n_u_u;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 2258, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_t_1, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_unicode_include_file_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2259
 *     s.next()  # 'include'
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]
 *     s.expect_newline("Syntax error in include statement")             # <<<<<<<<<<<<<<
 *     if s.compile_time_eval:
 *         include_file_name = unicode_include_file_name
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_include_statemen};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2260
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]
 *     s.expect_newline("Syntax error in include statement")
 *     if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *         include_file_name = unicode_include_file_name
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
*/
  if (__pyx_v_s->compile_time_eval) {

    /* "Cython/Compiler/Parsing.py":2261
 *     s.expect_newline("Syntax error in include statement")
 *     if s.compile_time_eval:
 *         include_file_name = unicode_include_file_name             # <<<<<<<<<<<<<<
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
 *         if include_file_path:
*/
    __Pyx_INCREF(__pyx_v_unicode_include_file_name);
    __pyx_v_include_file_name = __pyx_v_unicode_include_file_name;

    /* "Cython/Compiler/Parsing.py":2262
 *     if s.compile_time_eval:
 *         include_file_name = unicode_include_file_name
 *         include_file_path = s.context.find_include_file(include_file_name, pos)             # <<<<<<<<<<<<<<
 *         if include_file_path:
 *             s.included_files.append(include_file_name)
*/
    __pyx_t_1 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_include_file_name, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_find_include_file, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_include_file_path = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2263
 *         include_file_name = unicode_include_file_name
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
 *         if include_file_path:             # <<<<<<<<<<<<<<
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)
*/
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_include_file_path); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2263, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":2264
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
 *         if include_file_path:
 *             s.included_files.append(include_file_name)             # <<<<<<<<<<<<<<
 *             source_desc = FileSourceDescriptor(include_file_path)
 *             with source_desc.get_file_object() as f:
*/
      if (unlikely(__pyx_v_s->included_files == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 2264, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_s->included_files, __pyx_v_include_file_name); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2264, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":2265
 *         if include_file_path:
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)             # <<<<<<<<<<<<<<
 *             with source_desc.get_file_object() as f:
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_include_file_path};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2265, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_v_source_desc = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2266
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)
 *             with source_desc.get_file_object() as f:             # <<<<<<<<<<<<<<
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
 *                 tree = p_statement_list(s2, ctx)
*/
      /*with:*/ {
        __pyx_t_7 = __pyx_v_source_desc;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_file_object, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2266, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2266, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = NULL;
        __pyx_t_9 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2266, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2266, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_9 = __pyx_t_7;
        __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_12);
            /*try:*/ {
              __pyx_v_f = __pyx_t_9;
              __pyx_t_9 = 0;

              /* "Cython/Compiler/Parsing.py":2267
 *             source_desc = FileSourceDescriptor(include_file_path)
 *             with source_desc.get_file_object() as f:
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)             # <<<<<<<<<<<<<<
 *                 tree = p_statement_list(s2, ctx)
 *             return tree
*/
              __pyx_t_2 = NULL;
              __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_mstate_global->__pyx_n_u_encoding); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2267, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_s->parse_comments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2267, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_3 = 1;
              {
                PyObject *__pyx_callargs[4 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_f, __pyx_v_source_desc, ((PyObject *)__pyx_v_s)};
                __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2267, __pyx_L9_error)
                __Pyx_GOTREF(__pyx_t_13);
                if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_source_encoding, __pyx_t_7, __pyx_t_13, __pyx_callargs+4, 0) < (0)) __PYX_ERR(0, 2267, __pyx_L9_error)
                if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_parse_comments, __pyx_t_1, __pyx_t_13, __pyx_callargs+4, 1) < (0)) __PYX_ERR(0, 2267, __pyx_L9_error)
                __pyx_t_9 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, __pyx_callargs+__pyx_t_3, (4-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
                __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2267, __pyx_L9_error)
                __Pyx_GOTREF((PyObject *)__pyx_t_9);
              }
              __pyx_v_s2 = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_t_9);
              __pyx_t_9 = 0;

              /* "Cython/Compiler/Parsing.py":2268
 *             with source_desc.get_file_object() as f:
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
 *                 tree = p_statement_list(s2, ctx)             # <<<<<<<<<<<<<<
 *             return tree
 *         else:
*/
              __pyx_t_9 = __pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(__pyx_v_s2, __pyx_v_ctx, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2268, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_9);
              __pyx_v_tree = __pyx_t_9;
              __pyx_t_9 = 0;

              /* "Cython/Compiler/Parsing.py":2266
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)
 *             with source_desc.get_file_object() as f:             # <<<<<<<<<<<<<<
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
 *                 tree = p_statement_list(s2, ctx)
*/
            }
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            goto __pyx_L14_try_end;
            __pyx_L9_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("Cython.Compiler.Parsing.p_include_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_13, &__pyx_t_1) < 0) __PYX_ERR(0, 2266, __pyx_L11_except_error)
              __Pyx_XGOTREF(__pyx_t_9);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_1);
              __pyx_t_7 = PyTuple_Pack(3, __pyx_t_9, __pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2266, __pyx_L11_except_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_7, NULL);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2266, __pyx_L11_except_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (__pyx_t_5 < (0)) __PYX_ERR(0, 2266, __pyx_L11_except_error)
              __pyx_t_15 = (!__pyx_t_5);
              if (unlikely(__pyx_t_15)) {
                __Pyx_GIVEREF(__pyx_t_9);
                __Pyx_GIVEREF(__pyx_t_13);
                __Pyx_XGIVEREF(__pyx_t_1);
                __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_13, __pyx_t_1);
                __pyx_t_9 = 0;  __pyx_t_13 = 0;  __pyx_t_1 = 0; 
                __PYX_ERR(0, 2266, __pyx_L11_except_error)
              }
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              goto __pyx_L10_exception_handled;
            }
            __pyx_L11_except_error:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            goto __pyx_L1_error;
            __pyx_L10_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            __pyx_L14_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_8) {
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2266, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            goto __pyx_L8;
          }
          __pyx_L8:;
        }
        goto __pyx_L18;
        __pyx_L5_error:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L1_error;
        __pyx_L18:;
      }

      /* "Cython/Compiler/Parsing.py":2269
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
 *                 tree = p_statement_list(s2, ctx)
 *             return tree             # <<<<<<<<<<<<<<
 *         else:
 *             return None
*/
      __Pyx_XDECREF(__pyx_r);
      if (unlikely(!__pyx_v_tree)) { __Pyx_RaiseUnboundLocalError("tree"); __PYX_ERR(0, 2269, __pyx_L1_error) }
      __Pyx_INCREF(__pyx_v_tree);
      __pyx_r = __pyx_v_tree;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2263
 *         include_file_name = unicode_include_file_name
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
 *         if include_file_path:             # <<<<<<<<<<<<<<
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)
*/
    }

    /* "Cython/Compiler/Parsing.py":2271
 *             return tree
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 *     else:
 *         return Nodes.PassStatNode(pos)
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
    }

    /* "Cython/Compiler/Parsing.py":2260
 *     unicode_include_file_name = p_string_literal(s, 'u')[2]
 *     s.expect_newline("Syntax error in include statement")
 *     if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *         include_file_name = unicode_include_file_name
 *         include_file_path = s.context.find_include_file(include_file_name, pos)
*/
  }

  /* "Cython/Compiler/Parsing.py":2273
 *             return None
 *     else:
 *         return Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_13 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2254
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_include_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_include_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_unicode_include_file_name);
  __Pyx_XDECREF(__pyx_v_include_file_name);
  __Pyx_XDECREF(__pyx_v_include_file_path);
  __Pyx_XDECREF(__pyx_v_source_desc);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF((PyObject *)__pyx_v_s2);
  __Pyx_XDECREF(__pyx_v_tree);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2276
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_statement(s: PyrexScanner):
 *     s.next()  # 'with'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_statement", 0);

  /* "Cython/Compiler/Parsing.py":2278
 * @cython.cfunc
 * def p_with_statement(s: PyrexScanner):
 *     s.next()  # 'with'             # <<<<<<<<<<<<<<
 *     if s.systring == 'template' and not s.in_python_file:
 *         node = p_with_template(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2279
 * def p_with_statement(s: PyrexScanner):
 *     s.next()  # 'with'
 *     if s.systring == 'template' and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         node = p_with_template(s)
 *     else:
*/
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_template, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2279, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (!__pyx_v_s->in_python_file);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2280
 *     s.next()  # 'with'
 *     if s.systring == 'template' and not s.in_python_file:
 *         node = p_with_template(s)             # <<<<<<<<<<<<<<
 *     else:
 *         node = p_with_items(s)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_template(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2279
 * def p_with_statement(s: PyrexScanner):
 *     s.next()  # 'with'
 *     if s.systring == 'template' and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         node = p_with_template(s)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2282
 *         node = p_with_template(s)
 *     else:
 *         node = p_with_items(s)             # <<<<<<<<<<<<<<
 *     return node
 * 
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_items(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2283
 *     else:
 *         node = p_with_items(s)
 *     return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2276
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_statement(s: PyrexScanner):
 *     s.next()  # 'with'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2286
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_items(s: PyrexScanner, is_async: cython.bint = False):
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_items(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_with_items *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2287
 * 
 * @cython.cfunc
 * def p_with_items(s: PyrexScanner, is_async: cython.bint = False):             # <<<<<<<<<<<<<<
 *     """
 *     Copied from CPython:
*/
  int __pyx_v_is_async = ((int)0);
  int __pyx_v_brackets_succeeded;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_cls = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kwds = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *(*__pyx_t_17)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_items", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_is_async = __pyx_optional_args->is_async;
    }
  }

  /* "Cython/Compiler/Parsing.py":2297
 *     version and if that fails try the regular version
 *     """
 *     brackets_succeeded = False             # <<<<<<<<<<<<<<
 *     items = ()  # unused, but static analysis fails to track that below
 *     if s.sy == '(':
*/
  __pyx_v_brackets_succeeded = 0;

  /* "Cython/Compiler/Parsing.py":2298
 *     """
 *     brackets_succeeded = False
 *     items = ()  # unused, but static analysis fails to track that below             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         with tentatively_scan(s) as errors:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
  __pyx_v_items = __pyx_mstate_global->__pyx_empty_tuple;

  /* "Cython/Compiler/Parsing.py":2299
 *     brackets_succeeded = False
 *     items = ()  # unused, but static analysis fails to track that below
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2299, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2300
 *     items = ()  # unused, but static analysis fails to track that below
 *     if s.sy == '(':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             s.next()
 *             items = p_with_items_list(s, is_async)
*/
    /*with:*/ {
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_s)};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = NULL;
      __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2300, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2300, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_7 = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          /*try:*/ {
            __pyx_v_errors = __pyx_t_7;
            __pyx_t_7 = 0;

            /* "Cython/Compiler/Parsing.py":2301
 *     if s.sy == '(':
 *         with tentatively_scan(s) as errors:
 *             s.next()             # <<<<<<<<<<<<<<
 *             items = p_with_items_list(s, is_async)
 *             s.expect(")")
*/
            __pyx_t_2 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
              __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2301, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_7);
            }
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "Cython/Compiler/Parsing.py":2302
 *         with tentatively_scan(s) as errors:
 *             s.next()
 *             items = p_with_items_list(s, is_async)             # <<<<<<<<<<<<<<
 *             s.expect(")")
 *             if s.sy != ":":
*/
            __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_items_list(__pyx_v_s, __pyx_v_is_async); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2302, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF_SET(__pyx_v_items, __pyx_t_7);
            __pyx_t_7 = 0;

            /* "Cython/Compiler/Parsing.py":2303
 *             s.next()
 *             items = p_with_items_list(s, is_async)
 *             s.expect(")")             # <<<<<<<<<<<<<<
 *             if s.sy != ":":
 *                 # Fail - the message doesn't matter because we'll try the
*/
            __pyx_t_2 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_2);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__24};
              __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2303, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_7);
            }
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "Cython/Compiler/Parsing.py":2304
 *             items = p_with_items_list(s, is_async)
 *             s.expect(")")
 *             if s.sy != ":":             # <<<<<<<<<<<<<<
 *                 # Fail - the message doesn't matter because we'll try the
 *                 # non-bracket version so it'll never be shown
*/
            __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2304, __pyx_L8_error)
            if (__pyx_t_1) {

              /* "Cython/Compiler/Parsing.py":2307
 *                 # Fail - the message doesn't matter because we'll try the
 *                 # non-bracket version so it'll never be shown
 *                 s.error("")             # <<<<<<<<<<<<<<
 *         brackets_succeeded = not errors
 *     if not brackets_succeeded:
*/
              __pyx_t_2 = ((PyObject *)__pyx_v_s);
              __Pyx_INCREF(__pyx_t_2);
              __pyx_t_5 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__35};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2307, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

              /* "Cython/Compiler/Parsing.py":2304
 *             items = p_with_items_list(s, is_async)
 *             s.expect(")")
 *             if s.sy != ":":             # <<<<<<<<<<<<<<
 *                 # Fail - the message doesn't matter because we'll try the
 *                 # non-bracket version so it'll never be shown
*/
            }

            /* "Cython/Compiler/Parsing.py":2300
 *     items = ()  # unused, but static analysis fails to track that below
 *     if s.sy == '(':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             s.next()
 *             items = p_with_items_list(s, is_async)
*/
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L13_try_end;
          __pyx_L8_error:;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_items", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_4) < 0) __PYX_ERR(0, 2300, __pyx_L10_except_error)
            __Pyx_XGOTREF(__pyx_t_7);
            __Pyx_XGOTREF(__pyx_t_2);
            __Pyx_XGOTREF(__pyx_t_4);
            __pyx_t_3 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2300, __pyx_L10_except_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, NULL);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2300, __pyx_L10_except_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_1 < (0)) __PYX_ERR(0, 2300, __pyx_L10_except_error)
            __pyx_t_12 = (!__pyx_t_1);
            if (unlikely(__pyx_t_12)) {
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_2);
              __Pyx_XGIVEREF(__pyx_t_4);
              __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_2, __pyx_t_4);
              __pyx_t_7 = 0;  __pyx_t_2 = 0;  __pyx_t_4 = 0; 
              __PYX_ERR(0, 2300, __pyx_L10_except_error)
            }
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            goto __pyx_L9_exception_handled;
          }
          __pyx_L10_except_error:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          goto __pyx_L1_error;
          __pyx_L9_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          __pyx_L13_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_6) {
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2300, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
      goto __pyx_L18;
      __pyx_L4_error:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L1_error;
      __pyx_L18:;
    }

    /* "Cython/Compiler/Parsing.py":2308
 *                 # non-bracket version so it'll never be shown
 *                 s.error("")
 *         brackets_succeeded = not errors             # <<<<<<<<<<<<<<
 *     if not brackets_succeeded:
 *         # try the non-bracket version
*/
    if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 2308, __pyx_L1_error) }
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2308, __pyx_L1_error)
    __pyx_v_brackets_succeeded = (!__pyx_t_12);

    /* "Cython/Compiler/Parsing.py":2299
 *     brackets_succeeded = False
 *     items = ()  # unused, but static analysis fails to track that below
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":2309
 *                 s.error("")
 *         brackets_succeeded = not errors
 *     if not brackets_succeeded:             # <<<<<<<<<<<<<<
 *         # try the non-bracket version
 *         items = p_with_items_list(s, is_async)
*/
  __pyx_t_12 = (!__pyx_v_brackets_succeeded);
  if (__pyx_t_12) {

    /* "Cython/Compiler/Parsing.py":2311
 *     if not brackets_succeeded:
 *         # try the non-bracket version
 *         items = p_with_items_list(s, is_async)             # <<<<<<<<<<<<<<
 *     body = p_suite(s)
 *     for cls, pos, kwds in reversed(items):
*/
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_items_list(__pyx_v_s, __pyx_v_is_async); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_items, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":2309
 *                 s.error("")
 *         brackets_succeeded = not errors
 *     if not brackets_succeeded:             # <<<<<<<<<<<<<<
 *         # try the non-bracket version
 *         items = p_with_items_list(s, is_async)
*/
  }

  /* "Cython/Compiler/Parsing.py":2312
 *         # try the non-bracket version
 *         items = p_with_items_list(s, is_async)
 *     body = p_suite(s)             # <<<<<<<<<<<<<<
 *     for cls, pos, kwds in reversed(items):
 *         # construct the actual nodes now that we know what the body is
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_body = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":2313
 *         items = p_with_items_list(s, is_async)
 *     body = p_suite(s)
 *     for cls, pos, kwds in reversed(items):             # <<<<<<<<<<<<<<
 *         # construct the actual nodes now that we know what the body is
 *         body = cls(pos, body=body, **kwds)
*/
  __pyx_t_2 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_items};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_reversed, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_2 = __pyx_t_4; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_13 = 0;
    __pyx_t_14 = NULL;
  } else {
    __pyx_t_13 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2313, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_14)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2313, __pyx_L1_error)
          #endif
          if (__pyx_t_13 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_13, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_13;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2313, __pyx_L1_error)
          #endif
          if (__pyx_t_13 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_13));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_13);
        #endif
        ++__pyx_t_13;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2313, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_14(__pyx_t_2);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 2313, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2313, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_15 = PyTuple_GET_ITEM(sequence, 2);
        __Pyx_INCREF(__pyx_t_15);
      } else {
        __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2313, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2313, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_3);
        __pyx_t_15 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2313, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_15);
      }
      #else
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_15 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_16 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_17 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_16);
      index = 0; __pyx_t_7 = __pyx_t_17(__pyx_t_16); if (unlikely(!__pyx_t_7)) goto __pyx_L22_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      index = 1; __pyx_t_3 = __pyx_t_17(__pyx_t_16); if (unlikely(!__pyx_t_3)) goto __pyx_L22_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 2; __pyx_t_15 = __pyx_t_17(__pyx_t_16); if (unlikely(!__pyx_t_15)) goto __pyx_L22_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_15);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_16), 3) < (0)) __PYX_ERR(0, 2313, __pyx_L1_error)
      __pyx_t_17 = NULL;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      goto __pyx_L23_unpacking_done;
      __pyx_L22_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_17 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 2313, __pyx_L1_error)
      __pyx_L23_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_cls, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_kwds, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "Cython/Compiler/Parsing.py":2315
 *     for cls, pos, kwds in reversed(items):
 *         # construct the actual nodes now that we know what the body is
 *         body = cls(pos, body=body, **kwds)             # <<<<<<<<<<<<<<
 *     return body
 * 
*/
    __pyx_t_15 = NULL;
    __Pyx_INCREF(__pyx_v_cls);
    __pyx_t_3 = __pyx_v_cls; 
    __pyx_t_16 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    if (PyDict_SetItem(__pyx_t_16, __pyx_mstate_global->__pyx_n_u_body, __pyx_v_body) < (0)) __PYX_ERR(0, 2315, __pyx_L1_error)
    __pyx_t_7 = __pyx_t_16;
    __pyx_t_16 = 0;
    if (unlikely(__pyx_v_kwds == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 2315, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_7, __pyx_v_kwds) < (0)) __PYX_ERR(0, 2315, __pyx_L1_error)
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_15);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_v_pos};
      __pyx_t_4 = __Pyx_PyObject_FastCallDict((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF_SET(__pyx_v_body, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":2313
 *         items = p_with_items_list(s, is_async)
 *     body = p_suite(s)
 *     for cls, pos, kwds in reversed(items):             # <<<<<<<<<<<<<<
 *         # construct the actual nodes now that we know what the body is
 *         body = cls(pos, body=body, **kwds)
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2316
 *         # construct the actual nodes now that we know what the body is
 *         body = cls(pos, body=body, **kwds)
 *     return body             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_body);
  __pyx_r = __pyx_v_body;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2286
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_items(s: PyrexScanner, is_async: cython.bint = False):
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_items", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_cls);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kwds);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2319
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_items_list(s: PyrexScanner, is_async: cython.bint) -> list:
 *     items = []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_items_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_is_async) {
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_items_list", 0);

  /* "Cython/Compiler/Parsing.py":2321
 * @cython.cfunc
 * def p_with_items_list(s: PyrexScanner, is_async: cython.bint) -> list:
 *     items = []             # <<<<<<<<<<<<<<
 *     while True:
 *         items.append(p_with_item(s, is_async))
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_items = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2322
 * def p_with_items_list(s: PyrexScanner, is_async: cython.bint) -> list:
 *     items = []
 *     while True:             # <<<<<<<<<<<<<<
 *         items.append(p_with_item(s, is_async))
 *         if s.sy != ",":
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":2323
 *     items = []
 *     while True:
 *         items.append(p_with_item(s, is_async))             # <<<<<<<<<<<<<<
 *         if s.sy != ",":
 *             break
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_item(__pyx_v_s, __pyx_v_is_async); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2324
 *     while True:
 *         items.append(p_with_item(s, is_async))
 *         if s.sy != ",":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2324, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2325
 *         items.append(p_with_item(s, is_async))
 *         if s.sy != ",":
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ")":
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":2324
 *     while True:
 *         items.append(p_with_item(s, is_async))
 *         if s.sy != ",":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":2326
 *         if s.sy != ",":
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == ")":
 *             # trailing commas allowed
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2326, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2327
 *             break
 *         s.next()
 *         if s.sy == ")":             # <<<<<<<<<<<<<<
 *             # trailing commas allowed
 *             break
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2327, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2329
 *         if s.sy == ")":
 *             # trailing commas allowed
 *             break             # <<<<<<<<<<<<<<
 *     return items
 * 
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":2327
 *             break
 *         s.next()
 *         if s.sy == ")":             # <<<<<<<<<<<<<<
 *             # trailing commas allowed
 *             break
*/
    }
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":2330
 *             # trailing commas allowed
 *             break
 *     return items             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_items);
  __pyx_r = __pyx_v_items;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2319
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_items_list(s: PyrexScanner, is_async: cython.bint) -> list:
 *     items = []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_items_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2333
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_item(s: PyrexScanner, is_async: cython.bint) -> tuple:
 *     # In contrast to most parsing functions, this returns a tuple of
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_item(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_is_async) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v_condition = NULL;
  PyObject *__pyx_v_manager = NULL;
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_item", 0);

  /* "Cython/Compiler/Parsing.py":2339
 *     # This is because GILStatNode does a reasonable amount of initialization in its
 *     # constructor, and requires "body" to be set, which we don't currently have
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):
 *         if is_async:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2340
 *     # constructor, and requires "body" to be set, which we don't currently have
 *     pos = s.position()
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):             # <<<<<<<<<<<<<<
 *         if is_async:
 *             s.error("with gil/nogil cannot be async")
*/
  __pyx_t_3 = (!__pyx_v_s->in_python_file);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2340, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_s->systring);
  __pyx_t_1 = __pyx_v_s->systring;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_nogil, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2340, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_gil, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2340, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2341
 *     pos = s.position()
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):
 *         if is_async:             # <<<<<<<<<<<<<<
 *             s.error("with gil/nogil cannot be async")
 *         state = s.systring
*/
    if (__pyx_v_is_async) {

      /* "Cython/Compiler/Parsing.py":2342
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):
 *         if is_async:
 *             s.error("with gil/nogil cannot be async")             # <<<<<<<<<<<<<<
 *         state = s.systring
 *         s.next()
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_with_gil_nogil_cannot_be_async};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2342, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2341
 *     pos = s.position()
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):
 *         if is_async:             # <<<<<<<<<<<<<<
 *             s.error("with gil/nogil cannot be async")
 *         state = s.systring
*/
    }

    /* "Cython/Compiler/Parsing.py":2343
 *         if is_async:
 *             s.error("with gil/nogil cannot be async")
 *         state = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_state = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2344
 *             s.error("with gil/nogil cannot be async")
 *         state = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *         # support conditional gil/nogil
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2344, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2347
 * 
 *         # support conditional gil/nogil
 *         condition = None             # <<<<<<<<<<<<<<
 *         if s.sy == '(':
 *             s.next()
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_condition = Py_None;

    /* "Cython/Compiler/Parsing.py":2348
 *         # support conditional gil/nogil
 *         condition = None
 *         if s.sy == '(':             # <<<<<<<<<<<<<<
 *             s.next()
 *             condition = p_test(s)
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2348, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2349
 *         condition = None
 *         if s.sy == '(':
 *             s.next()             # <<<<<<<<<<<<<<
 *             condition = p_test(s)
 *             s.expect(')')
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2349, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2350
 *         if s.sy == '(':
 *             s.next()
 *             condition = p_test(s)             # <<<<<<<<<<<<<<
 *             s.expect(')')
 * 
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2350, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_condition, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2351
 *             s.next()
 *             condition = p_test(s)
 *             s.expect(')')             # <<<<<<<<<<<<<<
 * 
 *         return Nodes.GILStatNode, pos, {"state": state, "condition": condition}
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__24};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2348
 *         # support conditional gil/nogil
 *         condition = None
 *         if s.sy == '(':             # <<<<<<<<<<<<<<
 *             s.next()
 *             condition = p_test(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":2353
 *             s.expect(')')
 * 
 *         return Nodes.GILStatNode, pos, {"state": state, "condition": condition}             # <<<<<<<<<<<<<<
 *     else:
 *         manager = p_test(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_GILStatNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_state, __pyx_v_state) < (0)) __PYX_ERR(0, 2353, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_condition, __pyx_v_condition) < (0)) __PYX_ERR(0, 2353, __pyx_L1_error)
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 2353, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_pos);
    __Pyx_GIVEREF(__pyx_v_pos);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 2353, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 2353, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_5 = 0;
    __pyx_r = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2340
 *     # constructor, and requires "body" to be set, which we don't currently have
 *     pos = s.position()
 *     if not s.in_python_file and s.sy == 'IDENT' and s.systring in ('nogil', 'gil'):             # <<<<<<<<<<<<<<
 *         if is_async:
 *             s.error("with gil/nogil cannot be async")
*/
  }

  /* "Cython/Compiler/Parsing.py":2355
 *         return Nodes.GILStatNode, pos, {"state": state, "condition": condition}
 *     else:
 *         manager = p_test(s)             # <<<<<<<<<<<<<<
 *         target = None
 *         if s.sy == 'IDENT' and s.systring == 'as':
*/
  /*else*/ {
    __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2355, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_v_manager = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "Cython/Compiler/Parsing.py":2356
 *     else:
 *         manager = p_test(s)
 *         target = None             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT' and s.systring == 'as':
 *             s.next()
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_target = Py_None;

    /* "Cython/Compiler/Parsing.py":2357
 *         manager = p_test(s)
 *         target = None
 *         if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *             s.next()
 *             target = p_starred_expr(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2357, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_2 = __pyx_t_4;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2357, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_4;
    __pyx_L12_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2358
 *         target = None
 *         if s.sy == 'IDENT' and s.systring == 'as':
 *             s.next()             # <<<<<<<<<<<<<<
 *             target = p_starred_expr(s)
 *         return Nodes.WithStatNode, pos, {"manager": manager, "target": target, "is_async": is_async}
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2358, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":2359
 *         if s.sy == 'IDENT' and s.systring == 'as':
 *             s.next()
 *             target = p_starred_expr(s)             # <<<<<<<<<<<<<<
 *         return Nodes.WithStatNode, pos, {"manager": manager, "target": target, "is_async": is_async}
 * 
*/
      __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_starred_expr(__pyx_v_s); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":2357
 *         manager = p_test(s)
 *         target = None
 *         if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *             s.next()
 *             target = p_starred_expr(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":2360
 *             s.next()
 *             target = p_starred_expr(s)
 *         return Nodes.WithStatNode, pos, {"manager": manager, "target": target, "is_async": is_async}             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_WithStatNode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_manager, __pyx_v_manager) < (0)) __PYX_ERR(0, 2360, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_target, __pyx_v_target) < (0)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_is_async); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_is_async, __pyx_t_1) < (0)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7) != (0)) __PYX_ERR(0, 2360, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_pos);
    __Pyx_GIVEREF(__pyx_v_pos);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_pos) != (0)) __PYX_ERR(0, 2360, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 2360, __pyx_L1_error);
    __pyx_t_7 = 0;
    __pyx_t_5 = 0;
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2333
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_item(s: PyrexScanner, is_async: cython.bint) -> tuple:
 *     # In contrast to most parsing functions, this returns a tuple of
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v_condition);
  __Pyx_XDECREF(__pyx_v_manager);
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2363
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_template(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_with_template(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_templates = NULL;
  PyObject *__pyx_v_body_ctx = NULL;
  PyObject *__pyx_v_func_or_var = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_template", 0);

  /* "Cython/Compiler/Parsing.py":2365
 * @cython.cfunc
 * def p_with_template(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     templates = []
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2366
 * def p_with_template(s: PyrexScanner):
 *     pos = s.position()
 *     templates = []             # <<<<<<<<<<<<<<
 *     s.next()
 *     s.expect('[')
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_templates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2367
 *     pos = s.position()
 *     templates = []
 *     s.next()             # <<<<<<<<<<<<<<
 *     s.expect('[')
 *     templates.append(s.systring)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2368
 *     templates = []
 *     s.next()
 *     s.expect('[')             # <<<<<<<<<<<<<<
 *     templates.append(s.systring)
 *     s.next()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__26};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2369
 *     s.next()
 *     s.expect('[')
 *     templates.append(s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     while s.systring == ',':
*/
  __pyx_t_1 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_templates, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2370
 *     s.expect('[')
 *     templates.append(s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     while s.systring == ',':
 *         s.next()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2371
 *     templates.append(s.systring)
 *     s.next()
 *     while s.systring == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *         templates.append(s.systring)
*/
  while (1) {
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2371, __pyx_L1_error)
    if (!__pyx_t_5) break;

    /* "Cython/Compiler/Parsing.py":2372
 *     s.next()
 *     while s.systring == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *         templates.append(s.systring)
 *         s.next()
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2373
 *     while s.systring == ',':
 *         s.next()
 *         templates.append(s.systring)             # <<<<<<<<<<<<<<
 *         s.next()
 *     s.expect(']')
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_templates, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2373, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2374
 *         s.next()
 *         templates.append(s.systring)
 *         s.next()             # <<<<<<<<<<<<<<
 *     s.expect(']')
 *     if s.sy == ':':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2375
 *         templates.append(s.systring)
 *         s.next()
 *     s.expect(']')             # <<<<<<<<<<<<<<
 *     if s.sy == ':':
 *         s.next()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2376
 *         s.next()
 *     s.expect(']')
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_newline("Syntax error in template function declaration")
*/
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2376, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":2377
 *     s.expect(']')
 *     if s.sy == ':':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in template function declaration")
 *         s.expect_indent()
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2378
 *     if s.sy == ':':
 *         s.next()
 *         s.expect_newline("Syntax error in template function declaration")             # <<<<<<<<<<<<<<
 *         s.expect_indent()
 *         body_ctx = Ctx()
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_template_functio};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2379
 *         s.next()
 *         s.expect_newline("Syntax error in template function declaration")
 *         s.expect_indent()             # <<<<<<<<<<<<<<
 *         body_ctx = Ctx()
 *         body_ctx.templates = templates
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2379, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2380
 *         s.expect_newline("Syntax error in template function declaration")
 *         s.expect_indent()
 *         body_ctx = Ctx()             # <<<<<<<<<<<<<<
 *         body_ctx.templates = templates
 *         func_or_var = p_c_func_or_var_declaration(s, pos, body_ctx)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_body_ctx = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2381
 *         s.expect_indent()
 *         body_ctx = Ctx()
 *         body_ctx.templates = templates             # <<<<<<<<<<<<<<
 *         func_or_var = p_c_func_or_var_declaration(s, pos, body_ctx)
 *         s.expect_dedent()
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_body_ctx, __pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates) < (0)) __PYX_ERR(0, 2381, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2382
 *         body_ctx = Ctx()
 *         body_ctx.templates = templates
 *         func_or_var = p_c_func_or_var_declaration(s, pos, body_ctx)             # <<<<<<<<<<<<<<
 *         s.expect_dedent()
 *         return func_or_var
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(__pyx_v_s, __pyx_v_pos, __pyx_v_body_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_func_or_var = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2383
 *         body_ctx.templates = templates
 *         func_or_var = p_c_func_or_var_declaration(s, pos, body_ctx)
 *         s.expect_dedent()             # <<<<<<<<<<<<<<
 *         return func_or_var
 *     else:
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2384
 *         func_or_var = p_c_func_or_var_declaration(s, pos, body_ctx)
 *         s.expect_dedent()
 *         return func_or_var             # <<<<<<<<<<<<<<
 *     else:
 *         error(pos, "Syntax error in template function declaration")
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_func_or_var);
    __pyx_r = __pyx_v_func_or_var;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2376
 *         s.next()
 *     s.expect(']')
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_newline("Syntax error in template function declaration")
*/
  }

  /* "Cython/Compiler/Parsing.py":2386
 *         return func_or_var
 *     else:
 *         error(pos, "Syntax error in template function declaration")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_6 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_template_functio};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":2363
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_template(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_template", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_templates);
  __Pyx_XDECREF(__pyx_v_body_ctx);
  __Pyx_XDECREF(__pyx_v_func_or_var);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2389
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     #print "p_simple_statement:", s.sy, s.systring ###
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement *__pyx_optional_args) {
  int __pyx_v_first_statement = ((int)0);
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_from_import_statement __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_simple_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_first_statement = __pyx_optional_args->first_statement;
    }
  }

  /* "Cython/Compiler/Parsing.py":2392
 * def p_simple_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     #print "p_simple_statement:", s.sy, s.systring ###
 *     if s.sy == 'global':             # <<<<<<<<<<<<<<
 *         node = p_global_statement(s)
 *     elif s.sy == 'nonlocal':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_global, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2392, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2393
 *     #print "p_simple_statement:", s.sy, s.systring ###
 *     if s.sy == 'global':
 *         node = p_global_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'nonlocal':
 *         node = p_nonlocal_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_global_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2392
 * def p_simple_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     #print "p_simple_statement:", s.sy, s.systring ###
 *     if s.sy == 'global':             # <<<<<<<<<<<<<<
 *         node = p_global_statement(s)
 *     elif s.sy == 'nonlocal':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2394
 *     if s.sy == 'global':
 *         node = p_global_statement(s)
 *     elif s.sy == 'nonlocal':             # <<<<<<<<<<<<<<
 *         node = p_nonlocal_statement(s)
 *     elif s.sy == 'print':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_nonlocal, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2394, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2395
 *         node = p_global_statement(s)
 *     elif s.sy == 'nonlocal':
 *         node = p_nonlocal_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'print':
 *         node = p_print_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_nonlocal_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2394
 *     if s.sy == 'global':
 *         node = p_global_statement(s)
 *     elif s.sy == 'nonlocal':             # <<<<<<<<<<<<<<
 *         node = p_nonlocal_statement(s)
 *     elif s.sy == 'print':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2396
 *     elif s.sy == 'nonlocal':
 *         node = p_nonlocal_statement(s)
 *     elif s.sy == 'print':             # <<<<<<<<<<<<<<
 *         node = p_print_statement(s)
 *     elif s.sy == 'exec':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_print, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2396, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2397
 *         node = p_nonlocal_statement(s)
 *     elif s.sy == 'print':
 *         node = p_print_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'exec':
 *         node = p_exec_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_print_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2396
 *     elif s.sy == 'nonlocal':
 *         node = p_nonlocal_statement(s)
 *     elif s.sy == 'print':             # <<<<<<<<<<<<<<
 *         node = p_print_statement(s)
 *     elif s.sy == 'exec':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2398
 *     elif s.sy == 'print':
 *         node = p_print_statement(s)
 *     elif s.sy == 'exec':             # <<<<<<<<<<<<<<
 *         node = p_exec_statement(s)
 *     elif s.sy == 'del':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_exec, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2398, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2399
 *         node = p_print_statement(s)
 *     elif s.sy == 'exec':
 *         node = p_exec_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'del':
 *         node = p_del_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_exec_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2398
 *     elif s.sy == 'print':
 *         node = p_print_statement(s)
 *     elif s.sy == 'exec':             # <<<<<<<<<<<<<<
 *         node = p_exec_statement(s)
 *     elif s.sy == 'del':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2400
 *     elif s.sy == 'exec':
 *         node = p_exec_statement(s)
 *     elif s.sy == 'del':             # <<<<<<<<<<<<<<
 *         node = p_del_statement(s)
 *     elif s.sy == 'break':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_del, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2400, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2401
 *         node = p_exec_statement(s)
 *     elif s.sy == 'del':
 *         node = p_del_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'break':
 *         node = p_break_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_del_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2400
 *     elif s.sy == 'exec':
 *         node = p_exec_statement(s)
 *     elif s.sy == 'del':             # <<<<<<<<<<<<<<
 *         node = p_del_statement(s)
 *     elif s.sy == 'break':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2402
 *     elif s.sy == 'del':
 *         node = p_del_statement(s)
 *     elif s.sy == 'break':             # <<<<<<<<<<<<<<
 *         node = p_break_statement(s)
 *     elif s.sy == 'continue':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_break, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2402, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2403
 *         node = p_del_statement(s)
 *     elif s.sy == 'break':
 *         node = p_break_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'continue':
 *         node = p_continue_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_break_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2402
 *     elif s.sy == 'del':
 *         node = p_del_statement(s)
 *     elif s.sy == 'break':             # <<<<<<<<<<<<<<
 *         node = p_break_statement(s)
 *     elif s.sy == 'continue':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2404
 *     elif s.sy == 'break':
 *         node = p_break_statement(s)
 *     elif s.sy == 'continue':             # <<<<<<<<<<<<<<
 *         node = p_continue_statement(s)
 *     elif s.sy == 'return':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_continue, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2404, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2405
 *         node = p_break_statement(s)
 *     elif s.sy == 'continue':
 *         node = p_continue_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'return':
 *         node = p_return_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_continue_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2404
 *     elif s.sy == 'break':
 *         node = p_break_statement(s)
 *     elif s.sy == 'continue':             # <<<<<<<<<<<<<<
 *         node = p_continue_statement(s)
 *     elif s.sy == 'return':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2406
 *     elif s.sy == 'continue':
 *         node = p_continue_statement(s)
 *     elif s.sy == 'return':             # <<<<<<<<<<<<<<
 *         node = p_return_statement(s)
 *     elif s.sy == 'raise':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_return, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2406, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2407
 *         node = p_continue_statement(s)
 *     elif s.sy == 'return':
 *         node = p_return_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'raise':
 *         node = p_raise_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_return_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2406
 *     elif s.sy == 'continue':
 *         node = p_continue_statement(s)
 *     elif s.sy == 'return':             # <<<<<<<<<<<<<<
 *         node = p_return_statement(s)
 *     elif s.sy == 'raise':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2408
 *     elif s.sy == 'return':
 *         node = p_return_statement(s)
 *     elif s.sy == 'raise':             # <<<<<<<<<<<<<<
 *         node = p_raise_statement(s)
 *     elif s.sy in ('import', 'cimport'):
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_raise, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2408, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2409
 *         node = p_return_statement(s)
 *     elif s.sy == 'raise':
 *         node = p_raise_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy in ('import', 'cimport'):
 *         node = p_import_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_raise_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2408
 *     elif s.sy == 'return':
 *         node = p_return_statement(s)
 *     elif s.sy == 'raise':             # <<<<<<<<<<<<<<
 *         node = p_raise_statement(s)
 *     elif s.sy in ('import', 'cimport'):
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2410
 *     elif s.sy == 'raise':
 *         node = p_raise_statement(s)
 *     elif s.sy in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         node = p_import_statement(s)
 *     elif s.sy == 'from':
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_3 = __pyx_v_s->sy;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_import, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2410, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_cimport, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2410, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_1;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2411
 *         node = p_raise_statement(s)
 *     elif s.sy in ('import', 'cimport'):
 *         node = p_import_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'from':
 *         node = p_from_import_statement(s, first_statement = first_statement)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_import_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2410
 *     elif s.sy == 'raise':
 *         node = p_raise_statement(s)
 *     elif s.sy in ('import', 'cimport'):             # <<<<<<<<<<<<<<
 *         node = p_import_statement(s)
 *     elif s.sy == 'from':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2412
 *     elif s.sy in ('import', 'cimport'):
 *         node = p_import_statement(s)
 *     elif s.sy == 'from':             # <<<<<<<<<<<<<<
 *         node = p_from_import_statement(s, first_statement = first_statement)
 *     elif s.sy == 'yield':
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_from, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2412, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2413
 *         node = p_import_statement(s)
 *     elif s.sy == 'from':
 *         node = p_from_import_statement(s, first_statement = first_statement)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'yield':
 *         node = p_yield_statement(s)
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.first_statement = __pyx_v_first_statement;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_from_import_statement(__pyx_v_s, &__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2412
 *     elif s.sy in ('import', 'cimport'):
 *         node = p_import_statement(s)
 *     elif s.sy == 'from':             # <<<<<<<<<<<<<<
 *         node = p_from_import_statement(s, first_statement = first_statement)
 *     elif s.sy == 'yield':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2414
 *     elif s.sy == 'from':
 *         node = p_from_import_statement(s, first_statement = first_statement)
 *     elif s.sy == 'yield':             # <<<<<<<<<<<<<<
 *         node = p_yield_statement(s)
 *     elif s.sy == 'assert':
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_yield, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2414, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2415
 *         node = p_from_import_statement(s, first_statement = first_statement)
 *     elif s.sy == 'yield':
 *         node = p_yield_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'assert':
 *         node = p_assert_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_yield_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2414
 *     elif s.sy == 'from':
 *         node = p_from_import_statement(s, first_statement = first_statement)
 *     elif s.sy == 'yield':             # <<<<<<<<<<<<<<
 *         node = p_yield_statement(s)
 *     elif s.sy == 'assert':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2416
 *     elif s.sy == 'yield':
 *         node = p_yield_statement(s)
 *     elif s.sy == 'assert':             # <<<<<<<<<<<<<<
 *         node = p_assert_statement(s)
 *     elif s.sy == 'pass':
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_assert, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2416, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2417
 *         node = p_yield_statement(s)
 *     elif s.sy == 'assert':
 *         node = p_assert_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'pass':
 *         node = p_pass_statement(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_assert_statement(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2416
 *     elif s.sy == 'yield':
 *         node = p_yield_statement(s)
 *     elif s.sy == 'assert':             # <<<<<<<<<<<<<<
 *         node = p_assert_statement(s)
 *     elif s.sy == 'pass':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2418
 *     elif s.sy == 'assert':
 *         node = p_assert_statement(s)
 *     elif s.sy == 'pass':             # <<<<<<<<<<<<<<
 *         node = p_pass_statement(s)
 *     else:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2418, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2419
 *         node = p_assert_statement(s)
 *     elif s.sy == 'pass':
 *         node = p_pass_statement(s)             # <<<<<<<<<<<<<<
 *     else:
 *         node = p_expression_or_assignment(s)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(__pyx_v_s, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2418
 *     elif s.sy == 'assert':
 *         node = p_assert_statement(s)
 *     elif s.sy == 'pass':             # <<<<<<<<<<<<<<
 *         node = p_pass_statement(s)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2421
 *         node = p_pass_statement(s)
 *     else:
 *         node = p_expression_or_assignment(s)             # <<<<<<<<<<<<<<
 *     return node
 * 
*/
  /*else*/ {
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_expression_or_assignment(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_node = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2422
 *     else:
 *         node = p_expression_or_assignment(s)
 *     return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2389
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement(s: PyrexScanner, first_statement: cython.bint = 0):
 *     #print "p_simple_statement:", s.sy, s.systring ###
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_simple_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2425
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of simple statements on one line
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_ctx, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement_list *__pyx_optional_args) {
  int __pyx_v_first_statement = ((int)0);
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_stats = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_simple_statement_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_first_statement = __pyx_optional_args->first_statement;
    }
  }

  /* "Cython/Compiler/Parsing.py":2429
 *     # Parse a series of simple statements on one line
 *     # separated by semicolons.
 *     stat = p_simple_statement(s, first_statement = first_statement)             # <<<<<<<<<<<<<<
 *     pos = stat.pos
 *     stats = []
*/
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.first_statement = __pyx_v_first_statement;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement(__pyx_v_s, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_stat = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2430
 *     # separated by semicolons.
 *     stat = p_simple_statement(s, first_statement = first_statement)
 *     pos = stat.pos             # <<<<<<<<<<<<<<
 *     stats = []
 *     if not isinstance(stat, Nodes.PassStatNode):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2431
 *     stat = p_simple_statement(s, first_statement = first_statement)
 *     pos = stat.pos
 *     stats = []             # <<<<<<<<<<<<<<
 *     if not isinstance(stat, Nodes.PassStatNode):
 *         stats.append(stat)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2432
 *     pos = stat.pos
 *     stats = []
 *     if not isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *         stats.append(stat)
 *     while s.sy == ';':
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_PassStatNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 2432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2433
 *     stats = []
 *     if not isinstance(stat, Nodes.PassStatNode):
 *         stats.append(stat)             # <<<<<<<<<<<<<<
 *     while s.sy == ';':
 *         #print "p_simple_statement_list: maybe more to follow" ###
*/
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_stats, __pyx_v_stat); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2433, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2432
 *     pos = stat.pos
 *     stats = []
 *     if not isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *         stats.append(stat)
 *     while s.sy == ';':
*/
  }

  /* "Cython/Compiler/Parsing.py":2434
 *     if not isinstance(stat, Nodes.PassStatNode):
 *         stats.append(stat)
 *     while s.sy == ';':             # <<<<<<<<<<<<<<
 *         #print "p_simple_statement_list: maybe more to follow" ###
 *         s.next()
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__43, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2434, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":2436
 *     while s.sy == ';':
 *         #print "p_simple_statement_list: maybe more to follow" ###
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy in ('NEWLINE', 'EOF'):
 *             break
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2437
 *         #print "p_simple_statement_list: maybe more to follow" ###
 *         s.next()
 *         if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *             break
 *         stat = p_simple_statement(s, first_statement = first_statement)
*/
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_8 = __pyx_v_s->sy;
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2437, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2437, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_3;
    __pyx_L7_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_3 = __pyx_t_4;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2438
 *         s.next()
 *         if s.sy in ('NEWLINE', 'EOF'):
 *             break             # <<<<<<<<<<<<<<
 *         stat = p_simple_statement(s, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):
*/
      goto __pyx_L5_break;

      /* "Cython/Compiler/Parsing.py":2437
 *         #print "p_simple_statement_list: maybe more to follow" ###
 *         s.next()
 *         if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *             break
 *         stat = p_simple_statement(s, first_statement = first_statement)
*/
    }

    /* "Cython/Compiler/Parsing.py":2439
 *         if s.sy in ('NEWLINE', 'EOF'):
 *             break
 *         stat = p_simple_statement(s, first_statement = first_statement)             # <<<<<<<<<<<<<<
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue
*/
    __pyx_t_2.__pyx_n = 1;
    __pyx_t_2.first_statement = __pyx_v_first_statement;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement(__pyx_v_s, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_stat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2440
 *             break
 *         stat = p_simple_statement(s, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *             continue
 *         stats.append(stat)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_PassStatNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 2440, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2441
 *         stat = p_simple_statement(s, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue             # <<<<<<<<<<<<<<
 *         stats.append(stat)
 *         first_statement = False
*/
      goto __pyx_L4_continue;

      /* "Cython/Compiler/Parsing.py":2440
 *             break
 *         stat = p_simple_statement(s, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *             continue
 *         stats.append(stat)
*/
    }

    /* "Cython/Compiler/Parsing.py":2442
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue
 *         stats.append(stat)             # <<<<<<<<<<<<<<
 *         first_statement = False
 * 
*/
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_stats, __pyx_v_stat); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2442, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2443
 *             continue
 *         stats.append(stat)
 *         first_statement = False             # <<<<<<<<<<<<<<
 * 
 *     if not stats:
*/
    __pyx_v_first_statement = 0;
    __pyx_L4_continue:;
  }
  __pyx_L5_break:;

  /* "Cython/Compiler/Parsing.py":2445
 *         first_statement = False
 * 
 *     if not stats:             # <<<<<<<<<<<<<<
 *         stat = Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_stats);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 2445, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2446
 * 
 *     if not stats:
 *         stat = Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 *     elif len(stats) == 1:
 *         stat = stats[0]
*/
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_stat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2445
 *         first_statement = False
 * 
 *     if not stats:             # <<<<<<<<<<<<<<
 *         stat = Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
*/
    goto __pyx_L10;
  }

  /* "Cython/Compiler/Parsing.py":2447
 *     if not stats:
 *         stat = Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:             # <<<<<<<<<<<<<<
 *         stat = stats[0]
 *     else:
*/
  __pyx_t_9 = __Pyx_PyList_GET_SIZE(__pyx_v_stats); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2447, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_9 == 1);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2448
 *         stat = Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
 *         stat = stats[0]             # <<<<<<<<<<<<<<
 *     else:
 *         stat = Nodes.StatListNode(pos, stats = stats)
*/
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_stat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2447
 *     if not stats:
 *         stat = Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:             # <<<<<<<<<<<<<<
 *         stat = stats[0]
 *     else:
*/
    goto __pyx_L10;
  }

  /* "Cython/Compiler/Parsing.py":2450
 *         stat = stats[0]
 *     else:
 *         stat = Nodes.StatListNode(pos, stats = stats)             # <<<<<<<<<<<<<<
 * 
 *     if s.sy not in ('NEWLINE', 'EOF'):
*/
  /*else*/ {
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stats, __pyx_v_stats, __pyx_t_10, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2450, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_StatListNode, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_stat, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L10:;

  /* "Cython/Compiler/Parsing.py":2452
 *         stat = Nodes.StatListNode(pos, stats = stats)
 * 
 *     if s.sy not in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_8 = __pyx_v_s->sy;
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2452, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2452, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_3;
  __pyx_L12_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_3 = __pyx_t_4;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2454
 *     if s.sy not in ('NEWLINE', 'EOF'):
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *             if stat.expr.is_name and stat.expr.name == 'cdef':
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_ExprStatNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 2454, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2455
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):
 *             if stat.expr.is_name and stat.expr.name == 'cdef':             # <<<<<<<<<<<<<<
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)
 *     s.expect_newline("Syntax error in simple statement list")
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_4) {
      } else {
        __pyx_t_3 = __pyx_t_4;
        goto __pyx_L16_bool_binop_done;
      }
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_stat, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_cdef, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2455, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = __pyx_t_4;
      __pyx_L16_bool_binop_done:;
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2456
 *         if isinstance(stat, Nodes.ExprStatNode):
 *             if stat.expr.is_name and stat.expr.name == 'cdef':
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)             # <<<<<<<<<<<<<<
 *     s.expect_newline("Syntax error in simple statement list")
 * 
*/
        __pyx_t_10 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_The_cdef_keyword_is_only_allowed, __pyx_v_pos};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2456, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2455
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):
 *             if stat.expr.is_name and stat.expr.name == 'cdef':             # <<<<<<<<<<<<<<
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)
 *     s.expect_newline("Syntax error in simple statement list")
*/
      }

      /* "Cython/Compiler/Parsing.py":2454
 *     if s.sy not in ('NEWLINE', 'EOF'):
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *             if stat.expr.is_name and stat.expr.name == 'cdef':
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)
*/
    }

    /* "Cython/Compiler/Parsing.py":2452
 *         stat = Nodes.StatListNode(pos, stats = stats)
 * 
 *     if s.sy not in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *         # provide a better error message for users who accidentally write Cython code in .py files
 *         if isinstance(stat, Nodes.ExprStatNode):
*/
  }

  /* "Cython/Compiler/Parsing.py":2457
 *             if stat.expr.is_name and stat.expr.name == 'cdef':
 *                 s.error("The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)", pos)
 *     s.expect_newline("Syntax error in simple statement list")             # <<<<<<<<<<<<<<
 * 
 *     return stat
*/
  __pyx_t_10 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_simple_statement};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2459
 *     s.expect_newline("Syntax error in simple statement list")
 * 
 *     return stat             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stat);
  __pyx_r = __pyx_v_stat;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2425
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_simple_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of simple statements on one line
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_simple_statement_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_stats);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2462
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_compile_time_expr(s: PyrexScanner):
 *     old = s.compile_time_expr
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_compile_time_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_v_old;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_compile_time_expr", 0);

  /* "Cython/Compiler/Parsing.py":2464
 * @cython.cfunc
 * def p_compile_time_expr(s: PyrexScanner):
 *     old = s.compile_time_expr             # <<<<<<<<<<<<<<
 *     s.compile_time_expr = 1
 *     expr = p_testlist(s)
*/
  __pyx_t_1 = __pyx_v_s->compile_time_expr;
  __pyx_v_old = __pyx_t_1;

  /* "Cython/Compiler/Parsing.py":2465
 * def p_compile_time_expr(s: PyrexScanner):
 *     old = s.compile_time_expr
 *     s.compile_time_expr = 1             # <<<<<<<<<<<<<<
 *     expr = p_testlist(s)
 *     s.compile_time_expr = old
*/
  __pyx_v_s->compile_time_expr = 1;

  /* "Cython/Compiler/Parsing.py":2466
 *     old = s.compile_time_expr
 *     s.compile_time_expr = 1
 *     expr = p_testlist(s)             # <<<<<<<<<<<<<<
 *     s.compile_time_expr = old
 *     return expr
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_expr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2467
 *     s.compile_time_expr = 1
 *     expr = p_testlist(s)
 *     s.compile_time_expr = old             # <<<<<<<<<<<<<<
 *     return expr
 * 
*/
  __pyx_v_s->compile_time_expr = __pyx_v_old;

  /* "Cython/Compiler/Parsing.py":2468
 *     expr = p_testlist(s)
 *     s.compile_time_expr = old
 *     return expr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_expr);
  __pyx_r = __pyx_v_expr;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2462
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_compile_time_expr(s: PyrexScanner):
 *     old = s.compile_time_expr
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_compile_time_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2471
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_DEF_statement(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_DEF_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_denv = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_DEF_statement", 0);

  /* "Cython/Compiler/Parsing.py":2473
 * @cython.cfunc
 * def p_DEF_statement(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     denv = s.compile_time_env
 *     s.next()  # 'DEF'
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2474
 * def p_DEF_statement(s: PyrexScanner):
 *     pos = s.position()
 *     denv = s.compile_time_env             # <<<<<<<<<<<<<<
 *     s.next()  # 'DEF'
 *     name = p_ident(s)
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s->compile_time_env);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_denv = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2475
 *     pos = s.position()
 *     denv = s.compile_time_env
 *     s.next()  # 'DEF'             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     s.expect('=')
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2476
 *     denv = s.compile_time_env
 *     s.next()  # 'DEF'
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     s.expect('=')
 *     expr = p_compile_time_expr(s)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2477
 *     s.next()  # 'DEF'
 *     name = p_ident(s)
 *     s.expect('=')             # <<<<<<<<<<<<<<
 *     expr = p_compile_time_expr(s)
 *     if s.compile_time_eval:
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__29};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2478
 *     name = p_ident(s)
 *     s.expect('=')
 *     expr = p_compile_time_expr(s)             # <<<<<<<<<<<<<<
 *     if s.compile_time_eval:
 *         value = expr.compile_time_value(denv)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_compile_time_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2479
 *     s.expect('=')
 *     expr = p_compile_time_expr(s)
 *     if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *         value = expr.compile_time_value(denv)
 *         #print "p_DEF_statement: %s = %r" % (name, value) ###
*/
  if (__pyx_v_s->compile_time_eval) {

    /* "Cython/Compiler/Parsing.py":2480
 *     expr = p_compile_time_expr(s)
 *     if s.compile_time_eval:
 *         value = expr.compile_time_value(denv)             # <<<<<<<<<<<<<<
 *         #print "p_DEF_statement: %s = %r" % (name, value) ###
 *         denv.declare(name, value)
*/
    __pyx_t_2 = __pyx_v_expr;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_denv)};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_compile_time_value, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2482
 *         value = expr.compile_time_value(denv)
 *         #print "p_DEF_statement: %s = %r" % (name, value) ###
 *         denv.declare(name, value)             # <<<<<<<<<<<<<<
 *     s.expect_newline("Expected a newline", ignore_semicolon=True)
 *     return Nodes.PassStatNode(pos)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_denv);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_value};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_declare, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2479
 *     s.expect('=')
 *     expr = p_compile_time_expr(s)
 *     if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *         value = expr.compile_time_value(denv)
 *         #print "p_DEF_statement: %s = %r" % (name, value) ###
*/
  }

  /* "Cython/Compiler/Parsing.py":2483
 *         #print "p_DEF_statement: %s = %r" % (name, value) ###
 *         denv.declare(name, value)
 *     s.expect_newline("Expected a newline", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *     return Nodes.PassStatNode(pos)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2484
 *         denv.declare(name, value)
 *     s.expect_newline("Expected a newline", ignore_semicolon=True)
 *     return Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2471
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_DEF_statement(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_DEF_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF((PyObject *)__pyx_v_denv);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2487
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_IF_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_IF_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_saved_eval;
  PyObject *__pyx_v_current_eval = NULL;
  struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *__pyx_v_denv = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_IF_statement", 0);

  /* "Cython/Compiler/Parsing.py":2489
 * @cython.cfunc
 * def p_IF_statement(s: PyrexScanner, ctx):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     saved_eval = s.compile_time_eval
 *     current_eval = saved_eval
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2490
 * def p_IF_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
 *     saved_eval = s.compile_time_eval             # <<<<<<<<<<<<<<
 *     current_eval = saved_eval
 *     denv = s.compile_time_env
*/
  __pyx_t_2 = __pyx_v_s->compile_time_eval;
  __pyx_v_saved_eval = __pyx_t_2;

  /* "Cython/Compiler/Parsing.py":2491
 *     pos = s.position()
 *     saved_eval = s.compile_time_eval
 *     current_eval = saved_eval             # <<<<<<<<<<<<<<
 *     denv = s.compile_time_env
 *     result = None
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_saved_eval); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_current_eval = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2492
 *     saved_eval = s.compile_time_eval
 *     current_eval = saved_eval
 *     denv = s.compile_time_env             # <<<<<<<<<<<<<<
 *     result = None
 *     while 1:
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s->compile_time_env);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_denv = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2493
 *     current_eval = saved_eval
 *     denv = s.compile_time_env
 *     result = None             # <<<<<<<<<<<<<<
 *     while 1:
 *         s.next()  # 'IF' or 'ELIF'
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_result = Py_None;

  /* "Cython/Compiler/Parsing.py":2494
 *     denv = s.compile_time_env
 *     result = None
 *     while 1:             # <<<<<<<<<<<<<<
 *         s.next()  # 'IF' or 'ELIF'
 *         expr = p_compile_time_expr(s)
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":2495
 *     result = None
 *     while 1:
 *         s.next()  # 'IF' or 'ELIF'             # <<<<<<<<<<<<<<
 *         expr = p_compile_time_expr(s)
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2496
 *     while 1:
 *         s.next()  # 'IF' or 'ELIF'
 *         expr = p_compile_time_expr(s)             # <<<<<<<<<<<<<<
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))
 *         body = p_suite(s, ctx)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_compile_time_expr(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_expr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2497
 *         s.next()  # 'IF' or 'ELIF'
 *         expr = p_compile_time_expr(s)
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))             # <<<<<<<<<<<<<<
 *         body = p_suite(s, ctx)
 *         if s.compile_time_eval:
*/
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_current_eval); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2497, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = __pyx_v_expr;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_denv)};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_compile_time_value, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2497, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (!(!__pyx_t_5));
    __pyx_L5_bool_binop_done:;
    __pyx_v_s->compile_time_eval = __pyx_t_2;

    /* "Cython/Compiler/Parsing.py":2498
 *         expr = p_compile_time_expr(s)
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))
 *         body = p_suite(s, ctx)             # <<<<<<<<<<<<<<
 *         if s.compile_time_eval:
 *             result = body
*/
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.ctx = __pyx_v_ctx;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_body, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2499
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))
 *         body = p_suite(s, ctx)
 *         if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *             result = body
 *             current_eval = 0
*/
    if (__pyx_v_s->compile_time_eval) {

      /* "Cython/Compiler/Parsing.py":2500
 *         body = p_suite(s, ctx)
 *         if s.compile_time_eval:
 *             result = body             # <<<<<<<<<<<<<<
 *             current_eval = 0
 *         if s.sy != 'ELIF':
*/
      __Pyx_INCREF(__pyx_v_body);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_v_body);

      /* "Cython/Compiler/Parsing.py":2501
 *         if s.compile_time_eval:
 *             result = body
 *             current_eval = 0             # <<<<<<<<<<<<<<
 *         if s.sy != 'ELIF':
 *             break
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_current_eval, __pyx_mstate_global->__pyx_int_0);

      /* "Cython/Compiler/Parsing.py":2499
 *         s.compile_time_eval = current_eval and bool(expr.compile_time_value(denv))
 *         body = p_suite(s, ctx)
 *         if s.compile_time_eval:             # <<<<<<<<<<<<<<
 *             result = body
 *             current_eval = 0
*/
    }

    /* "Cython/Compiler/Parsing.py":2502
 *             result = body
 *             current_eval = 0
 *         if s.sy != 'ELIF':             # <<<<<<<<<<<<<<
 *             break
 *     if s.sy == 'ELSE':
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_ELIF, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2502, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2503
 *             current_eval = 0
 *         if s.sy != 'ELIF':
 *             break             # <<<<<<<<<<<<<<
 *     if s.sy == 'ELSE':
 *         s.next()
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":2502
 *             result = body
 *             current_eval = 0
 *         if s.sy != 'ELIF':             # <<<<<<<<<<<<<<
 *             break
 *     if s.sy == 'ELSE':
*/
    }
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":2504
 *         if s.sy != 'ELIF':
 *             break
 *     if s.sy == 'ELSE':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.compile_time_eval = current_eval
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_ELSE, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2504, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2505
 *             break
 *     if s.sy == 'ELSE':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.compile_time_eval = current_eval
 *         body = p_suite(s, ctx)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2506
 *     if s.sy == 'ELSE':
 *         s.next()
 *         s.compile_time_eval = current_eval             # <<<<<<<<<<<<<<
 *         body = p_suite(s, ctx)
 *         if current_eval:
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_current_eval); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2506, __pyx_L1_error)
    __pyx_v_s->compile_time_eval = __pyx_t_2;

    /* "Cython/Compiler/Parsing.py":2507
 *         s.next()
 *         s.compile_time_eval = current_eval
 *         body = p_suite(s, ctx)             # <<<<<<<<<<<<<<
 *         if current_eval:
 *             result = body
*/
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.ctx = __pyx_v_ctx;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_body, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2508
 *         s.compile_time_eval = current_eval
 *         body = p_suite(s, ctx)
 *         if current_eval:             # <<<<<<<<<<<<<<
 *             result = body
 *     if not result:
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_current_eval); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2508, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2509
 *         body = p_suite(s, ctx)
 *         if current_eval:
 *             result = body             # <<<<<<<<<<<<<<
 *     if not result:
 *         result = Nodes.PassStatNode(pos)
*/
      __Pyx_INCREF(__pyx_v_body);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_v_body);

      /* "Cython/Compiler/Parsing.py":2508
 *         s.compile_time_eval = current_eval
 *         body = p_suite(s, ctx)
 *         if current_eval:             # <<<<<<<<<<<<<<
 *             result = body
 *     if not result:
*/
    }

    /* "Cython/Compiler/Parsing.py":2504
 *         if s.sy != 'ELIF':
 *             break
 *     if s.sy == 'ELSE':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.compile_time_eval = current_eval
*/
  }

  /* "Cython/Compiler/Parsing.py":2510
 *         if current_eval:
 *             result = body
 *     if not result:             # <<<<<<<<<<<<<<
 *         result = Nodes.PassStatNode(pos)
 *     s.compile_time_eval = saved_eval
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2510, __pyx_L1_error)
  __pyx_t_5 = (!__pyx_t_2);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":2511
 *             result = body
 *     if not result:
 *         result = Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 *     s.compile_time_eval = saved_eval
 *     return result
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2510
 *         if current_eval:
 *             result = body
 *     if not result:             # <<<<<<<<<<<<<<
 *         result = Nodes.PassStatNode(pos)
 *     s.compile_time_eval = saved_eval
*/
  }

  /* "Cython/Compiler/Parsing.py":2512
 *     if not result:
 *         result = Nodes.PassStatNode(pos)
 *     s.compile_time_eval = saved_eval             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  __pyx_v_s->compile_time_eval = __pyx_v_saved_eval;

  /* "Cython/Compiler/Parsing.py":2513
 *         result = Nodes.PassStatNode(pos)
 *     s.compile_time_eval = saved_eval
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2487
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_IF_statement(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_IF_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_current_eval);
  __Pyx_XDECREF((PyObject *)__pyx_v_denv);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2516
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):
 *     cdef_flag: cython.bint = ctx.cdef_flag
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2517
 * 
 * @cython.cfunc
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):             # <<<<<<<<<<<<<<
 *     cdef_flag: cython.bint = ctx.cdef_flag
 *     pos = s.position()
*/
  int __pyx_v_first_statement = ((int)0);
  int __pyx_v_cdef_flag;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_decorators = NULL;
  int __pyx_v_overridable;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_v_ident_name = NULL;
  PyObject *__pyx_v_ident_pos = NULL;
  PyObject *__pyx_v_match_statement = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_pass_statement __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement __pyx_t_12;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_simple_statement_list __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_first_statement = __pyx_optional_args->first_statement;
    }
  }

  /* "Cython/Compiler/Parsing.py":2518
 * @cython.cfunc
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):
 *     cdef_flag: cython.bint = ctx.cdef_flag             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     decorators = None
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_cdef_flag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cdef_flag = __pyx_t_2;

  /* "Cython/Compiler/Parsing.py":2519
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):
 *     cdef_flag: cython.bint = ctx.cdef_flag
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     decorators = None
 *     if s.sy == 'ctypedef':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2520
 *     cdef_flag: cython.bint = ctx.cdef_flag
 *     pos = s.position()
 *     decorators = None             # <<<<<<<<<<<<<<
 *     if s.sy == 'ctypedef':
 *         if ctx.level not in ('module', 'module_pxd'):
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_decorators = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":2521
 *     pos = s.position()
 *     decorators = None
 *     if s.sy == 'ctypedef':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             s.error("ctypedef statement not allowed here")
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_ctypedef, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2521, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2522
 *     decorators = None
 *     if s.sy == 'ctypedef':
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             s.error("ctypedef statement not allowed here")
 *         #if ctx.api:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2522, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2522, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_2;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2523
 *     if s.sy == 'ctypedef':
 *         if ctx.level not in ('module', 'module_pxd'):
 *             s.error("ctypedef statement not allowed here")             # <<<<<<<<<<<<<<
 *         #if ctx.api:
 *         #    error(pos, "'api' not allowed with 'ctypedef'")
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_ctypedef_statement_not_allowed_h};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2523, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2522
 *     decorators = None
 *     if s.sy == 'ctypedef':
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             s.error("ctypedef statement not allowed here")
 *         #if ctx.api:
*/
    }

    /* "Cython/Compiler/Parsing.py":2526
 *         #if ctx.api:
 *         #    error(pos, "'api' not allowed with 'ctypedef'")
 *         return p_ctypedef_statement(s, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'DEF':
 *         # We used to dep-warn about this but removed the warning again since
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ctypedef_statement(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2521
 *     pos = s.position()
 *     decorators = None
 *     if s.sy == 'ctypedef':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             s.error("ctypedef statement not allowed here")
*/
  }

  /* "Cython/Compiler/Parsing.py":2527
 *         #    error(pos, "'api' not allowed with 'ctypedef'")
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'DEF':             # <<<<<<<<<<<<<<
 *         # We used to dep-warn about this but removed the warning again since
 *         # we don't have a good answer yet for all use cases.
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEF, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2527, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2530
 *         # We used to dep-warn about this but removed the warning again since
 *         # we don't have a good answer yet for all use cases.
 *         if s.context.compiler_directives.get("warn.deprecated.DEF", False):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'DEF' statement  will be removed in a future Cython version. "
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_compiler_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[9], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2530, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2531
 *         # we don't have a good answer yet for all use cases.
 *         if s.context.compiler_directives.get("warn.deprecated.DEF", False):
 *             warning(pos,             # <<<<<<<<<<<<<<
 *                     "The 'DEF' statement  will be removed in a future Cython version. "
 *                     "Consider using global variables, constants, and in-place literals instead. "
*/
      __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
      __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_The_DEF_statement_will_be_remove};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_int_1, __pyx_t_7, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 2531, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2530
 *         # We used to dep-warn about this but removed the warning again since
 *         # we don't have a good answer yet for all use cases.
 *         if s.context.compiler_directives.get("warn.deprecated.DEF", False):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'DEF' statement  will be removed in a future Cython version. "
*/
    }

    /* "Cython/Compiler/Parsing.py":2535
 *                     "Consider using global variables, constants, and in-place literals instead. "
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_DEF_statement(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IF':
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_DEF_statement(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2527
 *         #    error(pos, "'api' not allowed with 'ctypedef'")
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'DEF':             # <<<<<<<<<<<<<<
 *         # We used to dep-warn about this but removed the warning again since
 *         # we don't have a good answer yet for all use cases.
*/
  }

  /* "Cython/Compiler/Parsing.py":2536
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_DEF_statement(s)
 *     elif s.sy == 'IF':             # <<<<<<<<<<<<<<
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):
 *             warning(pos,
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IF, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2536, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2537
 *         return p_DEF_statement(s)
 *     elif s.sy == 'IF':
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'IF' statement is deprecated and will be removed in a future Cython version. "
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_compiler_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[10], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2537, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2538
 *     elif s.sy == 'IF':
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):
 *             warning(pos,             # <<<<<<<<<<<<<<
 *                     "The 'IF' statement is deprecated and will be removed in a future Cython version. "
 *                     "Consider using runtime conditions or C macros instead. "
*/
      __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_The_IF_statement_is_deprecated_a};
        __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2538, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_int_1, __pyx_t_4, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 2538, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2538, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2537
 *         return p_DEF_statement(s)
 *     elif s.sy == 'IF':
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'IF' statement is deprecated and will be removed in a future Cython version. "
*/
    }

    /* "Cython/Compiler/Parsing.py":2542
 *                     "Consider using runtime conditions or C macros instead. "
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_IF_statement(s, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == '@':
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_IF_statement(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2536
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_DEF_statement(s)
 *     elif s.sy == 'IF':             # <<<<<<<<<<<<<<
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):
 *             warning(pos,
*/
  }

  /* "Cython/Compiler/Parsing.py":2543
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_IF_statement(s, ctx)
 *     elif s.sy == '@':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):
 *             s.error('decorator not allowed here')
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__16, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2543, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2544
 *         return p_IF_statement(s, ctx)
 *     elif s.sy == '@':
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):             # <<<<<<<<<<<<<<
 *             s.error('decorator not allowed here')
 *         s.level = ctx.level
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_class_2, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_function, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_property, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_other, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2544, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_2;
    __pyx_L10_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_3;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2545
 *     elif s.sy == '@':
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):
 *             s.error('decorator not allowed here')             # <<<<<<<<<<<<<<
 *         s.level = ctx.level
 *         decorators = p_decorators(s)
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_decorator_not_allowed_here};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2544
 *         return p_IF_statement(s, ctx)
 *     elif s.sy == '@':
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):             # <<<<<<<<<<<<<<
 *             s.error('decorator not allowed here')
 *         s.level = ctx.level
*/
    }

    /* "Cython/Compiler/Parsing.py":2546
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):
 *             s.error('decorator not allowed here')
 *         s.level = ctx.level             # <<<<<<<<<<<<<<
 *         decorators = p_decorators(s)
 *         if not ctx.allow_struct_enum_decorator and s.sy not in ('def', 'cdef', 'cpdef', 'class', 'async'):
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_s->__pyx_base.level);
    __Pyx_DECREF(__pyx_v_s->__pyx_base.level);
    __pyx_v_s->__pyx_base.level = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2547
 *             s.error('decorator not allowed here')
 *         s.level = ctx.level
 *         decorators = p_decorators(s)             # <<<<<<<<<<<<<<
 *         if not ctx.allow_struct_enum_decorator and s.sy not in ('def', 'cdef', 'cpdef', 'class', 'async'):
 *             if s.sy == 'IDENT' and s.systring == 'async':
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_decorators(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_decorators, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2548
 *         s.level = ctx.level
 *         decorators = p_decorators(s)
 *         if not ctx.allow_struct_enum_decorator and s.sy not in ('def', 'cdef', 'cpdef', 'class', 'async'):             # <<<<<<<<<<<<<<
 *             if s.sy == 'IDENT' and s.systring == 'async':
 *                 pass  # handled below
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_allow_struct_enum_decorator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (!__pyx_t_3);
    if (__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L19_bool_binop_done;
    }
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_9 = __pyx_v_s->sy;
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_def, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_8 = __pyx_t_3;
      goto __pyx_L21_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_cdef, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_8 = __pyx_t_3;
      goto __pyx_L21_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_cpdef, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_8 = __pyx_t_3;
      goto __pyx_L21_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_class_2, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_8 = __pyx_t_3;
      goto __pyx_L21_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_async, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2548, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_3;
    __pyx_L21_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = __pyx_t_8;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L19_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2549
 *         decorators = p_decorators(s)
 *         if not ctx.allow_struct_enum_decorator and s.sy not in ('def', 'cdef', 'cpdef', 'class', 'async'):
 *             if s.sy == 'IDENT' and s.systring == 'async':             # <<<<<<<<<<<<<<
 *                 pass  # handled below
 *             else:
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2549, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L27_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2549, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_3;
      __pyx_L27_bool_binop_done:;
      if (__pyx_t_2) {
        goto __pyx_L26;
      }

      /* "Cython/Compiler/Parsing.py":2552
 *                 pass  # handled below
 *             else:
 *                 s.error("Decorators can only be followed by functions or classes")             # <<<<<<<<<<<<<<
 *     elif s.sy == 'pass' and cdef_flag:
 *         # empty cdef block
*/
      /*else*/ {
        __pyx_t_7 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Decorators_can_only_be_followed};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2552, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L26:;

      /* "Cython/Compiler/Parsing.py":2548
 *         s.level = ctx.level
 *         decorators = p_decorators(s)
 *         if not ctx.allow_struct_enum_decorator and s.sy not in ('def', 'cdef', 'cpdef', 'class', 'async'):             # <<<<<<<<<<<<<<
 *             if s.sy == 'IDENT' and s.systring == 'async':
 *                 pass  # handled below
*/
    }

    /* "Cython/Compiler/Parsing.py":2543
 *                     "See https://github.com/cython/cython/issues/4310", level=1)
 *         return p_IF_statement(s, ctx)
 *     elif s.sy == '@':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'class', 'c_class', 'function', 'property', 'module_pxd', 'c_class_pxd', 'other'):
 *             s.error('decorator not allowed here')
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2553
 *             else:
 *                 s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'pass' and cdef_flag:             # <<<<<<<<<<<<<<
 *         # empty cdef block
 *         return p_pass_statement(s, with_newline=True)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2553, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L29_bool_binop_done;
  }
  __pyx_t_2 = __pyx_v_cdef_flag;
  __pyx_L29_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2555
 *     elif s.sy == 'pass' and cdef_flag:
 *         # empty cdef block
 *         return p_pass_statement(s, with_newline=True)             # <<<<<<<<<<<<<<
 * 
 *     overridable = False
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.with_newline = 1;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2553
 *             else:
 *                 s.error("Decorators can only be followed by functions or classes")
 *     elif s.sy == 'pass' and cdef_flag:             # <<<<<<<<<<<<<<
 *         # empty cdef block
 *         return p_pass_statement(s, with_newline=True)
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2557
 *         return p_pass_statement(s, with_newline=True)
 * 
 *     overridable = False             # <<<<<<<<<<<<<<
 *     if s.sy == 'cdef':
 *         cdef_flag = True
*/
  __pyx_v_overridable = 0;

  /* "Cython/Compiler/Parsing.py":2558
 * 
 *     overridable = False
 *     if s.sy == 'cdef':             # <<<<<<<<<<<<<<
 *         cdef_flag = True
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_cdef, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2558, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2559
 *     overridable = False
 *     if s.sy == 'cdef':
 *         cdef_flag = True             # <<<<<<<<<<<<<<
 *         s.next()
 *     elif s.sy == 'cpdef':
*/
    __pyx_v_cdef_flag = 1;

    /* "Cython/Compiler/Parsing.py":2560
 *     if s.sy == 'cdef':
 *         cdef_flag = True
 *         s.next()             # <<<<<<<<<<<<<<
 *     elif s.sy == 'cpdef':
 *         cdef_flag = True
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2558
 * 
 *     overridable = False
 *     if s.sy == 'cdef':             # <<<<<<<<<<<<<<
 *         cdef_flag = True
 *         s.next()
*/
    goto __pyx_L31;
  }

  /* "Cython/Compiler/Parsing.py":2561
 *         cdef_flag = True
 *         s.next()
 *     elif s.sy == 'cpdef':             # <<<<<<<<<<<<<<
 *         cdef_flag = True
 *         overridable = True
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_cpdef, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2561, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2562
 *         s.next()
 *     elif s.sy == 'cpdef':
 *         cdef_flag = True             # <<<<<<<<<<<<<<
 *         overridable = True
 *         s.next()
*/
    __pyx_v_cdef_flag = 1;

    /* "Cython/Compiler/Parsing.py":2563
 *     elif s.sy == 'cpdef':
 *         cdef_flag = True
 *         overridable = True             # <<<<<<<<<<<<<<
 *         s.next()
 *     if cdef_flag:
*/
    __pyx_v_overridable = 1;

    /* "Cython/Compiler/Parsing.py":2564
 *         cdef_flag = True
 *         overridable = True
 *         s.next()             # <<<<<<<<<<<<<<
 *     if cdef_flag:
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2561
 *         cdef_flag = True
 *         s.next()
 *     elif s.sy == 'cpdef':             # <<<<<<<<<<<<<<
 *         cdef_flag = True
 *         overridable = True
*/
  }
  __pyx_L31:;

  /* "Cython/Compiler/Parsing.py":2565
 *         overridable = True
 *         s.next()
 *     if cdef_flag:             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
 *             s.error('cdef statement not allowed here')
*/
  if (__pyx_v_cdef_flag) {

    /* "Cython/Compiler/Parsing.py":2566
 *         s.next()
 *     if cdef_flag:
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):             # <<<<<<<<<<<<<<
 *             s.error('cdef statement not allowed here')
 *         s.level = ctx.level
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2566, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2566, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_function, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2566, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2566, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2566, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L34_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_2;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2567
 *     if cdef_flag:
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
 *             s.error('cdef statement not allowed here')             # <<<<<<<<<<<<<<
 *         s.level = ctx.level
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_cdef_statement_not_allowed_here};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2567, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2566
 *         s.next()
 *     if cdef_flag:
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):             # <<<<<<<<<<<<<<
 *             s.error('cdef statement not allowed here')
 *         s.level = ctx.level
*/
    }

    /* "Cython/Compiler/Parsing.py":2568
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
 *             s.error('cdef statement not allowed here')
 *         s.level = ctx.level             # <<<<<<<<<<<<<<
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))
 *         if decorators is not None:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_s->__pyx_base.level);
    __Pyx_DECREF(__pyx_v_s->__pyx_base.level);
    __pyx_v_s->__pyx_base.level = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2569
 *             s.error('cdef statement not allowed here')
 *         s.level = ctx.level
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))             # <<<<<<<<<<<<<<
 *         if decorators is not None:
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
*/
    __pyx_t_7 = NULL;
    __Pyx_INCREF(__pyx_v_ctx);
    __pyx_t_4 = __pyx_v_ctx; 
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_overridable); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_7);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, NULL};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_overridable, __pyx_t_6, __pyx_t_11, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 2569, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_cdef_statement(__pyx_v_s, __pyx_v_pos, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_node = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":2570
 *         s.level = ctx.level
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))
 *         if decorators is not None:             # <<<<<<<<<<<<<<
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
 *             if ctx.allow_struct_enum_decorator:
*/
    __pyx_t_3 = (__pyx_v_decorators != ((PyObject*)Py_None));
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2571
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))
 *         if decorators is not None:
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)             # <<<<<<<<<<<<<<
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CFuncDefNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CVarDefNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CClassDefNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4) != (0)) __PYX_ERR(0, 2571, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 2571, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_11);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_11) != (0)) __PYX_ERR(0, 2571, __pyx_L1_error);
      __pyx_t_4 = 0;
      __pyx_t_1 = 0;
      __pyx_t_11 = 0;
      __pyx_v_tup = ((PyObject*)__pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2572
 *         if decorators is not None:
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
 *             if ctx.allow_struct_enum_decorator:             # <<<<<<<<<<<<<<
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
 *             if not isinstance(node, tup):
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_allow_struct_enum_decorator); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2572, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2573
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)             # <<<<<<<<<<<<<<
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CStructOrUnionDefNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CEnumDefNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6) != (0)) __PYX_ERR(0, 2573, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_11);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_11) != (0)) __PYX_ERR(0, 2573, __pyx_L1_error);
        __pyx_t_6 = 0;
        __pyx_t_11 = 0;
        __pyx_t_11 = PyNumber_InPlaceAdd(__pyx_v_tup, __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_tup, ((PyObject*)__pyx_t_11));
        __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2572
 *         if decorators is not None:
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
 *             if ctx.allow_struct_enum_decorator:             # <<<<<<<<<<<<<<
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
 *             if not isinstance(node, tup):
*/
      }

      /* "Cython/Compiler/Parsing.py":2574
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
 *             if not isinstance(node, tup):             # <<<<<<<<<<<<<<
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
*/
      __pyx_t_3 = PyObject_IsInstance(__pyx_v_node, __pyx_v_tup); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 2574, __pyx_L1_error)
      __pyx_t_2 = (!__pyx_t_3);
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2575
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")             # <<<<<<<<<<<<<<
 *             node.decorators = decorators
 *         return node
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_Decorators_can_only_be_followed};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2575, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2574
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += (Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode)
 *             if not isinstance(node, tup):             # <<<<<<<<<<<<<<
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
*/
      }

      /* "Cython/Compiler/Parsing.py":2576
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators             # <<<<<<<<<<<<<<
 *         return node
 *     else:
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_decorators, __pyx_v_decorators) < (0)) __PYX_ERR(0, 2576, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":2570
 *         s.level = ctx.level
 *         node = p_cdef_statement(s, pos, ctx(overridable=overridable))
 *         if decorators is not None:             # <<<<<<<<<<<<<<
 *             tup = (Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode)
 *             if ctx.allow_struct_enum_decorator:
*/
    }

    /* "Cython/Compiler/Parsing.py":2577
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
 *         return node             # <<<<<<<<<<<<<<
 *     else:
 *         if ctx.api:
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2565
 *         overridable = True
 *         s.next()
 *     if cdef_flag:             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
 *             s.error('cdef statement not allowed here')
*/
  }

  /* "Cython/Compiler/Parsing.py":2579
 *         return node
 *     else:
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         elif s.sy == 'def':
*/
  /*else*/ {
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2580
 *     else:
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'def':
 *             # def statements aren't allowed in pxd files, except
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_api_not_allowed_with_this_state};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2580, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2580, __pyx_L1_error)
        __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2580, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":2579
 *         return node
 *     else:
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         elif s.sy == 'def':
*/
      goto __pyx_L42;
    }

    /* "Cython/Compiler/Parsing.py":2581
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         elif s.sy == 'def':             # <<<<<<<<<<<<<<
 *             # def statements aren't allowed in pxd files, except
 *             # as part of a cdef class
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_def, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2581, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2584
 *             # def statements aren't allowed in pxd files, except
 *             # as part of a cdef class
 *             if ('pxd' in ctx.level) and (ctx.level != 'c_class_pxd'):             # <<<<<<<<<<<<<<
 *                 s.error('def statement not allowed here')
 *             s.level = ctx.level
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_pxd, __pyx_t_11, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L44_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_2 = __pyx_t_3;
      __pyx_L44_bool_binop_done:;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2585
 *             # as part of a cdef class
 *             if ('pxd' in ctx.level) and (ctx.level != 'c_class_pxd'):
 *                 s.error('def statement not allowed here')             # <<<<<<<<<<<<<<
 *             s.level = ctx.level
 *             return p_def_statement(s, decorators)
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_def_statement_not_allowed_here};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2585, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2584
 *             # def statements aren't allowed in pxd files, except
 *             # as part of a cdef class
 *             if ('pxd' in ctx.level) and (ctx.level != 'c_class_pxd'):             # <<<<<<<<<<<<<<
 *                 s.error('def statement not allowed here')
 *             s.level = ctx.level
*/
      }

      /* "Cython/Compiler/Parsing.py":2586
 *             if ('pxd' in ctx.level) and (ctx.level != 'c_class_pxd'):
 *                 s.error('def statement not allowed here')
 *             s.level = ctx.level             # <<<<<<<<<<<<<<
 *             return p_def_statement(s, decorators)
 *         elif s.sy == 'class':
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_v_s->__pyx_base.level);
      __Pyx_DECREF(__pyx_v_s->__pyx_base.level);
      __pyx_v_s->__pyx_base.level = __pyx_t_11;
      __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":2587
 *                 s.error('def statement not allowed here')
 *             s.level = ctx.level
 *             return p_def_statement(s, decorators)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'class':
 *             if ctx.level not in ('module', 'function', 'class', 'other'):
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_12.__pyx_n = 1;
      __pyx_t_12.decorators = __pyx_v_decorators;
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_def_statement(__pyx_v_s, &__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2587, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2581
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         elif s.sy == 'def':             # <<<<<<<<<<<<<<
 *             # def statements aren't allowed in pxd files, except
 *             # as part of a cdef class
*/
    }

    /* "Cython/Compiler/Parsing.py":2588
 *             s.level = ctx.level
 *             return p_def_statement(s, decorators)
 *         elif s.sy == 'class':             # <<<<<<<<<<<<<<
 *             if ctx.level not in ('module', 'function', 'class', 'other'):
 *                 s.error("class definition not allowed here")
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_class_2, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2588, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2589
 *             return p_def_statement(s, decorators)
 *         elif s.sy == 'class':
 *             if ctx.level not in ('module', 'function', 'class', 'other'):             # <<<<<<<<<<<<<<
 *                 s.error("class definition not allowed here")
 *             return p_class_statement(s, decorators)
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2589, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L47_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_function, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2589, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L47_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_class_2, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2589, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L47_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_other, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2589, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_3;
      __pyx_L47_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_3 = __pyx_t_2;
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2590
 *         elif s.sy == 'class':
 *             if ctx.level not in ('module', 'function', 'class', 'other'):
 *                 s.error("class definition not allowed here")             # <<<<<<<<<<<<<<
 *             return p_class_statement(s, decorators)
 *         elif s.sy == 'include':
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_class_definition_not_allowed_her};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2590, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2589
 *             return p_def_statement(s, decorators)
 *         elif s.sy == 'class':
 *             if ctx.level not in ('module', 'function', 'class', 'other'):             # <<<<<<<<<<<<<<
 *                 s.error("class definition not allowed here")
 *             return p_class_statement(s, decorators)
*/
      }

      /* "Cython/Compiler/Parsing.py":2591
 *             if ctx.level not in ('module', 'function', 'class', 'other'):
 *                 s.error("class definition not allowed here")
 *             return p_class_statement(s, decorators)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'include':
 *             if ctx.level not in ('module', 'module_pxd'):
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_class_statement(__pyx_v_s, __pyx_v_decorators); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2591, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2588
 *             s.level = ctx.level
 *             return p_def_statement(s, decorators)
 *         elif s.sy == 'class':             # <<<<<<<<<<<<<<
 *             if ctx.level not in ('module', 'function', 'class', 'other'):
 *                 s.error("class definition not allowed here")
*/
    }

    /* "Cython/Compiler/Parsing.py":2592
 *                 s.error("class definition not allowed here")
 *             return p_class_statement(s, decorators)
 *         elif s.sy == 'include':             # <<<<<<<<<<<<<<
 *             if ctx.level not in ('module', 'module_pxd'):
 *                 s.error("include statement not allowed here")
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_include, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2592, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":2593
 *             return p_class_statement(s, decorators)
 *         elif s.sy == 'include':
 *             if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *                 s.error("include statement not allowed here")
 *             return p_include_statement(s, ctx)
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2593, __pyx_L1_error)
      if (__pyx_t_2) {
      } else {
        __pyx_t_3 = __pyx_t_2;
        goto __pyx_L52_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2593, __pyx_L1_error)
      __pyx_t_3 = __pyx_t_2;
      __pyx_L52_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_2 = __pyx_t_3;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2594
 *         elif s.sy == 'include':
 *             if ctx.level not in ('module', 'module_pxd'):
 *                 s.error("include statement not allowed here")             # <<<<<<<<<<<<<<
 *             return p_include_statement(s, ctx)
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_include_statement_not_allowed_he};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2593
 *             return p_class_statement(s, decorators)
 *         elif s.sy == 'include':
 *             if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *                 s.error("include statement not allowed here")
 *             return p_include_statement(s, ctx)
*/
      }

      /* "Cython/Compiler/Parsing.py":2595
 *             if ctx.level not in ('module', 'module_pxd'):
 *                 s.error("include statement not allowed here")
 *             return p_include_statement(s, ctx)             # <<<<<<<<<<<<<<
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':
 *             return p_property_decl(s)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_include_statement(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2592
 *                 s.error("class definition not allowed here")
 *             return p_class_statement(s, decorators)
 *         elif s.sy == 'include':             # <<<<<<<<<<<<<<
 *             if ctx.level not in ('module', 'module_pxd'):
 *                 s.error("include statement not allowed here")
*/
    }

    /* "Cython/Compiler/Parsing.py":2596
 *                 s.error("include statement not allowed here")
 *             return p_include_statement(s, ctx)
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':             # <<<<<<<<<<<<<<
 *             return p_property_decl(s)
 *         elif s.sy == 'pass' and ctx.level != 'property':
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_c_class, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2596, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L54_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2596, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L54_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_property, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2596, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L54_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2597
 *             return p_include_statement(s, ctx)
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':
 *             return p_property_decl(s)             # <<<<<<<<<<<<<<
 *         elif s.sy == 'pass' and ctx.level != 'property':
 *             return p_pass_statement(s, with_newline=True)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_property_decl(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2596
 *                 s.error("include statement not allowed here")
 *             return p_include_statement(s, ctx)
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':             # <<<<<<<<<<<<<<
 *             return p_property_decl(s)
 *         elif s.sy == 'pass' and ctx.level != 'property':
*/
    }

    /* "Cython/Compiler/Parsing.py":2598
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':
 *             return p_property_decl(s)
 *         elif s.sy == 'pass' and ctx.level != 'property':             # <<<<<<<<<<<<<<
 *             return p_pass_statement(s, with_newline=True)
 *         else:
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2598, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L57_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_property, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2598, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L57_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2599
 *             return p_property_decl(s)
 *         elif s.sy == 'pass' and ctx.level != 'property':
 *             return p_pass_statement(s, with_newline=True)             # <<<<<<<<<<<<<<
 *         else:
 *             if ctx.level in ('c_class_pxd', 'property'):
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_10.__pyx_n = 1;
      __pyx_t_10.with_newline = 1;
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2598
 *         elif ctx.level == 'c_class' and s.sy == 'IDENT' and s.systring == 'property':
 *             return p_property_decl(s)
 *         elif s.sy == 'pass' and ctx.level != 'property':             # <<<<<<<<<<<<<<
 *             return p_pass_statement(s, with_newline=True)
 *         else:
*/
    }

    /* "Cython/Compiler/Parsing.py":2601
 *             return p_pass_statement(s, with_newline=True)
 *         else:
 *             if ctx.level in ('c_class_pxd', 'property'):             # <<<<<<<<<<<<<<
 *                 node = p_ignorable_statement(s)
 *                 if node is not None:
*/
    /*else*/ {
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2601, __pyx_L1_error)
      if (!__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L60_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_property, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2601, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_3;
      __pyx_L60_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_3 = __pyx_t_2;
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2602
 *         else:
 *             if ctx.level in ('c_class_pxd', 'property'):
 *                 node = p_ignorable_statement(s)             # <<<<<<<<<<<<<<
 *                 if node is not None:
 *                     return node
*/
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_ignorable_statement(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2602, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_v_node = __pyx_t_11;
        __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2603
 *             if ctx.level in ('c_class_pxd', 'property'):
 *                 node = p_ignorable_statement(s)
 *                 if node is not None:             # <<<<<<<<<<<<<<
 *                     return node
 *                 s.error("Executable statement not allowed here")
*/
        __pyx_t_3 = (__pyx_v_node != Py_None);
        if (__pyx_t_3) {

          /* "Cython/Compiler/Parsing.py":2604
 *                 node = p_ignorable_statement(s)
 *                 if node is not None:
 *                     return node             # <<<<<<<<<<<<<<
 *                 s.error("Executable statement not allowed here")
 *             if s.sy == 'if':
*/
          __Pyx_XDECREF(__pyx_r);
          __Pyx_INCREF(__pyx_v_node);
          __pyx_r = __pyx_v_node;
          goto __pyx_L0;

          /* "Cython/Compiler/Parsing.py":2603
 *             if ctx.level in ('c_class_pxd', 'property'):
 *                 node = p_ignorable_statement(s)
 *                 if node is not None:             # <<<<<<<<<<<<<<
 *                     return node
 *                 s.error("Executable statement not allowed here")
*/
        }

        /* "Cython/Compiler/Parsing.py":2605
 *                 if node is not None:
 *                     return node
 *                 s.error("Executable statement not allowed here")             # <<<<<<<<<<<<<<
 *             if s.sy == 'if':
 *                 return p_if_statement(s)
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Executable_statement_not_allowed};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2605, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2601
 *             return p_pass_statement(s, with_newline=True)
 *         else:
 *             if ctx.level in ('c_class_pxd', 'property'):             # <<<<<<<<<<<<<<
 *                 node = p_ignorable_statement(s)
 *                 if node is not None:
*/
      }

      /* "Cython/Compiler/Parsing.py":2606
 *                     return node
 *                 s.error("Executable statement not allowed here")
 *             if s.sy == 'if':             # <<<<<<<<<<<<<<
 *                 return p_if_statement(s)
 *             elif s.sy == 'while':
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_if, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2606, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2607
 *                 s.error("Executable statement not allowed here")
 *             if s.sy == 'if':
 *                 return p_if_statement(s)             # <<<<<<<<<<<<<<
 *             elif s.sy == 'while':
 *                 return p_while_statement(s)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_if_statement(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2607, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2606
 *                     return node
 *                 s.error("Executable statement not allowed here")
 *             if s.sy == 'if':             # <<<<<<<<<<<<<<
 *                 return p_if_statement(s)
 *             elif s.sy == 'while':
*/
      }

      /* "Cython/Compiler/Parsing.py":2608
 *             if s.sy == 'if':
 *                 return p_if_statement(s)
 *             elif s.sy == 'while':             # <<<<<<<<<<<<<<
 *                 return p_while_statement(s)
 *             elif s.sy == 'for':
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_while, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2608, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2609
 *                 return p_if_statement(s)
 *             elif s.sy == 'while':
 *                 return p_while_statement(s)             # <<<<<<<<<<<<<<
 *             elif s.sy == 'for':
 *                 return p_for_statement(s)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_while_statement(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2609, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2608
 *             if s.sy == 'if':
 *                 return p_if_statement(s)
 *             elif s.sy == 'while':             # <<<<<<<<<<<<<<
 *                 return p_while_statement(s)
 *             elif s.sy == 'for':
*/
      }

      /* "Cython/Compiler/Parsing.py":2610
 *             elif s.sy == 'while':
 *                 return p_while_statement(s)
 *             elif s.sy == 'for':             # <<<<<<<<<<<<<<
 *                 return p_for_statement(s)
 *             elif s.sy == 'try':
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_for, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2610, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2611
 *                 return p_while_statement(s)
 *             elif s.sy == 'for':
 *                 return p_for_statement(s)             # <<<<<<<<<<<<<<
 *             elif s.sy == 'try':
 *                 return p_try_statement(s)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_for_statement(__pyx_v_s, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2611, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2610
 *             elif s.sy == 'while':
 *                 return p_while_statement(s)
 *             elif s.sy == 'for':             # <<<<<<<<<<<<<<
 *                 return p_for_statement(s)
 *             elif s.sy == 'try':
*/
      }

      /* "Cython/Compiler/Parsing.py":2612
 *             elif s.sy == 'for':
 *                 return p_for_statement(s)
 *             elif s.sy == 'try':             # <<<<<<<<<<<<<<
 *                 return p_try_statement(s)
 *             elif s.sy == 'with':
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_try, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2612, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2613
 *                 return p_for_statement(s)
 *             elif s.sy == 'try':
 *                 return p_try_statement(s)             # <<<<<<<<<<<<<<
 *             elif s.sy == 'with':
 *                 return p_with_statement(s)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_try_statement(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2612
 *             elif s.sy == 'for':
 *                 return p_for_statement(s)
 *             elif s.sy == 'try':             # <<<<<<<<<<<<<<
 *                 return p_try_statement(s)
 *             elif s.sy == 'with':
*/
      }

      /* "Cython/Compiler/Parsing.py":2614
 *             elif s.sy == 'try':
 *                 return p_try_statement(s)
 *             elif s.sy == 'with':             # <<<<<<<<<<<<<<
 *                 return p_with_statement(s)
 *             elif s.sy == 'async':
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_with, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2614, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2615
 *                 return p_try_statement(s)
 *             elif s.sy == 'with':
 *                 return p_with_statement(s)             # <<<<<<<<<<<<<<
 *             elif s.sy == 'async':
 *                 s.next()
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_statement(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2615, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2614
 *             elif s.sy == 'try':
 *                 return p_try_statement(s)
 *             elif s.sy == 'with':             # <<<<<<<<<<<<<<
 *                 return p_with_statement(s)
 *             elif s.sy == 'async':
*/
      }

      /* "Cython/Compiler/Parsing.py":2616
 *             elif s.sy == 'with':
 *                 return p_with_statement(s)
 *             elif s.sy == 'async':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 return p_async_statement(s, ctx, decorators)
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2616, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":2617
 *                 return p_with_statement(s)
 *             elif s.sy == 'async':
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 return p_async_statement(s, ctx, decorators)
 *             else:
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "Cython/Compiler/Parsing.py":2618
 *             elif s.sy == 'async':
 *                 s.next()
 *                 return p_async_statement(s, ctx, decorators)             # <<<<<<<<<<<<<<
 *             else:
 *                 if s.sy == 'IDENT' and s.systring == 'async':
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_async_statement(__pyx_v_s, __pyx_v_ctx, __pyx_v_decorators); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2618, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Parsing.py":2616
 *             elif s.sy == 'with':
 *                 return p_with_statement(s)
 *             elif s.sy == 'async':             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 return p_async_statement(s, ctx, decorators)
*/
      }

      /* "Cython/Compiler/Parsing.py":2620
 *                 return p_async_statement(s, ctx, decorators)
 *             else:
 *                 if s.sy == 'IDENT' and s.systring == 'async':             # <<<<<<<<<<<<<<
 *                     ident_name = s.systring
 *                     ident_pos = s.position()
*/
      /*else*/ {
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2620, __pyx_L1_error)
        if (__pyx_t_2) {
        } else {
          __pyx_t_3 = __pyx_t_2;
          goto __pyx_L65_bool_binop_done;
        }
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_async, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2620, __pyx_L1_error)
        __pyx_t_3 = __pyx_t_2;
        __pyx_L65_bool_binop_done:;
        if (__pyx_t_3) {

          /* "Cython/Compiler/Parsing.py":2621
 *             else:
 *                 if s.sy == 'IDENT' and s.systring == 'async':
 *                     ident_name = s.systring             # <<<<<<<<<<<<<<
 *                     ident_pos = s.position()
 *                     # PEP 492 enables the async/await keywords when it spots "async def ..."
*/
          __pyx_t_11 = __pyx_v_s->systring;
          __Pyx_INCREF(__pyx_t_11);
          __pyx_v_ident_name = __pyx_t_11;
          __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":2622
 *                 if s.sy == 'IDENT' and s.systring == 'async':
 *                     ident_name = s.systring
 *                     ident_pos = s.position()             # <<<<<<<<<<<<<<
 *                     # PEP 492 enables the async/await keywords when it spots "async def ..."
 *                     s.next()
*/
          __pyx_t_11 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2622, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_v_ident_pos = ((PyObject*)__pyx_t_11);
          __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":2624
 *                     ident_pos = s.position()
 *                     # PEP 492 enables the async/await keywords when it spots "async def ..."
 *                     s.next()             # <<<<<<<<<<<<<<
 *                     if s.sy == 'def':
 *                         return p_async_statement(s, ctx, decorators)
*/
          __pyx_t_6 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
            __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2624, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":2625
 *                     # PEP 492 enables the async/await keywords when it spots "async def ..."
 *                     s.next()
 *                     if s.sy == 'def':             # <<<<<<<<<<<<<<
 *                         return p_async_statement(s, ctx, decorators)
 *                     elif decorators:
*/
          __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_def, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2625, __pyx_L1_error)
          if (__pyx_t_3) {

            /* "Cython/Compiler/Parsing.py":2626
 *                     s.next()
 *                     if s.sy == 'def':
 *                         return p_async_statement(s, ctx, decorators)             # <<<<<<<<<<<<<<
 *                     elif decorators:
 *                         s.error("Decorators can only be followed by functions or classes")
*/
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_async_statement(__pyx_v_s, __pyx_v_ctx, __pyx_v_decorators); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2626, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_r = __pyx_t_11;
            __pyx_t_11 = 0;
            goto __pyx_L0;

            /* "Cython/Compiler/Parsing.py":2625
 *                     # PEP 492 enables the async/await keywords when it spots "async def ..."
 *                     s.next()
 *                     if s.sy == 'def':             # <<<<<<<<<<<<<<
 *                         return p_async_statement(s, ctx, decorators)
 *                     elif decorators:
*/
          }

          /* "Cython/Compiler/Parsing.py":2627
 *                     if s.sy == 'def':
 *                         return p_async_statement(s, ctx, decorators)
 *                     elif decorators:             # <<<<<<<<<<<<<<
 *                         s.error("Decorators can only be followed by functions or classes")
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token
*/
          if (__pyx_v_decorators == Py_None) __pyx_t_3 = 0;
          else
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_decorators);
            if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 2627, __pyx_L1_error)
            __pyx_t_3 = (__pyx_temp != 0);
          }

          if (__pyx_t_3) {

            /* "Cython/Compiler/Parsing.py":2628
 *                         return p_async_statement(s, ctx, decorators)
 *                     elif decorators:
 *                         s.error("Decorators can only be followed by functions or classes")             # <<<<<<<<<<<<<<
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token
 *                 if s.sy == 'IDENT' and s.systring == 'match':
*/
            __pyx_t_6 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_6);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Decorators_can_only_be_followed};
              __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2628, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_11);
            }
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

            /* "Cython/Compiler/Parsing.py":2627
 *                     if s.sy == 'def':
 *                         return p_async_statement(s, ctx, decorators)
 *                     elif decorators:             # <<<<<<<<<<<<<<
 *                         s.error("Decorators can only be followed by functions or classes")
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token
*/
          }

          /* "Cython/Compiler/Parsing.py":2629
 *                     elif decorators:
 *                         s.error("Decorators can only be followed by functions or classes")
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token             # <<<<<<<<<<<<<<
 *                 if s.sy == 'IDENT' and s.systring == 'match':
 *                     # p_match_statement returns None on a "soft" initial failure
*/
          __pyx_t_6 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_mstate_global->__pyx_n_u_IDENT, __pyx_v_ident_name, __pyx_v_ident_pos};
            __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2629, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":2620
 *                 return p_async_statement(s, ctx, decorators)
 *             else:
 *                 if s.sy == 'IDENT' and s.systring == 'async':             # <<<<<<<<<<<<<<
 *                     ident_name = s.systring
 *                     ident_pos = s.position()
*/
        }

        /* "Cython/Compiler/Parsing.py":2630
 *                         s.error("Decorators can only be followed by functions or classes")
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token
 *                 if s.sy == 'IDENT' and s.systring == 'match':             # <<<<<<<<<<<<<<
 *                     # p_match_statement returns None on a "soft" initial failure
 *                     match_statement = p_match_statement(s, ctx)
*/
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2630, __pyx_L1_error)
        if (__pyx_t_2) {
        } else {
          __pyx_t_3 = __pyx_t_2;
          goto __pyx_L69_bool_binop_done;
        }
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_match, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2630, __pyx_L1_error)
        __pyx_t_3 = __pyx_t_2;
        __pyx_L69_bool_binop_done:;
        if (__pyx_t_3) {

          /* "Cython/Compiler/Parsing.py":2632
 *                 if s.sy == 'IDENT' and s.systring == 'match':
 *                     # p_match_statement returns None on a "soft" initial failure
 *                     match_statement = p_match_statement(s, ctx)             # <<<<<<<<<<<<<<
 *                     if match_statement is not None:
 *                         return match_statement
*/
          __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_match_statement(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2632, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_v_match_statement = __pyx_t_11;
          __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":2633
 *                     # p_match_statement returns None on a "soft" initial failure
 *                     match_statement = p_match_statement(s, ctx)
 *                     if match_statement is not None:             # <<<<<<<<<<<<<<
 *                         return match_statement
 *                 return p_simple_statement_list(s, ctx, first_statement=first_statement)
*/
          __pyx_t_3 = (__pyx_v_match_statement != Py_None);
          if (__pyx_t_3) {

            /* "Cython/Compiler/Parsing.py":2634
 *                     match_statement = p_match_statement(s, ctx)
 *                     if match_statement is not None:
 *                         return match_statement             # <<<<<<<<<<<<<<
 *                 return p_simple_statement_list(s, ctx, first_statement=first_statement)
 * 
*/
            __Pyx_XDECREF(__pyx_r);
            __Pyx_INCREF(__pyx_v_match_statement);
            __pyx_r = __pyx_v_match_statement;
            goto __pyx_L0;

            /* "Cython/Compiler/Parsing.py":2633
 *                     # p_match_statement returns None on a "soft" initial failure
 *                     match_statement = p_match_statement(s, ctx)
 *                     if match_statement is not None:             # <<<<<<<<<<<<<<
 *                         return match_statement
 *                 return p_simple_statement_list(s, ctx, first_statement=first_statement)
*/
          }

          /* "Cython/Compiler/Parsing.py":2630
 *                         s.error("Decorators can only be followed by functions or classes")
 *                     s.put_back('IDENT', ident_name, ident_pos)  # re-insert original token
 *                 if s.sy == 'IDENT' and s.systring == 'match':             # <<<<<<<<<<<<<<
 *                     # p_match_statement returns None on a "soft" initial failure
 *                     match_statement = p_match_statement(s, ctx)
*/
        }

        /* "Cython/Compiler/Parsing.py":2635
 *                     if match_statement is not None:
 *                         return match_statement
 *                 return p_simple_statement_list(s, ctx, first_statement=first_statement)             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_13.__pyx_n = 1;
        __pyx_t_13.first_statement = __pyx_v_first_statement;
        __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement_list(__pyx_v_s, __pyx_v_ctx, &__pyx_t_13); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;
      }
    }
    __pyx_L42:;
  }

  /* "Cython/Compiler/Parsing.py":2516
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement(s: PyrexScanner, ctx, first_statement: cython.bint = False):
 *     cdef_flag: cython.bint = ctx.cdef_flag
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_decorators);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_v_ident_name);
  __Pyx_XDECREF(__pyx_v_ident_pos);
  __Pyx_XDECREF(__pyx_v_match_statement);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2638
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of statements separated by newlines.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list *__pyx_optional_args) {
  int __pyx_v_first_statement = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_stats = NULL;
  PyObject *__pyx_v_stat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_statement_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_first_statement = __pyx_optional_args->first_statement;
    }
  }

  /* "Cython/Compiler/Parsing.py":2641
 * def p_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of statements separated by newlines.
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     stats = []
 *     while s.sy not in ('DEDENT', 'EOF'):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2642
 *     # Parse a series of statements separated by newlines.
 *     pos = s.position()
 *     stats = []             # <<<<<<<<<<<<<<
 *     while s.sy not in ('DEDENT', 'EOF'):
 *         stat = p_statement(s, ctx, first_statement = first_statement)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_stats = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2643
 *     pos = s.position()
 *     stats = []
 *     while s.sy not in ('DEDENT', 'EOF'):             # <<<<<<<<<<<<<<
 *         stat = p_statement(s, ctx, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):
*/
  while (1) {
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_2 = __pyx_v_s->sy;
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2643, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2643, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __pyx_t_3;
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":2644
 *     stats = []
 *     while s.sy not in ('DEDENT', 'EOF'):
 *         stat = p_statement(s, ctx, first_statement = first_statement)             # <<<<<<<<<<<<<<
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue
*/
    __pyx_t_5.__pyx_n = 1;
    __pyx_t_5.first_statement = __pyx_v_first_statement;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_statement(__pyx_v_s, __pyx_v_ctx, &__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_stat, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2645
 *     while s.sy not in ('DEDENT', 'EOF'):
 *         stat = p_statement(s, ctx, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *             continue
 *         stats.append(stat)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_PassStatNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2645, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_stat, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2645, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2646
 *         stat = p_statement(s, ctx, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue             # <<<<<<<<<<<<<<
 *         stats.append(stat)
 *         first_statement = False
*/
      goto __pyx_L3_continue;

      /* "Cython/Compiler/Parsing.py":2645
 *     while s.sy not in ('DEDENT', 'EOF'):
 *         stat = p_statement(s, ctx, first_statement = first_statement)
 *         if isinstance(stat, Nodes.PassStatNode):             # <<<<<<<<<<<<<<
 *             continue
 *         stats.append(stat)
*/
    }

    /* "Cython/Compiler/Parsing.py":2647
 *         if isinstance(stat, Nodes.PassStatNode):
 *             continue
 *         stats.append(stat)             # <<<<<<<<<<<<<<
 *         first_statement = False
 *     if not stats:
*/
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_stats, __pyx_v_stat); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2647, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":2648
 *             continue
 *         stats.append(stat)
 *         first_statement = False             # <<<<<<<<<<<<<<
 *     if not stats:
 *         return Nodes.PassStatNode(pos)
*/
    __pyx_v_first_statement = 0;
    __pyx_L3_continue:;
  }

  /* "Cython/Compiler/Parsing.py":2649
 *         stats.append(stat)
 *         first_statement = False
 *     if not stats:             # <<<<<<<<<<<<<<
 *         return Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_stats);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 2649, __pyx_L1_error)
    __pyx_t_4 = (__pyx_temp != 0);
  }

  __pyx_t_3 = (!__pyx_t_4);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2650
 *         first_statement = False
 *     if not stats:
 *         return Nodes.PassStatNode(pos)             # <<<<<<<<<<<<<<
 *     elif len(stats) == 1:
 *         return stats[0]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_PassStatNode, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2649
 *         stats.append(stat)
 *         first_statement = False
 *     if not stats:             # <<<<<<<<<<<<<<
 *         return Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
*/
  }

  /* "Cython/Compiler/Parsing.py":2651
 *     if not stats:
 *         return Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:             # <<<<<<<<<<<<<<
 *         return stats[0]
 *     else:
*/
  __pyx_t_9 = __Pyx_PyList_GET_SIZE(__pyx_v_stats); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2651, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_9 == 1);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":2652
 *         return Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:
 *         return stats[0]             # <<<<<<<<<<<<<<
 *     else:
 *         return Nodes.StatListNode(pos, stats = stats)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2652, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2651
 *     if not stats:
 *         return Nodes.PassStatNode(pos)
 *     elif len(stats) == 1:             # <<<<<<<<<<<<<<
 *         return stats[0]
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":2654
 *         return stats[0]
 *     else:
 *         return Nodes.StatListNode(pos, stats = stats)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_v_pos};
      __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stats, __pyx_v_stats, __pyx_t_10, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2654, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_StatListNode, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2638
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_statement_list(s: PyrexScanner, ctx, first_statement: cython.bint = 0):
 *     # Parse a series of statements separated by newlines.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_statement_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_stats);
  __Pyx_XDECREF(__pyx_v_stat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2657
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite(s: PyrexScanner, ctx=Ctx()):
 *     return p_suite_with_docstring(s, ctx, with_doc_only=False)[1]
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_suite(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite *__pyx_optional_args) {
  PyObject *__pyx_v_ctx = __pyx_mstate_global->__pyx_k__44;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_suite", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_ctx = __pyx_optional_args->ctx;
    }
  }

  /* "Cython/Compiler/Parsing.py":2659
 * @cython.cfunc
 * def p_suite(s: PyrexScanner, ctx=Ctx()):
 *     return p_suite_with_docstring(s, ctx, with_doc_only=False)[1]             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.with_doc_only = 0;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_v_ctx, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 2659, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_t_1, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2657
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite(s: PyrexScanner, ctx=Ctx()):
 *     return p_suite_with_docstring(s, ctx, with_doc_only=False)[1]
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_suite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2662
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:
 *     s.expect(':')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2663
 * 
 * @cython.cfunc
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:             # <<<<<<<<<<<<<<
 *     s.expect(':')
 *     doc = None
*/
  int __pyx_v_with_doc_only = ((int)0);
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_suite_with_docstring", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_with_doc_only = __pyx_optional_args->with_doc_only;
    }
  }

  /* "Cython/Compiler/Parsing.py":2664
 * @cython.cfunc
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:
 *     s.expect(':')             # <<<<<<<<<<<<<<
 *     doc = None
 *     if s.sy == 'NEWLINE':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2665
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:
 *     s.expect(':')
 *     doc = None             # <<<<<<<<<<<<<<
 *     if s.sy == 'NEWLINE':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_doc = Py_None;

  /* "Cython/Compiler/Parsing.py":2666
 *     s.expect(':')
 *     doc = None
 *     if s.sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_indent()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2666, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2667
 *     doc = None
 *     if s.sy == 'NEWLINE':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.expect_indent()
 *         if with_doc_only:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2668
 *     if s.sy == 'NEWLINE':
 *         s.next()
 *         s.expect_indent()             # <<<<<<<<<<<<<<
 *         if with_doc_only:
 *             doc = p_doc_string(s)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2669
 *         s.next()
 *         s.expect_indent()
 *         if with_doc_only:             # <<<<<<<<<<<<<<
 *             doc = p_doc_string(s)
 *         body = p_statement_list(s, ctx)
*/
    if (__pyx_v_with_doc_only) {

      /* "Cython/Compiler/Parsing.py":2670
 *         s.expect_indent()
 *         if with_doc_only:
 *             doc = p_doc_string(s)             # <<<<<<<<<<<<<<
 *         body = p_statement_list(s, ctx)
 *         s.expect_dedent()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_doc, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2669
 *         s.next()
 *         s.expect_indent()
 *         if with_doc_only:             # <<<<<<<<<<<<<<
 *             doc = p_doc_string(s)
 *         body = p_statement_list(s, ctx)
*/
    }

    /* "Cython/Compiler/Parsing.py":2671
 *         if with_doc_only:
 *             doc = p_doc_string(s)
 *         body = p_statement_list(s, ctx)             # <<<<<<<<<<<<<<
 *         s.expect_dedent()
 *     else:
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(__pyx_v_s, __pyx_v_ctx, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_body = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2672
 *             doc = p_doc_string(s)
 *         body = p_statement_list(s, ctx)
 *         s.expect_dedent()             # <<<<<<<<<<<<<<
 *     else:
 *         if ctx.api:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2666
 *     s.expect(':')
 *     doc = None
 *     if s.sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_indent()
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2674
 *         s.expect_dedent()
 *     else:
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         if ctx.level in ('module', 'class', 'function', 'other'):
*/
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2674, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2675
 *     else:
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)             # <<<<<<<<<<<<<<
 *         if ctx.level in ('module', 'class', 'function', 'other'):
 *             body = p_simple_statement_list(s, ctx)
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_api_not_allowed_with_this_state};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2675, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2674
 *         s.expect_dedent()
 *     else:
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         if ctx.level in ('module', 'class', 'function', 'other'):
*/
    }

    /* "Cython/Compiler/Parsing.py":2676
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         if ctx.level in ('module', 'class', 'function', 'other'):             # <<<<<<<<<<<<<<
 *             body = p_simple_statement_list(s, ctx)
 *         else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2676, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_class_2, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2676, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_function, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2676, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_4 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_other, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2676, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __pyx_t_4;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":2677
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         if ctx.level in ('module', 'class', 'function', 'other'):
 *             body = p_simple_statement_list(s, ctx)             # <<<<<<<<<<<<<<
 *         else:
 *             body = p_pass_statement(s)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_simple_statement_list(__pyx_v_s, __pyx_v_ctx, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_body = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2676
 *         if ctx.api:
 *             s.error("'api' not allowed with this statement", fatal=False)
 *         if ctx.level in ('module', 'class', 'function', 'other'):             # <<<<<<<<<<<<<<
 *             body = p_simple_statement_list(s, ctx)
 *         else:
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":2679
 *             body = p_simple_statement_list(s, ctx)
 *         else:
 *             body = p_pass_statement(s)             # <<<<<<<<<<<<<<
 *             s.expect_newline("Syntax error in declarations", ignore_semicolon=True)
 *     if not with_doc_only:
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_pass_statement(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2679, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_body = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2680
 *         else:
 *             body = p_pass_statement(s)
 *             s.expect_newline("Syntax error in declarations", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *     if not with_doc_only:
 *         doc, body = _extract_docstring(body)
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_declarations};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2680, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2680, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L6:;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2681
 *             body = p_pass_statement(s)
 *             s.expect_newline("Syntax error in declarations", ignore_semicolon=True)
 *     if not with_doc_only:             # <<<<<<<<<<<<<<
 *         doc, body = _extract_docstring(body)
 *     return doc, body
*/
  __pyx_t_6 = (!__pyx_v_with_doc_only);
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2682
 *             s.expect_newline("Syntax error in declarations", ignore_semicolon=True)
 *     if not with_doc_only:
 *         doc, body = _extract_docstring(body)             # <<<<<<<<<<<<<<
 *     return doc, body
 * 
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing__extract_docstring(__pyx_v_body); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2682, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 2682, __pyx_L1_error)
    }
    __Pyx_DECREF_SET(__pyx_v_doc, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_body, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":2681
 *             body = p_pass_statement(s)
 *             s.expect_newline("Syntax error in declarations", ignore_semicolon=True)
 *     if not with_doc_only:             # <<<<<<<<<<<<<<
 *         doc, body = _extract_docstring(body)
 *     return doc, body
*/
  }

  /* "Cython/Compiler/Parsing.py":2683
 *     if not with_doc_only:
 *         doc, body = _extract_docstring(body)
 *     return doc, body             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_doc);
  __Pyx_GIVEREF(__pyx_v_doc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_doc) != (0)) __PYX_ERR(0, 2683, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_body);
  __Pyx_GIVEREF(__pyx_v_body);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_body) != (0)) __PYX_ERR(0, 2683, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2662
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_suite_with_docstring(s: PyrexScanner, ctx, with_doc_only: cython.bint = False) -> tuple:
 *     s.expect(':')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_suite_with_docstring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2686
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_positional_and_keyword_args(s: PyrexScanner, end_sy_set, templates = None) -> tuple:
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_end_sy_set, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2687
 * 
 * @cython.cfunc
 * def p_positional_and_keyword_args(s: PyrexScanner, end_sy_set, templates = None) -> tuple:             # <<<<<<<<<<<<<<
 *     """
 *     Parses positional and keyword arguments. end_sy_set
*/
  PyObject *__pyx_v_templates = ((PyObject *)Py_None);
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  long __pyx_v_pos_idx;
  int __pyx_v_parsed_type;
  PyObject *__pyx_v_ident = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  PyObject *__pyx_v_keyword_node = NULL;
  CYTHON_UNUSED int __pyx_v_was_keyword;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_positional_and_keyword_args", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_templates = __pyx_optional_args->templates;
    }
  }

  /* "Cython/Compiler/Parsing.py":2695
 *     Returns: (positional_args, keyword_args)
 *     """
 *     positional_args = []             # <<<<<<<<<<<<<<
 *     keyword_args = []
 *     pos_idx = 0
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_positional_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2696
 *     """
 *     positional_args = []
 *     keyword_args = []             # <<<<<<<<<<<<<<
 *     pos_idx = 0
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_keyword_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2697
 *     positional_args = []
 *     keyword_args = []
 *     pos_idx = 0             # <<<<<<<<<<<<<<
 * 
 *     while s.sy not in end_sy_set:
*/
  __pyx_v_pos_idx = 0;

  /* "Cython/Compiler/Parsing.py":2699
 *     pos_idx = 0
 * 
 *     while s.sy not in end_sy_set:             # <<<<<<<<<<<<<<
 *         if s.sy == '*' or s.sy == '**':
 *             s.error('Argument expansion not allowed here.', fatal=False)
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_end_sy_set, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2699, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":2700
 * 
 *     while s.sy not in end_sy_set:
 *         if s.sy == '*' or s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.error('Argument expansion not allowed here.', fatal=False)
 * 
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2700, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2700, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2701
 *     while s.sy not in end_sy_set:
 *         if s.sy == '*' or s.sy == '**':
 *             s.error('Argument expansion not allowed here.', fatal=False)             # <<<<<<<<<<<<<<
 * 
 *         parsed_type = False
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Argument_expansion_not_allowed_h};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2701, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2701, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2701, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2700
 * 
 *     while s.sy not in end_sy_set:
 *         if s.sy == '*' or s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.error('Argument expansion not allowed here.', fatal=False)
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":2703
 *             s.error('Argument expansion not allowed here.', fatal=False)
 * 
 *         parsed_type = False             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT' and s.peek()[0] == '=':
 *             ident = s.systring
*/
    __pyx_v_parsed_type = 0;

    /* "Cython/Compiler/Parsing.py":2704
 * 
 *         parsed_type = False
 *         if s.sy == 'IDENT' and s.peek()[0] == '=':             # <<<<<<<<<<<<<<
 *             ident = s.systring
 *             s.next()  # s.sy is '='
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_peek, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2704, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2705
 *         parsed_type = False
 *         if s.sy == 'IDENT' and s.peek()[0] == '=':
 *             ident = s.systring             # <<<<<<<<<<<<<<
 *             s.next()  # s.sy is '='
 *             s.next()
*/
      __pyx_t_6 = __pyx_v_s->systring;
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_ident, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2706
 *         if s.sy == 'IDENT' and s.peek()[0] == '=':
 *             ident = s.systring
 *             s.next()  # s.sy is '='             # <<<<<<<<<<<<<<
 *             s.next()
 *             if looking_at_expr(s):
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2706, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2707
 *             ident = s.systring
 *             s.next()  # s.sy is '='
 *             s.next()             # <<<<<<<<<<<<<<
 *             if looking_at_expr(s):
 *                 arg = p_test(s)
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2707, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2708
 *             s.next()  # s.sy is '='
 *             s.next()
 *             if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *                 arg = p_test(s)
 *             else:
*/
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(__pyx_v_s); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2708, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2709
 *             s.next()
 *             if looking_at_expr(s):
 *                 arg = p_test(s)             # <<<<<<<<<<<<<<
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)
*/
        __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2709, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2708
 *             s.next()  # s.sy is '='
 *             s.next()
 *             if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *                 arg = p_test(s)
 *             else:
*/
        goto __pyx_L11;
      }

      /* "Cython/Compiler/Parsing.py":2711
 *                 arg = p_test(s)
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)             # <<<<<<<<<<<<<<
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
*/
      /*else*/ {
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2711, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, ((PyObject *)__pyx_v_s)};
          __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2711, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2711, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2711, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_base_type, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2712
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)
 *                 declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)
*/
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2712, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, ((PyObject *)__pyx_v_s)};
          __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2712, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2712, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2712, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_declarator, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2713
 *                 base_type = p_c_base_type(s, templates = templates)
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,             # <<<<<<<<<<<<<<
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True
*/
        __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_base_type, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2713, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "Cython/Compiler/Parsing.py":2714
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)             # <<<<<<<<<<<<<<
 *                 parsed_type = True
 *             keyword_node = ExprNodes.IdentifierStringNode(arg.pos, value=ident)
*/
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_7, __pyx_t_1};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2713, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2713, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2713, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CComplexBaseTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2713, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2715
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True             # <<<<<<<<<<<<<<
 *             keyword_node = ExprNodes.IdentifierStringNode(arg.pos, value=ident)
 *             keyword_args.append((keyword_node, arg))
*/
        __pyx_v_parsed_type = 1;
      }
      __pyx_L11:;

      /* "Cython/Compiler/Parsing.py":2716
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True
 *             keyword_node = ExprNodes.IdentifierStringNode(arg.pos, value=ident)             # <<<<<<<<<<<<<<
 *             keyword_args.append((keyword_node, arg))
 *             was_keyword = True
*/
      __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2716, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_t_1};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2716, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_ident, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2716, __pyx_L1_error)
        __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_IdentifierStringNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2716, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_v_keyword_node, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2717
 *                 parsed_type = True
 *             keyword_node = ExprNodes.IdentifierStringNode(arg.pos, value=ident)
 *             keyword_args.append((keyword_node, arg))             # <<<<<<<<<<<<<<
 *             was_keyword = True
 * 
*/
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_keyword_node);
      __Pyx_GIVEREF(__pyx_v_keyword_node);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_keyword_node) != (0)) __PYX_ERR(0, 2717, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_arg);
      __Pyx_GIVEREF(__pyx_v_arg);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_arg) != (0)) __PYX_ERR(0, 2717, __pyx_L1_error);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_keyword_args, __pyx_t_6); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 2717, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":2718
 *             keyword_node = ExprNodes.IdentifierStringNode(arg.pos, value=ident)
 *             keyword_args.append((keyword_node, arg))
 *             was_keyword = True             # <<<<<<<<<<<<<<
 * 
 *         else:
*/
      __pyx_v_was_keyword = 1;

      /* "Cython/Compiler/Parsing.py":2704
 * 
 *         parsed_type = False
 *         if s.sy == 'IDENT' and s.peek()[0] == '=':             # <<<<<<<<<<<<<<
 *             ident = s.systring
 *             s.next()  # s.sy is '='
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/Parsing.py":2721
 * 
 *         else:
 *             if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *                 arg = p_test(s)
 *             else:
*/
    /*else*/ {
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(__pyx_v_s); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2721, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2722
 *         else:
 *             if looking_at_expr(s):
 *                 arg = p_test(s)             # <<<<<<<<<<<<<<
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)
*/
        __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2721
 * 
 *         else:
 *             if looking_at_expr(s):             # <<<<<<<<<<<<<<
 *                 arg = p_test(s)
 *             else:
*/
        goto __pyx_L12;
      }

      /* "Cython/Compiler/Parsing.py":2724
 *                 arg = p_test(s)
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)             # <<<<<<<<<<<<<<
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
*/
      /*else*/ {
        __pyx_t_7 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2724, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, ((PyObject *)__pyx_v_s)};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2724, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2724, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2724, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_base_type, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2725
 *             else:
 *                 base_type = p_c_base_type(s, templates = templates)
 *                 declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)
*/
        __pyx_t_1 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2725, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, ((PyObject *)__pyx_v_s)};
          __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2725, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2725, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2725, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_declarator, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2726
 *                 base_type = p_c_base_type(s, templates = templates)
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,             # <<<<<<<<<<<<<<
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True
*/
        __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_base_type, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2726, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "Cython/Compiler/Parsing.py":2727
 *                 declarator = p_c_declarator(s, empty=True)
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)             # <<<<<<<<<<<<<<
 *                 parsed_type = True
 *             positional_args.append(arg)
*/
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_t_7};
          __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2726, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2726, __pyx_L1_error)
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2726, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CComplexBaseTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2726, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2728
 *                 arg = Nodes.CComplexBaseTypeNode(base_type.pos,
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True             # <<<<<<<<<<<<<<
 *             positional_args.append(arg)
 *             pos_idx += 1
*/
        __pyx_v_parsed_type = 1;
      }
      __pyx_L12:;

      /* "Cython/Compiler/Parsing.py":2729
 *                     base_type = base_type, declarator = declarator)
 *                 parsed_type = True
 *             positional_args.append(arg)             # <<<<<<<<<<<<<<
 *             pos_idx += 1
 *             if len(keyword_args) > 0:
*/
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_positional_args, __pyx_v_arg); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 2729, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":2730
 *                 parsed_type = True
 *             positional_args.append(arg)
 *             pos_idx += 1             # <<<<<<<<<<<<<<
 *             if len(keyword_args) > 0:
 *                 s.error("Non-keyword arg following keyword arg",
*/
      __pyx_v_pos_idx = (__pyx_v_pos_idx + 1);

      /* "Cython/Compiler/Parsing.py":2731
 *             positional_args.append(arg)
 *             pos_idx += 1
 *             if len(keyword_args) > 0:             # <<<<<<<<<<<<<<
 *                 s.error("Non-keyword arg following keyword arg",
 *                         pos=arg.pos)
*/
      __pyx_t_9 = __Pyx_PyList_GET_SIZE(__pyx_v_keyword_args); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2731, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_9 > 0);
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2732
 *             pos_idx += 1
 *             if len(keyword_args) > 0:
 *                 s.error("Non-keyword arg following keyword arg",             # <<<<<<<<<<<<<<
 *                         pos=arg.pos)
 * 
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);

        /* "Cython/Compiler/Parsing.py":2733
 *             if len(keyword_args) > 0:
 *                 s.error("Non-keyword arg following keyword arg",
 *                         pos=arg.pos)             # <<<<<<<<<<<<<<
 * 
 *         if s.sy != ',':
*/
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2733, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_Non_keyword_arg_following_keywor};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2732, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_7, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2732, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2732, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":2731
 *             positional_args.append(arg)
 *             pos_idx += 1
 *             if len(keyword_args) > 0:             # <<<<<<<<<<<<<<
 *                 s.error("Non-keyword arg following keyword arg",
 *                         pos=arg.pos)
*/
      }
    }
    __pyx_L8:;

    /* "Cython/Compiler/Parsing.py":2735
 *                         pos=arg.pos)
 * 
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             if s.sy not in end_sy_set:
 *                 if parsed_type:
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2735, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2736
 * 
 *         if s.sy != ',':
 *             if s.sy not in end_sy_set:             # <<<<<<<<<<<<<<
 *                 if parsed_type:
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
*/
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_end_sy_set, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2736, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2737
 *         if s.sy != ',':
 *             if s.sy not in end_sy_set:
 *                 if parsed_type:             # <<<<<<<<<<<<<<
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
 *             break
*/
        if (__pyx_v_parsed_type) {

          /* "Cython/Compiler/Parsing.py":2738
 *             if s.sy not in end_sy_set:
 *                 if parsed_type:
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
          __pyx_t_4 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_7 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u_or_2, __pyx_v_end_sy_set); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2738, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Unmatched_s, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2738, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_1};
            __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2738, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "Cython/Compiler/Parsing.py":2737
 *         if s.sy != ',':
 *             if s.sy not in end_sy_set:
 *                 if parsed_type:             # <<<<<<<<<<<<<<
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
 *             break
*/
        }

        /* "Cython/Compiler/Parsing.py":2736
 * 
 *         if s.sy != ',':
 *             if s.sy not in end_sy_set:             # <<<<<<<<<<<<<<
 *                 if parsed_type:
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
*/
      }

      /* "Cython/Compiler/Parsing.py":2739
 *                 if parsed_type:
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     return positional_args, keyword_args
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":2735
 *                         pos=arg.pos)
 * 
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             if s.sy not in end_sy_set:
 *                 if parsed_type:
*/
    }

    /* "Cython/Compiler/Parsing.py":2740
 *                     s.error("Unmatched %s" % " or ".join(end_sy_set))
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     return positional_args, keyword_args
 * 
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":2741
 *             break
 *         s.next()
 *     return positional_args, keyword_args             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_positional_args);
  __Pyx_GIVEREF(__pyx_v_positional_args);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_positional_args) != (0)) __PYX_ERR(0, 2741, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_keyword_args);
  __Pyx_GIVEREF(__pyx_v_keyword_args);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_keyword_args) != (0)) __PYX_ERR(0, 2741, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2686
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_positional_and_keyword_args(s: PyrexScanner, end_sy_set, templates = None) -> tuple:
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_positional_and_keyword_args", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_ident);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_keyword_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3p_c_base_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2745
 * 
 * @cython.ccall
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         return p_c_complex_base_type(s, templates = templates)
*/
  int __pyx_v_nonempty = ((int)0);
  PyObject *__pyx_v_templates = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_complex_base_type __pyx_t_3;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_simple_base_type __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_base_type", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_nonempty = __pyx_optional_args->nonempty;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_templates = __pyx_optional_args->templates;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":2746
 * @cython.ccall
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         return p_c_complex_base_type(s, templates = templates)
 *     else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2746, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2747
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
 *         return p_c_complex_base_type(s, templates = templates)             # <<<<<<<<<<<<<<
 *     else:
 *         return p_c_simple_base_type(s, nonempty=nonempty, templates=templates)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3.__pyx_n = 1;
    __pyx_t_3.templates = __pyx_v_templates;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_complex_base_type(__pyx_v_s, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2746
 * @cython.ccall
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         return p_c_complex_base_type(s, templates = templates)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":2749
 *         return p_c_complex_base_type(s, templates = templates)
 *     else:
 *         return p_c_simple_base_type(s, nonempty=nonempty, templates=templates)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4.__pyx_n = 1;
    __pyx_t_4.templates = __pyx_v_templates;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_base_type(__pyx_v_s, __pyx_v_nonempty, &__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3p_c_base_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_3p_c_base_type = {"p_c_base_type", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_3p_c_base_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_3p_c_base_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s = 0;
  int __pyx_v_nonempty;
  PyObject *__pyx_v_templates = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p_c_base_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s,&__pyx_mstate_global->__pyx_n_u_nonempty,&__pyx_mstate_global->__pyx_n_u_templates,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2744, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2744, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2744, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2744, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "p_c_base_type", 0) < (0)) __PYX_ERR(0, 2744, __pyx_L3_error)

      /* "Cython/Compiler/Parsing.py":2745
 * 
 * @cython.ccall
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         return p_c_complex_base_type(s, templates = templates)
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("p_c_base_type", 0, 1, 3, i); __PYX_ERR(0, 2744, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2744, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2744, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2744, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_s = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)values[0]);
    if (values[1]) {
      __pyx_v_nonempty = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_nonempty == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2745, __pyx_L3_error)
    } else {
      __pyx_v_nonempty = ((int)0);
    }
    __pyx_v_templates = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("p_c_base_type", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 2744, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "s", 0))) __PYX_ERR(0, 2745, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_2p_c_base_type(__pyx_self, __pyx_v_s, __pyx_v_nonempty, __pyx_v_templates);

  /* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_2p_c_base_type(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_nonempty, PyObject *__pyx_v_templates) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_base_type", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(((PyObject *)__pyx_v_s) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 2744, __pyx_L1_error)
  }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.nonempty = __pyx_v_nonempty;
  __pyx_t_2.templates = __pyx_v_templates;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2752
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_calling_convention(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_calling_convention(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_calling_convention", 0);

  /* "Cython/Compiler/Parsing.py":2754
 * @cython.cfunc
 * def p_calling_convention(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:             # <<<<<<<<<<<<<<
 *         result = s.systring
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2754, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2754, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2755
 * def p_calling_convention(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:
 *         result = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         return result
*/
    __pyx_t_3 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2756
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:
 *         result = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         return result
 *     else:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2756, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":2757
 *         result = s.systring
 *         s.next()
 *         return result             # <<<<<<<<<<<<<<
 *     else:
 *         return EncodedString("")
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2754
 * @cython.cfunc
 * def p_calling_convention(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:             # <<<<<<<<<<<<<<
 *         result = s.systring
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":2759
 *         return result
 *     else:
 *         return EncodedString("")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__35};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2752
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_calling_convention(s: PyrexScanner):
 *     if s.sy == 'IDENT' and s.systring in calling_convention_words:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_calling_convention", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2766
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_complex_base_type(s: PyrexScanner, templates = None):
 *     # s.sy == '('
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_complex_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_complex_base_type *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2767
 * 
 * @cython.cfunc
 * def p_c_complex_base_type(s: PyrexScanner, templates = None):             # <<<<<<<<<<<<<<
 *     # s.sy == '('
 *     pos = s.position()
*/
  PyObject *__pyx_v_templates = ((PyObject *)Py_None);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  PyObject *__pyx_v_type_node = NULL;
  PyObject *__pyx_v_components = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_complex_base_type", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_templates = __pyx_optional_args->templates;
    }
  }

  /* "Cython/Compiler/Parsing.py":2769
 * def p_c_complex_base_type(s: PyrexScanner, templates = None):
 *     # s.sy == '('
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     base_type = p_c_base_type(s, templates=templates)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2770
 *     # s.sy == '('
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     base_type = p_c_base_type(s, templates=templates)
 *     declarator = p_c_declarator(s, empty=True)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2771
 *     pos = s.position()
 *     s.next()
 *     base_type = p_c_base_type(s, templates=templates)             # <<<<<<<<<<<<<<
 *     declarator = p_c_declarator(s, empty=True)
 *     type_node = Nodes.CComplexBaseTypeNode(
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_base_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2772
 *     s.next()
 *     base_type = p_c_base_type(s, templates=templates)
 *     declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *     type_node = Nodes.CComplexBaseTypeNode(
 *         pos, base_type=base_type, declarator=declarator)
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, ((PyObject *)__pyx_v_s)};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2772, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_declarator = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2773
 *     base_type = p_c_base_type(s, templates=templates)
 *     declarator = p_c_declarator(s, empty=True)
 *     type_node = Nodes.CComplexBaseTypeNode(             # <<<<<<<<<<<<<<
 *         pos, base_type=base_type, declarator=declarator)
 *     if s.sy == ',':
*/
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_5);

  /* "Cython/Compiler/Parsing.py":2774
 *     declarator = p_c_declarator(s, empty=True)
 *     type_node = Nodes.CComplexBaseTypeNode(
 *         pos, base_type=base_type, declarator=declarator)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         components = [type_node]
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2773, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2773, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CComplexBaseTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_type_node = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2775
 *     type_node = Nodes.CComplexBaseTypeNode(
 *         pos, base_type=base_type, declarator=declarator)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         components = [type_node]
 *         while s.sy == ',':
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2775, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2776
 *         pos, base_type=base_type, declarator=declarator)
 *     if s.sy == ',':
 *         components = [type_node]             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_type_node);
    __Pyx_GIVEREF(__pyx_v_type_node);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_type_node) != (0)) __PYX_ERR(0, 2776, __pyx_L1_error);
    __pyx_v_components = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2777
 *     if s.sy == ',':
 *         components = [type_node]
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == ')':
*/
    while (1) {
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2777, __pyx_L1_error)
      if (!__pyx_t_6) break;

      /* "Cython/Compiler/Parsing.py":2778
 *         components = [type_node]
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == ')':
 *                 break
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2778, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2779
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy == ')':             # <<<<<<<<<<<<<<
 *                 break
 *             base_type = p_c_base_type(s, templates=templates)
*/
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2779, __pyx_L1_error)
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":2780
 *             s.next()
 *             if s.sy == ')':
 *                 break             # <<<<<<<<<<<<<<
 *             base_type = p_c_base_type(s, templates=templates)
 *             declarator = p_c_declarator(s, empty=True)
*/
        goto __pyx_L5_break;

        /* "Cython/Compiler/Parsing.py":2779
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy == ')':             # <<<<<<<<<<<<<<
 *                 break
 *             base_type = p_c_base_type(s, templates=templates)
*/
      }

      /* "Cython/Compiler/Parsing.py":2781
 *             if s.sy == ')':
 *                 break
 *             base_type = p_c_base_type(s, templates=templates)             # <<<<<<<<<<<<<<
 *             declarator = p_c_declarator(s, empty=True)
 *             components.append(Nodes.CComplexBaseTypeNode(
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
        __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2781, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2781, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2781, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_base_type, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2782
 *                 break
 *             base_type = p_c_base_type(s, templates=templates)
 *             declarator = p_c_declarator(s, empty=True)             # <<<<<<<<<<<<<<
 *             components.append(Nodes.CComplexBaseTypeNode(
 *                 pos, base_type=base_type, declarator=declarator))
*/
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2782, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, ((PyObject *)__pyx_v_s)};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2782, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, Py_True, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2782, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2782, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_declarator, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2783
 *             base_type = p_c_base_type(s, templates=templates)
 *             declarator = p_c_declarator(s, empty=True)
 *             components.append(Nodes.CComplexBaseTypeNode(             # <<<<<<<<<<<<<<
 *                 pos, base_type=base_type, declarator=declarator))
 *         type_node = Nodes.CTupleBaseTypeNode(pos, components = components)
*/
      __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_4);

      /* "Cython/Compiler/Parsing.py":2784
 *             declarator = p_c_declarator(s, empty=True)
 *             components.append(Nodes.CComplexBaseTypeNode(
 *                 pos, base_type=base_type, declarator=declarator))             # <<<<<<<<<<<<<<
 *         type_node = Nodes.CTupleBaseTypeNode(pos, components = components)
 * 
*/
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2783, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2783, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2783, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CComplexBaseTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":2783
 *             base_type = p_c_base_type(s, templates=templates)
 *             declarator = p_c_declarator(s, empty=True)
 *             components.append(Nodes.CComplexBaseTypeNode(             # <<<<<<<<<<<<<<
 *                 pos, base_type=base_type, declarator=declarator))
 *         type_node = Nodes.CTupleBaseTypeNode(pos, components = components)
*/
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_components, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 2783, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5_break:;

    /* "Cython/Compiler/Parsing.py":2785
 *             components.append(Nodes.CComplexBaseTypeNode(
 *                 pos, base_type=base_type, declarator=declarator))
 *         type_node = Nodes.CTupleBaseTypeNode(pos, components = components)             # <<<<<<<<<<<<<<
 * 
 *     s.expect(')')
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_components, __pyx_v_components, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2785, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CTupleBaseTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2775
 *     type_node = Nodes.CComplexBaseTypeNode(
 *         pos, base_type=base_type, declarator=declarator)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         components = [type_node]
 *         while s.sy == ',':
*/
  }

  /* "Cython/Compiler/Parsing.py":2787
 *         type_node = Nodes.CTupleBaseTypeNode(pos, components = components)
 * 
 *     s.expect(')')             # <<<<<<<<<<<<<<
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2788
 * 
 *     s.expect(')')
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2788, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2789
 *     s.expect(')')
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):             # <<<<<<<<<<<<<<
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
*/
    __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_is_memoryviewslice_access(__pyx_v_s); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2789, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":2790
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)             # <<<<<<<<<<<<<<
 *         else:
 *             type_node = p_buffer_or_template(s, type_node, templates)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_memoryviewslice_access(__pyx_v_s, __pyx_v_type_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2789
 *     s.expect(')')
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):             # <<<<<<<<<<<<<<
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/Parsing.py":2792
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
 *             type_node = p_buffer_or_template(s, type_node, templates)             # <<<<<<<<<<<<<<
 *     return type_node
 * 
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_buffer_or_template(__pyx_v_s, __pyx_v_type_node, __pyx_v_templates); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2792, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L8:;

    /* "Cython/Compiler/Parsing.py":2788
 * 
 *     s.expect(')')
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)
*/
  }

  /* "Cython/Compiler/Parsing.py":2793
 *         else:
 *             type_node = p_buffer_or_template(s, type_node, templates)
 *     return type_node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_type_node);
  __pyx_r = __pyx_v_type_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2766
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_complex_base_type(s: PyrexScanner, templates = None):
 *     # s.sy == '('
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_complex_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_type_node);
  __Pyx_XDECREF(__pyx_v_components);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2796
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):
 *     is_basic = False
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_nonempty, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_simple_base_type *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":2797
 * 
 * @cython.cfunc
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):             # <<<<<<<<<<<<<<
 *     is_basic = False
 *     signed = 1
*/
  PyObject *__pyx_v_templates = ((PyObject *)Py_None);
  int __pyx_v_is_basic;
  PyObject *__pyx_v_signed = NULL;
  PyObject *__pyx_v_longness = NULL;
  int __pyx_v_complex;
  PyObject *__pyx_v_module_path = NULL;
  PyObject *__pyx_v_pos = NULL;
  int __pyx_v_is_const;
  int __pyx_v_is_volatile;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_name_pos = NULL;
  PyObject *__pyx_v_old_pos = NULL;
  PyObject *__pyx_v_type_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_simple_base_type", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_templates = __pyx_optional_args->templates;
    }
  }

  /* "Cython/Compiler/Parsing.py":2798
 * @cython.cfunc
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):
 *     is_basic = False             # <<<<<<<<<<<<<<
 *     signed = 1
 *     longness = 0
*/
  __pyx_v_is_basic = 0;

  /* "Cython/Compiler/Parsing.py":2799
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):
 *     is_basic = False
 *     signed = 1             # <<<<<<<<<<<<<<
 *     longness = 0
 *     complex = False
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_1);
  __pyx_v_signed = __pyx_mstate_global->__pyx_int_1;

  /* "Cython/Compiler/Parsing.py":2800
 *     is_basic = False
 *     signed = 1
 *     longness = 0             # <<<<<<<<<<<<<<
 *     complex = False
 *     module_path = []
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __pyx_v_longness = __pyx_mstate_global->__pyx_int_0;

  /* "Cython/Compiler/Parsing.py":2801
 *     signed = 1
 *     longness = 0
 *     complex = False             # <<<<<<<<<<<<<<
 *     module_path = []
 *     pos = s.position()
*/
  __pyx_v_complex = 0;

  /* "Cython/Compiler/Parsing.py":2802
 *     longness = 0
 *     complex = False
 *     module_path = []             # <<<<<<<<<<<<<<
 *     pos = s.position()
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_module_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2803
 *     complex = False
 *     module_path = []
 *     pos = s.position()             # <<<<<<<<<<<<<<
 * 
 *     # Handle const/volatile
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2806
 * 
 *     # Handle const/volatile
 *     is_const = is_volatile = False             # <<<<<<<<<<<<<<
 *     while s.sy == 'IDENT':
 *         if s.systring == 'const':
*/
  __pyx_v_is_const = 0;
  __pyx_v_is_volatile = 0;

  /* "Cython/Compiler/Parsing.py":2807
 *     # Handle const/volatile
 *     is_const = is_volatile = False
 *     while s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         if s.systring == 'const':
 *             if is_const: error(pos, "Duplicate 'const'")
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2807, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":2808
 *     is_const = is_volatile = False
 *     while s.sy == 'IDENT':
 *         if s.systring == 'const':             # <<<<<<<<<<<<<<
 *             if is_const: error(pos, "Duplicate 'const'")
 *             is_const = True
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_const, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2808, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2809
 *     while s.sy == 'IDENT':
 *         if s.systring == 'const':
 *             if is_const: error(pos, "Duplicate 'const'")             # <<<<<<<<<<<<<<
 *             is_const = True
 *         elif s.systring == 'volatile':
*/
      if (__pyx_v_is_const) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Duplicate_const};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2809, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }

      /* "Cython/Compiler/Parsing.py":2810
 *         if s.systring == 'const':
 *             if is_const: error(pos, "Duplicate 'const'")
 *             is_const = True             # <<<<<<<<<<<<<<
 *         elif s.systring == 'volatile':
 *             if is_volatile: error(pos, "Duplicate 'volatile'")
*/
      __pyx_v_is_const = 1;

      /* "Cython/Compiler/Parsing.py":2808
 *     is_const = is_volatile = False
 *     while s.sy == 'IDENT':
 *         if s.systring == 'const':             # <<<<<<<<<<<<<<
 *             if is_const: error(pos, "Duplicate 'const'")
 *             is_const = True
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":2811
 *             if is_const: error(pos, "Duplicate 'const'")
 *             is_const = True
 *         elif s.systring == 'volatile':             # <<<<<<<<<<<<<<
 *             if is_volatile: error(pos, "Duplicate 'volatile'")
 *             is_volatile = True
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_volatile, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2811, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2812
 *             is_const = True
 *         elif s.systring == 'volatile':
 *             if is_volatile: error(pos, "Duplicate 'volatile'")             # <<<<<<<<<<<<<<
 *             is_volatile = True
 *         else:
*/
      if (__pyx_v_is_volatile) {
        __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Duplicate_volatile};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2812, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }

      /* "Cython/Compiler/Parsing.py":2813
 *         elif s.systring == 'volatile':
 *             if is_volatile: error(pos, "Duplicate 'volatile'")
 *             is_volatile = True             # <<<<<<<<<<<<<<
 *         else:
 *             break
*/
      __pyx_v_is_volatile = 1;

      /* "Cython/Compiler/Parsing.py":2811
 *             if is_const: error(pos, "Duplicate 'const'")
 *             is_const = True
 *         elif s.systring == 'volatile':             # <<<<<<<<<<<<<<
 *             if is_volatile: error(pos, "Duplicate 'volatile'")
 *             is_volatile = True
*/
      goto __pyx_L5;
    }

    /* "Cython/Compiler/Parsing.py":2815
 *             is_volatile = True
 *         else:
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     if is_const or is_volatile:
*/
    /*else*/ {
      goto __pyx_L4_break;
    }
    __pyx_L5:;

    /* "Cython/Compiler/Parsing.py":2816
 *         else:
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     if is_const or is_volatile:
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":2817
 *             break
 *         s.next()
 *     if is_const or is_volatile:             # <<<<<<<<<<<<<<
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):
*/
  if (!__pyx_v_is_const) {
  } else {
    __pyx_t_2 = __pyx_v_is_const;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_2 = __pyx_v_is_volatile;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2818
 *         s.next()
 *     if is_const or is_volatile:
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)             # <<<<<<<<<<<<<<
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):
 *             # reverse order to avoid having to write "(const int)[:]"
*/
    __pyx_t_6.__pyx_n = 2;
    __pyx_t_6.nonempty = __pyx_v_nonempty;
    __pyx_t_6.templates = __pyx_v_templates;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2818, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_base_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2819
 *     if is_const or is_volatile:
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):             # <<<<<<<<<<<<<<
 *             # reverse order to avoid having to write "(const int)[:]"
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_MemoryViewSliceTypeNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_IsInstance(__pyx_v_base_type, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2821
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):
 *             # reverse order to avoid having to write "(const int)[:]"
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,             # <<<<<<<<<<<<<<
 *                 base_type=base_type.base_type_node, is_const=is_const, is_volatile=is_volatile)
 *             return base_type
*/
      __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_3);

      /* "Cython/Compiler/Parsing.py":2822
 *             # reverse order to avoid having to write "(const int)[:]"
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,
 *                 base_type=base_type.base_type_node, is_const=is_const, is_volatile=is_volatile)             # <<<<<<<<<<<<<<
 *             return base_type
 *         return Nodes.CConstOrVolatileTypeNode(pos,
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_base_type, __pyx_mstate_global->__pyx_n_u_base_type_node); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_is_const); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_is_volatile); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, __pyx_v_pos};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_t_4, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2821, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_const, __pyx_t_7, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2821, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_volatile, __pyx_t_8, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CConstOrVolatileTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2821, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":2821
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):
 *             # reverse order to avoid having to write "(const int)[:]"
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,             # <<<<<<<<<<<<<<
 *                 base_type=base_type.base_type_node, is_const=is_const, is_volatile=is_volatile)
 *             return base_type
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_base_type, __pyx_mstate_global->__pyx_n_u_base_type_node, __pyx_t_1) < (0)) __PYX_ERR(0, 2821, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2823
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,
 *                 base_type=base_type.base_type_node, is_const=is_const, is_volatile=is_volatile)
 *             return base_type             # <<<<<<<<<<<<<<
 *         return Nodes.CConstOrVolatileTypeNode(pos,
 *             base_type=base_type, is_const=is_const, is_volatile=is_volatile)
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_base_type);
      __pyx_r = __pyx_v_base_type;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":2819
 *     if is_const or is_volatile:
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):             # <<<<<<<<<<<<<<
 *             # reverse order to avoid having to write "(const int)[:]"
 *             base_type.base_type_node = Nodes.CConstOrVolatileTypeNode(pos,
*/
    }

    /* "Cython/Compiler/Parsing.py":2824
 *                 base_type=base_type.base_type_node, is_const=is_const, is_volatile=is_volatile)
 *             return base_type
 *         return Nodes.CConstOrVolatileTypeNode(pos,             # <<<<<<<<<<<<<<
 *             base_type=base_type, is_const=is_const, is_volatile=is_volatile)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);

    /* "Cython/Compiler/Parsing.py":2825
 *             return base_type
 *         return Nodes.CConstOrVolatileTypeNode(pos,
 *             base_type=base_type, is_const=is_const, is_volatile=is_volatile)             # <<<<<<<<<<<<<<
 * 
 *     if s.sy != 'IDENT':
*/
    __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_is_const); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_is_volatile); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2824, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_const, __pyx_t_8, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2824, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_volatile, __pyx_t_7, __pyx_t_4, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CConstOrVolatileTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2817
 *             break
 *         s.next()
 *     if is_const or is_volatile:             # <<<<<<<<<<<<<<
 *         base_type = p_c_base_type(s, nonempty=nonempty, templates=templates)
 *         if isinstance(base_type, Nodes.MemoryViewSliceTypeNode):
*/
  }

  /* "Cython/Compiler/Parsing.py":2827
 *             base_type=base_type, is_const=is_const, is_volatile=is_volatile)
 * 
 *     if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *         error(pos, "Expected an identifier, found '%s'" % s.sy)
 *     if looking_at_base_type(s):
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2827, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2828
 * 
 *     if s.sy != 'IDENT':
 *         error(pos, "Expected an identifier, found '%s'" % s.sy)             # <<<<<<<<<<<<<<
 *     if looking_at_base_type(s):
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_8 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Expected_an_identifier_found_s, __pyx_v_s->sy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2827
 *             base_type=base_type, is_const=is_const, is_volatile=is_volatile)
 * 
 *     if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *         error(pos, "Expected an identifier, found '%s'" % s.sy)
 *     if looking_at_base_type(s):
*/
  }

  /* "Cython/Compiler/Parsing.py":2829
 *     if s.sy != 'IDENT':
 *         error(pos, "Expected an identifier, found '%s'" % s.sy)
 *     if looking_at_base_type(s):             # <<<<<<<<<<<<<<
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
 *         is_basic = True
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_base_type(__pyx_v_s); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2829, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2831
 *     if looking_at_base_type(s):
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
 *         is_basic = True             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT' and s.systring in special_basic_c_types:
 *             signed, longness = special_basic_c_types[s.systring]
*/
    __pyx_v_is_basic = 1;

    /* "Cython/Compiler/Parsing.py":2832
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
 *         is_basic = True
 *         if s.sy == 'IDENT' and s.systring in special_basic_c_types:             # <<<<<<<<<<<<<<
 *             signed, longness = special_basic_c_types[s.systring]
 *             name = s.systring
*/
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2832, __pyx_L1_error)
    if (__pyx_t_10) {
    } else {
      __pyx_t_2 = __pyx_t_10;
      goto __pyx_L15_bool_binop_done;
    }
    if (unlikely(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 2832, __pyx_L1_error)
    }
    __pyx_t_10 = (__Pyx_PyDict_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2832, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_10;
    __pyx_L15_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2833
 *         is_basic = True
 *         if s.sy == 'IDENT' and s.systring in special_basic_c_types:
 *             signed, longness = special_basic_c_types[s.systring]             # <<<<<<<<<<<<<<
 *             name = s.systring
 *             s.next()
*/
      if (unlikely(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 2833, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types, __pyx_v_s->systring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2833, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_8);
        } else {
          __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2833, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2833, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_8);
        }
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2833, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2833, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2833, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
        index = 0; __pyx_t_7 = __pyx_t_11(__pyx_t_4); if (unlikely(!__pyx_t_7)) goto __pyx_L17_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_4); if (unlikely(!__pyx_t_8)) goto __pyx_L17_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 2833, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L18_unpacking_done;
        __pyx_L17_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 2833, __pyx_L1_error)
        __pyx_L18_unpacking_done:;
      }
      __Pyx_DECREF_SET(__pyx_v_signed, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_longness, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "Cython/Compiler/Parsing.py":2834
 *         if s.sy == 'IDENT' and s.systring in special_basic_c_types:
 *             signed, longness = special_basic_c_types[s.systring]
 *             name = s.systring             # <<<<<<<<<<<<<<
 *             s.next()
 *         else:
*/
      __pyx_t_1 = __pyx_v_s->systring;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2835
 *             signed, longness = special_basic_c_types[s.systring]
 *             name = s.systring
 *             s.next()             # <<<<<<<<<<<<<<
 *         else:
 *             signed, longness = p_sign_and_longness(s)
*/
      __pyx_t_8 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2832
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
 *         is_basic = True
 *         if s.sy == 'IDENT' and s.systring in special_basic_c_types:             # <<<<<<<<<<<<<<
 *             signed, longness = special_basic_c_types[s.systring]
 *             name = s.systring
*/
      goto __pyx_L14;
    }

    /* "Cython/Compiler/Parsing.py":2837
 *             s.next()
 *         else:
 *             signed, longness = p_sign_and_longness(s)             # <<<<<<<<<<<<<<
 *             if s.sy == 'IDENT' and s.systring in basic_c_type_names:
 *                 name = s.systring
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_sign_and_longness(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(__pyx_t_1 != Py_None)) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2837, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2837, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2837, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 2837, __pyx_L1_error)
      }
      __Pyx_DECREF_SET(__pyx_v_signed, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_longness, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":2838
 *         else:
 *             signed, longness = p_sign_and_longness(s)
 *             if s.sy == 'IDENT' and s.systring in basic_c_type_names:             # <<<<<<<<<<<<<<
 *                 name = s.systring
 *                 s.next()
*/
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2838, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2838, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_10;
      __pyx_L20_bool_binop_done:;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2839
 *             signed, longness = p_sign_and_longness(s)
 *             if s.sy == 'IDENT' and s.systring in basic_c_type_names:
 *                 name = s.systring             # <<<<<<<<<<<<<<
 *                 s.next()
 *             else:
*/
        __pyx_t_1 = __pyx_v_s->systring;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_name = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2840
 *             if s.sy == 'IDENT' and s.systring in basic_c_type_names:
 *                 name = s.systring
 *                 s.next()             # <<<<<<<<<<<<<<
 *             else:
 *                 name = 'int'  # long [int], short [int], long [int] complex, etc.
*/
        __pyx_t_7 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2840, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2838
 *         else:
 *             signed, longness = p_sign_and_longness(s)
 *             if s.sy == 'IDENT' and s.systring in basic_c_type_names:             # <<<<<<<<<<<<<<
 *                 name = s.systring
 *                 s.next()
*/
        goto __pyx_L19;
      }

      /* "Cython/Compiler/Parsing.py":2842
 *                 s.next()
 *             else:
 *                 name = 'int'  # long [int], short [int], long [int] complex, etc.             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT' and s.systring == 'complex':
 *             complex = True
*/
      /*else*/ {
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_int);
        __pyx_v_name = __pyx_mstate_global->__pyx_n_u_int;
      }
      __pyx_L19:;
    }
    __pyx_L14:;

    /* "Cython/Compiler/Parsing.py":2843
 *             else:
 *                 name = 'int'  # long [int], short [int], long [int] complex, etc.
 *         if s.sy == 'IDENT' and s.systring == 'complex':             # <<<<<<<<<<<<<<
 *             complex = True
 *             s.next()
*/
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2843, __pyx_L1_error)
    if (__pyx_t_10) {
    } else {
      __pyx_t_2 = __pyx_t_10;
      goto __pyx_L23_bool_binop_done;
    }
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_complex, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2843, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_10;
    __pyx_L23_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2844
 *                 name = 'int'  # long [int], short [int], long [int] complex, etc.
 *         if s.sy == 'IDENT' and s.systring == 'complex':
 *             complex = True             # <<<<<<<<<<<<<<
 *             s.next()
 *     elif looking_at_dotted_name(s):
*/
      __pyx_v_complex = 1;

      /* "Cython/Compiler/Parsing.py":2845
 *         if s.sy == 'IDENT' and s.systring == 'complex':
 *             complex = True
 *             s.next()             # <<<<<<<<<<<<<<
 *     elif looking_at_dotted_name(s):
 *         #print "p_c_simple_base_type: looking_at_type_name at", s.position()
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2845, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2843
 *             else:
 *                 name = 'int'  # long [int], short [int], long [int] complex, etc.
 *         if s.sy == 'IDENT' and s.systring == 'complex':             # <<<<<<<<<<<<<<
 *             complex = True
 *             s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":2829
 *     if s.sy != 'IDENT':
 *         error(pos, "Expected an identifier, found '%s'" % s.sy)
 *     if looking_at_base_type(s):             # <<<<<<<<<<<<<<
 *         #print "p_c_simple_base_type: looking_at_base_type at", s.position()
 *         is_basic = True
*/
    goto __pyx_L13;
  }

  /* "Cython/Compiler/Parsing.py":2846
 *             complex = True
 *             s.next()
 *     elif looking_at_dotted_name(s):             # <<<<<<<<<<<<<<
 *         #print "p_c_simple_base_type: looking_at_type_name at", s.position()
 *         name = s.systring
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_dotted_name(__pyx_v_s); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2846, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":2848
 *     elif looking_at_dotted_name(s):
 *         #print "p_c_simple_base_type: looking_at_type_name at", s.position()
 *         name = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         while s.sy == '.':
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2849
 *         #print "p_c_simple_base_type: looking_at_type_name at", s.position()
 *         name = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         while s.sy == '.':
 *             module_path.append(name)
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2850
 *         name = s.systring
 *         s.next()
 *         while s.sy == '.':             # <<<<<<<<<<<<<<
 *             module_path.append(name)
 *             s.next()
*/
    while (1) {
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2850, __pyx_L1_error)
      if (!__pyx_t_2) break;

      /* "Cython/Compiler/Parsing.py":2851
 *         s.next()
 *         while s.sy == '.':
 *             module_path.append(name)             # <<<<<<<<<<<<<<
 *             s.next()
 *             name = p_ident(s)
*/
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_module_path, __pyx_v_name); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 2851, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":2852
 *         while s.sy == '.':
 *             module_path.append(name)
 *             s.next()             # <<<<<<<<<<<<<<
 *             name = p_ident(s)
 *     else:
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2853
 *             module_path.append(name)
 *             s.next()
 *             name = p_ident(s)             # <<<<<<<<<<<<<<
 *     else:
 *         name = s.systring
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
      __pyx_t_1 = 0;
    }

    /* "Cython/Compiler/Parsing.py":2846
 *             complex = True
 *             s.next()
 *     elif looking_at_dotted_name(s):             # <<<<<<<<<<<<<<
 *         #print "p_c_simple_base_type: looking_at_type_name at", s.position()
 *         name = s.systring
*/
    goto __pyx_L13;
  }

  /* "Cython/Compiler/Parsing.py":2855
 *             name = p_ident(s)
 *     else:
 *         name = s.systring             # <<<<<<<<<<<<<<
 *         name_pos = s.position()
 *         s.next()
*/
  /*else*/ {
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2856
 *     else:
 *         name = s.systring
 *         name_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         if nonempty and s.sy != 'IDENT':
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_name_pos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2857
 *         name = s.systring
 *         name_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         if nonempty and s.sy != 'IDENT':
 *             # Make sure this is not a declaration of a variable or function.
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2858
 *         name_pos = s.position()
 *         s.next()
 *         if nonempty and s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *             # Make sure this is not a declaration of a variable or function.
 *             if s.sy == '(':
*/
    if (__pyx_v_nonempty) {
    } else {
      __pyx_t_2 = __pyx_v_nonempty;
      goto __pyx_L28_bool_binop_done;
    }
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2858, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_10;
    __pyx_L28_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":2860
 *         if nonempty and s.sy != 'IDENT':
 *             # Make sure this is not a declaration of a variable or function.
 *             if s.sy == '(':             # <<<<<<<<<<<<<<
 *                 old_pos = s.position()
 *                 s.next()
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2860, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":2861
 *             # Make sure this is not a declaration of a variable or function.
 *             if s.sy == '(':
 *                 old_pos = s.position()             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2861, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_old_pos = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2862
 *             if s.sy == '(':
 *                 old_pos = s.position()
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):
*/
        __pyx_t_7 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2862, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2863
 *                 old_pos = s.position()
 *                 s.next()
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'             # <<<<<<<<<<<<<<
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):
 *                     s.put_back('(', '(', old_pos)
*/
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2863, __pyx_L1_error)
        if (!__pyx_t_10) {
        } else {
          __pyx_t_2 = __pyx_t_10;
          goto __pyx_L32_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2863, __pyx_L1_error)
        if (!__pyx_t_10) {
        } else {
          __pyx_t_2 = __pyx_t_10;
          goto __pyx_L32_bool_binop_done;
        }

        /* "Cython/Compiler/Parsing.py":2864
 *                 s.next()
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):             # <<<<<<<<<<<<<<
 *                     s.put_back('(', '(', old_pos)
 *                 else:
*/
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__11, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2863, __pyx_L1_error)
        if (!__pyx_t_10) {
        } else {
          __pyx_t_2 = __pyx_t_10;
          goto __pyx_L32_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2864, __pyx_L1_error)
        if (__pyx_t_10) {
        } else {
          __pyx_t_2 = __pyx_t_10;
          goto __pyx_L32_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2864, __pyx_L1_error)
        __pyx_t_2 = __pyx_t_10;
        __pyx_L32_bool_binop_done:;

        /* "Cython/Compiler/Parsing.py":2863
 *                 old_pos = s.position()
 *                 s.next()
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'             # <<<<<<<<<<<<<<
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):
 *                     s.put_back('(', '(', old_pos)
*/
        if (__pyx_t_2) {

          /* "Cython/Compiler/Parsing.py":2865
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):
 *                     s.put_back('(', '(', old_pos)             # <<<<<<<<<<<<<<
 *                 else:
 *                     s.put_back('(', '(', old_pos)
*/
          __pyx_t_7 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__23, __pyx_mstate_global->__pyx_kp_u__23, __pyx_v_old_pos};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2865, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":2863
 *                 old_pos = s.position()
 *                 s.next()
 *                 if (s.sy == '*' or s.sy == '**' or s.sy == '&'             # <<<<<<<<<<<<<<
 *                         or (s.sy == 'IDENT' and s.systring in calling_convention_words)):
 *                     s.put_back('(', '(', old_pos)
*/
          goto __pyx_L31;
        }

        /* "Cython/Compiler/Parsing.py":2867
 *                     s.put_back('(', '(', old_pos)
 *                 else:
 *                     s.put_back('(', '(', old_pos)             # <<<<<<<<<<<<<<
 *                     s.put_back('IDENT', name, name_pos)
 *                     name = None
*/
        /*else*/ {
          __pyx_t_7 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__23, __pyx_mstate_global->__pyx_kp_u__23, __pyx_v_old_pos};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2867, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":2868
 *                 else:
 *                     s.put_back('(', '(', old_pos)
 *                     s.put_back('IDENT', name, name_pos)             # <<<<<<<<<<<<<<
 *                     name = None
 *             elif s.sy not in ('*', '**', '[', '&'):
*/
          __pyx_t_7 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_mstate_global->__pyx_n_u_IDENT, __pyx_v_name, __pyx_v_name_pos};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2868, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":2869
 *                     s.put_back('(', '(', old_pos)
 *                     s.put_back('IDENT', name, name_pos)
 *                     name = None             # <<<<<<<<<<<<<<
 *             elif s.sy not in ('*', '**', '[', '&'):
 *                 s.put_back('IDENT', name, name_pos)
*/
          __Pyx_INCREF(Py_None);
          __Pyx_DECREF_SET(__pyx_v_name, Py_None);
        }
        __pyx_L31:;

        /* "Cython/Compiler/Parsing.py":2860
 *         if nonempty and s.sy != 'IDENT':
 *             # Make sure this is not a declaration of a variable or function.
 *             if s.sy == '(':             # <<<<<<<<<<<<<<
 *                 old_pos = s.position()
 *                 s.next()
*/
        goto __pyx_L30;
      }

      /* "Cython/Compiler/Parsing.py":2870
 *                     s.put_back('IDENT', name, name_pos)
 *                     name = None
 *             elif s.sy not in ('*', '**', '[', '&'):             # <<<<<<<<<<<<<<
 *                 s.put_back('IDENT', name, name_pos)
 *                 name = None
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_13 = __pyx_v_s->sy;
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_13, __pyx_mstate_global->__pyx_kp_u__6, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2870, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L37_bool_binop_done;
      }
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_13, __pyx_mstate_global->__pyx_kp_u__28, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2870, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L37_bool_binop_done;
      }
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_13, __pyx_mstate_global->__pyx_kp_u__26, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2870, __pyx_L1_error)
      if (__pyx_t_10) {
      } else {
        __pyx_t_2 = __pyx_t_10;
        goto __pyx_L37_bool_binop_done;
      }
      __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_13, __pyx_mstate_global->__pyx_kp_u__11, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2870, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_10;
      __pyx_L37_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_10 = __pyx_t_2;
      if (__pyx_t_10) {

        /* "Cython/Compiler/Parsing.py":2871
 *                     name = None
 *             elif s.sy not in ('*', '**', '[', '&'):
 *                 s.put_back('IDENT', name, name_pos)             # <<<<<<<<<<<<<<
 *                 name = None
 * 
*/
        __pyx_t_7 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_mstate_global->__pyx_n_u_IDENT, __pyx_v_name, __pyx_v_name_pos};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2871, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":2872
 *             elif s.sy not in ('*', '**', '[', '&'):
 *                 s.put_back('IDENT', name, name_pos)
 *                 name = None             # <<<<<<<<<<<<<<
 * 
 *     type_node = Nodes.CSimpleBaseTypeNode(pos,
*/
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_name, Py_None);

        /* "Cython/Compiler/Parsing.py":2870
 *                     s.put_back('IDENT', name, name_pos)
 *                     name = None
 *             elif s.sy not in ('*', '**', '[', '&'):             # <<<<<<<<<<<<<<
 *                 s.put_back('IDENT', name, name_pos)
 *                 name = None
*/
      }
      __pyx_L30:;

      /* "Cython/Compiler/Parsing.py":2858
 *         name_pos = s.position()
 *         s.next()
 *         if nonempty and s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *             # Make sure this is not a declaration of a variable or function.
 *             if s.sy == '(':
*/
    }
  }
  __pyx_L13:;

  /* "Cython/Compiler/Parsing.py":2874
 *                 name = None
 * 
 *     type_node = Nodes.CSimpleBaseTypeNode(pos,             # <<<<<<<<<<<<<<
 *         name = name, module_path = module_path,
 *         is_basic_c_type = is_basic, signed = signed,
*/
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":2876
 *     type_node = Nodes.CSimpleBaseTypeNode(pos,
 *         name = name, module_path = module_path,
 *         is_basic_c_type = is_basic, signed = signed,             # <<<<<<<<<<<<<<
 *         complex = complex, longness = longness,
 *         templates = templates)
*/
  __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_is_basic); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "Cython/Compiler/Parsing.py":2877
 *         name = name, module_path = module_path,
 *         is_basic_c_type = is_basic, signed = signed,
 *         complex = complex, longness = longness,             # <<<<<<<<<<<<<<
 *         templates = templates)
 * 
*/
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_complex); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":2878
 *         is_basic_c_type = is_basic, signed = signed,
 *         complex = complex, longness = longness,
 *         templates = templates)             # <<<<<<<<<<<<<<
 * 
 *     #    declarations here.
*/
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 7 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_path, __pyx_v_module_path, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_basic_c_type, __pyx_t_8, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signed, __pyx_v_signed, __pyx_t_9, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_complex, __pyx_t_4, __pyx_t_9, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_longness, __pyx_v_longness, __pyx_t_9, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_9, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 2874, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CSimpleBaseTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_type_node = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2881
 * 
 *     #    declarations here.
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)
*/
  __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2881, __pyx_L1_error)
  if (__pyx_t_10) {

    /* "Cython/Compiler/Parsing.py":2882
 *     #    declarations here.
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):             # <<<<<<<<<<<<<<
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
*/
    __pyx_t_10 = __pyx_f_6Cython_8Compiler_7Parsing_is_memoryviewslice_access(__pyx_v_s); if (unlikely(__pyx_t_10 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2882, __pyx_L1_error)
    if (__pyx_t_10) {

      /* "Cython/Compiler/Parsing.py":2883
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)             # <<<<<<<<<<<<<<
 *         else:
 *             type_node = p_buffer_or_template(s, type_node, templates)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_memoryviewslice_access(__pyx_v_s, __pyx_v_type_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":2882
 *     #    declarations here.
 *     if s.sy == '[':
 *         if is_memoryviewslice_access(s):             # <<<<<<<<<<<<<<
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
*/
      goto __pyx_L42;
    }

    /* "Cython/Compiler/Parsing.py":2885
 *             type_node = p_memoryviewslice_access(s, type_node)
 *         else:
 *             type_node = p_buffer_or_template(s, type_node, templates)             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == '.':
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_buffer_or_template(__pyx_v_s, __pyx_v_type_node, __pyx_v_templates); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L42:;

    /* "Cython/Compiler/Parsing.py":2881
 * 
 *     #    declarations here.
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if is_memoryviewslice_access(s):
 *             type_node = p_memoryviewslice_access(s, type_node)
*/
  }

  /* "Cython/Compiler/Parsing.py":2887
 *             type_node = p_buffer_or_template(s, type_node, templates)
 * 
 *     if s.sy == '.':             # <<<<<<<<<<<<<<
 *         s.next()
 *         name = p_ident(s)
*/
  __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2887, __pyx_L1_error)
  if (__pyx_t_10) {

    /* "Cython/Compiler/Parsing.py":2888
 * 
 *     if s.sy == '.':
 *         s.next()             # <<<<<<<<<<<<<<
 *         name = p_ident(s)
 *         type_node = Nodes.CNestedBaseTypeNode(pos, base_type = type_node, name = name)
*/
    __pyx_t_9 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2889
 *     if s.sy == '.':
 *         s.next()
 *         name = p_ident(s)             # <<<<<<<<<<<<<<
 *         type_node = Nodes.CNestedBaseTypeNode(pos, base_type = type_node, name = name)
 * 
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2890
 *         s.next()
 *         name = p_ident(s)
 *         type_node = Nodes.CNestedBaseTypeNode(pos, base_type = type_node, name = name)             # <<<<<<<<<<<<<<
 * 
 *     return type_node
*/
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_type_node, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2890, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CNestedBaseTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_type_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2887
 *             type_node = p_buffer_or_template(s, type_node, templates)
 * 
 *     if s.sy == '.':             # <<<<<<<<<<<<<<
 *         s.next()
 *         name = p_ident(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":2892
 *         type_node = Nodes.CNestedBaseTypeNode(pos, base_type = type_node, name = name)
 * 
 *     return type_node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_type_node);
  __pyx_r = __pyx_v_type_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2796
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_simple_base_type(s: PyrexScanner, nonempty: cython.bint, templates=None):
 *     is_basic = False
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_simple_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_signed);
  __Pyx_XDECREF(__pyx_v_longness);
  __Pyx_XDECREF(__pyx_v_module_path);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_name_pos);
  __Pyx_XDECREF(__pyx_v_old_pos);
  __Pyx_XDECREF(__pyx_v_type_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2895
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_buffer_or_template(s: PyrexScanner, base_type_node, templates):
 *     # s.sy == '['
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_buffer_or_template(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_base_type_node, PyObject *__pyx_v_templates) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  PyObject *__pyx_v_keyword_dict = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_key = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_buffer_or_template", 0);
  __Pyx_INCREF(__pyx_v_base_type_node);

  /* "Cython/Compiler/Parsing.py":2898
 * def p_buffer_or_template(s: PyrexScanner, base_type_node, templates):
 *     # s.sy == '['
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     # Note that buffer_positional_options_count=1, so the only positional argument is dtype.
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2899
 *     # s.sy == '['
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     # Note that buffer_positional_options_count=1, so the only positional argument is dtype.
 *     # For templated types, all parameters are types.
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2903
 *     # For templated types, all parameters are types.
 *     positional_args, keyword_args = (
 *         p_positional_and_keyword_args(s, (']',), templates)             # <<<<<<<<<<<<<<
 *     )
 *     s.expect(']')
*/
  __pyx_t_4.__pyx_n = 1;
  __pyx_t_4.templates = __pyx_v_templates;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_positional_and_keyword_args(__pyx_v_s, __pyx_mstate_global->__pyx_tuple[11], &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 2902, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 2902, __pyx_L1_error)
  }

  /* "Cython/Compiler/Parsing.py":2902
 *     # Note that buffer_positional_options_count=1, so the only positional argument is dtype.
 *     # For templated types, all parameters are types.
 *     positional_args, keyword_args = (             # <<<<<<<<<<<<<<
 *         p_positional_and_keyword_args(s, (']',), templates)
 *     )
*/
  __pyx_v_positional_args = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_keyword_args = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":2905
 *         p_positional_and_keyword_args(s, (']',), templates)
 *     )
 *     s.expect(']')             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == '[':
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2907
 *     s.expect(']')
 * 
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         base_type_node = p_buffer_or_template(s, base_type_node, templates)
 * 
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2907, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":2908
 * 
 *     if s.sy == '[':
 *         base_type_node = p_buffer_or_template(s, base_type_node, templates)             # <<<<<<<<<<<<<<
 * 
 *     keyword_dict = ExprNodes.DictNode(pos,
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_buffer_or_template(__pyx_v_s, __pyx_v_base_type_node, __pyx_v_templates); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_base_type_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":2907
 *     s.expect(']')
 * 
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         base_type_node = p_buffer_or_template(s, base_type_node, templates)
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":2910
 *         base_type_node = p_buffer_or_template(s, base_type_node, templates)
 * 
 *     keyword_dict = ExprNodes.DictNode(pos,             # <<<<<<<<<<<<<<
 *         key_value_pairs = [
 *             ExprNodes.DictItemNode(pos=key.pos, key=key, value=value)
*/
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_5);
  { /* enter inner scope */

    /* "Cython/Compiler/Parsing.py":2911
 * 
 *     keyword_dict = ExprNodes.DictNode(pos,
 *         key_value_pairs = [             # <<<<<<<<<<<<<<
 *             ExprNodes.DictItemNode(pos=key.pos, key=key, value=value)
 *             for key, value in keyword_args
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2911, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":2913
 *         key_value_pairs = [
 *             ExprNodes.DictItemNode(pos=key.pos, key=key, value=value)
 *             for key, value in keyword_args             # <<<<<<<<<<<<<<
 *         ])
 *     result = Nodes.TemplatedTypeNode(pos,
*/
    if (likely(PyList_CheckExact(__pyx_v_keyword_args)) || PyTuple_CheckExact(__pyx_v_keyword_args)) {
      __pyx_t_7 = __pyx_v_keyword_args; __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_keyword_args); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2913, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2913, __pyx_L6_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2913, __pyx_L6_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          __pyx_t_10 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_8;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2913, __pyx_L6_error)
            #endif
            if (__pyx_t_8 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_8));
          #else
          __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8);
          #endif
          ++__pyx_t_8;
        }
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L6_error)
      } else {
        __pyx_t_10 = __pyx_t_9(__pyx_t_7);
        if (unlikely(!__pyx_t_10)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 2913, __pyx_L6_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_10);
      if ((likely(PyTuple_CheckExact(__pyx_t_10))) || (PyList_CheckExact(__pyx_t_10))) {
        PyObject* sequence = __pyx_t_10;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2913, __pyx_L6_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_11);
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_12);
        } else {
          __pyx_t_11 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2913, __pyx_L6_error)
          __Pyx_XGOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2913, __pyx_L6_error)
          __Pyx_XGOTREF(__pyx_t_12);
        }
        #else
        __pyx_t_11 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2913, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2913, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2913, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
        index = 0; __pyx_t_11 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_11)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        index = 1; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < (0)) __PYX_ERR(0, 2913, __pyx_L6_error)
        __pyx_t_14 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 2913, __pyx_L6_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_key, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_value, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "Cython/Compiler/Parsing.py":2912
 *     keyword_dict = ExprNodes.DictNode(pos,
 *         key_value_pairs = [
 *             ExprNodes.DictItemNode(pos=key.pos, key=key, value=value)             # <<<<<<<<<<<<<<
 *             for key, value in keyword_args
 *         ])
*/
      __pyx_t_12 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_12);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr3__pyx_v_key, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2912, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_12, NULL};
        __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2912, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_11, __pyx_t_13, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 2912, __pyx_L6_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key, __pyx_8genexpr3__pyx_v_key, __pyx_t_13, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 2912, __pyx_L6_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_8genexpr3__pyx_v_value, __pyx_t_13, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 2912, __pyx_L6_error)
        __pyx_t_10 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictItemNode, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2912, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_10))) __PYX_ERR(0, 2911, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "Cython/Compiler/Parsing.py":2913
 *         key_value_pairs = [
 *             ExprNodes.DictItemNode(pos=key.pos, key=key, value=value)
 *             for key, value in keyword_args             # <<<<<<<<<<<<<<
 *         ])
 *     result = Nodes.TemplatedTypeNode(pos,
*/
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_key); __pyx_8genexpr3__pyx_v_key = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_value); __pyx_8genexpr3__pyx_v_value = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_key); __pyx_8genexpr3__pyx_v_key = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_value); __pyx_8genexpr3__pyx_v_value = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key_value_pairs, __pyx_t_2, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DictNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_keyword_dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2915
 *             for key, value in keyword_args
 *         ])
 *     result = Nodes.TemplatedTypeNode(pos,             # <<<<<<<<<<<<<<
 *         positional_args = positional_args,
 *         keyword_args = keyword_dict,
*/
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":2918
 *         positional_args = positional_args,
 *         keyword_args = keyword_dict,
 *         base_type_node = base_type_node)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_positional_args, __pyx_v_positional_args, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2915, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_args, __pyx_v_keyword_dict, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2915, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type_node, __pyx_v_base_type_node, __pyx_t_2, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TemplatedTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2919
 *         keyword_args = keyword_dict,
 *         base_type_node = base_type_node)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2895
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_buffer_or_template(s: PyrexScanner, base_type_node, templates):
 *     # s.sy == '['
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_buffer_or_template", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_keyword_dict);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_key);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_base_type_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2922
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def is_memoryviewslice_access(s: PyrexScanner) -> cython.bint:
 *     # s.sy == '['
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_is_memoryviewslice_access(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_saved = NULL;
  int __pyx_v_retval;
  PyObject *__pyx_v_sv = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_memoryviewslice_access", 0);

  /* "Cython/Compiler/Parsing.py":2928
 *     # declaration by the first entry in the bracketed list.  The buffer will
 *     # not have an unnested colon in the first entry; the memoryview slice will.
 *     saved = [(s.sy, s.systring, s.position())]             # <<<<<<<<<<<<<<
 *     s.next()
 *     retval = False
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_s->sy);
  __Pyx_GIVEREF(__pyx_v_s->sy);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_s->sy) != (0)) __PYX_ERR(0, 2928, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_s->systring);
  __Pyx_GIVEREF(__pyx_v_s->systring);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_s->systring) != (0)) __PYX_ERR(0, 2928, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 2928, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 2928, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_v_saved = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2929
 *     # not have an unnested colon in the first entry; the memoryview slice will.
 *     saved = [(s.sy, s.systring, s.position())]
 *     s.next()             # <<<<<<<<<<<<<<
 *     retval = False
 *     if s.systring == ':':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2930
 *     saved = [(s.sy, s.systring, s.position())]
 *     s.next()
 *     retval = False             # <<<<<<<<<<<<<<
 *     if s.systring == ':':
 *         retval = True
*/
  __pyx_v_retval = 0;

  /* "Cython/Compiler/Parsing.py":2931
 *     s.next()
 *     retval = False
 *     if s.systring == ':':             # <<<<<<<<<<<<<<
 *         retval = True
 *     elif s.sy == 'INT':
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2931, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2932
 *     retval = False
 *     if s.systring == ':':
 *         retval = True             # <<<<<<<<<<<<<<
 *     elif s.sy == 'INT':
 *         saved.append((s.sy, s.systring, s.position()))
*/
    __pyx_v_retval = 1;

    /* "Cython/Compiler/Parsing.py":2931
 *     s.next()
 *     retval = False
 *     if s.systring == ':':             # <<<<<<<<<<<<<<
 *         retval = True
 *     elif s.sy == 'INT':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":2933
 *     if s.systring == ':':
 *         retval = True
 *     elif s.sy == 'INT':             # <<<<<<<<<<<<<<
 *         saved.append((s.sy, s.systring, s.position()))
 *         s.next()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_INT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2933, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":2934
 *         retval = True
 *     elif s.sy == 'INT':
 *         saved.append((s.sy, s.systring, s.position()))             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ':':
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_s->sy);
    __Pyx_GIVEREF(__pyx_v_s->sy);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_s->sy) != (0)) __PYX_ERR(0, 2934, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_s->systring);
    __Pyx_GIVEREF(__pyx_v_s->systring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_s->systring) != (0)) __PYX_ERR(0, 2934, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 2934, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_saved, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2935
 *     elif s.sy == 'INT':
 *         saved.append((s.sy, s.systring, s.position()))
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == ':':
 *             retval = True
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2936
 *         saved.append((s.sy, s.systring, s.position()))
 *         s.next()
 *         if s.sy == ':':             # <<<<<<<<<<<<<<
 *             retval = True
 * 
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2936, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":2937
 *         s.next()
 *         if s.sy == ':':
 *             retval = True             # <<<<<<<<<<<<<<
 * 
 *     for sv in saved[::-1]:
*/
      __pyx_v_retval = 1;

      /* "Cython/Compiler/Parsing.py":2936
 *         saved.append((s.sy, s.systring, s.position()))
 *         s.next()
 *         if s.sy == ':':             # <<<<<<<<<<<<<<
 *             retval = True
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":2933
 *     if s.systring == ':':
 *         retval = True
 *     elif s.sy == 'INT':             # <<<<<<<<<<<<<<
 *         saved.append((s.sy, s.systring, s.position()))
 *         s.next()
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":2939
 *             retval = True
 * 
 *     for sv in saved[::-1]:             # <<<<<<<<<<<<<<
 *         s.put_back(*sv)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_saved, __pyx_mstate_global->__pyx_slice[1]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2939, __pyx_L1_error)
      #endif
      if (__pyx_t_6 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_6;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_sv, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2940
 * 
 *     for sv in saved[::-1]:
 *         s.put_back(*sv)             # <<<<<<<<<<<<<<
 * 
 *     return retval
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PySequence_Tuple(__pyx_v_sv); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "Cython/Compiler/Parsing.py":2939
 *             retval = True
 * 
 *     for sv in saved[::-1]:             # <<<<<<<<<<<<<<
 *         s.put_back(*sv)
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2942
 *         s.put_back(*sv)
 * 
 *     return retval             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = __pyx_v_retval;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2922
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def is_memoryviewslice_access(s: PyrexScanner) -> cython.bint:
 *     # s.sy == '['
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.is_memoryviewslice_access", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_saved);
  __Pyx_XDECREF(__pyx_v_sv);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2945
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_memoryviewslice_access(s: PyrexScanner, base_type_node):
 *     # s.sy == '['
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_memoryviewslice_access(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_base_type_node) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_subscripts = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_subscript = NULL;
  PyObject *__pyx_v_indexes = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_memoryviewslice_access", 0);

  /* "Cython/Compiler/Parsing.py":2948
 * def p_memoryviewslice_access(s: PyrexScanner, base_type_node):
 *     # s.sy == '['
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     subscripts, _ = p_subscript_list(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2949
 *     # s.sy == '['
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     subscripts, _ = p_subscript_list(s)
 *     # make sure each entry in subscripts is a slice
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2950
 *     pos = s.position()
 *     s.next()
 *     subscripts, _ = p_subscript_list(s)             # <<<<<<<<<<<<<<
 *     # make sure each entry in subscripts is a slice
 *     for subscript in subscripts:
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_subscript_list(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 2950, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 2950, __pyx_L1_error)
  }
  __pyx_v_subscripts = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v__ = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":2952
 *     subscripts, _ = p_subscript_list(s)
 *     # make sure each entry in subscripts is a slice
 *     for subscript in subscripts:             # <<<<<<<<<<<<<<
 *         if len(subscript) < 2:
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
*/
  if (likely(PyList_CheckExact(__pyx_v_subscripts)) || PyTuple_CheckExact(__pyx_v_subscripts)) {
    __pyx_t_1 = __pyx_v_subscripts; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_subscripts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2952, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2952, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_5;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2952, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5);
        #endif
        ++__pyx_t_5;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2952, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 2952, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_subscript, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":2953
 *     # make sure each entry in subscripts is a slice
 *     for subscript in subscripts:
 *         if len(subscript) < 2:             # <<<<<<<<<<<<<<
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
 *     s.expect(']')
*/
    __pyx_t_7 = PyObject_Length(__pyx_v_subscript); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 2953, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_7 < 2);
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":2954
 *     for subscript in subscripts:
 *         if len(subscript) < 2:
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")             # <<<<<<<<<<<<<<
 *     s.expect(']')
 *     indexes = make_slice_nodes(pos, subscripts)
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_An_axis_specification_in_memoryv};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/Parsing.py":2953
 *     # make sure each entry in subscripts is a slice
 *     for subscript in subscripts:
 *         if len(subscript) < 2:             # <<<<<<<<<<<<<<
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
 *     s.expect(']')
*/
    }

    /* "Cython/Compiler/Parsing.py":2952
 *     subscripts, _ = p_subscript_list(s)
 *     # make sure each entry in subscripts is a slice
 *     for subscript in subscripts:             # <<<<<<<<<<<<<<
 *         if len(subscript) < 2:
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2955
 *         if len(subscript) < 2:
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
 *     s.expect(']')             # <<<<<<<<<<<<<<
 *     indexes = make_slice_nodes(pos, subscripts)
 *     result = Nodes.MemoryViewSliceTypeNode(pos,
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2956
 *             s.error("An axis specification in memoryview declaration does not have a ':'.")
 *     s.expect(']')
 *     indexes = make_slice_nodes(pos, subscripts)             # <<<<<<<<<<<<<<
 *     result = Nodes.MemoryViewSliceTypeNode(pos,
 *             base_type_node = base_type_node,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_make_slice_nodes(__pyx_v_pos, __pyx_v_subscripts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_indexes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2957
 *     s.expect(']')
 *     indexes = make_slice_nodes(pos, subscripts)
 *     result = Nodes.MemoryViewSliceTypeNode(pos,             # <<<<<<<<<<<<<<
 *             base_type_node = base_type_node,
 *             axes = indexes)
*/
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":2959
 *     result = Nodes.MemoryViewSliceTypeNode(pos,
 *             base_type_node = base_type_node,
 *             axes = indexes)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type_node, __pyx_v_base_type_node, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2957, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_axes, __pyx_v_indexes, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 2957, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_MemoryViewSliceTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":2960
 *             base_type_node = base_type_node,
 *             axes = indexes)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2945
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_memoryviewslice_access(s: PyrexScanner, base_type_node):
 *     # s.sy == '['
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_memoryviewslice_access", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_subscripts);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_subscript);
  __Pyx_XDECREF(__pyx_v_indexes);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2963
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_name(s: PyrexScanner) -> cython.bint:
 *     return s.sy == 'IDENT' and s.systring not in calling_convention_words
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "Cython/Compiler/Parsing.py":2965
 * @cython.cfunc
 * def looking_at_name(s: PyrexScanner) -> cython.bint:
 *     return s.sy == 'IDENT' and s.systring not in calling_convention_words             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2965, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2965, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":2963
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_name(s: PyrexScanner) -> cython.bint:
 *     return s.sy == 'IDENT' and s.systring not in calling_convention_words
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Parsing.looking_at_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":2968
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_expr(s: PyrexScanner) -> cython.bint:
 *     if s.systring in base_type_start_words:
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_is_type = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_name_pos = NULL;
  PyObject *__pyx_v_dotted_path = NULL;
  PyObject *__pyx_v_saved = NULL;
  PyObject *__pyx_v_p = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("looking_at_expr", 0);

  /* "Cython/Compiler/Parsing.py":2970
 * @cython.cfunc
 * def looking_at_expr(s: PyrexScanner) -> cython.bint:
 *     if s.systring in base_type_start_words:             # <<<<<<<<<<<<<<
 *         return False
 *     elif s.sy == 'IDENT':
*/
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2970, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2971
 * def looking_at_expr(s: PyrexScanner) -> cython.bint:
 *     if s.systring in base_type_start_words:
 *         return False             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT':
 *         is_type = False
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2970
 * @cython.cfunc
 * def looking_at_expr(s: PyrexScanner) -> cython.bint:
 *     if s.systring in base_type_start_words:             # <<<<<<<<<<<<<<
 *         return False
 *     elif s.sy == 'IDENT':
*/
  }

  /* "Cython/Compiler/Parsing.py":2972
 *     if s.systring in base_type_start_words:
 *         return False
 *     elif s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         is_type = False
 *         name = s.systring
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2972, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":2973
 *         return False
 *     elif s.sy == 'IDENT':
 *         is_type = False             # <<<<<<<<<<<<<<
 *         name = s.systring
 *         name_pos = s.position()
*/
    __Pyx_INCREF(Py_False);
    __pyx_v_is_type = Py_False;

    /* "Cython/Compiler/Parsing.py":2974
 *     elif s.sy == 'IDENT':
 *         is_type = False
 *         name = s.systring             # <<<<<<<<<<<<<<
 *         name_pos = s.position()
 *         dotted_path = []
*/
    __pyx_t_2 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_name = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2975
 *         is_type = False
 *         name = s.systring
 *         name_pos = s.position()             # <<<<<<<<<<<<<<
 *         dotted_path = []
 *         s.next()
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_name_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2976
 *         name = s.systring
 *         name_pos = s.position()
 *         dotted_path = []             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_dotted_path = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2977
 *         name_pos = s.position()
 *         dotted_path = []
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *         while s.sy == '.':
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2979
 *         s.next()
 * 
 *         while s.sy == '.':             # <<<<<<<<<<<<<<
 *             s.next()
 *             dotted_path.append((s.systring, s.position()))
*/
    while (1) {
      __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2979, __pyx_L1_error)
      if (!__pyx_t_1) break;

      /* "Cython/Compiler/Parsing.py":2980
 * 
 *         while s.sy == '.':
 *             s.next()             # <<<<<<<<<<<<<<
 *             dotted_path.append((s.systring, s.position()))
 *             s.expect('IDENT')
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2980, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2981
 *         while s.sy == '.':
 *             s.next()
 *             dotted_path.append((s.systring, s.position()))             # <<<<<<<<<<<<<<
 *             s.expect('IDENT')
 * 
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_s->systring);
      __Pyx_GIVEREF(__pyx_v_s->systring);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_s->systring) != (0)) __PYX_ERR(0, 2981, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 2981, __pyx_L1_error);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_dotted_path, __pyx_t_3); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2981, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2982
 *             s.next()
 *             dotted_path.append((s.systring, s.position()))
 *             s.expect('IDENT')             # <<<<<<<<<<<<<<
 * 
 *         saved = s.sy, s.systring, s.position()
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_IDENT};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2982, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "Cython/Compiler/Parsing.py":2984
 *             s.expect('IDENT')
 * 
 *         saved = s.sy, s.systring, s.position()             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT':
 *             is_type = True
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_s->sy);
    __Pyx_GIVEREF(__pyx_v_s->sy);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_s->sy) != (0)) __PYX_ERR(0, 2984, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_s->systring);
    __Pyx_GIVEREF(__pyx_v_s->systring);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_s->systring) != (0)) __PYX_ERR(0, 2984, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_3) != (0)) __PYX_ERR(0, 2984, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_v_saved = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":2985
 * 
 *         saved = s.sy, s.systring, s.position()
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             is_type = True
 *         elif s.sy == '*' or s.sy == '**':
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2985, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":2986
 *         saved = s.sy, s.systring, s.position()
 *         if s.sy == 'IDENT':
 *             is_type = True             # <<<<<<<<<<<<<<
 *         elif s.sy == '*' or s.sy == '**':
 *             s.next()
*/
      __Pyx_INCREF(Py_True);
      __Pyx_DECREF_SET(__pyx_v_is_type, Py_True);

      /* "Cython/Compiler/Parsing.py":2985
 * 
 *         saved = s.sy, s.systring, s.position()
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             is_type = True
 *         elif s.sy == '*' or s.sy == '**':
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":2987
 *         if s.sy == 'IDENT':
 *             is_type = True
 *         elif s.sy == '*' or s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy in (')', ']')
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2987, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2987, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":2988
 *             is_type = True
 *         elif s.sy == '*' or s.sy == '**':
 *             s.next()             # <<<<<<<<<<<<<<
 *             is_type = s.sy in (')', ']')
 *             s.put_back(*saved)
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2988, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2989
 *         elif s.sy == '*' or s.sy == '**':
 *             s.next()
 *             is_type = s.sy in (')', ']')             # <<<<<<<<<<<<<<
 *             s.put_back(*saved)
 *         elif s.sy == '(':
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_7 = __pyx_v_s->sy;
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2989, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_1 = __pyx_t_6;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__30, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2989, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_6;
      __pyx_L9_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2989, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_is_type, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2990
 *             s.next()
 *             is_type = s.sy in (')', ']')
 *             s.put_back(*saved)             # <<<<<<<<<<<<<<
 *         elif s.sy == '(':
 *             s.next()
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_v_saved, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2987
 *         if s.sy == 'IDENT':
 *             is_type = True
 *         elif s.sy == '*' or s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy in (')', ']')
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":2991
 *             is_type = s.sy in (')', ']')
 *             s.put_back(*saved)
 *         elif s.sy == '(':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy == '*'
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2991, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":2992
 *             s.put_back(*saved)
 *         elif s.sy == '(':
 *             s.next()             # <<<<<<<<<<<<<<
 *             is_type = s.sy == '*'
 *             s.put_back(*saved)
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2992, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2993
 *         elif s.sy == '(':
 *             s.next()
 *             is_type = s.sy == '*'             # <<<<<<<<<<<<<<
 *             s.put_back(*saved)
 *         elif s.sy == '[':
*/
      __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2993, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_is_type, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2994
 *             s.next()
 *             is_type = s.sy == '*'
 *             s.put_back(*saved)             # <<<<<<<<<<<<<<
 *         elif s.sy == '[':
 *             s.next()
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_v_saved, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2991
 *             is_type = s.sy in (')', ']')
 *             s.put_back(*saved)
 *         elif s.sy == '(':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy == '*'
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":2995
 *             is_type = s.sy == '*'
 *             s.put_back(*saved)
 *         elif s.sy == '[':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy == ']' or not looking_at_expr(s)  # could be a nested template type
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2995, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":2996
 *             s.put_back(*saved)
 *         elif s.sy == '[':
 *             s.next()             # <<<<<<<<<<<<<<
 *             is_type = s.sy == ']' or not looking_at_expr(s)  # could be a nested template type
 *             s.put_back(*saved)
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2996, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2997
 *         elif s.sy == '[':
 *             s.next()
 *             is_type = s.sy == ']' or not looking_at_expr(s)  # could be a nested template type             # <<<<<<<<<<<<<<
 *             s.put_back(*saved)
 * 
*/
      __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__30, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2997, __pyx_L1_error)
      if (!__pyx_t_1) {
      } else {
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2997, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_expr(__pyx_v_s); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2997, __pyx_L1_error)
      __pyx_t_6 = (!__pyx_t_1);
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2997, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      __pyx_L11_bool_binop_done:;
      __Pyx_DECREF_SET(__pyx_v_is_type, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":2998
 *             s.next()
 *             is_type = s.sy == ']' or not looking_at_expr(s)  # could be a nested template type
 *             s.put_back(*saved)             # <<<<<<<<<<<<<<
 * 
 *         dotted_path.reverse()
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2998, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_v_saved, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2998, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":2995
 *             is_type = s.sy == '*'
 *             s.put_back(*saved)
 *         elif s.sy == '[':             # <<<<<<<<<<<<<<
 *             s.next()
 *             is_type = s.sy == ']' or not looking_at_expr(s)  # could be a nested template type
*/
    }
    __pyx_L6:;

    /* "Cython/Compiler/Parsing.py":3000
 *             s.put_back(*saved)
 * 
 *         dotted_path.reverse()             # <<<<<<<<<<<<<<
 *         for p in dotted_path:
 *             s.put_back('IDENT', *p)
*/
    __pyx_t_5 = PyList_Reverse(__pyx_v_dotted_path); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 3000, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3001
 * 
 *         dotted_path.reverse()
 *         for p in dotted_path:             # <<<<<<<<<<<<<<
 *             s.put_back('IDENT', *p)
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong
*/
    __pyx_t_3 = __pyx_v_dotted_path; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_8 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3001, __pyx_L1_error)
        #endif
        if (__pyx_t_8 >= __pyx_temp) break;
      }
      __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_8;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3001, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3002
 *         dotted_path.reverse()
 *         for p in dotted_path:
 *             s.put_back('IDENT', *p)             # <<<<<<<<<<<<<<
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong
 * 
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_put_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PySequence_Tuple(__pyx_v_p); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = PyNumber_Add(__pyx_mstate_global->__pyx_tuple[12], __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "Cython/Compiler/Parsing.py":3003
 *         for p in dotted_path:
 *             s.put_back('IDENT', *p)
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong             # <<<<<<<<<<<<<<
 * 
 *         s.put_back('IDENT', name, name_pos)
*/
      __pyx_t_10 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_p, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u__27, __pyx_mstate_global->__pyx_kp_u__27, __pyx_t_2};
        __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "Cython/Compiler/Parsing.py":3001
 * 
 *         dotted_path.reverse()
 *         for p in dotted_path:             # <<<<<<<<<<<<<<
 *             s.put_back('IDENT', *p)
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3005
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong
 * 
 *         s.put_back('IDENT', name, name_pos)             # <<<<<<<<<<<<<<
 *         return not is_type and saved[0]
 *     else:
*/
    __pyx_t_9 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_mstate_global->__pyx_n_u_IDENT, __pyx_v_name, __pyx_v_name_pos};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3006
 * 
 *         s.put_back('IDENT', name, name_pos)
 *         return not is_type and saved[0]             # <<<<<<<<<<<<<<
 *     else:
 *         return True
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_is_type); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3006, __pyx_L1_error)
    __pyx_t_11 = (!__pyx_t_1);
    if (__pyx_t_11) {
    } else {
      __pyx_t_6 = __pyx_t_11;
      goto __pyx_L16_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_saved, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_3 == Py_None) __pyx_t_11 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_t_3);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3006, __pyx_L1_error)
      __pyx_t_11 = (__pyx_temp != 0);
    }

    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __pyx_t_11;
    __pyx_L16_bool_binop_done:;
    __pyx_r = __pyx_t_6;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":2972
 *     if s.systring in base_type_start_words:
 *         return False
 *     elif s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         is_type = False
 *         name = s.systring
*/
  }

  /* "Cython/Compiler/Parsing.py":3008
 *         return not is_type and saved[0]
 *     else:
 *         return True             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 1;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":2968
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_expr(s: PyrexScanner) -> cython.bint:
 *     if s.systring in base_type_start_words:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.looking_at_expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_is_type);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_name_pos);
  __Pyx_XDECREF(__pyx_v_dotted_path);
  __Pyx_XDECREF(__pyx_v_saved);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3011
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_base_type(s: PyrexScanner) -> cython.bint:
 *     #print "looking_at_base_type?", s.sy, s.systring, s.position()
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_base_type(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "Cython/Compiler/Parsing.py":3014
 * def looking_at_base_type(s: PyrexScanner) -> cython.bint:
 *     #print "looking_at_base_type?", s.sy, s.systring, s.position()
 *     return s.sy == 'IDENT' and s.systring in base_type_start_words             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3014, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3014, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3011
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_base_type(s: PyrexScanner) -> cython.bint:
 *     #print "looking_at_base_type?", s.sy, s.systring, s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Parsing.looking_at_base_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3017
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_dotted_name(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT':
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_looking_at_dotted_name(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_name_pos = NULL;
  int __pyx_v_result;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("looking_at_dotted_name", 0);

  /* "Cython/Compiler/Parsing.py":3019
 * @cython.cfunc
 * def looking_at_dotted_name(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.systring
 *         name_pos = s.position()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3019, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3020
 * def looking_at_dotted_name(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT':
 *         name = s.systring             # <<<<<<<<<<<<<<
 *         name_pos = s.position()
 *         s.next()
*/
    __pyx_t_2 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_name = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3021
 *     if s.sy == 'IDENT':
 *         name = s.systring
 *         name_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         result: cython.bint = s.sy == '.'
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3021, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_name_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3022
 *         name = s.systring
 *         name_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         result: cython.bint = s.sy == '.'
 *         s.put_back('IDENT', name, name_pos)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3023
 *         name_pos = s.position()
 *         s.next()
 *         result: cython.bint = s.sy == '.'             # <<<<<<<<<<<<<<
 *         s.put_back('IDENT', name, name_pos)
 *         return result
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3023, __pyx_L1_error)
    __pyx_v_result = __pyx_t_1;

    /* "Cython/Compiler/Parsing.py":3024
 *         s.next()
 *         result: cython.bint = s.sy == '.'
 *         s.put_back('IDENT', name, name_pos)             # <<<<<<<<<<<<<<
 *         return result
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_IDENT, __pyx_v_name, __pyx_v_name_pos};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_put_back, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3025
 *         result: cython.bint = s.sy == '.'
 *         s.put_back('IDENT', name, name_pos)
 *         return result             # <<<<<<<<<<<<<<
 *     else:
 *         return False
*/
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3019
 * @cython.cfunc
 * def looking_at_dotted_name(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.systring
 *         name_pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":3027
 *         return result
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3017
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def looking_at_dotted_name(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.looking_at_dotted_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_name_pos);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3058
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sign_and_longness(s: PyrexScanner) -> tuple:
 *     signed = 1
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sign_and_longness(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  long __pyx_v_signed;
  long __pyx_v_longness;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_sign_and_longness", 0);

  /* "Cython/Compiler/Parsing.py":3060
 * @cython.cfunc
 * def p_sign_and_longness(s: PyrexScanner) -> tuple:
 *     signed = 1             # <<<<<<<<<<<<<<
 *     longness = 0
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:
*/
  __pyx_v_signed = 1;

  /* "Cython/Compiler/Parsing.py":3061
 * def p_sign_and_longness(s: PyrexScanner) -> tuple:
 *     signed = 1
 *     longness = 0             # <<<<<<<<<<<<<<
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:
 *         if s.systring == 'unsigned':
*/
  __pyx_v_longness = 0;

  /* "Cython/Compiler/Parsing.py":3062
 *     signed = 1
 *     longness = 0
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:             # <<<<<<<<<<<<<<
 *         if s.systring == 'unsigned':
 *             signed = 0
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3062, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3062, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;
    if (!__pyx_t_1) break;

    /* "Cython/Compiler/Parsing.py":3063
 *     longness = 0
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:
 *         if s.systring == 'unsigned':             # <<<<<<<<<<<<<<
 *             signed = 0
 *         elif s.systring == 'signed':
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_unsigned, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3063, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3064
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:
 *         if s.systring == 'unsigned':
 *             signed = 0             # <<<<<<<<<<<<<<
 *         elif s.systring == 'signed':
 *             signed = 2
*/
      __pyx_v_signed = 0;

      /* "Cython/Compiler/Parsing.py":3063
 *     longness = 0
 *     while s.sy == 'IDENT' and s.systring in sign_and_longness_words:
 *         if s.systring == 'unsigned':             # <<<<<<<<<<<<<<
 *             signed = 0
 *         elif s.systring == 'signed':
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Parsing.py":3065
 *         if s.systring == 'unsigned':
 *             signed = 0
 *         elif s.systring == 'signed':             # <<<<<<<<<<<<<<
 *             signed = 2
 *         elif s.systring == 'short':
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_signed, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3065, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3066
 *             signed = 0
 *         elif s.systring == 'signed':
 *             signed = 2             # <<<<<<<<<<<<<<
 *         elif s.systring == 'short':
 *             longness = -1
*/
      __pyx_v_signed = 2;

      /* "Cython/Compiler/Parsing.py":3065
 *         if s.systring == 'unsigned':
 *             signed = 0
 *         elif s.systring == 'signed':             # <<<<<<<<<<<<<<
 *             signed = 2
 *         elif s.systring == 'short':
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Parsing.py":3067
 *         elif s.systring == 'signed':
 *             signed = 2
 *         elif s.systring == 'short':             # <<<<<<<<<<<<<<
 *             longness = -1
 *         elif s.systring == 'long':
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_short, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3067, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3068
 *             signed = 2
 *         elif s.systring == 'short':
 *             longness = -1             # <<<<<<<<<<<<<<
 *         elif s.systring == 'long':
 *             longness += 1
*/
      __pyx_v_longness = -1L;

      /* "Cython/Compiler/Parsing.py":3067
 *         elif s.systring == 'signed':
 *             signed = 2
 *         elif s.systring == 'short':             # <<<<<<<<<<<<<<
 *             longness = -1
 *         elif s.systring == 'long':
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Parsing.py":3069
 *         elif s.systring == 'short':
 *             longness = -1
 *         elif s.systring == 'long':             # <<<<<<<<<<<<<<
 *             longness += 1
 *         s.next()
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_long, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3069, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3070
 *             longness = -1
 *         elif s.systring == 'long':
 *             longness += 1             # <<<<<<<<<<<<<<
 *         s.next()
 *     return signed, longness
*/
      __pyx_v_longness = (__pyx_v_longness + 1);

      /* "Cython/Compiler/Parsing.py":3069
 *         elif s.systring == 'short':
 *             longness = -1
 *         elif s.systring == 'long':             # <<<<<<<<<<<<<<
 *             longness += 1
 *         s.next()
*/
    }
    __pyx_L7:;

    /* "Cython/Compiler/Parsing.py":3071
 *         elif s.systring == 'long':
 *             longness += 1
 *         s.next()             # <<<<<<<<<<<<<<
 *     return signed, longness
 * 
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }

  /* "Cython/Compiler/Parsing.py":3072
 *             longness += 1
 *         s.next()
 *     return signed, longness             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyLong_From_long(__pyx_v_signed); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyLong_From_long(__pyx_v_longness); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 3072, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 3072, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3058
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sign_and_longness(s: PyrexScanner) -> tuple:
 *     signed = 1
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_sign_and_longness", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3075
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_opt_cname(s: PyrexScanner):
 *     literal = p_opt_string_literal(s, 'u')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_literal = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_opt_string_literal __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_opt_cname", 0);

  /* "Cython/Compiler/Parsing.py":3077
 * @cython.cfunc
 * def p_opt_cname(s: PyrexScanner):
 *     literal = p_opt_string_literal(s, 'u')             # <<<<<<<<<<<<<<
 *     if literal is not None:
 *         cname = EncodedString(literal)
*/
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.required_type = __pyx_mstate_global->__pyx_n_u_u;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_string_literal(__pyx_v_s, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_literal = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3078
 * def p_opt_cname(s: PyrexScanner):
 *     literal = p_opt_string_literal(s, 'u')
 *     if literal is not None:             # <<<<<<<<<<<<<<
 *         cname = EncodedString(literal)
 *         cname.encoding = s.source_encoding
*/
  __pyx_t_3 = (__pyx_v_literal != Py_None);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":3079
 *     literal = p_opt_string_literal(s, 'u')
 *     if literal is not None:
 *         cname = EncodedString(literal)             # <<<<<<<<<<<<<<
 *         cname.encoding = s.source_encoding
 *     else:
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_literal};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_cname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3080
 *     if literal is not None:
 *         cname = EncodedString(literal)
 *         cname.encoding = s.source_encoding             # <<<<<<<<<<<<<<
 *     else:
 *         cname = None
*/
    __pyx_t_1 = __pyx_v_s->source_encoding;
    __Pyx_INCREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cname, __pyx_mstate_global->__pyx_n_u_encoding, __pyx_t_1) < (0)) __PYX_ERR(0, 3080, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3078
 * def p_opt_cname(s: PyrexScanner):
 *     literal = p_opt_string_literal(s, 'u')
 *     if literal is not None:             # <<<<<<<<<<<<<<
 *         cname = EncodedString(literal)
 *         cname.encoding = s.source_encoding
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3082
 *         cname.encoding = s.source_encoding
 *     else:
 *         cname = None             # <<<<<<<<<<<<<<
 *     return cname
 * 
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_cname = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3083
 *     else:
 *         cname = None
 *     return cname             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cname);
  __pyx_r = __pyx_v_cname;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3075
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_opt_cname(s: PyrexScanner):
 *     literal = p_opt_string_literal(s, 'u')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_opt_cname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_literal);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_5p_c_declarator(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator *__pyx_optional_args) {
  PyObject *__pyx_v_ctx = __pyx_mstate_global->__pyx_k__45;

  /* "Cython/Compiler/Parsing.py":3088
 * @cython.ccall
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,             # <<<<<<<<<<<<<<
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
 *                    calling_convention_allowed: cython.bint = False):
*/
  int __pyx_v_empty = ((int)0);
  int __pyx_v_is_type = ((int)0);
  int __pyx_v_cmethod_flag = ((int)0);

  /* "Cython/Compiler/Parsing.py":3089
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,             # <<<<<<<<<<<<<<
 *                    calling_convention_allowed: cython.bint = False):
 *     # If empty is true, the declarator must be empty. If nonempty is true,
*/
  int __pyx_v_assignable = ((int)0);
  int __pyx_v_nonempty = ((int)0);

  /* "Cython/Compiler/Parsing.py":3090
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
 *                    calling_convention_allowed: cython.bint = False):             # <<<<<<<<<<<<<<
 *     # If empty is true, the declarator must be empty. If nonempty is true,
 *     # the declarator must be nonempty. Otherwise we don't care.
*/
  int __pyx_v_calling_convention_allowed = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_declarator", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_ctx = __pyx_optional_args->ctx;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_empty = __pyx_optional_args->empty;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_is_type = __pyx_optional_args->is_type;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_cmethod_flag = __pyx_optional_args->cmethod_flag;
            if (__pyx_optional_args->__pyx_n > 4) {
              __pyx_v_assignable = __pyx_optional_args->assignable;
              if (__pyx_optional_args->__pyx_n > 5) {
                __pyx_v_nonempty = __pyx_optional_args->nonempty;
                if (__pyx_optional_args->__pyx_n > 6) {
                  __pyx_v_calling_convention_allowed = __pyx_optional_args->calling_convention_allowed;
                }
              }
            }
          }
        }
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":3095
 *     # If cmethod_flag is true, then if this declarator declares
 *     # a function, it's a C method of an extension type.
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3096
 *     # a function, it's a C method of an extension type.
 *     pos = s.position()
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ')' or looking_at_name(s):
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3096, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3097
 *     pos = s.position()
 *     if s.sy == '(':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == ')' or looking_at_name(s):
 *             base = Nodes.CNameDeclaratorNode(pos, name=s.context.intern_ustring(""), cname=None)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3097, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3098
 *     if s.sy == '(':
 *         s.next()
 *         if s.sy == ')' or looking_at_name(s):             # <<<<<<<<<<<<<<
 *             base = Nodes.CNameDeclaratorNode(pos, name=s.context.intern_ustring(""), cname=None)
 *             result = p_c_func_declarator(s, pos, ctx, base, cmethod_flag)
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3098, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_looking_at_name(__pyx_v_s); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3098, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3099
 *         s.next()
 *         if s.sy == ')' or looking_at_name(s):
 *             base = Nodes.CNameDeclaratorNode(pos, name=s.context.intern_ustring(""), cname=None)             # <<<<<<<<<<<<<<
 *             result = p_c_func_declarator(s, pos, ctx, base, cmethod_flag)
 *         else:
*/
      __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_7 = __pyx_v_s->context;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__35};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_intern_ustring, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_v_pos};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_6, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3099, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, Py_None, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3099, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CNameDeclaratorNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3099, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_base = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3100
 *         if s.sy == ')' or looking_at_name(s):
 *             base = Nodes.CNameDeclaratorNode(pos, name=s.context.intern_ustring(""), cname=None)
 *             result = p_c_func_declarator(s, pos, ctx, base, cmethod_flag)             # <<<<<<<<<<<<<<
 *         else:
 *             result = p_c_declarator(s, ctx, empty = empty, is_type = is_type,
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_declarator(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx, __pyx_v_base, __pyx_v_cmethod_flag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3100, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3098
 *     if s.sy == '(':
 *         s.next()
 *         if s.sy == ')' or looking_at_name(s):             # <<<<<<<<<<<<<<
 *             base = Nodes.CNameDeclaratorNode(pos, name=s.context.intern_ustring(""), cname=None)
 *             result = p_c_func_declarator(s, pos, ctx, base, cmethod_flag)
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":3102
 *             result = p_c_func_declarator(s, pos, ctx, base, cmethod_flag)
 *         else:
 *             result = p_c_declarator(s, ctx, empty = empty, is_type = is_type,             # <<<<<<<<<<<<<<
 *                                     cmethod_flag = cmethod_flag,
 *                                     nonempty = nonempty,
*/
    /*else*/ {
      __pyx_t_7 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_is_type); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);

      /* "Cython/Compiler/Parsing.py":3103
 *         else:
 *             result = p_c_declarator(s, ctx, empty = empty, is_type = is_type,
 *                                     cmethod_flag = cmethod_flag,             # <<<<<<<<<<<<<<
 *                                     nonempty = nonempty,
 *                                     calling_convention_allowed = True)
*/
      __pyx_t_9 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3103, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);

      /* "Cython/Compiler/Parsing.py":3104
 *             result = p_c_declarator(s, ctx, empty = empty, is_type = is_type,
 *                                     cmethod_flag = cmethod_flag,
 *                                     nonempty = nonempty,             # <<<<<<<<<<<<<<
 *                                     calling_convention_allowed = True)
 *             s.expect(')')
*/
      __pyx_t_10 = __Pyx_PyBool_FromLong(__pyx_v_nonempty); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);

      /* "Cython/Compiler/Parsing.py":3105
 *                                     cmethod_flag = cmethod_flag,
 *                                     nonempty = nonempty,
 *                                     calling_convention_allowed = True)             # <<<<<<<<<<<<<<
 *             s.expect(')')
 *     else:
*/
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_7, ((PyObject *)__pyx_v_s), __pyx_v_ctx};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3102, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_empty, __pyx_t_3, __pyx_t_11, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3102, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_type, __pyx_t_8, __pyx_t_11, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 3102, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_t_9, __pyx_t_11, __pyx_callargs+3, 2) < (0)) __PYX_ERR(0, 3102, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty, __pyx_t_10, __pyx_t_11, __pyx_callargs+3, 3) < (0)) __PYX_ERR(0, 3102, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_calling_convention_allowed, Py_True, __pyx_t_11, __pyx_callargs+3, 4) < (0)) __PYX_ERR(0, 3102, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3102, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3106
 *                                     nonempty = nonempty,
 *                                     calling_convention_allowed = True)
 *             s.expect(')')             # <<<<<<<<<<<<<<
 *     else:
 *         result = p_c_simple_declarator(s, ctx, empty, is_type, cmethod_flag,
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__24};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3106, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":3096
 *     # a function, it's a C method of an extension type.
 *     pos = s.position()
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == ')' or looking_at_name(s):
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3108
 *             s.expect(')')
 *     else:
 *         result = p_c_simple_declarator(s, ctx, empty, is_type, cmethod_flag,             # <<<<<<<<<<<<<<
 *                                        assignable, nonempty)
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':
*/
  /*else*/ {

    /* "Cython/Compiler/Parsing.py":3109
 *     else:
 *         result = p_c_simple_declarator(s, ctx, empty, is_type, cmethod_flag,
 *                                        assignable, nonempty)             # <<<<<<<<<<<<<<
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':
 *         error(s.position(), "%s on something that is not a function"
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_declarator(__pyx_v_s, __pyx_v_ctx, __pyx_v_empty, __pyx_v_is_type, __pyx_v_cmethod_flag, __pyx_v_assignable, __pyx_v_nonempty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3110
 *         result = p_c_simple_declarator(s, ctx, empty, is_type, cmethod_flag,
 *                                        assignable, nonempty)
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':             # <<<<<<<<<<<<<<
 *         error(s.position(), "%s on something that is not a function"
 *             % result.calling_convention)
*/
  __pyx_t_5 = (!__pyx_v_calling_convention_allowed);
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_mstate_global->__pyx_n_u_calling_convention); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3110, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_5;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3111
 *                                        assignable, nonempty)
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':
 *         error(s.position(), "%s on something that is not a function"             # <<<<<<<<<<<<<<
 *             % result.calling_convention)
 *     while s.sy in ('[', '('):
*/
    __pyx_t_6 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_10 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);

    /* "Cython/Compiler/Parsing.py":3112
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':
 *         error(s.position(), "%s on something that is not a function"
 *             % result.calling_convention)             # <<<<<<<<<<<<<<
 *     while s.sy in ('[', '('):
 *         pos = s.position()
*/
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_mstate_global->__pyx_n_u_calling_convention); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_s_on_something_that_is_not_a_fu, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_10, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3110
 *         result = p_c_simple_declarator(s, ctx, empty, is_type, cmethod_flag,
 *                                        assignable, nonempty)
 *     if not calling_convention_allowed and result.calling_convention and s.sy != '(':             # <<<<<<<<<<<<<<
 *         error(s.position(), "%s on something that is not a function"
 *             % result.calling_convention)
*/
  }

  /* "Cython/Compiler/Parsing.py":3113
 *         error(s.position(), "%s on something that is not a function"
 *             % result.calling_convention)
 *     while s.sy in ('[', '('):             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         if s.sy == '[':
*/
  while (1) {
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_12 = __pyx_v_s->sy;
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_12, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3113, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_12, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3113, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_5;
    __pyx_L13_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_5 = __pyx_t_2;
    if (!__pyx_t_5) break;

    /* "Cython/Compiler/Parsing.py":3114
 *             % result.calling_convention)
 *     while s.sy in ('[', '('):
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         if s.sy == '[':
 *             result = p_c_array_declarator(s, result)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_pos, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3115
 *     while s.sy in ('[', '('):
 *         pos = s.position()
 *         if s.sy == '[':             # <<<<<<<<<<<<<<
 *             result = p_c_array_declarator(s, result)
 *         else:  # sy == '('
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3115, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":3116
 *         pos = s.position()
 *         if s.sy == '[':
 *             result = p_c_array_declarator(s, result)             # <<<<<<<<<<<<<<
 *         else:  # sy == '('
 *             s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_array_declarator(__pyx_v_s, __pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3115
 *     while s.sy in ('[', '('):
 *         pos = s.position()
 *         if s.sy == '[':             # <<<<<<<<<<<<<<
 *             result = p_c_array_declarator(s, result)
 *         else:  # sy == '('
*/
      goto __pyx_L15;
    }

    /* "Cython/Compiler/Parsing.py":3118
 *             result = p_c_array_declarator(s, result)
 *         else:  # sy == '('
 *             s.next()             # <<<<<<<<<<<<<<
 *             result = p_c_func_declarator(s, pos, ctx, result, cmethod_flag)
 *         cmethod_flag = 0
*/
    /*else*/ {
      __pyx_t_11 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3119
 *         else:  # sy == '('
 *             s.next()
 *             result = p_c_func_declarator(s, pos, ctx, result, cmethod_flag)             # <<<<<<<<<<<<<<
 *         cmethod_flag = 0
 *     return result
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_declarator(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx, __pyx_v_result, __pyx_v_cmethod_flag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L15:;

    /* "Cython/Compiler/Parsing.py":3120
 *             s.next()
 *             result = p_c_func_declarator(s, pos, ctx, result, cmethod_flag)
 *         cmethod_flag = 0             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    __pyx_v_cmethod_flag = 0;
  }

  /* "Cython/Compiler/Parsing.py":3121
 *             result = p_c_func_declarator(s, pos, ctx, result, cmethod_flag)
 *         cmethod_flag = 0
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_5p_c_declarator(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_5p_c_declarator = {"p_c_declarator", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_5p_c_declarator, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_5p_c_declarator(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s = 0;
  PyObject *__pyx_v_ctx = 0;
  int __pyx_v_empty;
  int __pyx_v_is_type;
  int __pyx_v_cmethod_flag;
  int __pyx_v_assignable;
  int __pyx_v_nonempty;
  int __pyx_v_calling_convention_allowed;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p_c_declarator (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s,&__pyx_mstate_global->__pyx_n_u_ctx,&__pyx_mstate_global->__pyx_n_u_empty,&__pyx_mstate_global->__pyx_n_u_is_type,&__pyx_mstate_global->__pyx_n_u_cmethod_flag,&__pyx_mstate_global->__pyx_n_u_assignable,&__pyx_mstate_global->__pyx_n_u_nonempty,&__pyx_mstate_global->__pyx_n_u_calling_convention_allowed,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 3086, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "p_c_declarator", 0) < (0)) __PYX_ERR(0, 3086, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__45);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("p_c_declarator", 0, 1, 8, i); __PYX_ERR(0, 3086, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3086, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__45);
    }
    __pyx_v_s = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)values[0]);
    __pyx_v_ctx = values[1];
    if (values[2]) {
      __pyx_v_empty = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_empty == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3088, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3088
 * @cython.ccall
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,             # <<<<<<<<<<<<<<
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
 *                    calling_convention_allowed: cython.bint = False):
*/
      __pyx_v_empty = ((int)0);
    }
    if (values[3]) {
      __pyx_v_is_type = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_is_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3088, __pyx_L3_error)
    } else {
      __pyx_v_is_type = ((int)0);
    }
    if (values[4]) {
      __pyx_v_cmethod_flag = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_cmethod_flag == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3088, __pyx_L3_error)
    } else {
      __pyx_v_cmethod_flag = ((int)0);
    }
    if (values[5]) {
      __pyx_v_assignable = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_assignable == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3089, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3089
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,             # <<<<<<<<<<<<<<
 *                    calling_convention_allowed: cython.bint = False):
 *     # If empty is true, the declarator must be empty. If nonempty is true,
*/
      __pyx_v_assignable = ((int)0);
    }
    if (values[6]) {
      __pyx_v_nonempty = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_nonempty == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3089, __pyx_L3_error)
    } else {
      __pyx_v_nonempty = ((int)0);
    }
    if (values[7]) {
      __pyx_v_calling_convention_allowed = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_calling_convention_allowed == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3090, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3090
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
 *                    calling_convention_allowed: cython.bint = False):             # <<<<<<<<<<<<<<
 *     # If empty is true, the declarator must be empty. If nonempty is true,
 *     # the declarator must be nonempty. Otherwise we don't care.
*/
      __pyx_v_calling_convention_allowed = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("p_c_declarator", 0, 1, 8, __pyx_nargs); __PYX_ERR(0, 3086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "s", 0))) __PYX_ERR(0, 3087, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_4p_c_declarator(__pyx_self, __pyx_v_s, __pyx_v_ctx, __pyx_v_empty, __pyx_v_is_type, __pyx_v_cmethod_flag, __pyx_v_assignable, __pyx_v_nonempty, __pyx_v_calling_convention_allowed);

  /* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_4p_c_declarator(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_empty, int __pyx_v_is_type, int __pyx_v_cmethod_flag, int __pyx_v_assignable, int __pyx_v_nonempty, int __pyx_v_calling_convention_allowed) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_declarator", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(((PyObject *)__pyx_v_s) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 3086, __pyx_L1_error)
  }
  __pyx_t_2.__pyx_n = 7;
  __pyx_t_2.ctx = __pyx_v_ctx;
  __pyx_t_2.empty = __pyx_v_empty;
  __pyx_t_2.is_type = __pyx_v_is_type;
  __pyx_t_2.cmethod_flag = __pyx_v_cmethod_flag;
  __pyx_t_2.assignable = __pyx_v_assignable;
  __pyx_t_2.nonempty = __pyx_v_nonempty;
  __pyx_t_2.calling_convention_allowed = __pyx_v_calling_convention_allowed;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_declarator(__pyx_v_s, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3124
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_array_declarator(s: PyrexScanner, base):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_array_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_dim = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_array_declarator", 0);

  /* "Cython/Compiler/Parsing.py":3126
 * @cython.cfunc
 * def p_c_array_declarator(s: PyrexScanner, base):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()  # '['
 *     if s.sy != ']':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3127
 * def p_c_array_declarator(s: PyrexScanner, base):
 *     pos = s.position()
 *     s.next()  # '['             # <<<<<<<<<<<<<<
 *     if s.sy != ']':
 *         dim = p_testlist(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3128
 *     pos = s.position()
 *     s.next()  # '['
 *     if s.sy != ']':             # <<<<<<<<<<<<<<
 *         dim = p_testlist(s)
 *     else:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__30, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3128, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3129
 *     s.next()  # '['
 *     if s.sy != ']':
 *         dim = p_testlist(s)             # <<<<<<<<<<<<<<
 *     else:
 *         dim = None
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_testlist(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_dim = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3128
 *     pos = s.position()
 *     s.next()  # '['
 *     if s.sy != ']':             # <<<<<<<<<<<<<<
 *         dim = p_testlist(s)
 *     else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3131
 *         dim = p_testlist(s)
 *     else:
 *         dim = None             # <<<<<<<<<<<<<<
 *     s.expect(']')
 *     return Nodes.CArrayDeclaratorNode(pos, base = base, dimension = dim)
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_dim = Py_None;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3132
 *     else:
 *         dim = None
 *     s.expect(']')             # <<<<<<<<<<<<<<
 *     return Nodes.CArrayDeclaratorNode(pos, base = base, dimension = dim)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__30};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3133
 *         dim = None
 *     s.expect(']')
 *     return Nodes.CArrayDeclaratorNode(pos, base = base, dimension = dim)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3133, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_dimension, __pyx_v_dim, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CArrayDeclaratorNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3124
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_array_declarator(s: PyrexScanner, base):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_array_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_dim);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3136
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_func_declarator(s: PyrexScanner, pos, ctx, base, cmethod_flag: cython.bint):
 *     # Opening paren has already been skipped
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_func_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx, PyObject *__pyx_v_base, int __pyx_v_cmethod_flag) {
  PyObject *__pyx_v_args = NULL;
  int __pyx_v_ellipsis;
  int __pyx_v_nogil;
  PyObject *__pyx_v_exc_val = NULL;
  PyObject *__pyx_v_exc_check = NULL;
  PyObject *__pyx_v_exc_clause = NULL;
  int __pyx_v_with_gil;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_func_declarator", 0);

  /* "Cython/Compiler/Parsing.py":3139
 * def p_c_func_declarator(s: PyrexScanner, pos, ctx, base, cmethod_flag: cython.bint):
 *     # Opening paren has already been skipped
 *     args = p_c_arg_list(s, ctx, cmethod_flag = cmethod_flag,             # <<<<<<<<<<<<<<
 *                         nonempty_declarators = 0)
 *     ellipsis = p_optional_ellipsis(s)
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_p_c_arg_list); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, ((PyObject *)__pyx_v_s), __pyx_v_ctx};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_t_4, __pyx_t_6, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3139, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty_declarators, __pyx_mstate_global->__pyx_int_0, __pyx_t_6, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 3139, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 3139, __pyx_L1_error)
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3141
 *     args = p_c_arg_list(s, ctx, cmethod_flag = cmethod_flag,
 *                         nonempty_declarators = 0)
 *     ellipsis = p_optional_ellipsis(s)             # <<<<<<<<<<<<<<
 *     s.expect(')')
 *     nogil = p_nogil(s)
*/
  __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_optional_ellipsis(__pyx_v_s); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3141, __pyx_L1_error)
  __pyx_v_ellipsis = __pyx_t_7;

  /* "Cython/Compiler/Parsing.py":3142
 *                         nonempty_declarators = 0)
 *     ellipsis = p_optional_ellipsis(s)
 *     s.expect(')')             # <<<<<<<<<<<<<<
 *     nogil = p_nogil(s)
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3143
 *     ellipsis = p_optional_ellipsis(s)
 *     s.expect(')')
 *     nogil = p_nogil(s)             # <<<<<<<<<<<<<<
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')
 *     if nogil and exc_clause:
*/
  __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(__pyx_v_s); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3143, __pyx_L1_error)
  __pyx_v_nogil = __pyx_t_7;

  /* "Cython/Compiler/Parsing.py":3144
 *     s.expect(')')
 *     nogil = p_nogil(s)
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')             # <<<<<<<<<<<<<<
 *     if nogil and exc_clause:
 *         warning(
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_extern, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_exception_value_clause(__pyx_v_s, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(__pyx_t_3 != Py_None)) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3144, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3144, __pyx_L1_error)
  }
  __pyx_v_exc_val = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_exc_check = __pyx_t_6;
  __pyx_t_6 = 0;
  __pyx_v_exc_clause = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3145
 *     nogil = p_nogil(s)
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')
 *     if nogil and exc_clause:             # <<<<<<<<<<<<<<
 *         warning(
 *             s.position(),
*/
  if (__pyx_v_nogil) {
  } else {
    __pyx_t_7 = __pyx_v_nogil;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_exc_clause); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3145, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":3146
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')
 *     if nogil and exc_clause:
 *         warning(             # <<<<<<<<<<<<<<
 *             s.position(),
 *             "The keyword 'nogil' should appear at the end of the "
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 

    /* "Cython/Compiler/Parsing.py":3147
 *     if nogil and exc_clause:
 *         warning(
 *             s.position(),             # <<<<<<<<<<<<<<
 *             "The keyword 'nogil' should appear at the end of the "
 *             "function signature line. Placing it before 'except' "
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_t_1, __pyx_mstate_global->__pyx_kp_u_The_keyword_nogil_should_appear};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_int_2, __pyx_t_2, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3146, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3145
 *     nogil = p_nogil(s)
 *     exc_val, exc_check, exc_clause = p_exception_value_clause(s, ctx.visibility == 'extern')
 *     if nogil and exc_clause:             # <<<<<<<<<<<<<<
 *         warning(
 *             s.position(),
*/
  }

  /* "Cython/Compiler/Parsing.py":3154
 *             level=2
 *         )
 *     nogil = nogil or p_nogil(s)             # <<<<<<<<<<<<<<
 *     with_gil = p_with_gil(s)
 *     return Nodes.CFuncDeclaratorNode(pos,
*/
  if (!__pyx_v_nogil) {
  } else {
    __pyx_t_7 = __pyx_v_nogil;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(__pyx_v_s); if (unlikely(__pyx_t_8 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3154, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_8;
  __pyx_L6_bool_binop_done:;
  __pyx_v_nogil = __pyx_t_7;

  /* "Cython/Compiler/Parsing.py":3155
 *         )
 *     nogil = nogil or p_nogil(s)
 *     with_gil = p_with_gil(s)             # <<<<<<<<<<<<<<
 *     return Nodes.CFuncDeclaratorNode(pos,
 *         base = base, args = args, has_varargs = ellipsis,
*/
  __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_with_gil(__pyx_v_s); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3155, __pyx_L1_error)
  __pyx_v_with_gil = __pyx_t_7;

  /* "Cython/Compiler/Parsing.py":3156
 *     nogil = nogil or p_nogil(s)
 *     with_gil = p_with_gil(s)
 *     return Nodes.CFuncDeclaratorNode(pos,             # <<<<<<<<<<<<<<
 *         base = base, args = args, has_varargs = ellipsis,
 *         exception_value = exc_val, exception_check = exc_check,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_6);

  /* "Cython/Compiler/Parsing.py":3157
 *     with_gil = p_with_gil(s)
 *     return Nodes.CFuncDeclaratorNode(pos,
 *         base = base, args = args, has_varargs = ellipsis,             # <<<<<<<<<<<<<<
 *         exception_value = exc_val, exception_check = exc_check,
 *         nogil = nogil or ctx.nogil or with_gil, with_gil = with_gil, has_explicit_exc_clause=exc_clause)
*/
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_ellipsis); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":3159
 *         base = base, args = args, has_varargs = ellipsis,
 *         exception_value = exc_val, exception_check = exc_check,
 *         nogil = nogil or ctx.nogil or with_gil, with_gil = with_gil, has_explicit_exc_clause=exc_clause)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (!__pyx_v_nogil) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_nogil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_nogil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3159, __pyx_L1_error)
  if (!__pyx_t_7) {
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_with_gil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_L8_bool_binop_done:;
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_with_gil); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 8 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_has_varargs, __pyx_t_2, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exception_value, __pyx_v_exc_val, __pyx_t_9, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exception_check, __pyx_v_exc_check, __pyx_t_9, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nogil, __pyx_t_1, __pyx_t_9, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_with_gil, __pyx_t_4, __pyx_t_9, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_has_explicit_exc_clause, __pyx_v_exc_clause, __pyx_t_9, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3156, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CFuncDeclaratorNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3136
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_func_declarator(s: PyrexScanner, pos, ctx, base, cmethod_flag: cython.bint):
 *     # Opening paren has already been skipped
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_func_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_exc_val);
  __Pyx_XDECREF(__pyx_v_exc_check);
  __Pyx_XDECREF(__pyx_v_exc_clause);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3171
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_simple_declarator(s: PyrexScanner, ctx,
 *                           empty: cython.bint, is_type: cython.bint, cmethod_flag: cython.bint,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_simple_declarator(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_empty, int __pyx_v_is_type, int __pyx_v_cmethod_flag, int __pyx_v_assignable, int __pyx_v_nonempty) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_calling_convention = NULL;
  PyObject *__pyx_v_is_ptrptr = NULL;
  PyObject *__pyx_v_const_pos = NULL;
  PyObject *__pyx_v_is_const = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_node_class = NULL;
  PyObject *__pyx_v_rhs = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_8genexpr4__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_declarator __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_simple_declarator", 0);

  /* "Cython/Compiler/Parsing.py":3175
 *                           empty: cython.bint, is_type: cython.bint, cmethod_flag: cython.bint,
 *                           assignable: cython.bint, nonempty: cython.bint):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     calling_convention = p_calling_convention(s)
 *     if s.sy in ('*', '**'):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3176
 *                           assignable: cython.bint, nonempty: cython.bint):
 *     pos = s.position()
 *     calling_convention = p_calling_convention(s)             # <<<<<<<<<<<<<<
 *     if s.sy in ('*', '**'):
 *         # scanner returns '**' as a single token
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_calling_convention(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_calling_convention = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3177
 *     pos = s.position()
 *     calling_convention = p_calling_convention(s)
 *     if s.sy in ('*', '**'):             # <<<<<<<<<<<<<<
 *         # scanner returns '**' as a single token
 *         is_ptrptr = s.sy == '**'
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_2 = __pyx_v_s->sy;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3177, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3177, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_3;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3179
 *     if s.sy in ('*', '**'):
 *         # scanner returns '**' as a single token
 *         is_ptrptr = s.sy == '**'             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3179, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_is_ptrptr = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3180
 *         # scanner returns '**' as a single token
 *         is_ptrptr = s.sy == '**'
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *         const_pos = s.position()
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3182
 *         s.next()
 * 
 *         const_pos = s.position()             # <<<<<<<<<<<<<<
 *         is_const = s.systring == 'const' and s.sy == 'IDENT'
 *         if is_const:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_const_pos = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3183
 * 
 *         const_pos = s.position()
 *         is_const = s.systring == 'const' and s.sy == 'IDENT'             # <<<<<<<<<<<<<<
 *         if is_const:
 *             s.next()
*/
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_const, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3183, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3183, __pyx_L1_error)
    if (__pyx_t_4) {
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_1 = __pyx_t_5;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3183, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;
    __pyx_L6_bool_binop_done:;
    __pyx_v_is_const = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3184
 *         const_pos = s.position()
 *         is_const = s.systring == 'const' and s.sy == 'IDENT'
 *         if is_const:             # <<<<<<<<<<<<<<
 *             s.next()
 * 
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_is_const); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3184, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3185
 *         is_const = s.systring == 'const' and s.sy == 'IDENT'
 *         if is_const:
 *             s.next()             # <<<<<<<<<<<<<<
 * 
 *         base = p_c_declarator(s, ctx, empty=empty, is_type=is_type,
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3184
 *         const_pos = s.position()
 *         is_const = s.systring == 'const' and s.sy == 'IDENT'
 *         if is_const:             # <<<<<<<<<<<<<<
 *             s.next()
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":3187
 *             s.next()
 * 
 *         base = p_c_declarator(s, ctx, empty=empty, is_type=is_type,             # <<<<<<<<<<<<<<
 *                               cmethod_flag=cmethod_flag,
 *                               assignable=assignable, nonempty=nonempty)
*/
    __pyx_t_7.__pyx_n = 6;
    __pyx_t_7.ctx = __pyx_v_ctx;
    __pyx_t_7.empty = __pyx_v_empty;
    __pyx_t_7.is_type = __pyx_v_is_type;
    __pyx_t_7.cmethod_flag = __pyx_v_cmethod_flag;
    __pyx_t_7.assignable = __pyx_v_assignable;
    __pyx_t_7.nonempty = __pyx_v_nonempty;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_declarator(__pyx_v_s, 0, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_base = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3190
 *                               cmethod_flag=cmethod_flag,
 *                               assignable=assignable, nonempty=nonempty)
 *         if is_const:             # <<<<<<<<<<<<<<
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)
 *         if is_ptrptr:
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_is_const); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3190, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3191
 *                               assignable=assignable, nonempty=nonempty)
 *         if is_const:
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)             # <<<<<<<<<<<<<<
 *         if is_ptrptr:
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
*/
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_const_pos};
        __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3191, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CConstDeclaratorNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_base, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3190
 *                               cmethod_flag=cmethod_flag,
 *                               assignable=assignable, nonempty=nonempty)
 *         if is_const:             # <<<<<<<<<<<<<<
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)
 *         if is_ptrptr:
*/
    }

    /* "Cython/Compiler/Parsing.py":3192
 *         if is_const:
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)
 *         if is_ptrptr:             # <<<<<<<<<<<<<<
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_is_ptrptr); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3192, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3193
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)
 *         if is_ptrptr:
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)             # <<<<<<<<<<<<<<
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):
*/
      __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3193, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CPtrDeclaratorNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_base, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3192
 *         if is_const:
 *             base = Nodes.CConstDeclaratorNode(const_pos, base=base)
 *         if is_ptrptr:             # <<<<<<<<<<<<<<
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
*/
    }

    /* "Cython/Compiler/Parsing.py":3194
 *         if is_ptrptr:
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)             # <<<<<<<<<<<<<<
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode
*/
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3194, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CPtrDeclaratorNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3177
 *     pos = s.position()
 *     calling_convention = p_calling_convention(s)
 *     if s.sy in ('*', '**'):             # <<<<<<<<<<<<<<
 *         # scanner returns '**' as a single token
 *         is_ptrptr = s.sy == '**'
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3195
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):             # <<<<<<<<<<<<<<
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode
 *         s.next()
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__11, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3195, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__46, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3195, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_cpp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3196
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode             # <<<<<<<<<<<<<<
 *         s.next()
 *         base = p_c_declarator(s, ctx, empty=empty, is_type=is_type,
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__46, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3196, __pyx_L1_error)
    if (__pyx_t_4) {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CppRvalueReferenceDeclaratorNode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __pyx_t_8;
      __pyx_t_8 = 0;
    } else {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CReferenceDeclaratorNode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __pyx_t_8;
      __pyx_t_8 = 0;
    }
    __pyx_v_node_class = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3197
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode
 *         s.next()             # <<<<<<<<<<<<<<
 *         base = p_c_declarator(s, ctx, empty=empty, is_type=is_type,
 *                               cmethod_flag=cmethod_flag,
*/
    __pyx_t_8 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3198
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode
 *         s.next()
 *         base = p_c_declarator(s, ctx, empty=empty, is_type=is_type,             # <<<<<<<<<<<<<<
 *                               cmethod_flag=cmethod_flag,
 *                               assignable=assignable, nonempty=nonempty)
*/
    __pyx_t_7.__pyx_n = 6;
    __pyx_t_7.ctx = __pyx_v_ctx;
    __pyx_t_7.empty = __pyx_v_empty;
    __pyx_t_7.is_type = __pyx_v_is_type;
    __pyx_t_7.cmethod_flag = __pyx_v_cmethod_flag;
    __pyx_t_7.assignable = __pyx_v_assignable;
    __pyx_t_7.nonempty = __pyx_v_nonempty;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_declarator(__pyx_v_s, 0, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_base = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3201
 *                               cmethod_flag=cmethod_flag,
 *                               assignable=assignable, nonempty=nonempty)
 *         result = node_class(pos, base=base)             # <<<<<<<<<<<<<<
 *     else:
 *         rhs = None
*/
    __pyx_t_8 = NULL;
    __Pyx_INCREF(__pyx_v_node_class);
    __pyx_t_5 = __pyx_v_node_class; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_8);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base, __pyx_v_base, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3195
 *             base = Nodes.CPtrDeclaratorNode(pos, base=base)
 *         result = Nodes.CPtrDeclaratorNode(pos, base=base)
 *     elif s.sy == '&' or (s.sy == '&&' and s.context.cpp):             # <<<<<<<<<<<<<<
 *         node_class = Nodes.CppRvalueReferenceDeclaratorNode if s.sy == '&&' else Nodes.CReferenceDeclaratorNode
 *         s.next()
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3203
 *         result = node_class(pos, base=base)
 *     else:
 *         rhs = None             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT':
 *             name = s.systring
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_rhs = Py_None;

    /* "Cython/Compiler/Parsing.py":3204
 *     else:
 *         rhs = None
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             name = s.systring
 *             if empty:
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3204, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3205
 *         rhs = None
 *         if s.sy == 'IDENT':
 *             name = s.systring             # <<<<<<<<<<<<<<
 *             if empty:
 *                 error(s.position(), "Declarator should be empty")
*/
      __pyx_t_1 = __pyx_v_s->systring;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3206
 *         if s.sy == 'IDENT':
 *             name = s.systring
 *             if empty:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "Declarator should be empty")
 *             s.next()
*/
      if (__pyx_v_empty) {

        /* "Cython/Compiler/Parsing.py":3207
 *             name = s.systring
 *             if empty:
 *                 error(s.position(), "Declarator should be empty")             # <<<<<<<<<<<<<<
 *             s.next()
 *             cname = p_opt_cname(s)
*/
        __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_8 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_8, __pyx_mstate_global->__pyx_kp_u_Declarator_should_be_empty};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3206
 *         if s.sy == 'IDENT':
 *             name = s.systring
 *             if empty:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "Declarator should be empty")
 *             s.next()
*/
      }

      /* "Cython/Compiler/Parsing.py":3208
 *             if empty:
 *                 error(s.position(), "Declarator should be empty")
 *             s.next()             # <<<<<<<<<<<<<<
 *             cname = p_opt_cname(s)
 *             if name != 'operator' and s.sy == '=' and assignable:
*/
      __pyx_t_9 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3209
 *                 error(s.position(), "Declarator should be empty")
 *             s.next()
 *             cname = p_opt_cname(s)             # <<<<<<<<<<<<<<
 *             if name != 'operator' and s.sy == '=' and assignable:
 *                 s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_cname = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3210
 *             s.next()
 *             cname = p_opt_cname(s)
 *             if name != 'operator' and s.sy == '=' and assignable:             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 rhs = p_test(s)
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_operator, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3210, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_4 = __pyx_t_3;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3210, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_4 = __pyx_t_3;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_4 = __pyx_v_assignable;
      __pyx_L17_bool_binop_done:;
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":3211
 *             cname = p_opt_cname(s)
 *             if name != 'operator' and s.sy == '=' and assignable:
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 rhs = p_test(s)
 *         else:
*/
        __pyx_t_9 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3211, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3212
 *             if name != 'operator' and s.sy == '=' and assignable:
 *                 s.next()
 *                 rhs = p_test(s)             # <<<<<<<<<<<<<<
 *         else:
 *             if nonempty:
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3212, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_rhs, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3210
 *             s.next()
 *             cname = p_opt_cname(s)
 *             if name != 'operator' and s.sy == '=' and assignable:             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 rhs = p_test(s)
*/
      }

      /* "Cython/Compiler/Parsing.py":3204
 *     else:
 *         rhs = None
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             name = s.systring
 *             if empty:
*/
      goto __pyx_L14;
    }

    /* "Cython/Compiler/Parsing.py":3214
 *                 rhs = p_test(s)
 *         else:
 *             if nonempty:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "Empty declarator")
 *             name = ""
*/
    /*else*/ {
      if (__pyx_v_nonempty) {

        /* "Cython/Compiler/Parsing.py":3215
 *         else:
 *             if nonempty:
 *                 error(s.position(), "Empty declarator")             # <<<<<<<<<<<<<<
 *             name = ""
 *             cname = None
*/
        __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3215, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_Empty_declarator};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3215, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3214
 *                 rhs = p_test(s)
 *         else:
 *             if nonempty:             # <<<<<<<<<<<<<<
 *                 error(s.position(), "Empty declarator")
 *             name = ""
*/
      }

      /* "Cython/Compiler/Parsing.py":3216
 *             if nonempty:
 *                 error(s.position(), "Empty declarator")
 *             name = ""             # <<<<<<<<<<<<<<
 *             cname = None
 *         if cname is None and ctx.namespace is not None and nonempty:
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
      __pyx_v_name = __pyx_mstate_global->__pyx_kp_u__35;

      /* "Cython/Compiler/Parsing.py":3217
 *                 error(s.position(), "Empty declarator")
 *             name = ""
 *             cname = None             # <<<<<<<<<<<<<<
 *         if cname is None and ctx.namespace is not None and nonempty:
 *             cname = ctx.namespace + "::" + name
*/
      __Pyx_INCREF(Py_None);
      __pyx_v_cname = Py_None;
    }
    __pyx_L14:;

    /* "Cython/Compiler/Parsing.py":3218
 *             name = ""
 *             cname = None
 *         if cname is None and ctx.namespace is not None and nonempty:             # <<<<<<<<<<<<<<
 *             cname = ctx.namespace + "::" + name
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
*/
    __pyx_t_3 = (__pyx_v_cname == Py_None);
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L22_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L22_bool_binop_done;
    }
    __pyx_t_4 = __pyx_v_nonempty;
    __pyx_L22_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3219
 *             cname = None
 *         if cname is None and ctx.namespace is not None and nonempty:
 *             cname = ctx.namespace + "::" + name             # <<<<<<<<<<<<<<
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
 *             op = s.sy
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyNumber_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__47); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_8, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_cname, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3218
 *             name = ""
 *             cname = None
 *         if cname is None and ctx.namespace is not None and nonempty:             # <<<<<<<<<<<<<<
 *             cname = ctx.namespace + "::" + name
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
*/
    }

    /* "Cython/Compiler/Parsing.py":3220
 *         if cname is None and ctx.namespace is not None and nonempty:
 *             cname = ctx.namespace + "::" + name
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:             # <<<<<<<<<<<<<<
 *             op = s.sy
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_operator, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3220, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_extern, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3220, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_4 = __pyx_v_nonempty;
    __pyx_L26_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3221
 *             cname = ctx.namespace + "::" + name
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
 *             op = s.sy             # <<<<<<<<<<<<<<
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:
 *                 s.next()
*/
      __pyx_t_1 = __pyx_v_s->sy;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_op = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3222
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
 *             op = s.sy
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 # Handle diphthong operators.
*/
      { /* enter inner scope */
        __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3222, __pyx_L32_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (likely(PyList_CheckExact(__pyx_v_op)) || PyTuple_CheckExact(__pyx_v_op)) {
          __pyx_t_8 = __pyx_v_op; __Pyx_INCREF(__pyx_t_8);
          __pyx_t_10 = 0;
          __pyx_t_11 = NULL;
        } else {
          __pyx_t_10 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_op); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3222, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3222, __pyx_L32_error)
        }
        for (;;) {
          if (likely(!__pyx_t_11)) {
            if (likely(PyList_CheckExact(__pyx_t_8))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3222, __pyx_L32_error)
                #endif
                if (__pyx_t_10 >= __pyx_temp) break;
              }
              __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_8, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_10;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_8);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3222, __pyx_L32_error)
                #endif
                if (__pyx_t_10 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_10));
              #else
              __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_10);
              #endif
              ++__pyx_t_10;
            }
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3222, __pyx_L32_error)
          } else {
            __pyx_t_5 = __pyx_t_11(__pyx_t_8);
            if (unlikely(!__pyx_t_5)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 3222, __pyx_L32_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_XDECREF_SET(__pyx_8genexpr4__pyx_v_c, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_4 = (__Pyx_PyUnicode_ContainsTF(__pyx_8genexpr4__pyx_v_c, __pyx_mstate_global->__pyx_kp_u__48, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3222, __pyx_L32_error)
          if (__pyx_t_4) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_mstate_global->__pyx_int_1))) __PYX_ERR(0, 3222, __pyx_L32_error)
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_c); __pyx_8genexpr4__pyx_v_c = 0;
        goto __pyx_L37_exit_scope;
        __pyx_L32_error:;
        __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_c); __pyx_8genexpr4__pyx_v_c = 0;
        goto __pyx_L1_error;
        __pyx_L37_exit_scope:;
      } /* exit inner scope */
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3222, __pyx_L1_error)
        __pyx_t_4 = (__pyx_temp != 0);
      }

      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":3223
 *             op = s.sy
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 # Handle diphthong operators.
 *                 if op == '(':
*/
        __pyx_t_8 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3223, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3225
 *                 s.next()
 *                 # Handle diphthong operators.
 *                 if op == '(':             # <<<<<<<<<<<<<<
 *                     s.expect(')')
 *                     op = '()'
*/
        __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3225, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3226
 *                 # Handle diphthong operators.
 *                 if op == '(':
 *                     s.expect(')')             # <<<<<<<<<<<<<<
 *                     op = '()'
 *                 elif op == '[':
*/
          __pyx_t_8 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_kp_u__24};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3226, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3227
 *                 if op == '(':
 *                     s.expect(')')
 *                     op = '()'             # <<<<<<<<<<<<<<
 *                 elif op == '[':
 *                     s.expect(']')
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__49);
          __Pyx_DECREF_SET(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__49);

          /* "Cython/Compiler/Parsing.py":3225
 *                 s.next()
 *                 # Handle diphthong operators.
 *                 if op == '(':             # <<<<<<<<<<<<<<
 *                     s.expect(')')
 *                     op = '()'
*/
          goto __pyx_L38;
        }

        /* "Cython/Compiler/Parsing.py":3228
 *                     s.expect(')')
 *                     op = '()'
 *                 elif op == '[':             # <<<<<<<<<<<<<<
 *                     s.expect(']')
 *                     op = '[]'
*/
        __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3228, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3229
 *                     op = '()'
 *                 elif op == '[':
 *                     s.expect(']')             # <<<<<<<<<<<<<<
 *                     op = '[]'
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:
*/
          __pyx_t_8 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_kp_u__30};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3229, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3230
 *                 elif op == '[':
 *                     s.expect(']')
 *                     op = '[]'             # <<<<<<<<<<<<<<
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:
 *                     op *= 2       # ++, --, ...
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__50);
          __Pyx_DECREF_SET(__pyx_v_op, __pyx_mstate_global->__pyx_kp_u__50);

          /* "Cython/Compiler/Parsing.py":3228
 *                     s.expect(')')
 *                     op = '()'
 *                 elif op == '[':             # <<<<<<<<<<<<<<
 *                     s.expect(']')
 *                     op = '[]'
*/
          goto __pyx_L38;
        }

        /* "Cython/Compiler/Parsing.py":3231
 *                     s.expect(']')
 *                     op = '[]'
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:             # <<<<<<<<<<<<<<
 *                     op *= 2       # ++, --, ...
 *                     s.next()
*/
        __Pyx_INCREF(__pyx_v_op);
        __pyx_t_1 = __pyx_v_op;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3231, __pyx_L1_error)
        if (!__pyx_t_12) {
        } else {
          __pyx_t_3 = __pyx_t_12;
          goto __pyx_L41_bool_binop_done;
        }
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__14, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3231, __pyx_L1_error)
        if (!__pyx_t_12) {
        } else {
          __pyx_t_3 = __pyx_t_12;
          goto __pyx_L41_bool_binop_done;
        }
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__9, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3231, __pyx_L1_error)
        if (!__pyx_t_12) {
        } else {
          __pyx_t_3 = __pyx_t_12;
          goto __pyx_L41_bool_binop_done;
        }
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__11, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3231, __pyx_L1_error)
        __pyx_t_3 = __pyx_t_12;
        __pyx_L41_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_12 = __pyx_t_3;
        if (__pyx_t_12) {
        } else {
          __pyx_t_4 = __pyx_t_12;
          goto __pyx_L39_bool_binop_done;
        }
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_v_op, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3231, __pyx_L1_error)
        __pyx_t_4 = __pyx_t_12;
        __pyx_L39_bool_binop_done:;
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3232
 *                     op = '[]'
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:
 *                     op *= 2       # ++, --, ...             # <<<<<<<<<<<<<<
 *                     s.next()
 *                 elif s.sy == '=':
*/
          __pyx_t_1 = PyNumber_InPlaceMultiply(__pyx_v_op, __pyx_mstate_global->__pyx_int_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3232, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_op, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3233
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:
 *                     op *= 2       # ++, --, ...
 *                     s.next()             # <<<<<<<<<<<<<<
 *                 elif s.sy == '=':
 *                     op += s.sy    # +=, -=, ...
*/
          __pyx_t_8 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3233, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3231
 *                     s.expect(']')
 *                     op = '[]'
 *                 elif op in ('-', '+', '|', '&') and s.sy == op:             # <<<<<<<<<<<<<<
 *                     op *= 2       # ++, --, ...
 *                     s.next()
*/
          goto __pyx_L38;
        }

        /* "Cython/Compiler/Parsing.py":3234
 *                     op *= 2       # ++, --, ...
 *                     s.next()
 *                 elif s.sy == '=':             # <<<<<<<<<<<<<<
 *                     op += s.sy    # +=, -=, ...
 *                     s.next()
*/
        __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3234, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3235
 *                     s.next()
 *                 elif s.sy == '=':
 *                     op += s.sy    # +=, -=, ...             # <<<<<<<<<<<<<<
 *                     s.next()
 *                 if op not in supported_overloaded_operators:
*/
          __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(__pyx_v_op, __pyx_v_s->sy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3235, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_op, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3236
 *                 elif s.sy == '=':
 *                     op += s.sy    # +=, -=, ...
 *                     s.next()             # <<<<<<<<<<<<<<
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,
*/
          __pyx_t_8 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3236, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3234
 *                     op *= 2       # ++, --, ...
 *                     s.next()
 *                 elif s.sy == '=':             # <<<<<<<<<<<<<<
 *                     op += s.sy    # +=, -=, ...
 *                     s.next()
*/
        }
        __pyx_L38:;

        /* "Cython/Compiler/Parsing.py":3237
 *                     op += s.sy    # +=, -=, ...
 *                     s.next()
 *                 if op not in supported_overloaded_operators:             # <<<<<<<<<<<<<<
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
*/
        __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_op, __pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3237, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3238
 *                     s.next()
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,             # <<<<<<<<<<<<<<
 *                             fatal=False)
 *                 name += op
*/
          __pyx_t_8 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Overloading_operator_s_not_yet_s, __pyx_v_op); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3238, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Compiler/Parsing.py":3239
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)             # <<<<<<<<<<<<<<
 *                 name += op
 *             elif op == 'IDENT':
*/
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_t_5};
            __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3238, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3238, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3238, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3237
 *                     op += s.sy    # +=, -=, ...
 *                     s.next()
 *                 if op not in supported_overloaded_operators:             # <<<<<<<<<<<<<<
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
*/
        }

        /* "Cython/Compiler/Parsing.py":3240
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
 *                 name += op             # <<<<<<<<<<<<<<
 *             elif op == 'IDENT':
 *                 op = s.systring
*/
        __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_name, __pyx_v_op); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3222
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:
 *             op = s.sy
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 # Handle diphthong operators.
*/
        goto __pyx_L29;
      }

      /* "Cython/Compiler/Parsing.py":3241
 *                             fatal=False)
 *                 name += op
 *             elif op == 'IDENT':             # <<<<<<<<<<<<<<
 *                 op = s.systring
 *                 if op not in supported_overloaded_operators:
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_op, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3241, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":3242
 *                 name += op
 *             elif op == 'IDENT':
 *                 op = s.systring             # <<<<<<<<<<<<<<
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,
*/
        __pyx_t_1 = __pyx_v_s->systring;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_op, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3243
 *             elif op == 'IDENT':
 *                 op = s.systring
 *                 if op not in supported_overloaded_operators:             # <<<<<<<<<<<<<<
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
*/
        __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_op, __pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3243, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":3244
 *                 op = s.systring
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,             # <<<<<<<<<<<<<<
 *                             fatal=False)
 *                 name = name + ' ' + op
*/
          __pyx_t_9 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Overloading_operator_s_not_yet_s, __pyx_v_op); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3244, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);

          /* "Cython/Compiler/Parsing.py":3245
 *                 if op not in supported_overloaded_operators:
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)             # <<<<<<<<<<<<<<
 *                 name = name + ' ' + op
 *                 s.next()
*/
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, __pyx_t_5};
            __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3244, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3244, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3244, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":3243
 *             elif op == 'IDENT':
 *                 op = s.systring
 *                 if op not in supported_overloaded_operators:             # <<<<<<<<<<<<<<
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
*/
        }

        /* "Cython/Compiler/Parsing.py":3246
 *                     s.error("Overloading operator '%s' not yet supported." % op,
 *                             fatal=False)
 *                 name = name + ' ' + op             # <<<<<<<<<<<<<<
 *                 s.next()
 *         result = Nodes.CNameDeclaratorNode(pos,
*/
        __pyx_t_1 = PyNumber_Add(__pyx_v_name, __pyx_mstate_global->__pyx_kp_u__51); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3246, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = PyNumber_Add(__pyx_t_1, __pyx_v_op); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3246, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "Cython/Compiler/Parsing.py":3247
 *                             fatal=False)
 *                 name = name + ' ' + op
 *                 s.next()             # <<<<<<<<<<<<<<
 *         result = Nodes.CNameDeclaratorNode(pos,
 *             name = name, cname = cname, default = rhs)
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
          __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3247, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "Cython/Compiler/Parsing.py":3241
 *                             fatal=False)
 *                 name += op
 *             elif op == 'IDENT':             # <<<<<<<<<<<<<<
 *                 op = s.systring
 *                 if op not in supported_overloaded_operators:
*/
      }
      __pyx_L29:;

      /* "Cython/Compiler/Parsing.py":3220
 *         if cname is None and ctx.namespace is not None and nonempty:
 *             cname = ctx.namespace + "::" + name
 *         if name == 'operator' and ctx.visibility == 'extern' and nonempty:             # <<<<<<<<<<<<<<
 *             op = s.sy
 *             if [1 for c in op if c in '+-*[inserted by cython to avoid comment closer]/<=>!%&|([^~,']:
*/
    }

    /* "Cython/Compiler/Parsing.py":3248
 *                 name = name + ' ' + op
 *                 s.next()
 *         result = Nodes.CNameDeclaratorNode(pos,             # <<<<<<<<<<<<<<
 *             name = name, cname = cname, default = rhs)
 *     result.calling_convention = calling_convention
*/
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":3249
 *                 s.next()
 *         result = Nodes.CNameDeclaratorNode(pos,
 *             name = name, cname = cname, default = rhs)             # <<<<<<<<<<<<<<
 *     result.calling_convention = calling_convention
 *     return result
*/
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_1, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3248, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, __pyx_v_cname, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3248, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_default, __pyx_v_rhs, __pyx_t_5, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __pyx_t_8 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CNameDeclaratorNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __pyx_v_result = __pyx_t_8;
    __pyx_t_8 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3250
 *         result = Nodes.CNameDeclaratorNode(pos,
 *             name = name, cname = cname, default = rhs)
 *     result.calling_convention = calling_convention             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_result, __pyx_mstate_global->__pyx_n_u_calling_convention, __pyx_v_calling_convention) < (0)) __PYX_ERR(0, 3250, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3251
 *             name = name, cname = cname, default = rhs)
 *     result.calling_convention = calling_convention
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3171
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_simple_declarator(s: PyrexScanner, ctx,
 *                           empty: cython.bint, is_type: cython.bint, cmethod_flag: cython.bint,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_simple_declarator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_calling_convention);
  __Pyx_XDECREF(__pyx_v_is_ptrptr);
  __Pyx_XDECREF(__pyx_v_const_pos);
  __Pyx_XDECREF(__pyx_v_is_const);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_node_class);
  __Pyx_XDECREF(__pyx_v_rhs);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3254
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_nogil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'nogil':
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_nogil", 0);

  /* "Cython/Compiler/Parsing.py":3256
 * @cython.cfunc
 * def p_nogil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'nogil':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return True
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3256, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_nogil, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3256, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3257
 * def p_nogil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'nogil':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return True
 *     else:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3258
 *     if s.sy == 'IDENT' and s.systring == 'nogil':
 *         s.next()
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3256
 * @cython.cfunc
 * def p_nogil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'nogil':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return True
*/
  }

  /* "Cython/Compiler/Parsing.py":3260
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3254
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_nogil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'nogil':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_nogil", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3263
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_gil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'with':
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_p_with_gil(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_with_gil", 0);

  /* "Cython/Compiler/Parsing.py":3265
 * @cython.cfunc
 * def p_with_gil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'with':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_keyword('gil')
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_with, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3265, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3266
 * def p_with_gil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'with':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.expect_keyword('gil')
 *         return True
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3267
 *     if s.sy == 'with':
 *         s.next()
 *         s.expect_keyword('gil')             # <<<<<<<<<<<<<<
 *         return True
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_gil};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_keyword, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3268
 *         s.next()
 *         s.expect_keyword('gil')
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3265
 * @cython.cfunc
 * def p_with_gil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'with':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect_keyword('gil')
*/
  }

  /* "Cython/Compiler/Parsing.py":3270
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3263
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_with_gil(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'with':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_with_gil", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3273
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_exception_value_clause(s: PyrexScanner, is_extern: cython.bint) -> tuple:
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_exception_value_clause(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, int __pyx_v_is_extern) {
  int __pyx_v_exc_clause;
  PyObject *__pyx_v_exc_val = NULL;
  PyObject *__pyx_v_exc_check = NULL;
  PyObject *__pyx_v_plus_char_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_exception_value_clause", 0);

  /* "Cython/Compiler/Parsing.py":3299
 *     `'nogil'` keyword.
 *     """
 *     exc_clause: cython.bint = False             # <<<<<<<<<<<<<<
 *     exc_val = None
 *     exc_check = False if is_extern else True
*/
  __pyx_v_exc_clause = 0;

  /* "Cython/Compiler/Parsing.py":3300
 *     """
 *     exc_clause: cython.bint = False
 *     exc_val = None             # <<<<<<<<<<<<<<
 *     exc_check = False if is_extern else True
 * 
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_exc_val = Py_None;

  /* "Cython/Compiler/Parsing.py":3301
 *     exc_clause: cython.bint = False
 *     exc_val = None
 *     exc_check = False if is_extern else True             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == 'IDENT' and s.systring == 'noexcept':
*/
  if (__pyx_v_is_extern) {
    __Pyx_INCREF(Py_False);
    __pyx_t_1 = Py_False;
  } else {
    __Pyx_INCREF(Py_True);
    __pyx_t_1 = Py_True;
  }
  __pyx_v_exc_check = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3303
 *     exc_check = False if is_extern else True
 * 
 *     if s.sy == 'IDENT' and s.systring == 'noexcept':             # <<<<<<<<<<<<<<
 *         exc_clause = True
 *         s.next()
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3303, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_noexcept, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3303, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3304
 * 
 *     if s.sy == 'IDENT' and s.systring == 'noexcept':
 *         exc_clause = True             # <<<<<<<<<<<<<<
 *         s.next()
 *         exc_check = False
*/
    __pyx_v_exc_clause = 1;

    /* "Cython/Compiler/Parsing.py":3305
 *     if s.sy == 'IDENT' and s.systring == 'noexcept':
 *         exc_clause = True
 *         s.next()             # <<<<<<<<<<<<<<
 *         exc_check = False
 *     elif s.sy == 'except':
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3306
 *         exc_clause = True
 *         s.next()
 *         exc_check = False             # <<<<<<<<<<<<<<
 *     elif s.sy == 'except':
 *         exc_clause = True
*/
    __Pyx_INCREF(Py_False);
    __Pyx_DECREF_SET(__pyx_v_exc_check, Py_False);

    /* "Cython/Compiler/Parsing.py":3303
 *     exc_check = False if is_extern else True
 * 
 *     if s.sy == 'IDENT' and s.systring == 'noexcept':             # <<<<<<<<<<<<<<
 *         exc_clause = True
 *         s.next()
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3307
 *         s.next()
 *         exc_check = False
 *     elif s.sy == 'except':             # <<<<<<<<<<<<<<
 *         exc_clause = True
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_except, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3307, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3308
 *         exc_check = False
 *     elif s.sy == 'except':
 *         exc_clause = True             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == '*':
*/
    __pyx_v_exc_clause = 1;

    /* "Cython/Compiler/Parsing.py":3309
 *     elif s.sy == 'except':
 *         exc_clause = True
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == '*':
 *             exc_check = True
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3310
 *         exc_clause = True
 *         s.next()
 *         if s.sy == '*':             # <<<<<<<<<<<<<<
 *             exc_check = True
 *             s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3311
 *         s.next()
 *         if s.sy == '*':
 *             exc_check = True             # <<<<<<<<<<<<<<
 *             s.next()
 *         elif s.sy == '+':
*/
      __Pyx_INCREF(Py_True);
      __Pyx_DECREF_SET(__pyx_v_exc_check, Py_True);

      /* "Cython/Compiler/Parsing.py":3312
 *         if s.sy == '*':
 *             exc_check = True
 *             s.next()             # <<<<<<<<<<<<<<
 *         elif s.sy == '+':
 *             exc_check = '+'
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3312, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3310
 *         exc_clause = True
 *         s.next()
 *         if s.sy == '*':             # <<<<<<<<<<<<<<
 *             exc_check = True
 *             s.next()
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":3313
 *             exc_check = True
 *             s.next()
 *         elif s.sy == '+':             # <<<<<<<<<<<<<<
 *             exc_check = '+'
 *             plus_char_pos = s.position()[2]
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__14, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3313, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3314
 *             s.next()
 *         elif s.sy == '+':
 *             exc_check = '+'             # <<<<<<<<<<<<<<
 *             plus_char_pos = s.position()[2]
 *             s.next()
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__14);
      __Pyx_DECREF_SET(__pyx_v_exc_check, __pyx_mstate_global->__pyx_kp_u__14);

      /* "Cython/Compiler/Parsing.py":3315
 *         elif s.sy == '+':
 *             exc_check = '+'
 *             plus_char_pos = s.position()[2]             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == 'IDENT':
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 3315, __pyx_L1_error)
      }
      __pyx_t_4 = __Pyx_GetItemInt_Tuple(__pyx_t_1, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_plus_char_pos = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Parsing.py":3316
 *             exc_check = '+'
 *             plus_char_pos = s.position()[2]
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == 'IDENT':
 *                 name = s.systring
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3316, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/Parsing.py":3317
 *             plus_char_pos = s.position()[2]
 *             s.next()
 *             if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *                 name = s.systring
 *                 if name == 'nogil':
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3317, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":3318
 *             s.next()
 *             if s.sy == 'IDENT':
 *                 name = s.systring             # <<<<<<<<<<<<<<
 *                 if name == 'nogil':
 *                     if s.position()[2] == plus_char_pos + 1:
*/
        __pyx_t_4 = __pyx_v_s->systring;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_name = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "Cython/Compiler/Parsing.py":3319
 *             if s.sy == 'IDENT':
 *                 name = s.systring
 *                 if name == 'nogil':             # <<<<<<<<<<<<<<
 *                     if s.position()[2] == plus_char_pos + 1:
 *                         error(s.position(),
*/
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_nogil, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3319, __pyx_L1_error)
        if (__pyx_t_2) {

          /* "Cython/Compiler/Parsing.py":3320
 *                 name = s.systring
 *                 if name == 'nogil':
 *                     if s.position()[2] == plus_char_pos + 1:             # <<<<<<<<<<<<<<
 *                         error(s.position(),
 *                               "'except +nogil' defines an exception handling function. Use 'except + nogil' for the 'nogil' modifier.")
*/
          __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(__pyx_t_4 == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 3320, __pyx_L1_error)
          }
          __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_t_4, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_v_plus_char_pos, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3320, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3320, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (__pyx_t_2) {

            /* "Cython/Compiler/Parsing.py":3321
 *                 if name == 'nogil':
 *                     if s.position()[2] == plus_char_pos + 1:
 *                         error(s.position(),             # <<<<<<<<<<<<<<
 *                               "'except +nogil' defines an exception handling function. Use 'except + nogil' for the 'nogil' modifier.")
 *                     # 'except + nogil' is parsed outside
*/
            __pyx_t_4 = NULL;
            __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
            __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
            __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3321, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_5 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
              assert(__pyx_t_4);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
              __pyx_t_5 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_except_nogil_defines_an_excepti};
              __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3321, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":3320
 *                 name = s.systring
 *                 if name == 'nogil':
 *                     if s.position()[2] == plus_char_pos + 1:             # <<<<<<<<<<<<<<
 *                         error(s.position(),
 *                               "'except +nogil' defines an exception handling function. Use 'except + nogil' for the 'nogil' modifier.")
*/
          }

          /* "Cython/Compiler/Parsing.py":3319
 *             if s.sy == 'IDENT':
 *                 name = s.systring
 *                 if name == 'nogil':             # <<<<<<<<<<<<<<
 *                     if s.position()[2] == plus_char_pos + 1:
 *                         error(s.position(),
*/
          goto __pyx_L8;
        }

        /* "Cython/Compiler/Parsing.py":3325
 *                     # 'except + nogil' is parsed outside
 *                 else:
 *                     exc_val = p_name(s, name)             # <<<<<<<<<<<<<<
 *                     s.next()
 *             elif s.sy == '*':
*/
        /*else*/ {
          __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_v_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3325, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_exc_val, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "Cython/Compiler/Parsing.py":3326
 *                 else:
 *                     exc_val = p_name(s, name)
 *                     s.next()             # <<<<<<<<<<<<<<
 *             elif s.sy == '*':
 *                 exc_val = ExprNodes.CharNode(s.position(), value='*')
*/
          __pyx_t_1 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
            __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3326, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_L8:;

        /* "Cython/Compiler/Parsing.py":3317
 *             plus_char_pos = s.position()[2]
 *             s.next()
 *             if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *                 name = s.systring
 *                 if name == 'nogil':
*/
        goto __pyx_L7;
      }

      /* "Cython/Compiler/Parsing.py":3327
 *                     exc_val = p_name(s, name)
 *                     s.next()
 *             elif s.sy == '*':             # <<<<<<<<<<<<<<
 *                 exc_val = ExprNodes.CharNode(s.position(), value='*')
 *                 s.next()
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3327, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":3328
 *                     s.next()
 *             elif s.sy == '*':
 *                 exc_val = ExprNodes.CharNode(s.position(), value='*')             # <<<<<<<<<<<<<<
 *                 s.next()
 *         else:
*/
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3328, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_t_7};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_mstate_global->__pyx_kp_u__6, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3328, __pyx_L1_error)
          __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CharNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_DECREF_SET(__pyx_v_exc_val, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":3329
 *             elif s.sy == '*':
 *                 exc_val = ExprNodes.CharNode(s.position(), value='*')
 *                 s.next()             # <<<<<<<<<<<<<<
 *         else:
 *             if s.sy == '?':
*/
        __pyx_t_4 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3329, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":3327
 *                     exc_val = p_name(s, name)
 *                     s.next()
 *             elif s.sy == '*':             # <<<<<<<<<<<<<<
 *                 exc_val = ExprNodes.CharNode(s.position(), value='*')
 *                 s.next()
*/
      }
      __pyx_L7:;

      /* "Cython/Compiler/Parsing.py":3313
 *             exc_check = True
 *             s.next()
 *         elif s.sy == '+':             # <<<<<<<<<<<<<<
 *             exc_check = '+'
 *             plus_char_pos = s.position()[2]
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":3331
 *                 s.next()
 *         else:
 *             if s.sy == '?':             # <<<<<<<<<<<<<<
 *                 exc_check = True
 *                 s.next()
*/
    /*else*/ {
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__21, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3331, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":3332
 *         else:
 *             if s.sy == '?':
 *                 exc_check = True             # <<<<<<<<<<<<<<
 *                 s.next()
 *             else:
*/
        __Pyx_INCREF(Py_True);
        __Pyx_DECREF_SET(__pyx_v_exc_check, Py_True);

        /* "Cython/Compiler/Parsing.py":3333
 *             if s.sy == '?':
 *                 exc_check = True
 *                 s.next()             # <<<<<<<<<<<<<<
 *             else:
 *                 exc_check = False
*/
        __pyx_t_4 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3333, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":3331
 *                 s.next()
 *         else:
 *             if s.sy == '?':             # <<<<<<<<<<<<<<
 *                 exc_check = True
 *                 s.next()
*/
        goto __pyx_L10;
      }

      /* "Cython/Compiler/Parsing.py":3335
 *                 s.next()
 *             else:
 *                 exc_check = False             # <<<<<<<<<<<<<<
 *             # exc_val can be non-None even if exc_check is False, c.f. "except -1"
 *             exc_val = p_test(s)
*/
      /*else*/ {
        __Pyx_INCREF(Py_False);
        __Pyx_DECREF_SET(__pyx_v_exc_check, Py_False);
      }
      __pyx_L10:;

      /* "Cython/Compiler/Parsing.py":3337
 *                 exc_check = False
 *             # exc_val can be non-None even if exc_check is False, c.f. "except -1"
 *             exc_val = p_test(s)             # <<<<<<<<<<<<<<
 * 
 *     return exc_val, exc_check, exc_clause
*/
      __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_exc_val, __pyx_t_6);
      __pyx_t_6 = 0;
    }
    __pyx_L6:;

    /* "Cython/Compiler/Parsing.py":3307
 *         s.next()
 *         exc_check = False
 *     elif s.sy == 'except':             # <<<<<<<<<<<<<<
 *         exc_clause = True
 *         s.next()
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3339
 *             exc_val = p_test(s)
 * 
 *     return exc_val, exc_check, exc_clause             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_exc_clause); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_exc_val);
  __Pyx_GIVEREF(__pyx_v_exc_val);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_exc_val) != (0)) __PYX_ERR(0, 3339, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_exc_check);
  __Pyx_GIVEREF(__pyx_v_exc_check);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_exc_check) != (0)) __PYX_ERR(0, 3339, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6) != (0)) __PYX_ERR(0, 3339, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_r = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3273
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_exception_value_clause(s: PyrexScanner, is_extern: cython.bint) -> tuple:
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_exception_value_clause", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc_val);
  __Pyx_XDECREF(__pyx_v_exc_check);
  __Pyx_XDECREF(__pyx_v_plus_char_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_7p_c_arg_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_list(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_list *__pyx_optional_args) {
  PyObject *__pyx_v_ctx = __pyx_mstate_global->__pyx_k__52;

  /* "Cython/Compiler/Parsing.py":3348
 * @cython.ccall
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
 *                  annotated: cython.bint = True) -> list:
*/
  int __pyx_v_in_pyfunc = ((int)0);
  int __pyx_v_cmethod_flag = ((int)0);

  /* "Cython/Compiler/Parsing.py":3349
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  annotated: cython.bint = True) -> list:
 *     #  Comma-separated list of C argument declarations, possibly empty.
*/
  int __pyx_v_nonempty_declarators = ((int)0);
  int __pyx_v_kw_only = ((int)0);

  /* "Cython/Compiler/Parsing.py":3350
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
 *                  annotated: cython.bint = True) -> list:             # <<<<<<<<<<<<<<
 *     #  Comma-separated list of C argument declarations, possibly empty.
 *     #  May have a trailing comma.
*/
  int __pyx_v_annotated = ((int)1);
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_is_self_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_decl __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_arg_list", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_ctx = __pyx_optional_args->ctx;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_in_pyfunc = __pyx_optional_args->in_pyfunc;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_cmethod_flag = __pyx_optional_args->cmethod_flag;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_nonempty_declarators = __pyx_optional_args->nonempty_declarators;
            if (__pyx_optional_args->__pyx_n > 4) {
              __pyx_v_kw_only = __pyx_optional_args->kw_only;
              if (__pyx_optional_args->__pyx_n > 5) {
                __pyx_v_annotated = __pyx_optional_args->annotated;
              }
            }
          }
        }
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":3353
 *     #  Comma-separated list of C argument declarations, possibly empty.
 *     #  May have a trailing comma.
 *     args = []             # <<<<<<<<<<<<<<
 *     is_self_arg = cmethod_flag
 *     while s.sy not in c_arg_list_terminators:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3354
 *     #  May have a trailing comma.
 *     args = []
 *     is_self_arg = cmethod_flag             # <<<<<<<<<<<<<<
 *     while s.sy not in c_arg_list_terminators:
 *         args.append(p_c_arg_decl(s, ctx, in_pyfunc, is_self_arg,
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_is_self_arg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3355
 *     args = []
 *     is_self_arg = cmethod_flag
 *     while s.sy not in c_arg_list_terminators:             # <<<<<<<<<<<<<<
 *         args.append(p_c_arg_decl(s, ctx, in_pyfunc, is_self_arg,
 *             nonempty = nonempty_declarators, kw_only = kw_only,
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->sy, __pyx_v_6Cython_8Compiler_7Parsing_c_arg_list_terminators, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3355, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":3356
 *     is_self_arg = cmethod_flag
 *     while s.sy not in c_arg_list_terminators:
 *         args.append(p_c_arg_decl(s, ctx, in_pyfunc, is_self_arg,             # <<<<<<<<<<<<<<
 *             nonempty = nonempty_declarators, kw_only = kw_only,
 *             annotated = annotated))
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_is_self_arg); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3356, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3358
 *         args.append(p_c_arg_decl(s, ctx, in_pyfunc, is_self_arg,
 *             nonempty = nonempty_declarators, kw_only = kw_only,
 *             annotated = annotated))             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
    __pyx_t_3.__pyx_n = 4;
    __pyx_t_3.cmethod_flag = __pyx_t_2;
    __pyx_t_3.nonempty = __pyx_v_nonempty_declarators;
    __pyx_t_3.kw_only = __pyx_v_kw_only;
    __pyx_t_3.annotated = __pyx_v_annotated;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_decl(__pyx_v_s, __pyx_v_ctx, __pyx_v_in_pyfunc, &__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":3356
 *     is_self_arg = cmethod_flag
 *     while s.sy not in c_arg_list_terminators:
 *         args.append(p_c_arg_decl(s, ctx, in_pyfunc, is_self_arg,             # <<<<<<<<<<<<<<
 *             nonempty = nonempty_declarators, kw_only = kw_only,
 *             annotated = annotated))
*/
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 3356, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3359
 *             nonempty = nonempty_declarators, kw_only = kw_only,
 *             annotated = annotated))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3359, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3360
 *             annotated = annotated))
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *         is_self_arg = 0
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":3359
 *             nonempty = nonempty_declarators, kw_only = kw_only,
 *             annotated = annotated))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":3361
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *         is_self_arg = 0
 *     return args
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3361, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3362
 *             break
 *         s.next()
 *         is_self_arg = 0             # <<<<<<<<<<<<<<
 *     return args
 * 
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
    __Pyx_DECREF_SET(__pyx_v_is_self_arg, __pyx_mstate_global->__pyx_int_0);
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":3363
 *         s.next()
 *         is_self_arg = 0
 *     return args             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_args);
  __pyx_r = __pyx_v_args;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_arg_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_is_self_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_7p_c_arg_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_7p_c_arg_list = {"p_c_arg_list", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_7p_c_arg_list, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_7p_c_arg_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s = 0;
  PyObject *__pyx_v_ctx = 0;
  int __pyx_v_in_pyfunc;
  int __pyx_v_cmethod_flag;
  int __pyx_v_nonempty_declarators;
  int __pyx_v_kw_only;
  int __pyx_v_annotated;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p_c_arg_list (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s,&__pyx_mstate_global->__pyx_n_u_ctx,&__pyx_mstate_global->__pyx_n_u_in_pyfunc,&__pyx_mstate_global->__pyx_n_u_cmethod_flag,&__pyx_mstate_global->__pyx_n_u_nonempty_declarators,&__pyx_mstate_global->__pyx_n_u_kw_only,&__pyx_mstate_global->__pyx_n_u_annotated,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 3346, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "p_c_arg_list", 0) < (0)) __PYX_ERR(0, 3346, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__52);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("p_c_arg_list", 0, 1, 7, i); __PYX_ERR(0, 3346, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3346, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3346, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__52);
    }
    __pyx_v_s = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)values[0]);
    __pyx_v_ctx = values[1];
    if (values[2]) {
      __pyx_v_in_pyfunc = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_in_pyfunc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3348, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3348
 * @cython.ccall
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
 *                  annotated: cython.bint = True) -> list:
*/
      __pyx_v_in_pyfunc = ((int)0);
    }
    if (values[3]) {
      __pyx_v_cmethod_flag = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_cmethod_flag == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3348, __pyx_L3_error)
    } else {
      __pyx_v_cmethod_flag = ((int)0);
    }
    if (values[4]) {
      __pyx_v_nonempty_declarators = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_nonempty_declarators == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3349, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3349
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  annotated: cython.bint = True) -> list:
 *     #  Comma-separated list of C argument declarations, possibly empty.
*/
      __pyx_v_nonempty_declarators = ((int)0);
    }
    if (values[5]) {
      __pyx_v_kw_only = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_kw_only == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3349, __pyx_L3_error)
    } else {
      __pyx_v_kw_only = ((int)0);
    }
    if (values[6]) {
      __pyx_v_annotated = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_annotated == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3350, __pyx_L3_error)
    } else {

      /* "Cython/Compiler/Parsing.py":3350
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
 *                  annotated: cython.bint = True) -> list:             # <<<<<<<<<<<<<<
 *     #  Comma-separated list of C argument declarations, possibly empty.
 *     #  May have a trailing comma.
*/
      __pyx_v_annotated = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("p_c_arg_list", 0, 1, 7, __pyx_nargs); __PYX_ERR(0, 3346, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_arg_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "s", 0))) __PYX_ERR(0, 3347, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_6p_c_arg_list(__pyx_self, __pyx_v_s, __pyx_v_ctx, __pyx_v_in_pyfunc, __pyx_v_cmethod_flag, __pyx_v_nonempty_declarators, __pyx_v_kw_only, __pyx_v_annotated);

  /* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_6p_c_arg_list(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_in_pyfunc, int __pyx_v_cmethod_flag, int __pyx_v_nonempty_declarators, int __pyx_v_kw_only, int __pyx_v_annotated) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_list __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_arg_list", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(((PyObject *)__pyx_v_s) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 3346, __pyx_L1_error)
  }
  __pyx_t_2.__pyx_n = 6;
  __pyx_t_2.ctx = __pyx_v_ctx;
  __pyx_t_2.in_pyfunc = __pyx_v_in_pyfunc;
  __pyx_t_2.cmethod_flag = __pyx_v_cmethod_flag;
  __pyx_t_2.nonempty_declarators = __pyx_v_nonempty_declarators;
  __pyx_t_2.kw_only = __pyx_v_kw_only;
  __pyx_t_2.annotated = __pyx_v_annotated;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_list(__pyx_v_s, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_arg_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3366
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_optional_ellipsis(s: PyrexScanner) -> cython.bint:
 *     if s.sy == '...':
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_p_optional_ellipsis(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_optional_ellipsis", 0);

  /* "Cython/Compiler/Parsing.py":3368
 * @cython.cfunc
 * def p_optional_ellipsis(s: PyrexScanner) -> cython.bint:
 *     if s.sy == '...':             # <<<<<<<<<<<<<<
 *         expect_ellipsis(s)
 *         return True
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__31, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3368, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3369
 * def p_optional_ellipsis(s: PyrexScanner) -> cython.bint:
 *     if s.sy == '...':
 *         expect_ellipsis(s)             # <<<<<<<<<<<<<<
 *         return True
 *     else:
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_expect_ellipsis(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3370
 *     if s.sy == '...':
 *         expect_ellipsis(s)
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3368
 * @cython.cfunc
 * def p_optional_ellipsis(s: PyrexScanner) -> cython.bint:
 *     if s.sy == '...':             # <<<<<<<<<<<<<<
 *         expect_ellipsis(s)
 *         return True
*/
  }

  /* "Cython/Compiler/Parsing.py":3372
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3366
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_optional_ellipsis(s: PyrexScanner) -> cython.bint:
 *     if s.sy == '...':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_optional_ellipsis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3375
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,
 *                  nonempty: cython.bint = False,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_arg_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, int __pyx_v_in_pyfunc, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_arg_decl *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":3376
 * 
 * @cython.cfunc
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  nonempty: cython.bint = False,
 *                  kw_only: cython.bint = False, annotated: cython.bint = True):
*/
  int __pyx_v_cmethod_flag = ((int)0);

  /* "Cython/Compiler/Parsing.py":3377
 * @cython.cfunc
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,
 *                  nonempty: cython.bint = False,             # <<<<<<<<<<<<<<
 *                  kw_only: cython.bint = False, annotated: cython.bint = True):
 *     pos = s.position()
*/
  int __pyx_v_nonempty = ((int)0);

  /* "Cython/Compiler/Parsing.py":3378
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,
 *                  nonempty: cython.bint = False,
 *                  kw_only: cython.bint = False, annotated: cython.bint = True):             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     not_none = or_none = False
*/
  int __pyx_v_kw_only = ((int)0);
  int __pyx_v_annotated = ((int)1);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_not_none = NULL;
  PyObject *__pyx_v_or_none = NULL;
  PyObject *__pyx_v_default = NULL;
  PyObject *__pyx_v_annotation = NULL;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_arg_decl", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_cmethod_flag = __pyx_optional_args->cmethod_flag;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_nonempty = __pyx_optional_args->nonempty;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_kw_only = __pyx_optional_args->kw_only;
          if (__pyx_optional_args->__pyx_n > 3) {
            __pyx_v_annotated = __pyx_optional_args->annotated;
          }
        }
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":3379
 *                  nonempty: cython.bint = False,
 *                  kw_only: cython.bint = False, annotated: cython.bint = True):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     not_none = or_none = False
 *     default = None
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3380
 *                  kw_only: cython.bint = False, annotated: cython.bint = True):
 *     pos = s.position()
 *     not_none = or_none = False             # <<<<<<<<<<<<<<
 *     default = None
 *     annotation = None
*/
  __Pyx_INCREF(Py_False);
  __pyx_v_not_none = Py_False;
  __Pyx_INCREF(Py_False);
  __pyx_v_or_none = Py_False;

  /* "Cython/Compiler/Parsing.py":3381
 *     pos = s.position()
 *     not_none = or_none = False
 *     default = None             # <<<<<<<<<<<<<<
 *     annotation = None
 *     if s.in_python_file:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_default = Py_None;

  /* "Cython/Compiler/Parsing.py":3382
 *     not_none = or_none = False
 *     default = None
 *     annotation = None             # <<<<<<<<<<<<<<
 *     if s.in_python_file:
 *         # empty type declaration
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_annotation = Py_None;

  /* "Cython/Compiler/Parsing.py":3383
 *     default = None
 *     annotation = None
 *     if s.in_python_file:             # <<<<<<<<<<<<<<
 *         # empty type declaration
 *         base_type = Nodes.CSimpleBaseTypeNode(pos,
*/
  if (__pyx_v_s->in_python_file) {

    /* "Cython/Compiler/Parsing.py":3385
 *     if s.in_python_file:
 *         # empty type declaration
 *         base_type = Nodes.CSimpleBaseTypeNode(pos,             # <<<<<<<<<<<<<<
 *             name = None, module_path = [],
 *             is_basic_c_type = False, signed = 0,
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":3386
 *         # empty type declaration
 *         base_type = Nodes.CSimpleBaseTypeNode(pos,
 *             name = None, module_path = [],             # <<<<<<<<<<<<<<
 *             is_basic_c_type = False, signed = 0,
 *             complex = False, longness = 0,
*/
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "Cython/Compiler/Parsing.py":3389
 *             is_basic_c_type = False, signed = 0,
 *             complex = False, longness = 0,
 *             is_self_arg = cmethod_flag, templates = None)             # <<<<<<<<<<<<<<
 *     else:
 *         base_type = p_c_base_type(s, nonempty=nonempty)
*/
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 8 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, Py_None, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_path, __pyx_t_3, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_basic_c_type, Py_False, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signed, __pyx_mstate_global->__pyx_int_0, __pyx_t_6, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_complex, Py_False, __pyx_t_6, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_longness, __pyx_mstate_global->__pyx_int_0, __pyx_t_6, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_self_arg, __pyx_t_4, __pyx_t_6, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, Py_None, __pyx_t_6, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3385, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CSimpleBaseTypeNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_base_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3383
 *     default = None
 *     annotation = None
 *     if s.in_python_file:             # <<<<<<<<<<<<<<
 *         # empty type declaration
 *         base_type = Nodes.CSimpleBaseTypeNode(pos,
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3391
 *             is_self_arg = cmethod_flag, templates = None)
 *     else:
 *         base_type = p_c_base_type(s, nonempty=nonempty)             # <<<<<<<<<<<<<<
 *     declarator = p_c_declarator(s, ctx, nonempty = nonempty)
 *     if s.sy in ('not', 'or') and not s.in_python_file:
*/
  /*else*/ {
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.nonempty = __pyx_v_nonempty;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_base_type = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3392
 *     else:
 *         base_type = p_c_base_type(s, nonempty=nonempty)
 *     declarator = p_c_declarator(s, ctx, nonempty = nonempty)             # <<<<<<<<<<<<<<
 *     if s.sy in ('not', 'or') and not s.in_python_file:
 *         kind = s.sy
*/
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_nonempty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, ((PyObject *)__pyx_v_s), __pyx_v_ctx};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty, __pyx_t_3, __pyx_t_2, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3392, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_declarator = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3393
 *         base_type = p_c_base_type(s, nonempty=nonempty)
 *     declarator = p_c_declarator(s, ctx, nonempty = nonempty)
 *     if s.sy in ('not', 'or') and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         kind = s.sy
 *         s.next()
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_9 = __pyx_v_s->sy;
  __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_not, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3393, __pyx_L1_error)
  if (!__pyx_t_11) {
  } else {
    __pyx_t_10 = __pyx_t_11;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_or, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3393, __pyx_L1_error)
  __pyx_t_10 = __pyx_t_11;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_11 = __pyx_t_10;
  if (__pyx_t_11) {
  } else {
    __pyx_t_8 = __pyx_t_11;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_11 = (!__pyx_v_s->in_python_file);
  __pyx_t_8 = __pyx_t_11;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":3394
 *     declarator = p_c_declarator(s, ctx, nonempty = nonempty)
 *     if s.sy in ('not', 'or') and not s.in_python_file:
 *         kind = s.sy             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'IDENT' and s.systring == 'None':
*/
    __pyx_t_1 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_kind = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3395
 *     if s.sy in ('not', 'or') and not s.in_python_file:
 *         kind = s.sy
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT' and s.systring == 'None':
 *             s.next()
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3396
 *         kind = s.sy
 *         s.next()
 *         if s.sy == 'IDENT' and s.systring == 'None':             # <<<<<<<<<<<<<<
 *             s.next()
 *         else:
*/
    __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3396, __pyx_L1_error)
    if (__pyx_t_11) {
    } else {
      __pyx_t_8 = __pyx_t_11;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_None, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3396, __pyx_L1_error)
    __pyx_t_8 = __pyx_t_11;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":3397
 *         s.next()
 *         if s.sy == 'IDENT' and s.systring == 'None':
 *             s.next()             # <<<<<<<<<<<<<<
 *         else:
 *             s.error("Expected 'None'")
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3396
 *         kind = s.sy
 *         s.next()
 *         if s.sy == 'IDENT' and s.systring == 'None':             # <<<<<<<<<<<<<<
 *             s.next()
 *         else:
*/
      goto __pyx_L9;
    }

    /* "Cython/Compiler/Parsing.py":3399
 *             s.next()
 *         else:
 *             s.error("Expected 'None'")             # <<<<<<<<<<<<<<
 *         if not in_pyfunc:
 *             error(pos, "'%s None' only allowed in Python functions" % kind)
*/
    /*else*/ {
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Expected_None};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3399, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L9:;

    /* "Cython/Compiler/Parsing.py":3400
 *         else:
 *             s.error("Expected 'None'")
 *         if not in_pyfunc:             # <<<<<<<<<<<<<<
 *             error(pos, "'%s None' only allowed in Python functions" % kind)
 *         or_none = kind == 'or'
*/
    __pyx_t_8 = (!__pyx_v_in_pyfunc);
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":3401
 *             s.error("Expected 'None'")
 *         if not in_pyfunc:
 *             error(pos, "'%s None' only allowed in Python functions" % kind)             # <<<<<<<<<<<<<<
 *         or_none = kind == 'or'
 *         not_none = kind == 'not'
*/
      __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_s_None_only_allowed_in_Python_f, __pyx_v_kind); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3400
 *         else:
 *             s.error("Expected 'None'")
 *         if not in_pyfunc:             # <<<<<<<<<<<<<<
 *             error(pos, "'%s None' only allowed in Python functions" % kind)
 *         or_none = kind == 'or'
*/
    }

    /* "Cython/Compiler/Parsing.py":3402
 *         if not in_pyfunc:
 *             error(pos, "'%s None' only allowed in Python functions" % kind)
 *         or_none = kind == 'or'             # <<<<<<<<<<<<<<
 *         not_none = kind == 'not'
 *     if annotated and s.sy == ':':
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_or, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3402, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_or_none, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3403
 *             error(pos, "'%s None' only allowed in Python functions" % kind)
 *         or_none = kind == 'or'
 *         not_none = kind == 'not'             # <<<<<<<<<<<<<<
 *     if annotated and s.sy == ':':
 *         s.next()
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_kind, __pyx_mstate_global->__pyx_n_u_not, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3403, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_not_none, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3393
 *         base_type = p_c_base_type(s, nonempty=nonempty)
 *     declarator = p_c_declarator(s, ctx, nonempty = nonempty)
 *     if s.sy in ('not', 'or') and not s.in_python_file:             # <<<<<<<<<<<<<<
 *         kind = s.sy
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":3404
 *         or_none = kind == 'or'
 *         not_none = kind == 'not'
 *     if annotated and s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         annotation = p_annotation(s)
*/
  if (__pyx_v_annotated) {
  } else {
    __pyx_t_8 = __pyx_v_annotated;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3404, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_11;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":3405
 *         not_none = kind == 'not'
 *     if annotated and s.sy == ':':
 *         s.next()             # <<<<<<<<<<<<<<
 *         annotation = p_annotation(s)
 *     if s.sy == '=':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3406
 *     if annotated and s.sy == ':':
 *         s.next()
 *         annotation = p_annotation(s)             # <<<<<<<<<<<<<<
 *     if s.sy == '=':
 *         s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_annotation(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_annotation, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3404
 *         or_none = kind == 'or'
 *         not_none = kind == 'not'
 *     if annotated and s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         annotation = p_annotation(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":3407
 *         s.next()
 *         annotation = p_annotation(s)
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if 'pxd' in ctx.level:
*/
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3407, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":3408
 *         annotation = p_annotation(s)
 *     if s.sy == '=':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if 'pxd' in ctx.level:
 *             if s.sy in ['*', '?']:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3409
 *     if s.sy == '=':
 *         s.next()
 *         if 'pxd' in ctx.level:             # <<<<<<<<<<<<<<
 *             if s.sy in ['*', '?']:
 *                 # TODO(github/1736): Make this an error for inline declarations.
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_pxd, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":3410
 *         s.next()
 *         if 'pxd' in ctx.level:
 *             if s.sy in ['*', '?']:             # <<<<<<<<<<<<<<
 *                 # TODO(github/1736): Make this an error for inline declarations.
 *                 default = ExprNodes.NoneNode(pos)
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_9 = __pyx_v_s->sy;
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3410, __pyx_L1_error)
      if (!__pyx_t_11) {
      } else {
        __pyx_t_8 = __pyx_t_11;
        goto __pyx_L19_bool_binop_done;
      }
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_9, __pyx_mstate_global->__pyx_kp_u__21, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3410, __pyx_L1_error)
      __pyx_t_8 = __pyx_t_11;
      __pyx_L19_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_11 = __pyx_t_8;
      if (__pyx_t_11) {

        /* "Cython/Compiler/Parsing.py":3412
 *             if s.sy in ['*', '?']:
 *                 # TODO(github/1736): Make this an error for inline declarations.
 *                 default = ExprNodes.NoneNode(pos)             # <<<<<<<<<<<<<<
 *                 s.next()
 *             elif 'inline' in ctx.modifiers:
*/
        __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_pos};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_NoneNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3412, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF_SET(__pyx_v_default, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3413
 *                 # TODO(github/1736): Make this an error for inline declarations.
 *                 default = ExprNodes.NoneNode(pos)
 *                 s.next()             # <<<<<<<<<<<<<<
 *             elif 'inline' in ctx.modifiers:
 *                 default = p_test(s)
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3413, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3410
 *         s.next()
 *         if 'pxd' in ctx.level:
 *             if s.sy in ['*', '?']:             # <<<<<<<<<<<<<<
 *                 # TODO(github/1736): Make this an error for inline declarations.
 *                 default = ExprNodes.NoneNode(pos)
*/
        goto __pyx_L18;
      }

      /* "Cython/Compiler/Parsing.py":3414
 *                 default = ExprNodes.NoneNode(pos)
 *                 s.next()
 *             elif 'inline' in ctx.modifiers:             # <<<<<<<<<<<<<<
 *                 default = p_test(s)
 *             else:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_modifiers); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_inline, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 3414, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_11) {

        /* "Cython/Compiler/Parsing.py":3415
 *                 s.next()
 *             elif 'inline' in ctx.modifiers:
 *                 default = p_test(s)             # <<<<<<<<<<<<<<
 *             else:
 *                 error(pos, "default values cannot be specified in pxd files, use ? or *")
*/
        __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_default, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":3414
 *                 default = ExprNodes.NoneNode(pos)
 *                 s.next()
 *             elif 'inline' in ctx.modifiers:             # <<<<<<<<<<<<<<
 *                 default = p_test(s)
 *             else:
*/
        goto __pyx_L18;
      }

      /* "Cython/Compiler/Parsing.py":3417
 *                 default = p_test(s)
 *             else:
 *                 error(pos, "default values cannot be specified in pxd files, use ? or *")             # <<<<<<<<<<<<<<
 *         else:
 *             default = p_test(s)
*/
      /*else*/ {
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_default_values_cannot_be_specifi};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3417, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L18:;

      /* "Cython/Compiler/Parsing.py":3409
 *     if s.sy == '=':
 *         s.next()
 *         if 'pxd' in ctx.level:             # <<<<<<<<<<<<<<
 *             if s.sy in ['*', '?']:
 *                 # TODO(github/1736): Make this an error for inline declarations.
*/
      goto __pyx_L17;
    }

    /* "Cython/Compiler/Parsing.py":3419
 *                 error(pos, "default values cannot be specified in pxd files, use ? or *")
 *         else:
 *             default = p_test(s)             # <<<<<<<<<<<<<<
 *     return Nodes.CArgDeclNode(pos,
 *         base_type = base_type,
*/
    /*else*/ {
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_default, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L17:;

    /* "Cython/Compiler/Parsing.py":3407
 *         s.next()
 *         annotation = p_annotation(s)
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if 'pxd' in ctx.level:
*/
  }

  /* "Cython/Compiler/Parsing.py":3420
 *         else:
 *             default = p_test(s)
 *     return Nodes.CArgDeclNode(pos,             # <<<<<<<<<<<<<<
 *         base_type = base_type,
 *         declarator = declarator,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_3);

  /* "Cython/Compiler/Parsing.py":3427
 *         default = default,
 *         annotation = annotation,
 *         kw_only = kw_only)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_kw_only); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 7 : 0)] = {__pyx_t_3, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_not_none, __pyx_v_not_none, __pyx_t_4, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_or_none, __pyx_v_or_none, __pyx_t_4, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_default, __pyx_v_default, __pyx_t_4, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotation, __pyx_v_annotation, __pyx_t_4, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_kw_only, __pyx_t_2, __pyx_t_4, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3420, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CArgDeclNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3375
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_arg_decl(s: PyrexScanner, ctx, in_pyfunc: cython.bint, cmethod_flag: cython.bint = False,
 *                  nonempty: cython.bint = False,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_arg_decl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_not_none);
  __Pyx_XDECREF(__pyx_v_or_none);
  __Pyx_XDECREF(__pyx_v_default);
  __Pyx_XDECREF(__pyx_v_annotation);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3430
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_annotation(s: PyrexScanner):
 *     """An annotation just has the "test" syntax, but also stores the string it came from
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_annotation(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_annotation", 0);

  /* "Cython/Compiler/Parsing.py":3438
 *     then it is not a bug.
 *     """
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     expr = p_test(s)
 *     return ExprNodes.AnnotationNode(pos, expr=expr)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3439
 *     """
 *     pos = s.position()
 *     expr = p_test(s)             # <<<<<<<<<<<<<<
 *     return ExprNodes.AnnotationNode(pos, expr=expr)
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3440
 *     pos = s.position()
 *     expr = p_test(s)
 *     return ExprNodes.AnnotationNode(pos, expr=expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_expr, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3440, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AnnotationNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3430
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_annotation(s: PyrexScanner):
 *     """An annotation just has the "test" syntax, but also stores the string it came from
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_annotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3443
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_api(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'api':
*/

static int __pyx_f_6Cython_8Compiler_7Parsing_p_api(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_api", 0);

  /* "Cython/Compiler/Parsing.py":3445
 * @cython.cfunc
 * def p_api(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'api':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return True
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3445, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_api, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3445, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3446
 * def p_api(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'api':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return True
 *     else:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3447
 *     if s.sy == 'IDENT' and s.systring == 'api':
 *         s.next()
 *         return True             # <<<<<<<<<<<<<<
 *     else:
 *         return False
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3445
 * @cython.cfunc
 * def p_api(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'api':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return True
*/
  }

  /* "Cython/Compiler/Parsing.py":3449
 *         return True
 *     else:
 *         return False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3443
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_api(s: PyrexScanner) -> cython.bint:
 *     if s.sy == 'IDENT' and s.systring == 'api':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3452
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_statement(s: PyrexScanner, pos, ctx):
 *     ctx.visibility = p_visibility(s, ctx.visibility)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cdef_statement", 0);

  /* "Cython/Compiler/Parsing.py":3454
 * @cython.cfunc
 * def p_cdef_statement(s: PyrexScanner, pos, ctx):
 *     ctx.visibility = p_visibility(s, ctx.visibility)             # <<<<<<<<<<<<<<
 *     ctx.api = ctx.api or p_api(s)
 *     if ctx.api:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_visibility(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_2) < (0)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3455
 * def p_cdef_statement(s: PyrexScanner, pos, ctx):
 *     ctx.visibility = p_visibility(s, ctx.visibility)
 *     ctx.api = ctx.api or p_api(s)             # <<<<<<<<<<<<<<
 *     if ctx.api:
 *         if ctx.visibility not in ('private', 'public'):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3455, __pyx_L1_error)
  if (!__pyx_t_3) {
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_api(__pyx_v_s); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3455, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_L3_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api, __pyx_t_2) < (0)) __PYX_ERR(0, 3455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3456
 *     ctx.visibility = p_visibility(s, ctx.visibility)
 *     ctx.api = ctx.api or p_api(s)
 *     if ctx.api:             # <<<<<<<<<<<<<<
 *         if ctx.visibility not in ('private', 'public'):
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":3457
 *     ctx.api = ctx.api or p_api(s)
 *     if ctx.api:
 *         if ctx.visibility not in ('private', 'public'):             # <<<<<<<<<<<<<<
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_private, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3457, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_public, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3457, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __pyx_L7_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __pyx_t_3;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3458
 *     if ctx.api:
 *         if ctx.visibility not in ('private', 'public'):
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)             # <<<<<<<<<<<<<<
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
 *         return p_cdef_extern_block(s, pos, ctx)
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3458, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Cannot_combine_api_with_s, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3458, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_t_7};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3457
 *     ctx.api = ctx.api or p_api(s)
 *     if ctx.api:
 *         if ctx.visibility not in ('private', 'public'):             # <<<<<<<<<<<<<<
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
*/
    }

    /* "Cython/Compiler/Parsing.py":3456
 *     ctx.visibility = p_visibility(s, ctx.visibility)
 *     ctx.api = ctx.api or p_api(s)
 *     if ctx.api:             # <<<<<<<<<<<<<<
 *         if ctx.visibility not in ('private', 'public'):
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
*/
  }

  /* "Cython/Compiler/Parsing.py":3459
 *         if ctx.visibility not in ('private', 'public'):
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
 *     if (ctx.visibility == 'extern') and s.sy == 'from':             # <<<<<<<<<<<<<<
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif s.sy == 'import':
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_extern, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_from, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3459, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_3;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3460
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
 *         return p_cdef_extern_block(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'import':
 *         s.next()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cdef_extern_block(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3459
 *         if ctx.visibility not in ('private', 'public'):
 *             error(pos, "Cannot combine 'api' with '%s'" % ctx.visibility)
 *     if (ctx.visibility == 'extern') and s.sy == 'from':             # <<<<<<<<<<<<<<
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif s.sy == 'import':
*/
  }

  /* "Cython/Compiler/Parsing.py":3461
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif s.sy == 'import':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_cdef_extern_block(s, pos, ctx)
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_import, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3461, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3462
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif s.sy == 'import':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif p_nogil(s):
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3463
 *     elif s.sy == 'import':
 *         s.next()
 *         return p_cdef_extern_block(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif p_nogil(s):
 *         ctx.nogil = True
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cdef_extern_block(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3461
 *     if (ctx.visibility == 'extern') and s.sy == 'from':
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif s.sy == 'import':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return p_cdef_extern_block(s, pos, ctx)
*/
  }

  /* "Cython/Compiler/Parsing.py":3464
 *         s.next()
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif p_nogil(s):             # <<<<<<<<<<<<<<
 *         ctx.nogil = True
 *         if ctx.overridable:
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(__pyx_v_s); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3464, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3465
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif p_nogil(s):
 *         ctx.nogil = True             # <<<<<<<<<<<<<<
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_nogil, Py_True) < (0)) __PYX_ERR(0, 3465, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3466
 *     elif p_nogil(s):
 *         ctx.nogil = True
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3466, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3467
 *         ctx.nogil = True
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")             # <<<<<<<<<<<<<<
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == ':':
*/
      __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_cdef_blocks_cannot_be_declared_c};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3466
 *     elif p_nogil(s):
 *         ctx.nogil = True
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
*/
    }

    /* "Cython/Compiler/Parsing.py":3468
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == ':':
 *         if ctx.overridable:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cdef_block(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3468, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3464
 *         s.next()
 *         return p_cdef_extern_block(s, pos, ctx)
 *     elif p_nogil(s):             # <<<<<<<<<<<<<<
 *         ctx.nogil = True
 *         if ctx.overridable:
*/
  }

  /* "Cython/Compiler/Parsing.py":3469
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3469, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3470
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == ':':
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3470, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3470, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3471
 *     elif s.sy == ':':
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")             # <<<<<<<<<<<<<<
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == 'class':
*/
      __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_cdef_blocks_cannot_be_declared_c};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3471, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3470
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == ':':
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
*/
    }

    /* "Cython/Compiler/Parsing.py":3472
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'class':
 *         if ctx.level not in ('module', 'module_pxd'):
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cdef_block(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3469
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.overridable:
 *             error(pos, "cdef blocks cannot be declared cpdef")
*/
  }

  /* "Cython/Compiler/Parsing.py":3473
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == 'class':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "Extension type definition not allowed here")
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_class_2, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3474
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == 'class':
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             error(pos, "Extension type definition not allowed here")
 *         if ctx.overridable:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_3;
    __pyx_L15_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_4;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":3475
 *     elif s.sy == 'class':
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "Extension type definition not allowed here")             # <<<<<<<<<<<<<<
 *         if ctx.overridable:
 *             error(pos, "Extension types cannot be declared cpdef")
*/
      __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Extension_type_definition_not_al};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3475, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3474
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == 'class':
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             error(pos, "Extension type definition not allowed here")
 *         if ctx.overridable:
*/
    }

    /* "Cython/Compiler/Parsing.py":3476
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "Extension type definition not allowed here")
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "Extension types cannot be declared cpdef")
 *         return p_c_class_definition(s, pos, ctx)
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3476, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":3477
 *             error(pos, "Extension type definition not allowed here")
 *         if ctx.overridable:
 *             error(pos, "Extension types cannot be declared cpdef")             # <<<<<<<<<<<<<<
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':
*/
      __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Extension_types_cannot_be_declar};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3476
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "Extension type definition not allowed here")
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             error(pos, "Extension types cannot be declared cpdef")
 *         return p_c_class_definition(s, pos, ctx)
*/
    }

    /* "Cython/Compiler/Parsing.py":3478
 *         if ctx.overridable:
 *             error(pos, "Extension types cannot be declared cpdef")
 *         return p_c_class_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_class_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3473
 *             error(pos, "cdef blocks cannot be declared cpdef")
 *         return p_cdef_block(s, ctx)
 *     elif s.sy == 'class':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "Extension type definition not allowed here")
*/
  }

  /* "Cython/Compiler/Parsing.py":3479
 *             error(pos, "Extension types cannot be declared cpdef")
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':             # <<<<<<<<<<<<<<
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3479, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_cppclass, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3479, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L18_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":3480
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if ctx.level not in ('module', 'module_pxd'):
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3479
 *             error(pos, "Extension types cannot be declared cpdef")
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':             # <<<<<<<<<<<<<<
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  }

  /* "Cython/Compiler/Parsing.py":3481
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "C struct/union/enum definition not allowed here")
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3481, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3481, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":3482
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3482, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L23_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3482, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __pyx_L23_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __pyx_t_3;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3483
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "C struct/union/enum definition not allowed here")             # <<<<<<<<<<<<<<
 *         if ctx.overridable:
 *             if s.systring != 'enum':
*/
      __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_C_struct_union_enum_definition_n};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3482
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:
*/
    }

    /* "Cython/Compiler/Parsing.py":3484
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             if s.systring != 'enum':
 *                 error(pos, "C struct/union cannot be declared cpdef")
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3485
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:
 *             if s.systring != 'enum':             # <<<<<<<<<<<<<<
 *                 error(pos, "C struct/union cannot be declared cpdef")
 *         return p_struct_enum(s, pos, ctx)
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_enum, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3485, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":3486
 *         if ctx.overridable:
 *             if s.systring != 'enum':
 *                 error(pos, "C struct/union cannot be declared cpdef")             # <<<<<<<<<<<<<<
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
*/
        __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_8 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_8 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_C_struct_union_cannot_be_declare};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3486, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":3485
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:
 *             if s.systring != 'enum':             # <<<<<<<<<<<<<<
 *                 error(pos, "C struct/union cannot be declared cpdef")
 *         return p_struct_enum(s, pos, ctx)
*/
      }

      /* "Cython/Compiler/Parsing.py":3484
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "C struct/union/enum definition not allowed here")
 *         if ctx.overridable:             # <<<<<<<<<<<<<<
 *             if s.systring != 'enum':
 *                 error(pos, "C struct/union cannot be declared cpdef")
*/
    }

    /* "Cython/Compiler/Parsing.py":3487
 *             if s.systring != 'enum':
 *                 error(pos, "C struct/union cannot be declared cpdef")
 *         return p_struct_enum(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
 *         return p_fused_definition(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_struct_enum(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3481
 *     elif s.sy == 'IDENT' and s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'module_pxd'):
 *             error(pos, "C struct/union/enum definition not allowed here")
*/
  }

  /* "Cython/Compiler/Parsing.py":3488
 *                 error(pos, "C struct/union cannot be declared cpdef")
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':             # <<<<<<<<<<<<<<
 *         return p_fused_definition(s, pos, ctx)
 *     else:
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3488, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L27_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_fused, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3488, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_3;
  __pyx_L27_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3489
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
 *         return p_fused_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     else:
 *         return p_c_func_or_var_declaration(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_fused_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3488
 *                 error(pos, "C struct/union cannot be declared cpdef")
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':             # <<<<<<<<<<<<<<
 *         return p_fused_definition(s, pos, ctx)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":3491
 *         return p_fused_definition(s, pos, ctx)
 *     else:
 *         return p_c_func_or_var_declaration(s, pos, ctx)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3452
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_statement(s: PyrexScanner, pos, ctx):
 *     ctx.visibility = p_visibility(s, ctx.visibility)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cdef_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3494
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_block(s: PyrexScanner, ctx):
 *     return p_suite(s, ctx(cdef_flag = True))
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cdef_block", 0);

  /* "Cython/Compiler/Parsing.py":3496
 * @cython.cfunc
 * def p_cdef_block(s: PyrexScanner, ctx):
 *     return p_suite(s, ctx(cdef_flag = True))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_3 = __pyx_v_ctx; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cdef_flag, Py_True, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.ctx = __pyx_t_1;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3494
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_block(s: PyrexScanner, ctx):
 *     return p_suite(s, ctx(cdef_flag = True))
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cdef_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3499
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_extern_block(s: PyrexScanner, pos, ctx):
 *     if ctx.overridable:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cdef_extern_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_include_file = NULL;
  PyObject *__pyx_v_verbatim_include = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_string_literal __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cdef_extern_block", 0);
  __Pyx_INCREF(__pyx_v_ctx);

  /* "Cython/Compiler/Parsing.py":3501
 * @cython.cfunc
 * def p_cdef_extern_block(s: PyrexScanner, pos, ctx):
 *     if ctx.overridable:             # <<<<<<<<<<<<<<
 *         error(pos, "cdef extern blocks cannot be declared cpdef")
 *     include_file = None
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3502
 * def p_cdef_extern_block(s: PyrexScanner, pos, ctx):
 *     if ctx.overridable:
 *         error(pos, "cdef extern blocks cannot be declared cpdef")             # <<<<<<<<<<<<<<
 *     include_file = None
 *     s.expect('from')
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_cdef_extern_blocks_cannot_be_dec};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3501
 * @cython.cfunc
 * def p_cdef_extern_block(s: PyrexScanner, pos, ctx):
 *     if ctx.overridable:             # <<<<<<<<<<<<<<
 *         error(pos, "cdef extern blocks cannot be declared cpdef")
 *     include_file = None
*/
  }

  /* "Cython/Compiler/Parsing.py":3503
 *     if ctx.overridable:
 *         error(pos, "cdef extern blocks cannot be declared cpdef")
 *     include_file = None             # <<<<<<<<<<<<<<
 *     s.expect('from')
 *     if s.sy == '*':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_include_file = Py_None;

  /* "Cython/Compiler/Parsing.py":3504
 *         error(pos, "cdef extern blocks cannot be declared cpdef")
 *     include_file = None
 *     s.expect('from')             # <<<<<<<<<<<<<<
 *     if s.sy == '*':
 *         s.next()
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_from};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3505
 *     include_file = None
 *     s.expect('from')
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         s.next()
 *     else:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3505, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3506
 *     s.expect('from')
 *     if s.sy == '*':
 *         s.next()             # <<<<<<<<<<<<<<
 *     else:
 *         include_file = p_string_literal(s, 'u')[2]
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3505
 *     include_file = None
 *     s.expect('from')
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         s.next()
 *     else:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":3508
 *         s.next()
 *     else:
 *         include_file = p_string_literal(s, 'u')[2]             # <<<<<<<<<<<<<<
 *     ctx = ctx(cdef_flag = True, visibility = 'extern')
 *     if s.systring == "namespace":
*/
  /*else*/ {
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.kind_override = __pyx_mstate_global->__pyx_n_u_u;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 3508, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_Tuple(__pyx_t_1, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_include_file, __pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":3509
 *     else:
 *         include_file = p_string_literal(s, 'u')[2]
 *     ctx = ctx(cdef_flag = True, visibility = 'extern')             # <<<<<<<<<<<<<<
 *     if s.systring == "namespace":
 *         s.next()
*/
  __pyx_t_1 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_3 = __pyx_v_ctx; 
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cdef_flag, Py_True, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3509, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_mstate_global->__pyx_n_u_extern, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF_SET(__pyx_v_ctx, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3510
 *         include_file = p_string_literal(s, 'u')[2]
 *     ctx = ctx(cdef_flag = True, visibility = 'extern')
 *     if s.systring == "namespace":             # <<<<<<<<<<<<<<
 *         s.next()
 *         ctx.namespace = p_string_literal(s, 'u')[2]
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_namespace, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3510, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3511
 *     ctx = ctx(cdef_flag = True, visibility = 'extern')
 *     if s.systring == "namespace":
 *         s.next()             # <<<<<<<<<<<<<<
 *         ctx.namespace = p_string_literal(s, 'u')[2]
 *     if p_nogil(s):
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3512
 *     if s.systring == "namespace":
 *         s.next()
 *         ctx.namespace = p_string_literal(s, 'u')[2]             # <<<<<<<<<<<<<<
 *     if p_nogil(s):
 *         ctx.nogil = True
*/
    __pyx_t_6.__pyx_n = 1;
    __pyx_t_6.kind_override = __pyx_mstate_global->__pyx_n_u_u;
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_string_literal(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_t_4 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 3512, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_t_4, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace, __pyx_t_3) < (0)) __PYX_ERR(0, 3512, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3510
 *         include_file = p_string_literal(s, 'u')[2]
 *     ctx = ctx(cdef_flag = True, visibility = 'extern')
 *     if s.systring == "namespace":             # <<<<<<<<<<<<<<
 *         s.next()
 *         ctx.namespace = p_string_literal(s, 'u')[2]
*/
  }

  /* "Cython/Compiler/Parsing.py":3513
 *         s.next()
 *         ctx.namespace = p_string_literal(s, 'u')[2]
 *     if p_nogil(s):             # <<<<<<<<<<<<<<
 *         ctx.nogil = True
 * 
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(__pyx_v_s); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3513, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3514
 *         ctx.namespace = p_string_literal(s, 'u')[2]
 *     if p_nogil(s):
 *         ctx.nogil = True             # <<<<<<<<<<<<<<
 * 
 *     # Use "docstring" as verbatim string to include
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_nogil, Py_True) < (0)) __PYX_ERR(0, 3514, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3513
 *         s.next()
 *         ctx.namespace = p_string_literal(s, 'u')[2]
 *     if p_nogil(s):             # <<<<<<<<<<<<<<
 *         ctx.nogil = True
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3517
 * 
 *     # Use "docstring" as verbatim string to include
 *     verbatim_include, body = p_suite_with_docstring(s, ctx, True)             # <<<<<<<<<<<<<<
 * 
 *     return Nodes.CDefExternNode(pos,
*/
  __pyx_t_8.__pyx_n = 1;
  __pyx_t_8.with_doc_only = 1;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_v_ctx, &__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(__pyx_t_3 != Py_None)) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3517, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_7);
    #else
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3517, __pyx_L1_error)
  }
  __pyx_v_verbatim_include = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_body = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "Cython/Compiler/Parsing.py":3519
 *     verbatim_include, body = p_suite_with_docstring(s, ctx, True)
 * 
 *     return Nodes.CDefExternNode(pos,             # <<<<<<<<<<<<<<
 *         include_file = include_file,
 *         verbatim_include = verbatim_include,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":3523
 *         verbatim_include = verbatim_include,
 *         body = body,
 *         namespace = ctx.namespace)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_7, __pyx_v_pos};
    __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_include_file, __pyx_v_include_file, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3519, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_verbatim_include, __pyx_v_verbatim_include, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3519, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3519, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_namespace, __pyx_t_4, __pyx_t_1, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3519, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CDefExternNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3499
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cdef_extern_block(s: PyrexScanner, pos, ctx):
 *     if ctx.overridable:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cdef_extern_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_include_file);
  __Pyx_XDECREF(__pyx_v_verbatim_include);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_ctx);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3526
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_definition(s: PyrexScanner, pos, ctx):
 *     # s.sy == ident 'enum'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  int __pyx_v_scoped;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_v_underlying_type = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_enum_definition", 0);

  /* "Cython/Compiler/Parsing.py":3529
 * def p_c_enum_definition(s: PyrexScanner, pos, ctx):
 *     # s.sy == ident 'enum'
 *     s.next()             # <<<<<<<<<<<<<<
 * 
 *     scoped = False
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3531
 *     s.next()
 * 
 *     scoped = False             # <<<<<<<<<<<<<<
 *     if s.context.cpp and (s.sy == 'class' or (s.sy == 'IDENT' and s.systring == 'struct')):
 *         scoped = True
*/
  __pyx_v_scoped = 0;

  /* "Cython/Compiler/Parsing.py":3532
 * 
 *     scoped = False
 *     if s.context.cpp and (s.sy == 'class' or (s.sy == 'IDENT' and s.systring == 'struct')):             # <<<<<<<<<<<<<<
 *         scoped = True
 *         s.next()
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_cpp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_class_2, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_struct, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3533
 *     scoped = False
 *     if s.context.cpp and (s.sy == 'class' or (s.sy == 'IDENT' and s.systring == 'struct')):
 *         scoped = True             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
    __pyx_v_scoped = 1;

    /* "Cython/Compiler/Parsing.py":3534
 *     if s.context.cpp and (s.sy == 'class' or (s.sy == 'IDENT' and s.systring == 'struct')):
 *         scoped = True
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == 'IDENT':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3532
 * 
 *     scoped = False
 *     if s.context.cpp and (s.sy == 'class' or (s.sy == 'IDENT' and s.systring == 'struct')):             # <<<<<<<<<<<<<<
 *         scoped = True
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":3536
 *         s.next()
 * 
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.systring
 *         s.next()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3536, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3537
 * 
 *     if s.sy == 'IDENT':
 *         name = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         cname = p_opt_cname(s)
*/
    __pyx_t_1 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3538
 *     if s.sy == 'IDENT':
 *         name = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         cname = p_opt_cname(s)
 *         if cname is None and ctx.namespace is not None:
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3538, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3539
 *         name = s.systring
 *         s.next()
 *         cname = p_opt_cname(s)             # <<<<<<<<<<<<<<
 *         if cname is None and ctx.namespace is not None:
 *             cname = ctx.namespace + "::" + name
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_cname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3540
 *         s.next()
 *         cname = p_opt_cname(s)
 *         if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *             cname = ctx.namespace + "::" + name
 *     else:
*/
    __pyx_t_5 = (__pyx_v_cname == Py_None);
    if (__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __pyx_t_5;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3541
 *         cname = p_opt_cname(s)
 *         if cname is None and ctx.namespace is not None:
 *             cname = ctx.namespace + "::" + name             # <<<<<<<<<<<<<<
 *     else:
 *         name = cname = None
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__47); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_cname, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3540
 *         s.next()
 *         cname = p_opt_cname(s)
 *         if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *             cname = ctx.namespace + "::" + name
 *     else:
*/
    }

    /* "Cython/Compiler/Parsing.py":3536
 *         s.next()
 * 
 *     if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         name = s.systring
 *         s.next()
*/
    goto __pyx_L8;
  }

  /* "Cython/Compiler/Parsing.py":3543
 *             cname = ctx.namespace + "::" + name
 *     else:
 *         name = cname = None             # <<<<<<<<<<<<<<
 *         if scoped:
 *             s.error("Unnamed scoped enum not allowed")
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_name = Py_None;
    __Pyx_INCREF(Py_None);
    __pyx_v_cname = Py_None;

    /* "Cython/Compiler/Parsing.py":3544
 *     else:
 *         name = cname = None
 *         if scoped:             # <<<<<<<<<<<<<<
 *             s.error("Unnamed scoped enum not allowed")
 * 
*/
    if (__pyx_v_scoped) {

      /* "Cython/Compiler/Parsing.py":3545
 *         name = cname = None
 *         if scoped:
 *             s.error("Unnamed scoped enum not allowed")             # <<<<<<<<<<<<<<
 * 
 *     if scoped and s.sy == '(':
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Unnamed_scoped_enum_not_allowed};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3544
 *     else:
 *         name = cname = None
 *         if scoped:             # <<<<<<<<<<<<<<
 *             s.error("Unnamed scoped enum not allowed")
 * 
*/
    }
  }
  __pyx_L8:;

  /* "Cython/Compiler/Parsing.py":3547
 *             s.error("Unnamed scoped enum not allowed")
 * 
 *     if scoped and s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         underlying_type = p_c_base_type(s)
*/
  if (__pyx_v_scoped) {
  } else {
    __pyx_t_4 = __pyx_v_scoped;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3547, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3548
 * 
 *     if scoped and s.sy == '(':
 *         s.next()             # <<<<<<<<<<<<<<
 *         underlying_type = p_c_base_type(s)
 *         s.expect(')')
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3549
 *     if scoped and s.sy == '(':
 *         s.next()
 *         underlying_type = p_c_base_type(s)             # <<<<<<<<<<<<<<
 *         s.expect(')')
 *     else:
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_underlying_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3550
 *         s.next()
 *         underlying_type = p_c_base_type(s)
 *         s.expect(')')             # <<<<<<<<<<<<<<
 *     else:
 *         underlying_type = Nodes.CSimpleBaseTypeNode(
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__24};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3547
 *             s.error("Unnamed scoped enum not allowed")
 * 
 *     if scoped and s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         underlying_type = p_c_base_type(s)
*/
    goto __pyx_L13;
  }

  /* "Cython/Compiler/Parsing.py":3552
 *         s.expect(')')
 *     else:
 *         underlying_type = Nodes.CSimpleBaseTypeNode(             # <<<<<<<<<<<<<<
 *             pos,
 *             name="int",
*/
  /*else*/ {
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_2);

    /* "Cython/Compiler/Parsing.py":3555
 *             pos,
 *             name="int",
 *             module_path = [],             # <<<<<<<<<<<<<<
 *             is_basic_c_type = True,
 *             signed = 1,
*/
    __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "Cython/Compiler/Parsing.py":3558
 *             is_basic_c_type = True,
 *             signed = 1,
 *             complex = False,             # <<<<<<<<<<<<<<
 *             longness = 0
 *         )
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_int, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_path, __pyx_t_6, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_basic_c_type, Py_True, __pyx_t_7, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signed, __pyx_mstate_global->__pyx_int_1, __pyx_t_7, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_complex, Py_False, __pyx_t_7, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_longness, __pyx_mstate_global->__pyx_int_0, __pyx_t_7, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3552, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CSimpleBaseTypeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_underlying_type = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L13:;

  /* "Cython/Compiler/Parsing.py":3562
 *         )
 * 
 *     s.expect(':')             # <<<<<<<<<<<<<<
 *     items = []
 * 
*/
  __pyx_t_7 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3563
 * 
 *     s.expect(':')
 *     items = []             # <<<<<<<<<<<<<<
 * 
 *     doc = None
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_items = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3565
 *     items = []
 * 
 *     doc = None             # <<<<<<<<<<<<<<
 *     if s.sy != 'NEWLINE':
 *         p_c_enum_line(s, ctx, items)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_doc = Py_None;

  /* "Cython/Compiler/Parsing.py":3566
 * 
 *     doc = None
 *     if s.sy != 'NEWLINE':             # <<<<<<<<<<<<<<
 *         p_c_enum_line(s, ctx, items)
 *     else:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3566, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3567
 *     doc = None
 *     if s.sy != 'NEWLINE':
 *         p_c_enum_line(s, ctx, items)             # <<<<<<<<<<<<<<
 *     else:
 *         s.next()  # 'NEWLINE'
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_line(__pyx_v_s, __pyx_v_ctx, __pyx_v_items); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3566
 * 
 *     doc = None
 *     if s.sy != 'NEWLINE':             # <<<<<<<<<<<<<<
 *         p_c_enum_line(s, ctx, items)
 *     else:
*/
    goto __pyx_L16;
  }

  /* "Cython/Compiler/Parsing.py":3569
 *         p_c_enum_line(s, ctx, items)
 *     else:
 *         s.next()  # 'NEWLINE'             # <<<<<<<<<<<<<<
 *         s.expect_indent()
 *         doc = p_doc_string(s)
*/
  /*else*/ {
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3570
 *     else:
 *         s.next()  # 'NEWLINE'
 *         s.expect_indent()             # <<<<<<<<<<<<<<
 *         doc = p_doc_string(s)
 * 
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3571
 *         s.next()  # 'NEWLINE'
 *         s.expect_indent()
 *         doc = p_doc_string(s)             # <<<<<<<<<<<<<<
 * 
 *         while s.sy not in ('DEDENT', 'EOF'):
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_doc, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3573
 *         doc = p_doc_string(s)
 * 
 *         while s.sy not in ('DEDENT', 'EOF'):             # <<<<<<<<<<<<<<
 *             p_c_enum_line(s, ctx, items)
 * 
*/
    while (1) {
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_8 = __pyx_v_s->sy;
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3573, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L19_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3573, __pyx_L1_error)
      __pyx_t_4 = __pyx_t_5;
      __pyx_L19_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_5 = __pyx_t_4;
      if (!__pyx_t_5) break;

      /* "Cython/Compiler/Parsing.py":3574
 * 
 *         while s.sy not in ('DEDENT', 'EOF'):
 *             p_c_enum_line(s, ctx, items)             # <<<<<<<<<<<<<<
 * 
 *         s.expect_dedent()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_line(__pyx_v_s, __pyx_v_ctx, __pyx_v_items); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "Cython/Compiler/Parsing.py":3576
 *             p_c_enum_line(s, ctx, items)
 * 
 *         s.expect_dedent()             # <<<<<<<<<<<<<<
 * 
 *     if not items and ctx.visibility != "extern":
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L16:;

  /* "Cython/Compiler/Parsing.py":3578
 *         s.expect_dedent()
 * 
 *     if not items and ctx.visibility != "extern":             # <<<<<<<<<<<<<<
 *         error(pos, "Empty enum definition not allowed outside a 'cdef extern from' block")
 * 
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_items);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3578, __pyx_L1_error)
    __pyx_t_4 = (__pyx_temp != 0);
  }

  __pyx_t_9 = (!__pyx_t_4);
  if (__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L22_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_extern, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_9;
  __pyx_L22_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Cython/Compiler/Parsing.py":3579
 * 
 *     if not items and ctx.visibility != "extern":
 *         error(pos, "Empty enum definition not allowed outside a 'cdef extern from' block")             # <<<<<<<<<<<<<<
 * 
 *     return Nodes.CEnumDefNode(
*/
    __pyx_t_7 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_7);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Empty_enum_definition_not_allowe};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3578
 *         s.expect_dedent()
 * 
 *     if not items and ctx.visibility != "extern":             # <<<<<<<<<<<<<<
 *         error(pos, "Empty enum definition not allowed outside a 'cdef extern from' block")
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3581
 *         error(pos, "Empty enum definition not allowed outside a 'cdef extern from' block")
 * 
 *     return Nodes.CEnumDefNode(             # <<<<<<<<<<<<<<
 *         pos, name=name, cname=cname,
 *         scoped=scoped, items=items,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_6);

  /* "Cython/Compiler/Parsing.py":3583
 *     return Nodes.CEnumDefNode(
 *         pos, name=name, cname=cname,
 *         scoped=scoped, items=items,             # <<<<<<<<<<<<<<
 *         underlying_type=underlying_type,
 *         typedef_flag=ctx.typedef_flag, visibility=ctx.visibility,
*/
  __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_scoped); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":3585
 *         scoped=scoped, items=items,
 *         underlying_type=underlying_type,
 *         typedef_flag=ctx.typedef_flag, visibility=ctx.visibility,             # <<<<<<<<<<<<<<
 *         create_wrapper=ctx.overridable,
 *         api=ctx.api, in_pxd=ctx.level == 'module_pxd', doc=doc)
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_typedef_flag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "Cython/Compiler/Parsing.py":3586
 *         underlying_type=underlying_type,
 *         typedef_flag=ctx.typedef_flag, visibility=ctx.visibility,
 *         create_wrapper=ctx.overridable,             # <<<<<<<<<<<<<<
 *         api=ctx.api, in_pxd=ctx.level == 'module_pxd', doc=doc)
 * 
*/
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);

  /* "Cython/Compiler/Parsing.py":3587
 *         typedef_flag=ctx.typedef_flag, visibility=ctx.visibility,
 *         create_wrapper=ctx.overridable,
 *         api=ctx.api, in_pxd=ctx.level == 'module_pxd', doc=doc)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = PyObject_RichCompare(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 11 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, __pyx_v_cname, __pyx_t_13, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_scoped, __pyx_t_7, __pyx_t_13, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_items, __pyx_v_items, __pyx_t_13, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_underlying_type, __pyx_v_underlying_type, __pyx_t_13, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typedef_flag, __pyx_t_2, __pyx_t_13, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_10, __pyx_t_13, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_create_wrapper, __pyx_t_11, __pyx_t_13, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_12, __pyx_t_13, __pyx_callargs+2, 8) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_14, __pyx_t_13, __pyx_callargs+2, 9) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_13, __pyx_callargs+2, 10) < (0)) __PYX_ERR(0, 3581, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CEnumDefNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3526
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_definition(s: PyrexScanner, pos, ctx):
 *     # s.sy == ident 'enum'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_enum_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XDECREF(__pyx_v_underlying_type);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3590
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_line(s: PyrexScanner, ctx, items: list):
 *     if s.sy != 'pass':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_line(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, PyObject *__pyx_v_items) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_enum_line", 0);

  /* "Cython/Compiler/Parsing.py":3592
 * @cython.cfunc
 * def p_c_enum_line(s: PyrexScanner, ctx, items: list):
 *     if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *         p_c_enum_item(s, ctx, items)
 *         while s.sy == ',':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3592, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3593
 * def p_c_enum_line(s: PyrexScanner, ctx, items: list):
 *     if s.sy != 'pass':
 *         p_c_enum_item(s, ctx, items)             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_item(__pyx_v_s, __pyx_v_ctx, __pyx_v_items); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3594
 *     if s.sy != 'pass':
 *         p_c_enum_item(s, ctx, items)
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):
*/
    while (1) {
      __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3594, __pyx_L1_error)
      if (!__pyx_t_1) break;

      /* "Cython/Compiler/Parsing.py":3595
 *         p_c_enum_item(s, ctx, items)
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 break
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3595, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3596
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *                 break
 *             p_c_enum_item(s, ctx, items)
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_5 = __pyx_v_s->sy;
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3596, __pyx_L1_error)
      if (!__pyx_t_6) {
      } else {
        __pyx_t_1 = __pyx_t_6;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_EOF, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3596, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_6;
      __pyx_L7_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __pyx_t_1;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":3597
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 break             # <<<<<<<<<<<<<<
 *             p_c_enum_item(s, ctx, items)
 *     else:
*/
        goto __pyx_L5_break;

        /* "Cython/Compiler/Parsing.py":3596
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy in ('NEWLINE', 'EOF'):             # <<<<<<<<<<<<<<
 *                 break
 *             p_c_enum_item(s, ctx, items)
*/
      }

      /* "Cython/Compiler/Parsing.py":3598
 *             if s.sy in ('NEWLINE', 'EOF'):
 *                 break
 *             p_c_enum_item(s, ctx, items)             # <<<<<<<<<<<<<<
 *     else:
 *         s.next()
*/
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_item(__pyx_v_s, __pyx_v_ctx, __pyx_v_items); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L5_break:;

    /* "Cython/Compiler/Parsing.py":3592
 * @cython.cfunc
 * def p_c_enum_line(s: PyrexScanner, ctx, items: list):
 *     if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *         p_c_enum_item(s, ctx, items)
 *         while s.sy == ',':
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":3600
 *             p_c_enum_item(s, ctx, items)
 *     else:
 *         s.next()             # <<<<<<<<<<<<<<
 *     s.expect_newline("Syntax error in enum item list")
 * 
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":3601
 *     else:
 *         s.next()
 *     s.expect_newline("Syntax error in enum item list")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_enum_item_list};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3590
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_line(s: PyrexScanner, ctx, items: list):
 *     if s.sy != 'pass':
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_enum_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3604
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_item(s: PyrexScanner, ctx, items: list):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_item(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx, PyObject *__pyx_v_items) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_enum_item", 0);

  /* "Cython/Compiler/Parsing.py":3606
 * @cython.cfunc
 * def p_c_enum_item(s: PyrexScanner, ctx, items: list):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3607
 * def p_c_enum_item(s: PyrexScanner, ctx, items: list):
 *     pos = s.position()
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3608
 *     pos = s.position()
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)             # <<<<<<<<<<<<<<
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cname = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3609
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + name
 *     value = None
*/
  __pyx_t_3 = (__pyx_v_cname == Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3610
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name             # <<<<<<<<<<<<<<
 *     value = None
 *     if s.sy == '=':
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__47); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_cname, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3609
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + name
 *     value = None
*/
  }

  /* "Cython/Compiler/Parsing.py":3611
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name
 *     value = None             # <<<<<<<<<<<<<<
 *     if s.sy == '=':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_value = Py_None;

  /* "Cython/Compiler/Parsing.py":3612
 *         cname = ctx.namespace + "::" + name
 *     value = None
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.next()
 *         value = p_test(s)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3612, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3613
 *     value = None
 *     if s.sy == '=':
 *         s.next()             # <<<<<<<<<<<<<<
 *         value = p_test(s)
 *     items.append(Nodes.CEnumDefItemNode(pos,
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3614
 *     if s.sy == '=':
 *         s.next()
 *         value = p_test(s)             # <<<<<<<<<<<<<<
 *     items.append(Nodes.CEnumDefItemNode(pos,
 *         name = name, cname = cname, value = value))
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3612
 *         cname = ctx.namespace + "::" + name
 *     value = None
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.next()
 *         value = p_test(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":3615
 *         s.next()
 *         value = p_test(s)
 *     items.append(Nodes.CEnumDefItemNode(pos,             # <<<<<<<<<<<<<<
 *         name = name, cname = cname, value = value))
 * 
*/
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":3616
 *         value = p_test(s)
 *     items.append(Nodes.CEnumDefItemNode(pos,
 *         name = name, cname = cname, value = value))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3615, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, __pyx_v_cname, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3615, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3615, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CEnumDefItemNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }

  /* "Cython/Compiler/Parsing.py":3615
 *         s.next()
 *         value = p_test(s)
 *     items.append(Nodes.CEnumDefItemNode(pos,             # <<<<<<<<<<<<<<
 *         name = name, cname = cname, value = value))
 * 
*/
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_items, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 3615, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3604
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_enum_item(s: PyrexScanner, ctx, items: list):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_enum_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3619
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_struct_or_union_definition(s: PyrexScanner, pos, ctx):
 *     packed = False
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_struct_or_union_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  int __pyx_v_packed;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_v_attributes = NULL;
  PyObject *__pyx_v_body_ctx = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_struct_or_union_definition", 0);

  /* "Cython/Compiler/Parsing.py":3621
 * @cython.cfunc
 * def p_c_struct_or_union_definition(s: PyrexScanner, pos, ctx):
 *     packed = False             # <<<<<<<<<<<<<<
 *     if s.systring == 'packed':
 *         packed = True
*/
  __pyx_v_packed = 0;

  /* "Cython/Compiler/Parsing.py":3622
 * def p_c_struct_or_union_definition(s: PyrexScanner, pos, ctx):
 *     packed = False
 *     if s.systring == 'packed':             # <<<<<<<<<<<<<<
 *         packed = True
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_packed, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3622, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3623
 *     packed = False
 *     if s.systring == 'packed':
 *         packed = True             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy != 'IDENT' or s.systring != 'struct':
*/
    __pyx_v_packed = 1;

    /* "Cython/Compiler/Parsing.py":3624
 *     if s.systring == 'packed':
 *         packed = True
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy != 'IDENT' or s.systring != 'struct':
 *             s.expected('struct')
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3625
 *         packed = True
 *         s.next()
 *         if s.sy != 'IDENT' or s.systring != 'struct':             # <<<<<<<<<<<<<<
 *             s.expected('struct')
 *     # s.sy == ident 'struct' or 'union'
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3625, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_1 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_struct, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3625, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3626
 *         s.next()
 *         if s.sy != 'IDENT' or s.systring != 'struct':
 *             s.expected('struct')             # <<<<<<<<<<<<<<
 *     # s.sy == ident 'struct' or 'union'
 *     kind = s.systring
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_struct};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3626, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3625
 *         packed = True
 *         s.next()
 *         if s.sy != 'IDENT' or s.systring != 'struct':             # <<<<<<<<<<<<<<
 *             s.expected('struct')
 *     # s.sy == ident 'struct' or 'union'
*/
    }

    /* "Cython/Compiler/Parsing.py":3622
 * def p_c_struct_or_union_definition(s: PyrexScanner, pos, ctx):
 *     packed = False
 *     if s.systring == 'packed':             # <<<<<<<<<<<<<<
 *         packed = True
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":3628
 *             s.expected('struct')
 *     # s.sy == ident 'struct' or 'union'
 *     kind = s.systring             # <<<<<<<<<<<<<<
 *     s.next()
 *     name = p_ident(s)
*/
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_kind = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3629
 *     # s.sy == ident 'struct' or 'union'
 *     kind = s.systring
 *     s.next()             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3630
 *     kind = s.systring
 *     s.next()
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3631
 *     s.next()
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)             # <<<<<<<<<<<<<<
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name
*/
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_cname = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3632
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + name
 *     attributes = None
*/
  __pyx_t_5 = (__pyx_v_cname == Py_None);
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_5;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3633
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name             # <<<<<<<<<<<<<<
 *     attributes = None
 *     if s.sy == ':':
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__47); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_cname, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3632
 *     name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + name
 *     attributes = None
*/
  }

  /* "Cython/Compiler/Parsing.py":3634
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + name
 *     attributes = None             # <<<<<<<<<<<<<<
 *     if s.sy == ':':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_attributes = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":3635
 *         cname = ctx.namespace + "::" + name
 *     attributes = None
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         attributes = []
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3635, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3636
 *     attributes = None
 *     if s.sy == ':':
 *         s.next()             # <<<<<<<<<<<<<<
 *         attributes = []
 *         if s.sy == 'pass':
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3637
 *     if s.sy == ':':
 *         s.next()
 *         attributes = []             # <<<<<<<<<<<<<<
 *         if s.sy == 'pass':
 *             s.next()
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_attributes, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3638
 *         s.next()
 *         attributes = []
 *         if s.sy == 'pass':             # <<<<<<<<<<<<<<
 *             s.next()
 *             s.expect_newline("Expected a newline", ignore_semicolon=True)
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3638, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3639
 *         attributes = []
 *         if s.sy == 'pass':
 *             s.next()             # <<<<<<<<<<<<<<
 *             s.expect_newline("Expected a newline", ignore_semicolon=True)
 *         else:
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3639, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3640
 *         if s.sy == 'pass':
 *             s.next()
 *             s.expect_newline("Expected a newline", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *         else:
 *             s.expect('NEWLINE')
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline};
        __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3640, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3638
 *         s.next()
 *         attributes = []
 *         if s.sy == 'pass':             # <<<<<<<<<<<<<<
 *             s.next()
 *             s.expect_newline("Expected a newline", ignore_semicolon=True)
*/
      goto __pyx_L11;
    }

    /* "Cython/Compiler/Parsing.py":3642
 *             s.expect_newline("Expected a newline", ignore_semicolon=True)
 *         else:
 *             s.expect('NEWLINE')             # <<<<<<<<<<<<<<
 *             s.expect_indent()
 *             body_ctx = Ctx(visibility=ctx.visibility)
*/
    /*else*/ {
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_n_u_NEWLINE};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3642, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3643
 *         else:
 *             s.expect('NEWLINE')
 *             s.expect_indent()             # <<<<<<<<<<<<<<
 *             body_ctx = Ctx(visibility=ctx.visibility)
 *             while s.sy != 'DEDENT':
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3643, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3644
 *             s.expect('NEWLINE')
 *             s.expect_indent()
 *             body_ctx = Ctx(visibility=ctx.visibility)             # <<<<<<<<<<<<<<
 *             while s.sy != 'DEDENT':
 *                 if s.sy != 'pass':
*/
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, NULL};
        __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3644, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_7, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3644, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3644, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_v_body_ctx = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":3645
 *             s.expect_indent()
 *             body_ctx = Ctx(visibility=ctx.visibility)
 *             while s.sy != 'DEDENT':             # <<<<<<<<<<<<<<
 *                 if s.sy != 'pass':
 *                     attributes.append(
*/
      while (1) {
        __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3645, __pyx_L1_error)
        if (!__pyx_t_1) break;

        /* "Cython/Compiler/Parsing.py":3646
 *             body_ctx = Ctx(visibility=ctx.visibility)
 *             while s.sy != 'DEDENT':
 *                 if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *                     attributes.append(
 *                         p_c_func_or_var_declaration(s, s.position(), body_ctx))
*/
        __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3646, __pyx_L1_error)
        if (__pyx_t_1) {

          /* "Cython/Compiler/Parsing.py":3648
 *                 if s.sy != 'pass':
 *                     attributes.append(
 *                         p_c_func_or_var_declaration(s, s.position(), body_ctx))             # <<<<<<<<<<<<<<
 *                 else:
 *                     s.next()
*/
          __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3648, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(__pyx_v_s, __pyx_t_2, __pyx_v_body_ctx); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3648, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "Cython/Compiler/Parsing.py":3647
 *             while s.sy != 'DEDENT':
 *                 if s.sy != 'pass':
 *                     attributes.append(             # <<<<<<<<<<<<<<
 *                         p_c_func_or_var_declaration(s, s.position(), body_ctx))
 *                 else:
*/
          __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_attributes, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3647, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "Cython/Compiler/Parsing.py":3646
 *             body_ctx = Ctx(visibility=ctx.visibility)
 *             while s.sy != 'DEDENT':
 *                 if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *                     attributes.append(
 *                         p_c_func_or_var_declaration(s, s.position(), body_ctx))
*/
          goto __pyx_L14;
        }

        /* "Cython/Compiler/Parsing.py":3650
 *                         p_c_func_or_var_declaration(s, s.position(), body_ctx))
 *                 else:
 *                     s.next()             # <<<<<<<<<<<<<<
 *                     s.expect_newline("Expected a newline")
 *             s.expect_dedent()
*/
        /*else*/ {
          __pyx_t_2 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_4 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
            __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3650, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "Cython/Compiler/Parsing.py":3651
 *                 else:
 *                     s.next()
 *                     s.expect_newline("Expected a newline")             # <<<<<<<<<<<<<<
 *             s.expect_dedent()
 * 
*/
          __pyx_t_2 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_4 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline};
            __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3651, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L14:;
      }

      /* "Cython/Compiler/Parsing.py":3652
 *                     s.next()
 *                     s.expect_newline("Expected a newline")
 *             s.expect_dedent()             # <<<<<<<<<<<<<<
 * 
 *         if not attributes and ctx.visibility != "extern":
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L11:;

    /* "Cython/Compiler/Parsing.py":3654
 *             s.expect_dedent()
 * 
 *         if not attributes and ctx.visibility != "extern":             # <<<<<<<<<<<<<<
 *             error(pos, "Empty struct or union definition not allowed outside a 'cdef extern from' block")
 *     else:
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_attributes);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3654, __pyx_L1_error)
      __pyx_t_5 = (__pyx_temp != 0);
    }

    __pyx_t_10 = (!__pyx_t_5);
    if (__pyx_t_10) {
    } else {
      __pyx_t_1 = __pyx_t_10;
      goto __pyx_L16_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_extern, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 3654, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_10;
    __pyx_L16_bool_binop_done:;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3655
 * 
 *         if not attributes and ctx.visibility != "extern":
 *             error(pos, "Empty struct or union definition not allowed outside a 'cdef extern from' block")             # <<<<<<<<<<<<<<
 *     else:
 *         s.expect_newline("Syntax error in struct or union definition")
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Empty_struct_or_union_definition};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3655, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":3654
 *             s.expect_dedent()
 * 
 *         if not attributes and ctx.visibility != "extern":             # <<<<<<<<<<<<<<
 *             error(pos, "Empty struct or union definition not allowed outside a 'cdef extern from' block")
 *     else:
*/
    }

    /* "Cython/Compiler/Parsing.py":3635
 *         cname = ctx.namespace + "::" + name
 *     attributes = None
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         attributes = []
*/
    goto __pyx_L10;
  }

  /* "Cython/Compiler/Parsing.py":3657
 *             error(pos, "Empty struct or union definition not allowed outside a 'cdef extern from' block")
 *     else:
 *         s.expect_newline("Syntax error in struct or union definition")             # <<<<<<<<<<<<<<
 * 
 *     return Nodes.CStructOrUnionDefNode(pos,
*/
  /*else*/ {
    __pyx_t_8 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_struct_or_union};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3657, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L10:;

  /* "Cython/Compiler/Parsing.py":3659
 *         s.expect_newline("Syntax error in struct or union definition")
 * 
 *     return Nodes.CStructOrUnionDefNode(pos,             # <<<<<<<<<<<<<<
 *         name = name, cname = cname, kind = kind, attributes = attributes,
 *         typedef_flag = ctx.typedef_flag, visibility = ctx.visibility,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_8);

  /* "Cython/Compiler/Parsing.py":3661
 *     return Nodes.CStructOrUnionDefNode(pos,
 *         name = name, cname = cname, kind = kind, attributes = attributes,
 *         typedef_flag = ctx.typedef_flag, visibility = ctx.visibility,             # <<<<<<<<<<<<<<
 *         api = ctx.api, in_pxd = ctx.level == 'module_pxd', packed = packed)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_typedef_flag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "Cython/Compiler/Parsing.py":3662
 *         name = name, cname = cname, kind = kind, attributes = attributes,
 *         typedef_flag = ctx.typedef_flag, visibility = ctx.visibility,
 *         api = ctx.api, in_pxd = ctx.level == 'module_pxd', packed = packed)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = PyObject_RichCompare(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyBool_FromLong(__pyx_v_packed); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 9 : 0)] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, __pyx_v_cname, __pyx_t_13, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_kind, __pyx_v_kind, __pyx_t_13, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_attributes, __pyx_v_attributes, __pyx_t_13, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typedef_flag, __pyx_t_2, __pyx_t_13, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_7, __pyx_t_13, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_6, __pyx_t_13, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_12, __pyx_t_13, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_packed, __pyx_t_11, __pyx_t_13, __pyx_callargs+2, 8) < (0)) __PYX_ERR(0, 3659, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CStructOrUnionDefNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3619
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_struct_or_union_definition(s: PyrexScanner, pos, ctx):
 *     packed = False
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_struct_or_union_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XDECREF(__pyx_v_attributes);
  __Pyx_XDECREF(__pyx_v_body_ctx);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3665
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_fused_definition(s: PyrexScanner, pos, ctx):
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_fused_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_types = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_fused_definition", 0);

  /* "Cython/Compiler/Parsing.py":3673
 *     # s.systring == 'fused'
 * 
 *     if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *         error(pos, "Fused type definition not allowed here")
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3673, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3673, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":3674
 * 
 *     if ctx.level not in ('module', 'module_pxd'):
 *         error(pos, "Fused type definition not allowed here")             # <<<<<<<<<<<<<<
 * 
 *     s.next()
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Fused_type_definition_not_allowe};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3673
 *     # s.systring == 'fused'
 * 
 *     if ctx.level not in ('module', 'module_pxd'):             # <<<<<<<<<<<<<<
 *         error(pos, "Fused type definition not allowed here")
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3676
 *         error(pos, "Fused type definition not allowed here")
 * 
 *     s.next()             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3677
 * 
 *     s.next()
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 * 
 *     s.expect(":")
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3679
 *     name = p_ident(s)
 * 
 *     s.expect(":")             # <<<<<<<<<<<<<<
 *     s.expect_newline()
 *     s.expect_indent()
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3680
 * 
 *     s.expect(":")
 *     s.expect_newline()             # <<<<<<<<<<<<<<
 *     s.expect_indent()
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3681
 *     s.expect(":")
 *     s.expect_newline()
 *     s.expect_indent()             # <<<<<<<<<<<<<<
 * 
 *     types = []
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3683
 *     s.expect_indent()
 * 
 *     types = []             # <<<<<<<<<<<<<<
 *     while s.sy != 'DEDENT':
 *         if s.sy != 'pass':
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3684
 * 
 *     types = []
 *     while s.sy != 'DEDENT':             # <<<<<<<<<<<<<<
 *         if s.sy != 'pass':
 *             #types.append(p_c_declarator(s))
*/
  while (1) {
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3684, __pyx_L1_error)
    if (!__pyx_t_3) break;

    /* "Cython/Compiler/Parsing.py":3685
 *     types = []
 *     while s.sy != 'DEDENT':
 *         if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *             #types.append(p_c_declarator(s))
 *             types.append(p_c_base_type(s))  #, nonempty=1))
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3685, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":3687
 *         if s.sy != 'pass':
 *             #types.append(p_c_declarator(s))
 *             types.append(p_c_base_type(s))  #, nonempty=1))             # <<<<<<<<<<<<<<
 *         else:
 *             s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_types, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 3687, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3685
 *     types = []
 *     while s.sy != 'DEDENT':
 *         if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *             #types.append(p_c_declarator(s))
 *             types.append(p_c_base_type(s))  #, nonempty=1))
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/Parsing.py":3689
 *             types.append(p_c_base_type(s))  #, nonempty=1))
 *         else:
 *             s.next()             # <<<<<<<<<<<<<<
 * 
 *         s.expect_newline()
*/
    /*else*/ {
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L8:;

    /* "Cython/Compiler/Parsing.py":3691
 *             s.next()
 * 
 *         s.expect_newline()             # <<<<<<<<<<<<<<
 * 
 *     s.expect_dedent()
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3691, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":3693
 *         s.expect_newline()
 * 
 *     s.expect_dedent()             # <<<<<<<<<<<<<<
 * 
 *     if not types:
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3695
 *     s.expect_dedent()
 * 
 *     if not types:             # <<<<<<<<<<<<<<
 *         error(pos, "Need at least one type")
 * 
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_types);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3695, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_3);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3696
 * 
 *     if not types:
 *         error(pos, "Need at least one type")             # <<<<<<<<<<<<<<
 * 
 *     return Nodes.FusedTypeNode(pos, name=name, types=types)
*/
    __pyx_t_5 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Need_at_least_one_type};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3695
 *     s.expect_dedent()
 * 
 *     if not types:             # <<<<<<<<<<<<<<
 *         error(pos, "Need at least one type")
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3698
 *         error(pos, "Need at least one type")
 * 
 *     return Nodes.FusedTypeNode(pos, name=name, types=types)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3698, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_types, __pyx_v_types, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3698, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FusedTypeNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3665
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_fused_definition(s: PyrexScanner, pos, ctx):
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_fused_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_types);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3701
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_struct_enum(s: PyrexScanner, pos, ctx):
 *     if s.systring == 'enum':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_struct_enum(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_struct_enum", 0);

  /* "Cython/Compiler/Parsing.py":3703
 * @cython.cfunc
 * def p_struct_enum(s: PyrexScanner, pos, ctx):
 *     if s.systring == 'enum':             # <<<<<<<<<<<<<<
 *         return p_c_enum_definition(s, pos, ctx)
 *     else:
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_enum, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3703, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3704
 * def p_struct_enum(s: PyrexScanner, pos, ctx):
 *     if s.systring == 'enum':
 *         return p_c_enum_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     else:
 *         return p_c_struct_or_union_definition(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_enum_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3703
 * @cython.cfunc
 * def p_struct_enum(s: PyrexScanner, pos, ctx):
 *     if s.systring == 'enum':             # <<<<<<<<<<<<<<
 *         return p_c_enum_definition(s, pos, ctx)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":3706
 *         return p_c_enum_definition(s, pos, ctx)
 *     else:
 *         return p_c_struct_or_union_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_struct_or_union_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3701
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_struct_enum(s: PyrexScanner, pos, ctx):
 *     if s.systring == 'enum':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_struct_enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3709
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_visibility(s: PyrexScanner, prev_visibility):
 *     visibility = prev_visibility
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_visibility(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_prev_visibility) {
  PyObject *__pyx_v_visibility = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8[5];
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_visibility", 0);

  /* "Cython/Compiler/Parsing.py":3711
 * @cython.cfunc
 * def p_visibility(s: PyrexScanner, prev_visibility):
 *     visibility = prev_visibility             # <<<<<<<<<<<<<<
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):
 *         visibility = s.systring
*/
  __Pyx_INCREF(__pyx_v_prev_visibility);
  __pyx_v_visibility = __pyx_v_prev_visibility;

  /* "Cython/Compiler/Parsing.py":3712
 * def p_visibility(s: PyrexScanner, prev_visibility):
 *     visibility = prev_visibility
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):             # <<<<<<<<<<<<<<
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3712, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_s->systring);
  __pyx_t_3 = __pyx_v_s->systring;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_extern, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3712, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_public, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3712, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_readonly, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3712, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_2;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3713
 *     visibility = prev_visibility
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):
 *         visibility = s.systring             # <<<<<<<<<<<<<<
 *         if prev_visibility != 'private' and visibility != prev_visibility:
 *             s.error("Conflicting visibility options '%s' and '%s'"
*/
    __pyx_t_3 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_visibility, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3714
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:             # <<<<<<<<<<<<<<
 *             s.error("Conflicting visibility options '%s' and '%s'"
 *                 % (prev_visibility, visibility), fatal=False)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_prev_visibility, __pyx_mstate_global->__pyx_n_u_private, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3714, __pyx_L1_error)
    if (__pyx_t_4) {
    } else {
      __pyx_t_1 = __pyx_t_4;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_visibility, __pyx_v_prev_visibility, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3714, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3714, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":3715
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:
 *             s.error("Conflicting visibility options '%s' and '%s'"             # <<<<<<<<<<<<<<
 *                 % (prev_visibility, visibility), fatal=False)
 *         s.next()
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_5);

      /* "Cython/Compiler/Parsing.py":3716
 *         if prev_visibility != 'private' and visibility != prev_visibility:
 *             s.error("Conflicting visibility options '%s' and '%s'"
 *                 % (prev_visibility, visibility), fatal=False)             # <<<<<<<<<<<<<<
 *         s.next()
 *     return visibility
*/
      __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_prev_visibility), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3716, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_visibility), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3716, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_Conflicting_visibility_options;
      __pyx_t_8[1] = __pyx_t_6;
      __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_and_3;
      __pyx_t_8[3] = __pyx_t_7;
      __pyx_t_8[4] = __pyx_mstate_global->__pyx_kp_u__34;

      /* "Cython/Compiler/Parsing.py":3715
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:
 *             s.error("Conflicting visibility options '%s' and '%s'"             # <<<<<<<<<<<<<<
 *                 % (prev_visibility, visibility), fatal=False)
 *         s.next()
*/
      __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_8, 5, 32 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":3716
 *         if prev_visibility != 'private' and visibility != prev_visibility:
 *             s.error("Conflicting visibility options '%s' and '%s'"
 *                 % (prev_visibility, visibility), fatal=False)             # <<<<<<<<<<<<<<
 *         s.next()
 *     return visibility
*/
      __pyx_t_10 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_9};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3715, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":3714
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:             # <<<<<<<<<<<<<<
 *             s.error("Conflicting visibility options '%s' and '%s'"
 *                 % (prev_visibility, visibility), fatal=False)
*/
    }

    /* "Cython/Compiler/Parsing.py":3717
 *             s.error("Conflicting visibility options '%s' and '%s'"
 *                 % (prev_visibility, visibility), fatal=False)
 *         s.next()             # <<<<<<<<<<<<<<
 *     return visibility
 * 
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3712
 * def p_visibility(s: PyrexScanner, prev_visibility):
 *     visibility = prev_visibility
 *     if s.sy == 'IDENT' and s.systring in ('extern', 'public', 'readonly'):             # <<<<<<<<<<<<<<
 *         visibility = s.systring
 *         if prev_visibility != 'private' and visibility != prev_visibility:
*/
  }

  /* "Cython/Compiler/Parsing.py":3718
 *                 % (prev_visibility, visibility), fatal=False)
 *         s.next()
 *     return visibility             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_visibility);
  __pyx_r = __pyx_v_visibility;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3709
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_visibility(s: PyrexScanner, prev_visibility):
 *     visibility = prev_visibility
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_visibility", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_visibility);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3721
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_modifiers(s: PyrexScanner) -> list:
 *     if s.sy == 'IDENT' and s.systring in ('inline',):
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_modifiers(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_modifier = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_modifiers", 0);

  /* "Cython/Compiler/Parsing.py":3723
 * @cython.cfunc
 * def p_c_modifiers(s: PyrexScanner) -> list:
 *     if s.sy == 'IDENT' and s.systring in ('inline',):             # <<<<<<<<<<<<<<
 *         modifier = s.systring
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3723, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_s->systring);
  __pyx_t_3 = __pyx_v_s->systring;
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_inline, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_2;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3724
 * def p_c_modifiers(s: PyrexScanner) -> list:
 *     if s.sy == 'IDENT' and s.systring in ('inline',):
 *         modifier = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         return [modifier] + p_c_modifiers(s)
*/
    __pyx_t_3 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_modifier = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3725
 *     if s.sy == 'IDENT' and s.systring in ('inline',):
 *         modifier = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         return [modifier] + p_c_modifiers(s)
 *     return []
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3725, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3726
 *         modifier = s.systring
 *         s.next()
 *         return [modifier] + p_c_modifiers(s)             # <<<<<<<<<<<<<<
 *     return []
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_modifier);
    __Pyx_GIVEREF(__pyx_v_modifier);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_modifier) != (0)) __PYX_ERR(0, 3726, __pyx_L1_error);
    __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_modifiers(__pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3723
 * @cython.cfunc
 * def p_c_modifiers(s: PyrexScanner) -> list:
 *     if s.sy == 'IDENT' and s.systring in ('inline',):             # <<<<<<<<<<<<<<
 *         modifier = s.systring
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":3727
 *         s.next()
 *         return [modifier] + p_c_modifiers(s)
 *     return []             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3721
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_modifiers(s: PyrexScanner) -> list:
 *     if s.sy == 'IDENT' and s.systring in ('inline',):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_modifiers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_modifier);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3730
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_func_or_var_declaration(s: PyrexScanner, pos, ctx):
 *     cmethod_flag: cython.bint = ctx.level in ('c_class', 'c_class_pxd')
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  int __pyx_v_cmethod_flag;
  PyObject *__pyx_v_modifiers = NULL;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  int __pyx_v_is_const_method;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_suite = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_declarators = NULL;
  PyObject *__pyx_v_doc_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_func_or_var_declaration", 0);

  /* "Cython/Compiler/Parsing.py":3732
 * @cython.cfunc
 * def p_c_func_or_var_declaration(s: PyrexScanner, pos, ctx):
 *     cmethod_flag: cython.bint = ctx.level in ('c_class', 'c_class_pxd')             # <<<<<<<<<<<<<<
 *     modifiers = p_c_modifiers(s)
 *     base_type = p_c_base_type(s, nonempty=True, templates = ctx.templates)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3732, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3732, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L3_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cmethod_flag = __pyx_t_2;

  /* "Cython/Compiler/Parsing.py":3733
 * def p_c_func_or_var_declaration(s: PyrexScanner, pos, ctx):
 *     cmethod_flag: cython.bint = ctx.level in ('c_class', 'c_class_pxd')
 *     modifiers = p_c_modifiers(s)             # <<<<<<<<<<<<<<
 *     base_type = p_c_base_type(s, nonempty=True, templates = ctx.templates)
 *     declarator = p_c_declarator(s, ctx(modifiers=modifiers), cmethod_flag = cmethod_flag,
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_modifiers(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_modifiers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3734
 *     cmethod_flag: cython.bint = ctx.level in ('c_class', 'c_class_pxd')
 *     modifiers = p_c_modifiers(s)
 *     base_type = p_c_base_type(s, nonempty=True, templates = ctx.templates)             # <<<<<<<<<<<<<<
 *     declarator = p_c_declarator(s, ctx(modifiers=modifiers), cmethod_flag = cmethod_flag,
 *                                 assignable=True, nonempty =True)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_templates); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5.__pyx_n = 2;
  __pyx_t_5.nonempty = 1;
  __pyx_t_5.templates = __pyx_t_1;
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, &__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_base_type = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3735
 *     modifiers = p_c_modifiers(s)
 *     base_type = p_c_base_type(s, nonempty=True, templates = ctx.templates)
 *     declarator = p_c_declarator(s, ctx(modifiers=modifiers), cmethod_flag = cmethod_flag,             # <<<<<<<<<<<<<<
 *                                 assignable=True, nonempty =True)
 *     declarator.overridable = ctx.overridable
*/
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_9 = __pyx_v_ctx; 
  __pyx_t_10 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
    __pyx_t_10 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, NULL};
    __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_modifiers, __pyx_v_modifiers, __pyx_t_11, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __pyx_t_7 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __pyx_t_9 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "Cython/Compiler/Parsing.py":3736
 *     base_type = p_c_base_type(s, nonempty=True, templates = ctx.templates)
 *     declarator = p_c_declarator(s, ctx(modifiers=modifiers), cmethod_flag = cmethod_flag,
 *                                 assignable=True, nonempty =True)             # <<<<<<<<<<<<<<
 *     declarator.overridable = ctx.overridable
 * 
*/
  __pyx_t_10 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_10 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_1, ((PyObject *)__pyx_v_s), __pyx_t_7};
    __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_t_9, __pyx_t_11, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3735, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_assignable, Py_True, __pyx_t_11, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 3735, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty, Py_True, __pyx_t_11, __pyx_callargs+3, 2) < (0)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_10, (3-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_v_declarator = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3737
 *     declarator = p_c_declarator(s, ctx(modifiers=modifiers), cmethod_flag = cmethod_flag,
 *                                 assignable=True, nonempty =True)
 *     declarator.overridable = ctx.overridable             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == 'IDENT' and s.systring == 'const' and ctx.level == 'cpp_class':
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_declarator, __pyx_mstate_global->__pyx_n_u_overridable, __pyx_t_4) < (0)) __PYX_ERR(0, 3737, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3739
 *     declarator.overridable = ctx.overridable
 * 
 *     if s.sy == 'IDENT' and s.systring == 'const' and ctx.level == 'cpp_class':             # <<<<<<<<<<<<<<
 *         s.next()
 *         is_const_method = True
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3739, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_const, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3739, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cpp_class, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3740
 * 
 *     if s.sy == 'IDENT' and s.systring == 'const' and ctx.level == 'cpp_class':
 *         s.next()             # <<<<<<<<<<<<<<
 *         is_const_method = True
 *     else:
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3741
 *     if s.sy == 'IDENT' and s.systring == 'const' and ctx.level == 'cpp_class':
 *         s.next()
 *         is_const_method = True             # <<<<<<<<<<<<<<
 *     else:
 *         is_const_method = False
*/
    __pyx_v_is_const_method = 1;

    /* "Cython/Compiler/Parsing.py":3739
 *     declarator.overridable = ctx.overridable
 * 
 *     if s.sy == 'IDENT' and s.systring == 'const' and ctx.level == 'cpp_class':             # <<<<<<<<<<<<<<
 *         s.next()
 *         is_const_method = True
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/Parsing.py":3743
 *         is_const_method = True
 *     else:
 *         is_const_method = False             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == '->':
*/
  /*else*/ {
    __pyx_v_is_const_method = 0;
  }
  __pyx_L5:;

  /* "Cython/Compiler/Parsing.py":3745
 *         is_const_method = False
 * 
 *     if s.sy == '->':             # <<<<<<<<<<<<<<
 *         # Special enough to give a better error message and keep going.
 *         s.error(
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__53, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3745, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3747
 *     if s.sy == '->':
 *         # Special enough to give a better error message and keep going.
 *         s.error(             # <<<<<<<<<<<<<<
 *             "Return type annotation is not allowed in cdef/cpdef signatures. "
 *             "Please define it before the function name, as in C signatures.",
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);

    /* "Cython/Compiler/Parsing.py":3750
 *             "Return type annotation is not allowed in cdef/cpdef signatures. "
 *             "Please define it before the function name, as in C signatures.",
 *             fatal=False)             # <<<<<<<<<<<<<<
 *         s.next()
 *         p_test(s)  # Keep going, but ignore result.
*/
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Return_type_annotation_is_not_al};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3747, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3747, __pyx_L1_error)
      __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3747, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3751
 *             "Please define it before the function name, as in C signatures.",
 *             fatal=False)
 *         s.next()             # <<<<<<<<<<<<<<
 *         p_test(s)  # Keep going, but ignore result.
 * 
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3752
 *             fatal=False)
 *         s.next()
 *         p_test(s)  # Keep going, but ignore result.             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == ':':
*/
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3745
 *         is_const_method = False
 * 
 *     if s.sy == '->':             # <<<<<<<<<<<<<<
 *         # Special enough to give a better error message and keep going.
 *         s.error(
*/
  }

  /* "Cython/Compiler/Parsing.py":3754
 *         p_test(s)  # Keep going, but ignore result.
 * 
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:
 *             s.error("C function definition not allowed here")
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3754, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3755
 * 
 *     if s.sy == ':':
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:             # <<<<<<<<<<<<<<
 *             s.error("C function definition not allowed here")
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_module, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    if (__pyx_t_12) {
    } else {
      __pyx_t_3 = __pyx_t_12;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_c_class, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    if (__pyx_t_12) {
    } else {
      __pyx_t_3 = __pyx_t_12;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    if (__pyx_t_12) {
    } else {
      __pyx_t_3 = __pyx_t_12;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    if (__pyx_t_12) {
    } else {
      __pyx_t_3 = __pyx_t_12;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cpp_class, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_12;
    __pyx_L14_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_12 = __pyx_t_3;
    if (__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_templates); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3755, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = (!__pyx_t_12);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L12_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3756
 *     if s.sy == ':':
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:
 *             s.error("C function definition not allowed here")             # <<<<<<<<<<<<<<
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))
 *         result = Nodes.CFuncDefNode(pos,
*/
      __pyx_t_11 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_10 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_C_function_definition_not_allowe};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3756, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "Cython/Compiler/Parsing.py":3755
 * 
 *     if s.sy == ':':
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:             # <<<<<<<<<<<<<<
 *             s.error("C function definition not allowed here")
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))
*/
    }

    /* "Cython/Compiler/Parsing.py":3757
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:
 *             s.error("C function definition not allowed here")
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))             # <<<<<<<<<<<<<<
 *         result = Nodes.CFuncDefNode(pos,
 *             visibility = ctx.visibility,
*/
    __pyx_t_11 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_11);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_10 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, NULL};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_function, __pyx_t_9, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(__pyx_t_6 != Py_None)) {
      PyObject* sequence = __pyx_t_6;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3757, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_9);
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      #endif
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3757, __pyx_L1_error)
    }
    __pyx_v_doc = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_suite = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "Cython/Compiler/Parsing.py":3758
 *             s.error("C function definition not allowed here")
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))
 *         result = Nodes.CFuncDefNode(pos,             # <<<<<<<<<<<<<<
 *             visibility = ctx.visibility,
 *             base_type = base_type,
*/
    __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_9);

    /* "Cython/Compiler/Parsing.py":3759
 *         doc, suite = p_suite_with_docstring(s, Ctx(level='function'))
 *         result = Nodes.CFuncDefNode(pos,
 *             visibility = ctx.visibility,             # <<<<<<<<<<<<<<
 *             base_type = base_type,
 *             declarator = declarator,
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "Cython/Compiler/Parsing.py":3765
 *             doc = doc,
 *             modifiers = modifiers,
 *             api = ctx.api,             # <<<<<<<<<<<<<<
 *             overridable = ctx.overridable,
 *             is_const_method = is_const_method)
*/
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);

    /* "Cython/Compiler/Parsing.py":3766
 *             modifiers = modifiers,
 *             api = ctx.api,
 *             overridable = ctx.overridable,             # <<<<<<<<<<<<<<
 *             is_const_method = is_const_method)
 *     else:
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "Cython/Compiler/Parsing.py":3767
 *             api = ctx.api,
 *             overridable = ctx.overridable,
 *             is_const_method = is_const_method)             # <<<<<<<<<<<<<<
 *     else:
 *         #if api:
*/
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_is_const_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 9 : 0)] = {__pyx_t_9, __pyx_v_pos};
      __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_4, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_8, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_suite, __pyx_t_8, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_8, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_modifiers, __pyx_v_modifiers, __pyx_t_8, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_11, __pyx_t_8, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_overridable, __pyx_t_7, __pyx_t_8, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_const_method, __pyx_t_1, __pyx_t_8, __pyx_callargs+2, 8) < (0)) __PYX_ERR(0, 3758, __pyx_L1_error)
      __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CFuncDefNode, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":3754
 *         p_test(s)  # Keep going, but ignore result.
 * 
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.level not in ('module', 'c_class', 'module_pxd', 'c_class_pxd', 'cpp_class') and not ctx.templates:
 *             s.error("C function definition not allowed here")
*/
    goto __pyx_L10;
  }

  /* "Cython/Compiler/Parsing.py":3771
 *         #if api:
 *         #    s.error("'api' not allowed with variable declaration")
 *         if is_const_method:             # <<<<<<<<<<<<<<
 *             declarator.is_const_method = is_const_method
 *         declarators = [declarator]
*/
  /*else*/ {
    if (__pyx_v_is_const_method) {

      /* "Cython/Compiler/Parsing.py":3772
 *         #    s.error("'api' not allowed with variable declaration")
 *         if is_const_method:
 *             declarator.is_const_method = is_const_method             # <<<<<<<<<<<<<<
 *         declarators = [declarator]
 *         while s.sy == ',':
*/
      __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_is_const_method); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_declarator, __pyx_mstate_global->__pyx_n_u_is_const_method, __pyx_t_6) < (0)) __PYX_ERR(0, 3772, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":3771
 *         #if api:
 *         #    s.error("'api' not allowed with variable declaration")
 *         if is_const_method:             # <<<<<<<<<<<<<<
 *             declarator.is_const_method = is_const_method
 *         declarators = [declarator]
*/
    }

    /* "Cython/Compiler/Parsing.py":3773
 *         if is_const_method:
 *             declarator.is_const_method = is_const_method
 *         declarators = [declarator]             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_declarator);
    __Pyx_GIVEREF(__pyx_v_declarator);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_declarator) != (0)) __PYX_ERR(0, 3773, __pyx_L1_error);
    __pyx_v_declarators = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":3774
 *             declarator.is_const_method = is_const_method
 *         declarators = [declarator]
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == 'NEWLINE':
*/
    while (1) {
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3774, __pyx_L1_error)
      if (!__pyx_t_2) break;

      /* "Cython/Compiler/Parsing.py":3775
 *         declarators = [declarator]
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == 'NEWLINE':
 *                 break
*/
      __pyx_t_8 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_10 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3775, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":3776
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *                 break
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_NEWLINE, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3776, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":3777
 *             s.next()
 *             if s.sy == 'NEWLINE':
 *                 break             # <<<<<<<<<<<<<<
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,
 *                                         assignable=True, nonempty=True)
*/
        goto __pyx_L21_break;

        /* "Cython/Compiler/Parsing.py":3776
 *         while s.sy == ',':
 *             s.next()
 *             if s.sy == 'NEWLINE':             # <<<<<<<<<<<<<<
 *                 break
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,
*/
      }

      /* "Cython/Compiler/Parsing.py":3778
 *             if s.sy == 'NEWLINE':
 *                 break
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,             # <<<<<<<<<<<<<<
 *                                         assignable=True, nonempty=True)
 *             declarators.append(declarator)
*/
      __pyx_t_8 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_cmethod_flag); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "Cython/Compiler/Parsing.py":3779
 *                 break
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,
 *                                         assignable=True, nonempty=True)             # <<<<<<<<<<<<<<
 *             declarators.append(declarator)
 *         doc_line = s.start_line + 1
*/
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_8, ((PyObject *)__pyx_v_s), __pyx_v_ctx};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3778, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_t_7, __pyx_t_11, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3778, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_assignable, Py_True, __pyx_t_11, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 3778, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty, Py_True, __pyx_t_11, __pyx_callargs+3, 2) < (0)) __PYX_ERR(0, 3778, __pyx_L1_error)
        __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_10, (3-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3778, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF_SET(__pyx_v_declarator, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":3780
 *             declarator = p_c_declarator(s, ctx, cmethod_flag = cmethod_flag,
 *                                         assignable=True, nonempty=True)
 *             declarators.append(declarator)             # <<<<<<<<<<<<<<
 *         doc_line = s.start_line + 1
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)
*/
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_declarators, __pyx_v_declarator); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 3780, __pyx_L1_error)
    }
    __pyx_L21_break:;

    /* "Cython/Compiler/Parsing.py":3781
 *                                         assignable=True, nonempty=True)
 *             declarators.append(declarator)
 *         doc_line = s.start_line + 1             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)
 *         if ctx.level in ('c_class', 'c_class_pxd') and s.start_line == doc_line:
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_start_line); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_t_6, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_doc_line = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3782
 *             declarators.append(declarator)
 *         doc_line = s.start_line + 1
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *         if ctx.level in ('c_class', 'c_class_pxd') and s.start_line == doc_line:
 *             doc = p_doc_string(s)
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_C_variable_decla};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3782, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3782, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3783
 *         doc_line = s.start_line + 1
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)
 *         if ctx.level in ('c_class', 'c_class_pxd') and s.start_line == doc_line:             # <<<<<<<<<<<<<<
 *             doc = p_doc_string(s)
 *         else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3783, __pyx_L1_error)
    if (!__pyx_t_12) {
    } else {
      __pyx_t_3 = __pyx_t_12;
      goto __pyx_L26_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3783, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_12;
    __pyx_L26_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = __pyx_t_3;
    if (__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_start_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = PyObject_RichCompare(__pyx_t_1, __pyx_v_doc_line, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3783, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3783, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_2 = __pyx_t_12;
    __pyx_L24_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":3784
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)
 *         if ctx.level in ('c_class', 'c_class_pxd') and s.start_line == doc_line:
 *             doc = p_doc_string(s)             # <<<<<<<<<<<<<<
 *         else:
 *             doc = None
*/
      __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(__pyx_v_s); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_v_doc = __pyx_t_11;
      __pyx_t_11 = 0;

      /* "Cython/Compiler/Parsing.py":3783
 *         doc_line = s.start_line + 1
 *         s.expect_newline("Syntax error in C variable declaration", ignore_semicolon=True)
 *         if ctx.level in ('c_class', 'c_class_pxd') and s.start_line == doc_line:             # <<<<<<<<<<<<<<
 *             doc = p_doc_string(s)
 *         else:
*/
      goto __pyx_L23;
    }

    /* "Cython/Compiler/Parsing.py":3786
 *             doc = p_doc_string(s)
 *         else:
 *             doc = None             # <<<<<<<<<<<<<<
 *         result = Nodes.CVarDefNode(pos,
 *             visibility = ctx.visibility,
*/
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __pyx_v_doc = Py_None;
    }
    __pyx_L23:;

    /* "Cython/Compiler/Parsing.py":3787
 *         else:
 *             doc = None
 *         result = Nodes.CVarDefNode(pos,             # <<<<<<<<<<<<<<
 *             visibility = ctx.visibility,
 *             base_type = base_type,
*/
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":3788
 *             doc = None
 *         result = Nodes.CVarDefNode(pos,
 *             visibility = ctx.visibility,             # <<<<<<<<<<<<<<
 *             base_type = base_type,
 *             declarators = declarators,
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "Cython/Compiler/Parsing.py":3791
 *             base_type = base_type,
 *             declarators = declarators,
 *             in_pxd = ctx.level in ('module_pxd', 'c_class_pxd'),             # <<<<<<<<<<<<<<
 *             doc = doc,
 *             api = ctx.api,
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3791, __pyx_L1_error)
    if (!__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L28_bool_binop_done;
    }
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_c_class_pxd, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 3791, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_12;
    __pyx_L28_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "Cython/Compiler/Parsing.py":3793
 *             in_pxd = ctx.level in ('module_pxd', 'c_class_pxd'),
 *             doc = doc,
 *             api = ctx.api,             # <<<<<<<<<<<<<<
 *             modifiers = modifiers,
 *             overridable = ctx.overridable)
*/
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "Cython/Compiler/Parsing.py":3795
 *             api = ctx.api,
 *             modifiers = modifiers,
 *             overridable = ctx.overridable)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_overridable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 8 : 0)] = {__pyx_t_1, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_6, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarators, __pyx_v_declarators, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_7, __pyx_t_9, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_9, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_8, __pyx_t_9, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_modifiers, __pyx_v_modifiers, __pyx_t_9, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_overridable, __pyx_t_4, __pyx_t_9, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3787, __pyx_L1_error)
      __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CVarDefNode, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }
    __pyx_v_result = __pyx_t_11;
    __pyx_t_11 = 0;
  }
  __pyx_L10:;

  /* "Cython/Compiler/Parsing.py":3796
 *             modifiers = modifiers,
 *             overridable = ctx.overridable)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3730
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_func_or_var_declaration(s: PyrexScanner, pos, ctx):
 *     cmethod_flag: cython.bint = ctx.level in ('c_class', 'c_class_pxd')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_func_or_var_declaration", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_modifiers);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_suite);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_declarators);
  __Pyx_XDECREF(__pyx_v_doc_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3799
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ctypedef_statement(s: PyrexScanner, ctx):
 *     # s.sy == 'ctypedef'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ctypedef_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_visibility = NULL;
  int __pyx_v_api;
  PyObject *__pyx_v_base_type = NULL;
  PyObject *__pyx_v_declarator = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_c_base_type __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ctypedef_statement", 0);
  __Pyx_INCREF(__pyx_v_ctx);

  /* "Cython/Compiler/Parsing.py":3802
 * def p_ctypedef_statement(s: PyrexScanner, ctx):
 *     # s.sy == 'ctypedef'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     visibility = p_visibility(s, ctx.visibility)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3803
 *     # s.sy == 'ctypedef'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     visibility = p_visibility(s, ctx.visibility)
 *     api = p_api(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3804
 *     pos = s.position()
 *     s.next()
 *     visibility = p_visibility(s, ctx.visibility)             # <<<<<<<<<<<<<<
 *     api = p_api(s)
 *     ctx = ctx(typedef_flag=True, visibility = visibility)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_visibility(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_visibility = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3805
 *     s.next()
 *     visibility = p_visibility(s, ctx.visibility)
 *     api = p_api(s)             # <<<<<<<<<<<<<<
 *     ctx = ctx(typedef_flag=True, visibility = visibility)
 *     if api:
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_api(__pyx_v_s); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3805, __pyx_L1_error)
  __pyx_v_api = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":3806
 *     visibility = p_visibility(s, ctx.visibility)
 *     api = p_api(s)
 *     ctx = ctx(typedef_flag=True, visibility = visibility)             # <<<<<<<<<<<<<<
 *     if api:
 *         ctx.api = True
*/
  __pyx_t_1 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_5 = __pyx_v_ctx; 
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typedef_flag, Py_True, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3806, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_v_visibility, __pyx_t_6, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 3806, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF_SET(__pyx_v_ctx, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":3807
 *     api = p_api(s)
 *     ctx = ctx(typedef_flag=True, visibility = visibility)
 *     if api:             # <<<<<<<<<<<<<<
 *         ctx.api = True
 *     if s.sy == 'class':
*/
  if (__pyx_v_api) {

    /* "Cython/Compiler/Parsing.py":3808
 *     ctx = ctx(typedef_flag=True, visibility = visibility)
 *     if api:
 *         ctx.api = True             # <<<<<<<<<<<<<<
 *     if s.sy == 'class':
 *         return p_c_class_definition(s, pos, ctx)
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api, Py_True) < (0)) __PYX_ERR(0, 3808, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3807
 *     api = p_api(s)
 *     ctx = ctx(typedef_flag=True, visibility = visibility)
 *     if api:             # <<<<<<<<<<<<<<
 *         ctx.api = True
 *     if s.sy == 'class':
*/
  }

  /* "Cython/Compiler/Parsing.py":3809
 *     if api:
 *         ctx.api = True
 *     if s.sy == 'class':             # <<<<<<<<<<<<<<
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_class_2, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3809, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3810
 *         ctx.api = True
 *     if s.sy == 'class':
 *         return p_c_class_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         return p_struct_enum(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_class_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3809
 *     if api:
 *         ctx.api = True
 *     if s.sy == 'class':             # <<<<<<<<<<<<<<
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  }

  /* "Cython/Compiler/Parsing.py":3811
 *     if s.sy == 'class':
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3811, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3811, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3812
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         return p_struct_enum(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
 *         return p_fused_definition(s, pos, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_struct_enum(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3811
 *     if s.sy == 'class':
 *         return p_c_class_definition(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
*/
  }

  /* "Cython/Compiler/Parsing.py":3813
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':             # <<<<<<<<<<<<<<
 *         return p_fused_definition(s, pos, ctx)
 *     else:
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3813, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_fused, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3813, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3814
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':
 *         return p_fused_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     else:
 *         base_type = p_c_base_type(s, nonempty=True)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_fused_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3813
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         return p_struct_enum(s, pos, ctx)
 *     elif s.sy == 'IDENT' and s.systring == 'fused':             # <<<<<<<<<<<<<<
 *         return p_fused_definition(s, pos, ctx)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":3816
 *         return p_fused_definition(s, pos, ctx)
 *     else:
 *         base_type = p_c_base_type(s, nonempty=True)             # <<<<<<<<<<<<<<
 *         declarator = p_c_declarator(s, ctx, is_type=True, nonempty=True)
 *         s.expect_newline("Syntax error in ctypedef statement", ignore_semicolon=True)
*/
  /*else*/ {
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.nonempty = 1;
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_base_type(__pyx_v_s, 0, &__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_base_type = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3817
 *     else:
 *         base_type = p_c_base_type(s, nonempty=True)
 *         declarator = p_c_declarator(s, ctx, is_type=True, nonempty=True)             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in ctypedef statement", ignore_semicolon=True)
 *         return Nodes.CTypeDefNode(
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_p_c_declarator); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, ((PyObject *)__pyx_v_s), __pyx_v_ctx};
      __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_type, Py_True, __pyx_t_1, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3817, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty, Py_True, __pyx_t_1, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 3817, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_declarator = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3818
 *         base_type = p_c_base_type(s, nonempty=True)
 *         declarator = p_c_declarator(s, ctx, is_type=True, nonempty=True)
 *         s.expect_newline("Syntax error in ctypedef statement", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *         return Nodes.CTypeDefNode(
 *             pos, base_type = base_type,
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_ctypedef_stateme};
      __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3818, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3819
 *         declarator = p_c_declarator(s, ctx, is_type=True, nonempty=True)
 *         s.expect_newline("Syntax error in ctypedef statement", ignore_semicolon=True)
 *         return Nodes.CTypeDefNode(             # <<<<<<<<<<<<<<
 *             pos, base_type = base_type,
 *             declarator = declarator,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":3822
 *             pos, base_type = base_type,
 *             declarator = declarator,
 *             visibility = visibility, api = api,             # <<<<<<<<<<<<<<
 *             in_pxd = ctx.level == 'module_pxd')
 * 
*/
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_api); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "Cython/Compiler/Parsing.py":3823
 *             declarator = declarator,
 *             visibility = visibility, api = api,
 *             in_pxd = ctx.level == 'module_pxd')             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3823, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_1, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_type, __pyx_v_base_type, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3819, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_declarator, __pyx_v_declarator, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3819, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_v_visibility, __pyx_t_5, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3819, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_6, __pyx_t_5, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3819, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_9, __pyx_t_5, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3819, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CTypeDefNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":3799
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ctypedef_statement(s: PyrexScanner, ctx):
 *     # s.sy == 'ctypedef'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ctypedef_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_visibility);
  __Pyx_XDECREF(__pyx_v_base_type);
  __Pyx_XDECREF(__pyx_v_declarator);
  __Pyx_XDECREF(__pyx_v_ctx);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3826
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_decorators(s: PyrexScanner) -> list:
 *     decorators = []
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_decorators(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_decorators = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_decorator = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_decorators", 0);

  /* "Cython/Compiler/Parsing.py":3828
 * @cython.cfunc
 * def p_decorators(s: PyrexScanner) -> list:
 *     decorators = []             # <<<<<<<<<<<<<<
 *     while s.sy == '@':
 *         pos = s.position()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_decorators = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3829
 * def p_decorators(s: PyrexScanner) -> list:
 *     decorators = []
 *     while s.sy == '@':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__16, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3829, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":3830
 *     decorators = []
 *     while s.sy == '@':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         decorator = p_namedexpr_test(s)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_pos, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3831
 *     while s.sy == '@':
 *         pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         decorator = p_namedexpr_test(s)
 *         decorators.append(Nodes.DecoratorNode(pos, decorator=decorator))
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3832
 *         pos = s.position()
 *         s.next()
 *         decorator = p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 *         decorators.append(Nodes.DecoratorNode(pos, decorator=decorator))
 *         s.expect_newline("Expected a newline after decorator")
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_decorator, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3833
 *         s.next()
 *         decorator = p_namedexpr_test(s)
 *         decorators.append(Nodes.DecoratorNode(pos, decorator=decorator))             # <<<<<<<<<<<<<<
 *         s.expect_newline("Expected a newline after decorator")
 *     return decorators
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_decorator, __pyx_v_decorator, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3833, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DecoratorNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_decorators, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3834
 *         decorator = p_namedexpr_test(s)
 *         decorators.append(Nodes.DecoratorNode(pos, decorator=decorator))
 *         s.expect_newline("Expected a newline after decorator")             # <<<<<<<<<<<<<<
 *     return decorators
 * 
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline_after_decorat};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":3835
 *         decorators.append(Nodes.DecoratorNode(pos, decorator=decorator))
 *         s.expect_newline("Expected a newline after decorator")
 *     return decorators             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_decorators);
  __pyx_r = __pyx_v_decorators;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3826
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_decorators(s: PyrexScanner) -> list:
 *     decorators = []
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_decorators", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_decorators);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_decorator);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3838
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _reject_cdef_modifier_in_py(s: PyrexScanner, name):
 *     """Step over incorrectly placed cdef modifiers (@see _CDEF_MODIFIERS) to provide a good error message for them.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__reject_cdef_modifier_in_py(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_reject_cdef_modifier_in_py", 0);

  /* "Cython/Compiler/Parsing.py":3842
 *     """Step over incorrectly placed cdef modifiers (@see _CDEF_MODIFIERS) to provide a good error message for them.
 *     """
 *     if s.sy == 'IDENT' and name in _CDEF_MODIFIERS:             # <<<<<<<<<<<<<<
 *         # Special enough to provide a good error message.
 *         s.error("Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead." % name, fatal=False)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3842, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_6Cython_8Compiler_7Parsing__CDEF_MODIFIERS, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3842, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":3844
 *     if s.sy == 'IDENT' and name in _CDEF_MODIFIERS:
 *         # Special enough to provide a good error message.
 *         s.error("Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead." % name, fatal=False)             # <<<<<<<<<<<<<<
 *         return p_ident(s)  # Keep going, in case there are other errors.
 *     return name
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Cannot_use_cdef_modifier_s_in_Py, __pyx_v_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3844, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3844, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3845
 *         # Special enough to provide a good error message.
 *         s.error("Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead." % name, fatal=False)
 *         return p_ident(s)  # Keep going, in case there are other errors.             # <<<<<<<<<<<<<<
 *     return name
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":3842
 *     """Step over incorrectly placed cdef modifiers (@see _CDEF_MODIFIERS) to provide a good error message for them.
 *     """
 *     if s.sy == 'IDENT' and name in _CDEF_MODIFIERS:             # <<<<<<<<<<<<<<
 *         # Special enough to provide a good error message.
 *         s.error("Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead." % name, fatal=False)
*/
  }

  /* "Cython/Compiler/Parsing.py":3846
 *         s.error("Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead." % name, fatal=False)
 *         return p_ident(s)  # Keep going, in case there are other errors.
 *     return name             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_name);
  __pyx_r = __pyx_v_name;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3838
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _reject_cdef_modifier_in_py(s: PyrexScanner, name):
 *     """Step over incorrectly placed cdef modifiers (@see _CDEF_MODIFIERS) to provide a good error message for them.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing._reject_cdef_modifier_in_py", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3849
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_def_statement(s: PyrexScanner, decorators: list = None, is_async_def: cython.bint = False):
 *     # s.sy == 'def'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_def_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_def_statement *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":3850
 * 
 * @cython.cfunc
 * def p_def_statement(s: PyrexScanner, decorators: list = None, is_async_def: cython.bint = False):             # <<<<<<<<<<<<<<
 *     # s.sy == 'def'
 *     pos = decorators[0].pos if decorators else s.position()
*/
  PyObject *__pyx_v_decorators = ((PyObject*)Py_None);
  int __pyx_v_is_async_def = ((int)0);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_star_arg = NULL;
  PyObject *__pyx_v_starstar_arg = NULL;
  PyObject *__pyx_v_return_type_annotation = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_def_statement", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_decorators = __pyx_optional_args->decorators;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_is_async_def = __pyx_optional_args->is_async_def;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":3852
 * def p_def_statement(s: PyrexScanner, decorators: list = None, is_async_def: cython.bint = False):
 *     # s.sy == 'def'
 *     pos = decorators[0].pos if decorators else s.position()             # <<<<<<<<<<<<<<
 *     # PEP 492 switches the async/await keywords on in "async def" functions
 *     if is_async_def:
*/
  if (__pyx_v_decorators == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_decorators);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3852, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {
    if (unlikely(__pyx_v_decorators == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 3852, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_decorators, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  } else {
    __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_v_pos = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3854
 *     pos = decorators[0].pos if decorators else s.position()
 *     # PEP 492 switches the async/await keywords on in "async def" functions
 *     if is_async_def:             # <<<<<<<<<<<<<<
 *         s.enter_async()
 *     s.next()
*/
  if (__pyx_v_is_async_def) {

    /* "Cython/Compiler/Parsing.py":3855
 *     # PEP 492 switches the async/await keywords on in "async def" functions
 *     if is_async_def:
 *         s.enter_async()             # <<<<<<<<<<<<<<
 *     s.next()
 *     name = _reject_cdef_modifier_in_py(s, p_ident(s))
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_async, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3855, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3854
 *     pos = decorators[0].pos if decorators else s.position()
 *     # PEP 492 switches the async/await keywords on in "async def" functions
 *     if is_async_def:             # <<<<<<<<<<<<<<
 *         s.enter_async()
 *     s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":3856
 *     if is_async_def:
 *         s.enter_async()
 *     s.next()             # <<<<<<<<<<<<<<
 *     name = _reject_cdef_modifier_in_py(s, p_ident(s))
 *     s.expect(
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3857
 *         s.enter_async()
 *     s.next()
 *     name = _reject_cdef_modifier_in_py(s, p_ident(s))             # <<<<<<<<<<<<<<
 *     s.expect(
 *         '(',
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing__reject_cdef_modifier_in_py(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_name = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3858
 *     s.next()
 *     name = _reject_cdef_modifier_in_py(s, p_ident(s))
 *     s.expect(             # <<<<<<<<<<<<<<
 *         '(',
 *         "Expected '(', found '%s'. Did you use cdef syntax in a Python declaration? "
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);

  /* "Cython/Compiler/Parsing.py":3862
 *         "Expected '(', found '%s'. Did you use cdef syntax in a Python declaration? "
 *         "Use decorators and Python type annotations instead." % (
 *             s.systring if s.sy == 'IDENT' else s.sy))             # <<<<<<<<<<<<<<
 *     args, star_arg, starstar_arg = p_varargslist(s, terminator=')')
 *     s.expect(')')
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3862, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_v_s->systring);
    __pyx_t_3 = __pyx_v_s->systring;
  } else {
    __Pyx_INCREF(__pyx_v_s->sy);
    __pyx_t_3 = __pyx_v_s->sy;
  }

  /* "Cython/Compiler/Parsing.py":3861
 *         '(',
 *         "Expected '(', found '%s'. Did you use cdef syntax in a Python declaration? "
 *         "Use decorators and Python type annotations instead." % (             # <<<<<<<<<<<<<<
 *             s.systring if s.sy == 'IDENT' else s.sy))
 *     args, star_arg, starstar_arg = p_varargslist(s, terminator=')')
*/
  __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Expected_found_s_Did_you_use_cde, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__23, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3863
 *         "Use decorators and Python type annotations instead." % (
 *             s.systring if s.sy == 'IDENT' else s.sy))
 *     args, star_arg, starstar_arg = p_varargslist(s, terminator=')')             # <<<<<<<<<<<<<<
 *     s.expect(')')
 *     _reject_cdef_modifier_in_py(s, s.systring)
*/
  __pyx_t_7.__pyx_n = 1;
  __pyx_t_7.terminator = 41;
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_varargslist(__pyx_v_s, &__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (likely(__pyx_t_4 != Py_None)) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3863, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3863, __pyx_L1_error)
  }
  __pyx_v_args = __pyx_t_6;
  __pyx_t_6 = 0;
  __pyx_v_star_arg = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_starstar_arg = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":3864
 *             s.systring if s.sy == 'IDENT' else s.sy))
 *     args, star_arg, starstar_arg = p_varargslist(s, terminator=')')
 *     s.expect(')')             # <<<<<<<<<<<<<<
 *     _reject_cdef_modifier_in_py(s, s.systring)
 *     return_type_annotation = None
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3865
 *     args, star_arg, starstar_arg = p_varargslist(s, terminator=')')
 *     s.expect(')')
 *     _reject_cdef_modifier_in_py(s, s.systring)             # <<<<<<<<<<<<<<
 *     return_type_annotation = None
 *     if s.sy == '->':
*/
  __pyx_t_4 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing__reject_cdef_modifier_in_py(__pyx_v_s, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":3866
 *     s.expect(')')
 *     _reject_cdef_modifier_in_py(s, s.systring)
 *     return_type_annotation = None             # <<<<<<<<<<<<<<
 *     if s.sy == '->':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_return_type_annotation = Py_None;

  /* "Cython/Compiler/Parsing.py":3867
 *     _reject_cdef_modifier_in_py(s, s.systring)
 *     return_type_annotation = None
 *     if s.sy == '->':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return_type_annotation = p_annotation(s)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__53, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3867, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3868
 *     return_type_annotation = None
 *     if s.sy == '->':
 *         s.next()             # <<<<<<<<<<<<<<
 *         return_type_annotation = p_annotation(s)
 *         _reject_cdef_modifier_in_py(s, s.systring)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3868, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3869
 *     if s.sy == '->':
 *         s.next()
 *         return_type_annotation = p_annotation(s)             # <<<<<<<<<<<<<<
 *         _reject_cdef_modifier_in_py(s, s.systring)
 * 
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_annotation(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3869, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_return_type_annotation, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":3870
 *         s.next()
 *         return_type_annotation = p_annotation(s)
 *         _reject_cdef_modifier_in_py(s, s.systring)             # <<<<<<<<<<<<<<
 * 
 *     doc, body = p_suite_with_docstring(s, Ctx(level='function'))
*/
    __pyx_t_3 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing__reject_cdef_modifier_in_py(__pyx_v_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3867
 *     _reject_cdef_modifier_in_py(s, s.systring)
 *     return_type_annotation = None
 *     if s.sy == '->':             # <<<<<<<<<<<<<<
 *         s.next()
 *         return_type_annotation = p_annotation(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":3872
 *         _reject_cdef_modifier_in_py(s, s.systring)
 * 
 *     doc, body = p_suite_with_docstring(s, Ctx(level='function'))             # <<<<<<<<<<<<<<
 *     if is_async_def:
 *         s.exit_async()
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_function, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3872, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3872, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_6);
    #else
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3872, __pyx_L1_error)
  }
  __pyx_v_doc = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_body = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "Cython/Compiler/Parsing.py":3873
 * 
 *     doc, body = p_suite_with_docstring(s, Ctx(level='function'))
 *     if is_async_def:             # <<<<<<<<<<<<<<
 *         s.exit_async()
 * 
*/
  if (__pyx_v_is_async_def) {

    /* "Cython/Compiler/Parsing.py":3874
 *     doc, body = p_suite_with_docstring(s, Ctx(level='function'))
 *     if is_async_def:
 *         s.exit_async()             # <<<<<<<<<<<<<<
 * 
 *     return Nodes.DefNode(
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_async, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3874, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3873
 * 
 *     doc, body = p_suite_with_docstring(s, Ctx(level='function'))
 *     if is_async_def:             # <<<<<<<<<<<<<<
 *         s.exit_async()
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3876
 *         s.exit_async()
 * 
 *     return Nodes.DefNode(             # <<<<<<<<<<<<<<
 *         pos, name=name, args=args, star_arg=star_arg, starstar_arg=starstar_arg,
 *         doc=doc, body=body, decorators=decorators, is_async_def=is_async_def,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_6);

  /* "Cython/Compiler/Parsing.py":3878
 *     return Nodes.DefNode(
 *         pos, name=name, args=args, star_arg=star_arg, starstar_arg=starstar_arg,
 *         doc=doc, body=body, decorators=decorators, is_async_def=is_async_def,             # <<<<<<<<<<<<<<
 *         return_type_annotation=return_type_annotation)
 * 
*/
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_is_async_def); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":3879
 *         pos, name=name, args=args, star_arg=star_arg, starstar_arg=starstar_arg,
 *         doc=doc, body=body, decorators=decorators, is_async_def=is_async_def,
 *         return_type_annotation=return_type_annotation)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 9 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_args, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_star_arg, __pyx_v_star_arg, __pyx_t_3, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_starstar_arg, __pyx_v_starstar_arg, __pyx_t_3, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_3, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_3, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_decorators, __pyx_v_decorators, __pyx_t_3, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_async_def, __pyx_t_4, __pyx_t_3, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_return_type_annotation, __pyx_v_return_type_annotation, __pyx_t_3, __pyx_callargs+2, 8) < (0)) __PYX_ERR(0, 3876, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_DefNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3849
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_def_statement(s: PyrexScanner, decorators: list = None, is_async_def: cython.bint = False):
 *     # s.sy == 'def'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_def_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_star_arg);
  __Pyx_XDECREF(__pyx_v_starstar_arg);
  __Pyx_XDECREF(__pyx_v_return_type_annotation);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3882
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_varargslist(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_varargslist *__pyx_optional_args) {
  Py_UCS4 __pyx_v_terminator = ((Py_UCS4)41);

  /* "Cython/Compiler/Parsing.py":3883
 * 
 * @cython.cfunc
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:             # <<<<<<<<<<<<<<
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
 *                         annotated = annotated)
*/
  int __pyx_v_annotated = ((int)1);
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_star_arg = NULL;
  PyObject *__pyx_v_starstar_arg = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_py_arg_decl __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_varargslist", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_terminator = __pyx_optional_args->terminator;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_annotated = __pyx_optional_args->annotated;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":3884
 * @cython.cfunc
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,             # <<<<<<<<<<<<<<
 *                         annotated = annotated)
 *     star_arg = None
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_p_c_arg_list); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "Cython/Compiler/Parsing.py":3885
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
 *                         annotated = annotated)             # <<<<<<<<<<<<<<
 *     star_arg = None
 *     starstar_arg = None
*/
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_annotated); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pyfunc, Py_True, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3884, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty_declarators, Py_True, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3884, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotated, __pyx_t_4, __pyx_t_6, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3884, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }

  /* "Cython/Compiler/Parsing.py":3884
 * @cython.cfunc
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,             # <<<<<<<<<<<<<<
 *                         annotated = annotated)
 *     star_arg = None
*/
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 3884, __pyx_L1_error)
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3886
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
 *                         annotated = annotated)
 *     star_arg = None             # <<<<<<<<<<<<<<
 *     starstar_arg = None
 *     if s.sy == '/':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_star_arg = Py_None;

  /* "Cython/Compiler/Parsing.py":3887
 *                         annotated = annotated)
 *     star_arg = None
 *     starstar_arg = None             # <<<<<<<<<<<<<<
 *     if s.sy == '/':
 *         if len(args) == 0:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_starstar_arg = Py_None;

  /* "Cython/Compiler/Parsing.py":3888
 *     star_arg = None
 *     starstar_arg = None
 *     if s.sy == '/':             # <<<<<<<<<<<<<<
 *         if len(args) == 0:
 *             s.error("Got zero positional-only arguments despite presence of "
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__2, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3888, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":3889
 *     starstar_arg = None
 *     if s.sy == '/':
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             s.error("Got zero positional-only arguments despite presence of "
 *                     "positional-only specifier '/'")
*/
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 3889, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 3889, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_8 == 0);
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3890
 *     if s.sy == '/':
 *         if len(args) == 0:
 *             s.error("Got zero positional-only arguments despite presence of "             # <<<<<<<<<<<<<<
 *                     "positional-only specifier '/'")
 *         s.next()
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Got_zero_positional_only_argumen};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3890, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3889
 *     starstar_arg = None
 *     if s.sy == '/':
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             s.error("Got zero positional-only arguments despite presence of "
 *                     "positional-only specifier '/'")
*/
    }

    /* "Cython/Compiler/Parsing.py":3892
 *             s.error("Got zero positional-only arguments despite presence of "
 *                     "positional-only specifier '/'")
 *         s.next()             # <<<<<<<<<<<<<<
 *         # Mark all args to the left as pos only
 *         for arg in args:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3894
 *         s.next()
 *         # Mark all args to the left as pos only
 *         for arg in args:             # <<<<<<<<<<<<<<
 *             arg.pos_only = 1
 *         if s.sy == ',':
*/
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 3894, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_args; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_8 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3894, __pyx_L1_error)
        #endif
        if (__pyx_t_8 >= __pyx_temp) break;
      }
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_8;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":3895
 *         # Mark all args to the left as pos only
 *         for arg in args:
 *             arg.pos_only = 1             # <<<<<<<<<<<<<<
 *         if s.sy == ',':
 *             s.next()
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_arg, __pyx_mstate_global->__pyx_n_u_pos_only, __pyx_mstate_global->__pyx_int_1) < (0)) __PYX_ERR(0, 3895, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":3894
 *         s.next()
 *         # Mark all args to the left as pos only
 *         for arg in args:             # <<<<<<<<<<<<<<
 *             arg.pos_only = 1
 *         if s.sy == ',':
*/
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3896
 *         for arg in args:
 *             arg.pos_only = 1
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.extend(p_c_arg_list(
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3896, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3897
 *             arg.pos_only = 1
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3898
 *         if s.sy == ',':
 *             s.next()
 *             args.extend(p_c_arg_list(             # <<<<<<<<<<<<<<
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
 *         elif s.sy != terminator:
*/
      if (unlikely(__pyx_v_args == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
        __PYX_ERR(0, 3898, __pyx_L1_error)
      }
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_p_c_arg_list); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3898, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "Cython/Compiler/Parsing.py":3899
 *             s.next()
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))             # <<<<<<<<<<<<<<
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
*/
      __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_annotated); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_3, ((PyObject *)__pyx_v_s)};
        __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pyfunc, Py_True, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3898, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty_declarators, Py_True, __pyx_t_2, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3898, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotated, __pyx_t_4, __pyx_t_2, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3898, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":3898
 *         if s.sy == ',':
 *             s.next()
 *             args.extend(p_c_arg_list(             # <<<<<<<<<<<<<<
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
 *         elif s.sy != terminator:
*/
      __pyx_t_9 = __Pyx_PyList_Extend(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3898, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3896
 *         for arg in args:
 *             arg.pos_only = 1
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.extend(p_c_arg_list(
*/
      goto __pyx_L8;
    }

    /* "Cython/Compiler/Parsing.py":3900
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
 *         elif s.sy != terminator:             # <<<<<<<<<<<<<<
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '*':
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_terminator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3901
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")             # <<<<<<<<<<<<<<
 *     if s.sy == '*':
 *         s.next()
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_Python_function};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3900
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc=True, nonempty_declarators=True, annotated = annotated))
 *         elif s.sy != terminator:             # <<<<<<<<<<<<<<
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '*':
*/
    }
    __pyx_L8:;

    /* "Cython/Compiler/Parsing.py":3888
 *     star_arg = None
 *     starstar_arg = None
 *     if s.sy == '/':             # <<<<<<<<<<<<<<
 *         if len(args) == 0:
 *             s.error("Got zero positional-only arguments despite presence of "
*/
  }

  /* "Cython/Compiler/Parsing.py":3902
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'IDENT':
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3902, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":3903
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '*':
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy == 'IDENT':
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3904
 *     if s.sy == '*':
 *         s.next()
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
 *         if s.sy == ',':
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3904, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3905
 *         s.next()
 *         if s.sy == 'IDENT':
 *             star_arg = p_py_arg_decl(s, annotated=annotated)             # <<<<<<<<<<<<<<
 *         if s.sy == ',':
 *             s.next()
*/
      __pyx_t_10.__pyx_n = 1;
      __pyx_t_10.annotated = __pyx_v_annotated;
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_py_arg_decl(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_star_arg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3904
 *     if s.sy == '*':
 *         s.next()
 *         if s.sy == 'IDENT':             # <<<<<<<<<<<<<<
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
 *         if s.sy == ',':
*/
    }

    /* "Cython/Compiler/Parsing.py":3906
 *         if s.sy == 'IDENT':
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.extend(p_c_arg_list(
*/
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3906, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3907
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
 *         if s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3907, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3908
 *         if s.sy == ',':
 *             s.next()
 *             args.extend(p_c_arg_list(             # <<<<<<<<<<<<<<
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
 *         elif s.sy != terminator:
*/
      if (unlikely(__pyx_v_args == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
        __PYX_ERR(0, 3908, __pyx_L1_error)
      }
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_p_c_arg_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3908, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "Cython/Compiler/Parsing.py":3909
 *             s.next()
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))             # <<<<<<<<<<<<<<
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
*/
      __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_annotated); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_6, ((PyObject *)__pyx_v_s)};
        __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pyfunc, Py_True, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3908, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nonempty_declarators, Py_True, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3908, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_kw_only, Py_True, __pyx_t_3, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3908, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotated, __pyx_t_4, __pyx_t_3, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3908, __pyx_L1_error)
        __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }

      /* "Cython/Compiler/Parsing.py":3908
 *         if s.sy == ',':
 *             s.next()
 *             args.extend(p_c_arg_list(             # <<<<<<<<<<<<<<
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
 *         elif s.sy != terminator:
*/
      __pyx_t_9 = __Pyx_PyList_Extend(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3908, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3906
 *         if s.sy == 'IDENT':
 *             star_arg = p_py_arg_decl(s, annotated=annotated)
 *         if s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             args.extend(p_c_arg_list(
*/
      goto __pyx_L11;
    }

    /* "Cython/Compiler/Parsing.py":3910
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
 *         elif s.sy != terminator:             # <<<<<<<<<<<<<<
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '**':
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromOrdinal(__pyx_v_terminator); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3910, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":3911
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")             # <<<<<<<<<<<<<<
 *     if s.sy == '**':
 *         s.next()
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_Python_function};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3911, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3910
 *             args.extend(p_c_arg_list(
 *                 s, in_pyfunc =True, nonempty_declarators=True, kw_only=True, annotated = annotated))
 *         elif s.sy != terminator:             # <<<<<<<<<<<<<<
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '**':
*/
    }
    __pyx_L11:;

    /* "Cython/Compiler/Parsing.py":3902
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '*':             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy == 'IDENT':
*/
  }

  /* "Cython/Compiler/Parsing.py":3912
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '**':             # <<<<<<<<<<<<<<
 *         s.next()
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3912, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":3913
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '**':
 *         s.next()             # <<<<<<<<<<<<<<
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
 *     if s.sy == ',':
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3913, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3914
 *     if s.sy == '**':
 *         s.next()
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)             # <<<<<<<<<<<<<<
 *     if s.sy == ',':
 *         s.next()
*/
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.annotated = __pyx_v_annotated;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_py_arg_decl(__pyx_v_s, &__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_starstar_arg, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3912
 *         elif s.sy != terminator:
 *             s.error("Syntax error in Python function argument list")
 *     if s.sy == '**':             # <<<<<<<<<<<<<<
 *         s.next()
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
*/
  }

  /* "Cython/Compiler/Parsing.py":3915
 *         s.next()
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *     return (args, star_arg, starstar_arg)
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3915, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":3916
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
 *     if s.sy == ',':
 *         s.next()             # <<<<<<<<<<<<<<
 *     return (args, star_arg, starstar_arg)
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3916, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3915
 *         s.next()
 *         starstar_arg = p_py_arg_decl(s, annotated=annotated)
 *     if s.sy == ',':             # <<<<<<<<<<<<<<
 *         s.next()
 *     return (args, star_arg, starstar_arg)
*/
  }

  /* "Cython/Compiler/Parsing.py":3917
 *     if s.sy == ',':
 *         s.next()
 *     return (args, star_arg, starstar_arg)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_args) != (0)) __PYX_ERR(0, 3917, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_star_arg);
  __Pyx_GIVEREF(__pyx_v_star_arg);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_star_arg) != (0)) __PYX_ERR(0, 3917, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_starstar_arg);
  __Pyx_GIVEREF(__pyx_v_starstar_arg);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_starstar_arg) != (0)) __PYX_ERR(0, 3917, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3882
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_varargslist(s: PyrexScanner, terminator: cython.Py_UCS4 = ')', annotated: cython.bint = True) -> tuple:
 *     args = p_c_arg_list(s, in_pyfunc=True, nonempty_declarators=True,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_varargslist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_star_arg);
  __Pyx_XDECREF(__pyx_v_starstar_arg);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3920
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_py_arg_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_py_arg_decl *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":3921
 * 
 * @cython.cfunc
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     name = p_ident(s)
*/
  int __pyx_v_annotated = ((int)1);
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_annotation = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_py_arg_decl", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_annotated = __pyx_optional_args->annotated;
    }
  }

  /* "Cython/Compiler/Parsing.py":3922
 * @cython.cfunc
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     annotation = None
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3923
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):
 *     pos = s.position()
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     annotation = None
 *     if annotated and s.sy == ':':
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3924
 *     pos = s.position()
 *     name = p_ident(s)
 *     annotation = None             # <<<<<<<<<<<<<<
 *     if annotated and s.sy == ':':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_annotation = Py_None;

  /* "Cython/Compiler/Parsing.py":3925
 *     name = p_ident(s)
 *     annotation = None
 *     if annotated and s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         annotation = p_annotation(s)
*/
  if (__pyx_v_annotated) {
  } else {
    __pyx_t_2 = __pyx_v_annotated;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3925, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":3926
 *     annotation = None
 *     if annotated and s.sy == ':':
 *         s.next()             # <<<<<<<<<<<<<<
 *         annotation = p_annotation(s)
 *     return Nodes.PyArgDeclNode(pos, name = name, annotation = annotation)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3926, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3927
 *     if annotated and s.sy == ':':
 *         s.next()
 *         annotation = p_annotation(s)             # <<<<<<<<<<<<<<
 *     return Nodes.PyArgDeclNode(pos, name = name, annotation = annotation)
 * 
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_annotation(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_annotation, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3925
 *     name = p_ident(s)
 *     annotation = None
 *     if annotated and s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         annotation = p_annotation(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":3928
 *         s.next()
 *         annotation = p_annotation(s)
 *     return Nodes.PyArgDeclNode(pos, name = name, annotation = annotation)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3928, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_annotation, __pyx_v_annotation, __pyx_t_6, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3928, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_PyArgDeclNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3920
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_py_arg_decl(s: PyrexScanner, annotated: cython.bint = True):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_py_arg_decl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_annotation);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3931
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_class_statement(s: PyrexScanner, decorators):
 *     # s.sy == 'class'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_class_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_decorators) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_class_name = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_v_keyword_dict = NULL;
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_class_statement", 0);

  /* "Cython/Compiler/Parsing.py":3934
 * def p_class_statement(s: PyrexScanner, decorators):
 *     # s.sy == 'class'
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()
 *     class_name = EncodedString(p_ident(s))
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3935
 *     # s.sy == 'class'
 *     pos = s.position()
 *     s.next()             # <<<<<<<<<<<<<<
 *     class_name = EncodedString(p_ident(s))
 *     class_name.encoding = s.source_encoding  # FIXME: why is this needed?
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3936
 *     pos = s.position()
 *     s.next()
 *     class_name = EncodedString(p_ident(s))             # <<<<<<<<<<<<<<
 *     class_name.encoding = s.source_encoding  # FIXME: why is this needed?
 *     arg_tuple = None
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_EncodedString; 
  __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_class_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3937
 *     s.next()
 *     class_name = EncodedString(p_ident(s))
 *     class_name.encoding = s.source_encoding  # FIXME: why is this needed?             # <<<<<<<<<<<<<<
 *     arg_tuple = None
 *     keyword_dict = None
*/
  __pyx_t_1 = __pyx_v_s->source_encoding;
  __Pyx_INCREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_class_name, __pyx_mstate_global->__pyx_n_u_encoding, __pyx_t_1) < (0)) __PYX_ERR(0, 3937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3938
 *     class_name = EncodedString(p_ident(s))
 *     class_name.encoding = s.source_encoding  # FIXME: why is this needed?
 *     arg_tuple = None             # <<<<<<<<<<<<<<
 *     keyword_dict = None
 *     if s.sy == '(':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_arg_tuple = Py_None;

  /* "Cython/Compiler/Parsing.py":3939
 *     class_name.encoding = s.source_encoding  # FIXME: why is this needed?
 *     arg_tuple = None
 *     keyword_dict = None             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_keyword_dict = Py_None;

  /* "Cython/Compiler/Parsing.py":3940
 *     arg_tuple = None
 *     keyword_dict = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
*/
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3940, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":3941
 *     keyword_dict = None
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)             # <<<<<<<<<<<<<<
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if arg_tuple is None:
*/
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.allow_genexp = 0;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_parse_args(__pyx_v_s, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3941, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3941, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3941, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3941, __pyx_L1_error)
    }
    __pyx_v_positional_args = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_keyword_args = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":3942
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)             # <<<<<<<<<<<<<<
 *     if arg_tuple is None:
 *         # XXX: empty arg_tuple
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_build_packed_args(__pyx_v_pos, __pyx_v_positional_args, __pyx_v_keyword_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3942, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3942, __pyx_L1_error)
    }
    __Pyx_DECREF_SET(__pyx_v_arg_tuple, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_keyword_dict, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Parsing.py":3940
 *     arg_tuple = None
 *     keyword_dict = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
*/
  }

  /* "Cython/Compiler/Parsing.py":3943
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if arg_tuple is None:             # <<<<<<<<<<<<<<
 *         # XXX: empty arg_tuple
 *         arg_tuple = ExprNodes.TupleNode(pos, args=[])
*/
  __pyx_t_6 = (__pyx_v_arg_tuple == Py_None);
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":3945
 *     if arg_tuple is None:
 *         # XXX: empty arg_tuple
 *         arg_tuple = ExprNodes.TupleNode(pos, args=[])             # <<<<<<<<<<<<<<
 *     doc, body = p_suite_with_docstring(s, Ctx(level='class'))
 *     return Nodes.PyClassDefNode(
*/
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_t_5, __pyx_t_2, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3945, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_arg_tuple, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3943
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         arg_tuple, keyword_dict = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if arg_tuple is None:             # <<<<<<<<<<<<<<
 *         # XXX: empty arg_tuple
 *         arg_tuple = ExprNodes.TupleNode(pos, args=[])
*/
  }

  /* "Cython/Compiler/Parsing.py":3946
 *         # XXX: empty arg_tuple
 *         arg_tuple = ExprNodes.TupleNode(pos, args=[])
 *     doc, body = p_suite_with_docstring(s, Ctx(level='class'))             # <<<<<<<<<<<<<<
 *     return Nodes.PyClassDefNode(
 *         pos, name=class_name,
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_class_2, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3946, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5 != Py_None)) {
    PyObject* sequence = __pyx_t_5;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3946, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3946, __pyx_L1_error)
  }
  __pyx_v_doc = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_body = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3947
 *         arg_tuple = ExprNodes.TupleNode(pos, args=[])
 *     doc, body = p_suite_with_docstring(s, Ctx(level='class'))
 *     return Nodes.PyClassDefNode(             # <<<<<<<<<<<<<<
 *         pos, name=class_name,
 *         bases=arg_tuple,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_4);

  /* "Cython/Compiler/Parsing.py":3952
 *         keyword_args=keyword_dict,
 *         doc=doc, body=body, decorators=decorators,
 *         force_py3_semantics=s.context.language_level >= 3)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_mstate_global->__pyx_int_3, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 7 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_class_name, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bases, __pyx_v_arg_tuple, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_args, __pyx_v_keyword_dict, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_1, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_1, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_decorators, __pyx_v_decorators, __pyx_t_1, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_force_py3_semantics, __pyx_t_2, __pyx_t_1, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 3947, __pyx_L1_error)
    __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_PyClassDefNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3931
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_class_statement(s: PyrexScanner, decorators):
 *     # s.sy == 'class'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_class_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XDECREF(__pyx_v_keyword_dict);
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":3955
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'class'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_class_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_module_path = NULL;
  PyObject *__pyx_v_class_name = NULL;
  PyObject *__pyx_v_as_name = NULL;
  PyObject *__pyx_v_objstruct_name = NULL;
  PyObject *__pyx_v_typeobj_name = NULL;
  PyObject *__pyx_v_bases = NULL;
  PyObject *__pyx_v_check_size = NULL;
  PyObject *__pyx_v_positional_args = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_body_level = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_call_parse_args __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_class_definition", 0);

  /* "Cython/Compiler/Parsing.py":3958
 * def p_c_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'class'
 *     s.next()             # <<<<<<<<<<<<<<
 *     module_path = []
 *     class_name = p_ident(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3959
 *     # s.sy == 'class'
 *     s.next()
 *     module_path = []             # <<<<<<<<<<<<<<
 *     class_name = p_ident(s)
 *     while s.sy == '.':
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_module_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3960
 *     s.next()
 *     module_path = []
 *     class_name = p_ident(s)             # <<<<<<<<<<<<<<
 *     while s.sy == '.':
 *         s.next()
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_class_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":3961
 *     module_path = []
 *     class_name = p_ident(s)
 *     while s.sy == '.':             # <<<<<<<<<<<<<<
 *         s.next()
 *         module_path.append(class_name)
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3961, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":3962
 *     class_name = p_ident(s)
 *     while s.sy == '.':
 *         s.next()             # <<<<<<<<<<<<<<
 *         module_path.append(class_name)
 *         class_name = p_ident(s)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3962, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3963
 *     while s.sy == '.':
 *         s.next()
 *         module_path.append(class_name)             # <<<<<<<<<<<<<<
 *         class_name = p_ident(s)
 *     if module_path and ctx.visibility != 'extern':
*/
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_module_path, __pyx_v_class_name); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 3963, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":3964
 *         s.next()
 *         module_path.append(class_name)
 *         class_name = p_ident(s)             # <<<<<<<<<<<<<<
 *     if module_path and ctx.visibility != 'extern':
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_class_name, __pyx_t_1);
    __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":3965
 *         module_path.append(class_name)
 *         class_name = p_ident(s)
 *     if module_path and ctx.visibility != 'extern':             # <<<<<<<<<<<<<<
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_module_path);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3965, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_extern, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3966
 *         class_name = p_ident(s)
 *     if module_path and ctx.visibility != 'extern':
 *         error(pos, "Qualified class name only allowed for 'extern' C class")             # <<<<<<<<<<<<<<
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Qualified_class_name_only_allowe};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3965
 *         module_path.append(class_name)
 *         class_name = p_ident(s)
 *     if module_path and ctx.visibility != 'extern':             # <<<<<<<<<<<<<<
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':
*/
  }

  /* "Cython/Compiler/Parsing.py":3967
 *     if module_path and ctx.visibility != 'extern':
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         as_name = p_ident(s)
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_module_path);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3967, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3967, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3967, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_6;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3968
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()             # <<<<<<<<<<<<<<
 *         as_name = p_ident(s)
 *     else:
*/
    __pyx_t_7 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3968, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3969
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()
 *         as_name = p_ident(s)             # <<<<<<<<<<<<<<
 *     else:
 *         as_name = class_name
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_as_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3967
 *     if module_path and ctx.visibility != 'extern':
 *         error(pos, "Qualified class name only allowed for 'extern' C class")
 *     if module_path and s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         as_name = p_ident(s)
*/
    goto __pyx_L8;
  }

  /* "Cython/Compiler/Parsing.py":3971
 *         as_name = p_ident(s)
 *     else:
 *         as_name = class_name             # <<<<<<<<<<<<<<
 *     objstruct_name = None
 *     typeobj_name = None
*/
  /*else*/ {
    __Pyx_INCREF(__pyx_v_class_name);
    __pyx_v_as_name = __pyx_v_class_name;
  }
  __pyx_L8:;

  /* "Cython/Compiler/Parsing.py":3972
 *     else:
 *         as_name = class_name
 *     objstruct_name = None             # <<<<<<<<<<<<<<
 *     typeobj_name = None
 *     bases = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_objstruct_name = Py_None;

  /* "Cython/Compiler/Parsing.py":3973
 *         as_name = class_name
 *     objstruct_name = None
 *     typeobj_name = None             # <<<<<<<<<<<<<<
 *     bases = None
 *     check_size = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_typeobj_name = Py_None;

  /* "Cython/Compiler/Parsing.py":3974
 *     objstruct_name = None
 *     typeobj_name = None
 *     bases = None             # <<<<<<<<<<<<<<
 *     check_size = None
 *     if s.sy == '(':
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_bases = Py_None;

  /* "Cython/Compiler/Parsing.py":3975
 *     typeobj_name = None
 *     bases = None
 *     check_size = None             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_check_size = Py_None;

  /* "Cython/Compiler/Parsing.py":3976
 *     bases = None
 *     check_size = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         if keyword_args:
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3976, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3977
 *     check_size = None
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)             # <<<<<<<<<<<<<<
 *         if keyword_args:
 *             s.error("C classes cannot take keyword bases.")
*/
    __pyx_t_8.__pyx_n = 1;
    __pyx_t_8.allow_genexp = 0;
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_parse_args(__pyx_v_s, &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3977, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_2);
      #else
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3977, __pyx_L1_error)
    }
    __pyx_v_positional_args = __pyx_t_7;
    __pyx_t_7 = 0;
    __pyx_v_keyword_args = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3978
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         if keyword_args:             # <<<<<<<<<<<<<<
 *             s.error("C classes cannot take keyword bases.")
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_keyword_args); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3978, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3979
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         if keyword_args:
 *             s.error("C classes cannot take keyword bases.")             # <<<<<<<<<<<<<<
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if bases is None:
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_C_classes_cannot_take_keyword_ba};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3979, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3978
 *     if s.sy == '(':
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         if keyword_args:             # <<<<<<<<<<<<<<
 *             s.error("C classes cannot take keyword bases.")
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
*/
    }

    /* "Cython/Compiler/Parsing.py":3980
 *         if keyword_args:
 *             s.error("C classes cannot take keyword bases.")
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)             # <<<<<<<<<<<<<<
 *     if bases is None:
 *         bases = ExprNodes.TupleNode(pos, args=[])
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_call_build_packed_args(__pyx_v_pos, __pyx_v_positional_args, __pyx_v_keyword_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3980, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3980, __pyx_L1_error)
    }
    __Pyx_DECREF_SET(__pyx_v_bases, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_v__ = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "Cython/Compiler/Parsing.py":3976
 *     bases = None
 *     check_size = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         positional_args, keyword_args = p_call_parse_args(s, allow_genexp=False)
 *         if keyword_args:
*/
  }

  /* "Cython/Compiler/Parsing.py":3981
 *             s.error("C classes cannot take keyword bases.")
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if bases is None:             # <<<<<<<<<<<<<<
 *         bases = ExprNodes.TupleNode(pos, args=[])
 * 
*/
  __pyx_t_4 = (__pyx_v_bases == Py_None);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3982
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if bases is None:
 *         bases = ExprNodes.TupleNode(pos, args=[])             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == '[':
*/
    __pyx_t_7 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_7, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_t_2, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3982, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_bases, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":3981
 *             s.error("C classes cannot take keyword bases.")
 *         bases, _ = p_call_build_packed_args(pos, positional_args, keyword_args)
 *     if bases is None:             # <<<<<<<<<<<<<<
 *         bases = ExprNodes.TupleNode(pos, args=[])
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":3984
 *         bases = ExprNodes.TupleNode(pos, args=[])
 * 
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3984, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3985
 * 
 *     if s.sy == '[':
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:             # <<<<<<<<<<<<<<
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_public, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 3985, __pyx_L1_error)
    if (__pyx_t_10) {
    } else {
      __pyx_t_6 = __pyx_t_10;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_10 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_extern, Py_NE)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 3985, __pyx_L1_error)
    __pyx_t_6 = __pyx_t_10;
    __pyx_L19_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_10 = __pyx_t_6;
    if (__pyx_t_10) {
    } else {
      __pyx_t_4 = __pyx_t_10;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 3985, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (!__pyx_t_10);
    __pyx_t_4 = __pyx_t_6;
    __pyx_L17_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3986
 *     if s.sy == '[':
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")             # <<<<<<<<<<<<<<
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
 *     if s.sy == ':':
*/
      __pyx_t_9 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_7 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3986, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Name_options_only_allowed_for_pu};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3986, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":3985
 * 
 *     if s.sy == '[':
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:             # <<<<<<<<<<<<<<
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":3987
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ':':
 *         if ctx.level == 'module_pxd':
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_class_options(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(__pyx_t_1 != Py_None)) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3987, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_9);
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3987, __pyx_L1_error)
    }
    __Pyx_DECREF_SET(__pyx_v_objstruct_name, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_typeobj_name, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_check_size, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "Cython/Compiler/Parsing.py":3984
 *         bases = ExprNodes.TupleNode(pos, args=[])
 * 
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         if ctx.visibility not in ('public', 'extern') and not ctx.api:
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
*/
  }

  /* "Cython/Compiler/Parsing.py":3988
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.level == 'module_pxd':
 *             body_level = 'c_class_pxd'
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3988, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3989
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
 *     if s.sy == ':':
 *         if ctx.level == 'module_pxd':             # <<<<<<<<<<<<<<
 *             body_level = 'c_class_pxd'
 *         else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":3990
 *     if s.sy == ':':
 *         if ctx.level == 'module_pxd':
 *             body_level = 'c_class_pxd'             # <<<<<<<<<<<<<<
 *         else:
 *             body_level = 'c_class'
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_c_class_pxd);
      __pyx_v_body_level = __pyx_mstate_global->__pyx_n_u_c_class_pxd;

      /* "Cython/Compiler/Parsing.py":3989
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
 *     if s.sy == ':':
 *         if ctx.level == 'module_pxd':             # <<<<<<<<<<<<<<
 *             body_level = 'c_class_pxd'
 *         else:
*/
      goto __pyx_L22;
    }

    /* "Cython/Compiler/Parsing.py":3992
 *             body_level = 'c_class_pxd'
 *         else:
 *             body_level = 'c_class'             # <<<<<<<<<<<<<<
 *         doc, body = p_suite_with_docstring(s, Ctx(level=body_level))
 *     else:
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_c_class);
      __pyx_v_body_level = __pyx_mstate_global->__pyx_n_u_c_class;
    }
    __pyx_L22:;

    /* "Cython/Compiler/Parsing.py":3993
 *         else:
 *             body_level = 'c_class'
 *         doc, body = p_suite_with_docstring(s, Ctx(level=body_level))             # <<<<<<<<<<<<<<
 *     else:
 *         s.expect_newline("Syntax error in C class definition")
*/
    __pyx_t_9 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_9);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, NULL};
      __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_v_body_level, __pyx_t_2, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 3993, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(__pyx_t_7 != Py_None)) {
      PyObject* sequence = __pyx_t_7;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3993, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_2);
      #else
      __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 3993, __pyx_L1_error)
    }
    __pyx_v_doc = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v_body = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":3988
 *             error(s.position(), "Name options only allowed for 'public', 'api', or 'extern' C class")
 *         objstruct_name, typeobj_name, check_size = p_c_class_options(s)
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         if ctx.level == 'module_pxd':
 *             body_level = 'c_class_pxd'
*/
    goto __pyx_L21;
  }

  /* "Cython/Compiler/Parsing.py":3995
 *         doc, body = p_suite_with_docstring(s, Ctx(level=body_level))
 *     else:
 *         s.expect_newline("Syntax error in C class definition")             # <<<<<<<<<<<<<<
 *         doc = None
 *         body = None
*/
  /*else*/ {
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_C_class_definiti};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3995, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "Cython/Compiler/Parsing.py":3996
 *     else:
 *         s.expect_newline("Syntax error in C class definition")
 *         doc = None             # <<<<<<<<<<<<<<
 *         body = None
 *     if ctx.visibility == 'extern':
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_doc = Py_None;

    /* "Cython/Compiler/Parsing.py":3997
 *         s.expect_newline("Syntax error in C class definition")
 *         doc = None
 *         body = None             # <<<<<<<<<<<<<<
 *     if ctx.visibility == 'extern':
 *         if not module_path:
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_body = Py_None;
  }
  __pyx_L21:;

  /* "Cython/Compiler/Parsing.py":3998
 *         doc = None
 *         body = None
 *     if ctx.visibility == 'extern':             # <<<<<<<<<<<<<<
 *         if not module_path:
 *             error(pos, "Module name required for 'extern' C class")
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_extern, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":3999
 *         body = None
 *     if ctx.visibility == 'extern':
 *         if not module_path:             # <<<<<<<<<<<<<<
 *             error(pos, "Module name required for 'extern' C class")
 *         if typeobj_name:
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_module_path);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 3999, __pyx_L1_error)
      __pyx_t_4 = (__pyx_temp != 0);
    }

    __pyx_t_6 = (!__pyx_t_4);
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":4000
 *     if ctx.visibility == 'extern':
 *         if not module_path:
 *             error(pos, "Module name required for 'extern' C class")             # <<<<<<<<<<<<<<
 *         if typeobj_name:
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Module_name_required_for_extern};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4000, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":3999
 *         body = None
 *     if ctx.visibility == 'extern':
 *         if not module_path:             # <<<<<<<<<<<<<<
 *             error(pos, "Module name required for 'extern' C class")
 *         if typeobj_name:
*/
    }

    /* "Cython/Compiler/Parsing.py":4001
 *         if not module_path:
 *             error(pos, "Module name required for 'extern' C class")
 *         if typeobj_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_typeobj_name); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4001, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":4002
 *             error(pos, "Module name required for 'extern' C class")
 *         if typeobj_name:
 *             error(pos, "Type object name specification not allowed for 'extern' C class")             # <<<<<<<<<<<<<<
 *     elif ctx.visibility == 'public':
 *         if not objstruct_name:
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Type_object_name_specification_n};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4002, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":4001
 *         if not module_path:
 *             error(pos, "Module name required for 'extern' C class")
 *         if typeobj_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':
*/
    }

    /* "Cython/Compiler/Parsing.py":3998
 *         doc = None
 *         body = None
 *     if ctx.visibility == 'extern':             # <<<<<<<<<<<<<<
 *         if not module_path:
 *             error(pos, "Module name required for 'extern' C class")
*/
    goto __pyx_L23;
  }

  /* "Cython/Compiler/Parsing.py":4003
 *         if typeobj_name:
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':             # <<<<<<<<<<<<<<
 *         if not objstruct_name:
 *             error(pos, "Object struct name specification required for 'public' C class")
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_public, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":4004
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':
 *         if not objstruct_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Object struct name specification required for 'public' C class")
 *         if not typeobj_name:
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_objstruct_name); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4004, __pyx_L1_error)
    __pyx_t_4 = (!__pyx_t_6);
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4005
 *     elif ctx.visibility == 'public':
 *         if not objstruct_name:
 *             error(pos, "Object struct name specification required for 'public' C class")             # <<<<<<<<<<<<<<
 *         if not typeobj_name:
 *             error(pos, "Type object name specification required for 'public' C class")
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Object_struct_name_specification};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4005, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":4004
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':
 *         if not objstruct_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Object struct name specification required for 'public' C class")
 *         if not typeobj_name:
*/
    }

    /* "Cython/Compiler/Parsing.py":4006
 *         if not objstruct_name:
 *             error(pos, "Object struct name specification required for 'public' C class")
 *         if not typeobj_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_typeobj_name); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4006, __pyx_L1_error)
    __pyx_t_6 = (!__pyx_t_4);
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":4007
 *             error(pos, "Object struct name specification required for 'public' C class")
 *         if not typeobj_name:
 *             error(pos, "Type object name specification required for 'public' C class")             # <<<<<<<<<<<<<<
 *     elif ctx.visibility == 'private':
 *         if ctx.api:
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Type_object_name_specification_r};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4007, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":4006
 *         if not objstruct_name:
 *             error(pos, "Object struct name specification required for 'public' C class")
 *         if not typeobj_name:             # <<<<<<<<<<<<<<
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':
*/
    }

    /* "Cython/Compiler/Parsing.py":4003
 *         if typeobj_name:
 *             error(pos, "Type object name specification not allowed for 'extern' C class")
 *     elif ctx.visibility == 'public':             # <<<<<<<<<<<<<<
 *         if not objstruct_name:
 *             error(pos, "Object struct name specification required for 'public' C class")
*/
    goto __pyx_L23;
  }

  /* "Cython/Compiler/Parsing.py":4008
 *         if not typeobj_name:
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':             # <<<<<<<<<<<<<<
 *         if ctx.api:
 *             if not objstruct_name:
*/
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_private, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":4009
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             if not objstruct_name:
 *                 error(pos, "Object struct name specification required for 'api' C class")
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4009, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Parsing.py":4010
 *     elif ctx.visibility == 'private':
 *         if ctx.api:
 *             if not objstruct_name:             # <<<<<<<<<<<<<<
 *                 error(pos, "Object struct name specification required for 'api' C class")
 *             if not typeobj_name:
*/
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_objstruct_name); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4010, __pyx_L1_error)
      __pyx_t_4 = (!__pyx_t_6);
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":4011
 *         if ctx.api:
 *             if not objstruct_name:
 *                 error(pos, "Object struct name specification required for 'api' C class")             # <<<<<<<<<<<<<<
 *             if not typeobj_name:
 *                 error(pos, "Type object name specification required for 'api' C class")
*/
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Object_struct_name_specification_2};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4011, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":4010
 *     elif ctx.visibility == 'private':
 *         if ctx.api:
 *             if not objstruct_name:             # <<<<<<<<<<<<<<
 *                 error(pos, "Object struct name specification required for 'api' C class")
 *             if not typeobj_name:
*/
      }

      /* "Cython/Compiler/Parsing.py":4012
 *             if not objstruct_name:
 *                 error(pos, "Object struct name specification required for 'api' C class")
 *             if not typeobj_name:             # <<<<<<<<<<<<<<
 *                 error(pos, "Type object name specification required for 'api' C class")
 *     else:
*/
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_typeobj_name); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4012, __pyx_L1_error)
      __pyx_t_6 = (!__pyx_t_4);
      if (__pyx_t_6) {

        /* "Cython/Compiler/Parsing.py":4013
 *                 error(pos, "Object struct name specification required for 'api' C class")
 *             if not typeobj_name:
 *                 error(pos, "Type object name specification required for 'api' C class")             # <<<<<<<<<<<<<<
 *     else:
 *         error(pos, "Invalid class visibility '%s'" % ctx.visibility)
*/
        __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Type_object_name_specification_r_2};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4013, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Parsing.py":4012
 *             if not objstruct_name:
 *                 error(pos, "Object struct name specification required for 'api' C class")
 *             if not typeobj_name:             # <<<<<<<<<<<<<<
 *                 error(pos, "Type object name specification required for 'api' C class")
 *     else:
*/
      }

      /* "Cython/Compiler/Parsing.py":4009
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':
 *         if ctx.api:             # <<<<<<<<<<<<<<
 *             if not objstruct_name:
 *                 error(pos, "Object struct name specification required for 'api' C class")
*/
    }

    /* "Cython/Compiler/Parsing.py":4008
 *         if not typeobj_name:
 *             error(pos, "Type object name specification required for 'public' C class")
 *     elif ctx.visibility == 'private':             # <<<<<<<<<<<<<<
 *         if ctx.api:
 *             if not objstruct_name:
*/
    goto __pyx_L23;
  }

  /* "Cython/Compiler/Parsing.py":4015
 *                 error(pos, "Type object name specification required for 'api' C class")
 *     else:
 *         error(pos, "Invalid class visibility '%s'" % ctx.visibility)             # <<<<<<<<<<<<<<
 *     return Nodes.CClassDefNode(pos,
 *         visibility = ctx.visibility,
*/
  /*else*/ {
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Invalid_class_visibility_s, __pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_t_11};
      __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L23:;

  /* "Cython/Compiler/Parsing.py":4016
 *     else:
 *         error(pos, "Invalid class visibility '%s'" % ctx.visibility)
 *     return Nodes.CClassDefNode(pos,             # <<<<<<<<<<<<<<
 *         visibility = ctx.visibility,
 *         typedef_flag = ctx.typedef_flag,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_1);

  /* "Cython/Compiler/Parsing.py":4017
 *         error(pos, "Invalid class visibility '%s'" % ctx.visibility)
 *     return Nodes.CClassDefNode(pos,
 *         visibility = ctx.visibility,             # <<<<<<<<<<<<<<
 *         typedef_flag = ctx.typedef_flag,
 *         api = ctx.api,
*/
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);

  /* "Cython/Compiler/Parsing.py":4018
 *     return Nodes.CClassDefNode(pos,
 *         visibility = ctx.visibility,
 *         typedef_flag = ctx.typedef_flag,             # <<<<<<<<<<<<<<
 *         api = ctx.api,
 *         module_name = ".".join(module_path),
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_typedef_flag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":4019
 *         visibility = ctx.visibility,
 *         typedef_flag = ctx.typedef_flag,
 *         api = ctx.api,             # <<<<<<<<<<<<<<
 *         module_name = ".".join(module_path),
 *         class_name = class_name,
*/
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "Cython/Compiler/Parsing.py":4020
 *         typedef_flag = ctx.typedef_flag,
 *         api = ctx.api,
 *         module_name = ".".join(module_path),             # <<<<<<<<<<<<<<
 *         class_name = class_name,
 *         as_name = as_name,
*/
  __pyx_t_12 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__27, __pyx_v_module_path); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);

  /* "Cython/Compiler/Parsing.py":4027
 *         typeobj_name = typeobj_name,
 *         check_size = check_size,
 *         in_pxd = ctx.level == 'module_pxd',             # <<<<<<<<<<<<<<
 *         doc = doc,
 *         body = body)
*/
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = PyObject_RichCompare(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4027, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "Cython/Compiler/Parsing.py":4029
 *         in_pxd = ctx.level == 'module_pxd',
 *         doc = doc,
 *         body = body)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 13 : 0)] = {__pyx_t_1, __pyx_v_pos};
    __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_11, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typedef_flag, __pyx_t_2, __pyx_t_13, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_api, __pyx_t_9, __pyx_t_13, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_module_name, __pyx_t_12, __pyx_t_13, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_class_name, __pyx_v_class_name, __pyx_t_13, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_as_name, __pyx_v_as_name, __pyx_t_13, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_bases, __pyx_v_bases, __pyx_t_13, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_objstruct_name, __pyx_v_objstruct_name, __pyx_t_13, __pyx_callargs+2, 7) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_typeobj_name, __pyx_v_typeobj_name, __pyx_t_13, __pyx_callargs+2, 8) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_check_size, __pyx_v_check_size, __pyx_t_13, __pyx_callargs+2, 9) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_14, __pyx_t_13, __pyx_callargs+2, 10) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_13, __pyx_callargs+2, 11) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_13, __pyx_callargs+2, 12) < (0)) __PYX_ERR(0, 4016, __pyx_L1_error)
    __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CClassDefNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":3955
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'class'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_class_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_module_path);
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_XDECREF(__pyx_v_as_name);
  __Pyx_XDECREF(__pyx_v_objstruct_name);
  __Pyx_XDECREF(__pyx_v_typeobj_name);
  __Pyx_XDECREF(__pyx_v_bases);
  __Pyx_XDECREF(__pyx_v_check_size);
  __Pyx_XDECREF(__pyx_v_positional_args);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_body_level);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4032
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_class_options(s: PyrexScanner) -> tuple:
 *     objstruct_name = None
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_c_class_options(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_objstruct_name = NULL;
  PyObject *__pyx_v_typeobj_name = NULL;
  PyObject *__pyx_v_check_size = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_c_class_options", 0);

  /* "Cython/Compiler/Parsing.py":4034
 * @cython.cfunc
 * def p_c_class_options(s: PyrexScanner) -> tuple:
 *     objstruct_name = None             # <<<<<<<<<<<<<<
 *     typeobj_name = None
 *     check_size = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_objstruct_name = Py_None;

  /* "Cython/Compiler/Parsing.py":4035
 * def p_c_class_options(s: PyrexScanner) -> tuple:
 *     objstruct_name = None
 *     typeobj_name = None             # <<<<<<<<<<<<<<
 *     check_size = None
 *     s.expect('[')
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_typeobj_name = Py_None;

  /* "Cython/Compiler/Parsing.py":4036
 *     objstruct_name = None
 *     typeobj_name = None
 *     check_size = None             # <<<<<<<<<<<<<<
 *     s.expect('[')
 *     while 1:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_check_size = Py_None;

  /* "Cython/Compiler/Parsing.py":4037
 *     typeobj_name = None
 *     check_size = None
 *     s.expect('[')             # <<<<<<<<<<<<<<
 *     while 1:
 *         if s.sy != 'IDENT':
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__26};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4037, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4038
 *     check_size = None
 *     s.expect('[')
 *     while 1:             # <<<<<<<<<<<<<<
 *         if s.sy != 'IDENT':
 *             break
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":4039
 *     s.expect('[')
 *     while 1:
 *         if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *             break
 *         if s.systring == 'object':
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4039, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4040
 *     while 1:
 *         if s.sy != 'IDENT':
 *             break             # <<<<<<<<<<<<<<
 *         if s.systring == 'object':
 *             s.next()
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":4039
 *     s.expect('[')
 *     while 1:
 *         if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *             break
 *         if s.systring == 'object':
*/
    }

    /* "Cython/Compiler/Parsing.py":4041
 *         if s.sy != 'IDENT':
 *             break
 *         if s.systring == 'object':             # <<<<<<<<<<<<<<
 *             s.next()
 *             objstruct_name = p_ident(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_object, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4041, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4042
 *             break
 *         if s.systring == 'object':
 *             s.next()             # <<<<<<<<<<<<<<
 *             objstruct_name = p_ident(s)
 *         elif s.systring == 'type':
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4042, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4043
 *         if s.systring == 'object':
 *             s.next()
 *             objstruct_name = p_ident(s)             # <<<<<<<<<<<<<<
 *         elif s.systring == 'type':
 *             s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4043, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_objstruct_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4041
 *         if s.sy != 'IDENT':
 *             break
 *         if s.systring == 'object':             # <<<<<<<<<<<<<<
 *             s.next()
 *             objstruct_name = p_ident(s)
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":4044
 *             s.next()
 *             objstruct_name = p_ident(s)
 *         elif s.systring == 'type':             # <<<<<<<<<<<<<<
 *             s.next()
 *             typeobj_name = p_ident(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_type_2, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4044, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4045
 *             objstruct_name = p_ident(s)
 *         elif s.systring == 'type':
 *             s.next()             # <<<<<<<<<<<<<<
 *             typeobj_name = p_ident(s)
 *         elif s.systring == 'check_size':
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4045, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4046
 *         elif s.systring == 'type':
 *             s.next()
 *             typeobj_name = p_ident(s)             # <<<<<<<<<<<<<<
 *         elif s.systring == 'check_size':
 *             s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4046, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_typeobj_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4044
 *             s.next()
 *             objstruct_name = p_ident(s)
 *         elif s.systring == 'type':             # <<<<<<<<<<<<<<
 *             s.next()
 *             typeobj_name = p_ident(s)
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Parsing.py":4047
 *             s.next()
 *             typeobj_name = p_ident(s)
 *         elif s.systring == 'check_size':             # <<<<<<<<<<<<<<
 *             s.next()
 *             check_size = p_ident(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_check_size, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4047, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4048
 *             typeobj_name = p_ident(s)
 *         elif s.systring == 'check_size':
 *             s.next()             # <<<<<<<<<<<<<<
 *             check_size = p_ident(s)
 *             if check_size not in ('ignore', 'warn', 'error'):
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4048, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4049
 *         elif s.systring == 'check_size':
 *             s.next()
 *             check_size = p_ident(s)             # <<<<<<<<<<<<<<
 *             if check_size not in ('ignore', 'warn', 'error'):
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_check_size, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4050
 *             s.next()
 *             check_size = p_ident(s)
 *             if check_size not in ('ignore', 'warn', 'error'):             # <<<<<<<<<<<<<<
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
 *         if s.sy != ',':
*/
      __Pyx_INCREF(__pyx_v_check_size);
      __pyx_t_1 = __pyx_v_check_size;
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ignore, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4050, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_warn, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4050, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_error, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4050, __pyx_L1_error)
      __pyx_t_4 = __pyx_t_5;
      __pyx_L8_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = __pyx_t_4;
      if (__pyx_t_5) {

        /* "Cython/Compiler/Parsing.py":4051
 *             check_size = p_ident(s)
 *             if check_size not in ('ignore', 'warn', 'error'):
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_6 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Expected_one_of_ignore_warn_or_e, __pyx_v_check_size); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4051, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4051, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":4050
 *             s.next()
 *             check_size = p_ident(s)
 *             if check_size not in ('ignore', 'warn', 'error'):             # <<<<<<<<<<<<<<
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
 *         if s.sy != ',':
*/
      }

      /* "Cython/Compiler/Parsing.py":4047
 *             s.next()
 *             typeobj_name = p_ident(s)
 *         elif s.systring == 'check_size':             # <<<<<<<<<<<<<<
 *             s.next()
 *             check_size = p_ident(s)
*/
    }
    __pyx_L6:;

    /* "Cython/Compiler/Parsing.py":4052
 *             if check_size not in ('ignore', 'warn', 'error'):
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 4052, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "Cython/Compiler/Parsing.py":4053
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     s.expect(']', "Expected 'object', 'type' or 'check_size'")
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":4052
 *             if check_size not in ('ignore', 'warn', 'error'):
 *                 s.error("Expected one of ignore, warn or error, found %r" % check_size)
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":4054
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     s.expect(']', "Expected 'object', 'type' or 'check_size'")
 *     return objstruct_name, typeobj_name, check_size
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":4055
 *             break
 *         s.next()
 *     s.expect(']', "Expected 'object', 'type' or 'check_size'")             # <<<<<<<<<<<<<<
 *     return objstruct_name, typeobj_name, check_size
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_n_u_expect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[13], NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "Cython/Compiler/Parsing.py":4056
 *         s.next()
 *     s.expect(']', "Expected 'object', 'type' or 'check_size'")
 *     return objstruct_name, typeobj_name, check_size             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_objstruct_name);
  __Pyx_GIVEREF(__pyx_v_objstruct_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_objstruct_name) != (0)) __PYX_ERR(0, 4056, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_typeobj_name);
  __Pyx_GIVEREF(__pyx_v_typeobj_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_typeobj_name) != (0)) __PYX_ERR(0, 4056, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_check_size);
  __Pyx_GIVEREF(__pyx_v_check_size);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_check_size) != (0)) __PYX_ERR(0, 4056, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4032
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_c_class_options(s: PyrexScanner) -> tuple:
 *     objstruct_name = None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_c_class_options", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_objstruct_name);
  __Pyx_XDECREF(__pyx_v_typeobj_name);
  __Pyx_XDECREF(__pyx_v_check_size);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4059
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_property_decl(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_property_decl(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite_with_docstring __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_property_decl", 0);

  /* "Cython/Compiler/Parsing.py":4061
 * @cython.cfunc
 * def p_property_decl(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.next()  # 'property'
 *     name = p_ident(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4062
 * def p_property_decl(s: PyrexScanner):
 *     pos = s.position()
 *     s.next()  # 'property'             # <<<<<<<<<<<<<<
 *     name = p_ident(s)
 *     doc, body = p_suite_with_docstring(
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4063
 *     pos = s.position()
 *     s.next()  # 'property'
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     doc, body = p_suite_with_docstring(
 *         s, Ctx(level='property'), with_doc_only=True)
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4065
 *     name = p_ident(s)
 *     doc, body = p_suite_with_docstring(
 *         s, Ctx(level='property'), with_doc_only=True)             # <<<<<<<<<<<<<<
 *     return Nodes.PropertyNode(pos, name=name, doc=doc, body=body)
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_property, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 4065, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }

  /* "Cython/Compiler/Parsing.py":4064
 *     s.next()  # 'property'
 *     name = p_ident(s)
 *     doc, body = p_suite_with_docstring(             # <<<<<<<<<<<<<<
 *         s, Ctx(level='property'), with_doc_only=True)
 *     return Nodes.PropertyNode(pos, name=name, doc=doc, body=body)
*/
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.with_doc_only = 1;
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite_with_docstring(__pyx_v_s, __pyx_t_1, &__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_4 != Py_None)) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 4064, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 4064, __pyx_L1_error)
  }
  __pyx_v_doc = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_body = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":4066
 *     doc, body = p_suite_with_docstring(
 *         s, Ctx(level='property'), with_doc_only=True)
 *     return Nodes.PropertyNode(pos, name=name, doc=doc, body=body)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4066, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_name, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4066, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_1, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4066, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_1, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4066, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_PropertyNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4066, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4059
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_property_decl(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_property_decl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4069
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ignorable_statement(s: PyrexScanner):
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_ignorable_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_string_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_ignorable_statement", 0);

  /* "Cython/Compiler/Parsing.py":4074
 *     Parses any kind of ignorable statement that is allowed in .pxd files.
 *     """
 *     if s.sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         string_node = p_atom(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4074, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4075
 *     """
 *     if s.sy == 'BEGIN_STRING':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         string_node = p_atom(s)
 *         s.expect_newline("Syntax error in string", ignore_semicolon=True)
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4075, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4076
 *     if s.sy == 'BEGIN_STRING':
 *         pos = s.position()
 *         string_node = p_atom(s)             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in string", ignore_semicolon=True)
 *         return Nodes.ExprStatNode(pos, expr=string_node)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4076, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_string_node = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4077
 *         pos = s.position()
 *         string_node = p_atom(s)
 *         s.expect_newline("Syntax error in string", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *         return Nodes.ExprStatNode(pos, expr=string_node)
 *     return None
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_string};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4077, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4078
 *         string_node = p_atom(s)
 *         s.expect_newline("Syntax error in string", ignore_semicolon=True)
 *         return Nodes.ExprStatNode(pos, expr=string_node)             # <<<<<<<<<<<<<<
 *     return None
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_expr, __pyx_v_string_node, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4078, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ExprStatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4074
 *     Parses any kind of ignorable statement that is allowed in .pxd files.
 *     """
 *     if s.sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         string_node = p_atom(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":4079
 *         s.expect_newline("Syntax error in string", ignore_semicolon=True)
 *         return Nodes.ExprStatNode(pos, expr=string_node)
 *     return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4069
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_ignorable_statement(s: PyrexScanner):
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_ignorable_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_string_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4082
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_doc_string(s: PyrexScanner):
 *     if s.sy == 'BEGIN_STRING':
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_kind = NULL;
  PyObject *__pyx_v_bytes_result = NULL;
  PyObject *__pyx_v_unicode_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_doc_string", 0);

  /* "Cython/Compiler/Parsing.py":4084
 * @cython.cfunc
 * def p_doc_string(s: PyrexScanner):
 *     if s.sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4084, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4085
 * def p_doc_string(s: PyrexScanner):
 *     if s.sy == 'BEGIN_STRING':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4085, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4086
 *     if s.sy == 'BEGIN_STRING':
 *         pos = s.position()
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)
 *         if kind in ('u', ''):
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cat_string_literal(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4086, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(__pyx_t_2 != Py_None)) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 4086, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4086, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4086, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4086, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 4086, __pyx_L1_error)
    }
    __pyx_v_kind = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_bytes_result = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_unicode_result = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":4087
 *         pos = s.position()
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)             # <<<<<<<<<<<<<<
 *         if kind in ('u', ''):
 *             return unicode_result
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_doc_string};
      __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4087, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_semicolon, Py_True, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4087, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4087, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4088
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)
 *         if kind in ('u', ''):             # <<<<<<<<<<<<<<
 *             return unicode_result
 *         warning(pos, "Python 3 requires docstrings to be unicode strings")
*/
    __Pyx_INCREF(__pyx_v_kind);
    __pyx_t_2 = __pyx_v_kind;
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_u, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4088, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_1 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__35, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4088, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_7;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __pyx_t_1;
    if (__pyx_t_7) {

      /* "Cython/Compiler/Parsing.py":4089
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)
 *         if kind in ('u', ''):
 *             return unicode_result             # <<<<<<<<<<<<<<
 *         warning(pos, "Python 3 requires docstrings to be unicode strings")
 *         return bytes_result
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_unicode_result);
      __pyx_r = __pyx_v_unicode_result;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":4088
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
 *         s.expect_newline("Syntax error in doc string", ignore_semicolon=True)
 *         if kind in ('u', ''):             # <<<<<<<<<<<<<<
 *             return unicode_result
 *         warning(pos, "Python 3 requires docstrings to be unicode strings")
*/
    }

    /* "Cython/Compiler/Parsing.py":4090
 *         if kind in ('u', ''):
 *             return unicode_result
 *         warning(pos, "Python 3 requires docstrings to be unicode strings")             # <<<<<<<<<<<<<<
 *         return bytes_result
 *     else:
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Python_3_requires_docstrings_to};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4091
 *             return unicode_result
 *         warning(pos, "Python 3 requires docstrings to be unicode strings")
 *         return bytes_result             # <<<<<<<<<<<<<<
 *     else:
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_bytes_result);
    __pyx_r = __pyx_v_bytes_result;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4084
 * @cython.cfunc
 * def p_doc_string(s: PyrexScanner):
 *     if s.sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         kind, bytes_result, unicode_result = p_cat_string_literal(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":4093
 *         return bytes_result
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":4082
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_doc_string(s: PyrexScanner):
 *     if s.sy == 'BEGIN_STRING':
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_doc_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_kind);
  __Pyx_XDECREF(__pyx_v_bytes_result);
  __Pyx_XDECREF(__pyx_v_unicode_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4096
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _extract_docstring(node) -> tuple:
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing__extract_docstring(PyObject *__pyx_v_node) {
  PyObject *__pyx_v_doc_node = NULL;
  PyObject *__pyx_v_stats = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_extract_docstring", 0);
  __Pyx_INCREF(__pyx_v_node);

  /* "Cython/Compiler/Parsing.py":4103
 *     (plain-docstring or None, node).
 *     """
 *     doc_node = None             # <<<<<<<<<<<<<<
 *     if node is None:
 *         pass
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_doc_node = Py_None;

  /* "Cython/Compiler/Parsing.py":4104
 *     """
 *     doc_node = None
 *     if node is None:             # <<<<<<<<<<<<<<
 *         pass
 *     elif isinstance(node, Nodes.ExprStatNode):
*/
  __pyx_t_1 = (__pyx_v_node == Py_None);
  if (__pyx_t_1) {
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":4106
 *     if node is None:
 *         pass
 *     elif isinstance(node, Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *         if node.expr.is_string_literal:
 *             doc_node = node.expr
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_ExprStatNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4107
 *         pass
 *     elif isinstance(node, Nodes.ExprStatNode):
 *         if node.expr.is_string_literal:             # <<<<<<<<<<<<<<
 *             doc_node = node.expr
 *             node = Nodes.StatListNode(node.pos, stats=[])
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_string_literal); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4107, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4108
 *     elif isinstance(node, Nodes.ExprStatNode):
 *         if node.expr.is_string_literal:
 *             doc_node = node.expr             # <<<<<<<<<<<<<<
 *             node = Nodes.StatListNode(node.pos, stats=[])
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_doc_node, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":4109
 *         if node.expr.is_string_literal:
 *             doc_node = node.expr
 *             node = Nodes.StatListNode(node.pos, stats=[])             # <<<<<<<<<<<<<<
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:
 *         stats = node.stats
*/
      __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_4};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4109, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_stats, __pyx_t_5, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4109, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_StatListNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4109, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":4107
 *         pass
 *     elif isinstance(node, Nodes.ExprStatNode):
 *         if node.expr.is_string_literal:             # <<<<<<<<<<<<<<
 *             doc_node = node.expr
 *             node = Nodes.StatListNode(node.pos, stats=[])
*/
    }

    /* "Cython/Compiler/Parsing.py":4106
 *     if node is None:
 *         pass
 *     elif isinstance(node, Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *         if node.expr.is_string_literal:
 *             doc_node = node.expr
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":4110
 *             doc_node = node.expr
 *             node = Nodes.StatListNode(node.pos, stats=[])
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:             # <<<<<<<<<<<<<<
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_StatListNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4111
 *             node = Nodes.StatListNode(node.pos, stats=[])
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:
 *         stats = node.stats             # <<<<<<<<<<<<<<
 *         if isinstance(stats[0], Nodes.ExprStatNode):
 *             if stats[0].expr.is_string_literal:
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_stats = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4112
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *             if stats[0].expr.is_string_literal:
 *                 doc_node = stats[0].expr
*/
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_ExprStatNode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = PyObject_IsInstance(__pyx_t_3, __pyx_t_7); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4113
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):
 *             if stats[0].expr.is_string_literal:             # <<<<<<<<<<<<<<
 *                 doc_node = stats[0].expr
 *                 del stats[0]
*/
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_is_string_literal); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4113, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_1) {

        /* "Cython/Compiler/Parsing.py":4114
 *         if isinstance(stats[0], Nodes.ExprStatNode):
 *             if stats[0].expr.is_string_literal:
 *                 doc_node = stats[0].expr             # <<<<<<<<<<<<<<
 *                 del stats[0]
 * 
*/
        __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF_SET(__pyx_v_doc_node, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":4115
 *             if stats[0].expr.is_string_literal:
 *                 doc_node = stats[0].expr
 *                 del stats[0]             # <<<<<<<<<<<<<<
 * 
 *     if doc_node is None:
*/
        if (unlikely((__Pyx_DelItemInt(__pyx_v_stats, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference) < 0))) __PYX_ERR(0, 4115, __pyx_L1_error)

        /* "Cython/Compiler/Parsing.py":4113
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):
 *             if stats[0].expr.is_string_literal:             # <<<<<<<<<<<<<<
 *                 doc_node = stats[0].expr
 *                 del stats[0]
*/
      }

      /* "Cython/Compiler/Parsing.py":4112
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):             # <<<<<<<<<<<<<<
 *             if stats[0].expr.is_string_literal:
 *                 doc_node = stats[0].expr
*/
    }

    /* "Cython/Compiler/Parsing.py":4110
 *             doc_node = node.expr
 *             node = Nodes.StatListNode(node.pos, stats=[])
 *     elif isinstance(node, Nodes.StatListNode) and node.stats:             # <<<<<<<<<<<<<<
 *         stats = node.stats
 *         if isinstance(stats[0], Nodes.ExprStatNode):
*/
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":4117
 *                 del stats[0]
 * 
 *     if doc_node is None:             # <<<<<<<<<<<<<<
 *         doc = None
 *     elif isinstance(doc_node, ExprNodes.BytesNode):
*/
  __pyx_t_1 = (__pyx_v_doc_node == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4118
 * 
 *     if doc_node is None:
 *         doc = None             # <<<<<<<<<<<<<<
 *     elif isinstance(doc_node, ExprNodes.BytesNode):
 *         warning(node.pos,
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_doc = Py_None;

    /* "Cython/Compiler/Parsing.py":4117
 *                 del stats[0]
 * 
 *     if doc_node is None:             # <<<<<<<<<<<<<<
 *         doc = None
 *     elif isinstance(doc_node, ExprNodes.BytesNode):
*/
    goto __pyx_L9;
  }

  /* "Cython/Compiler/Parsing.py":4119
 *     if doc_node is None:
 *         doc = None
 *     elif isinstance(doc_node, ExprNodes.BytesNode):             # <<<<<<<<<<<<<<
 *         warning(node.pos,
 *                 "Python 3 requires docstrings to be unicode strings")
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_mstate_global->__pyx_n_u_BytesNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_doc_node, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 4119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4120
 *         doc = None
 *     elif isinstance(doc_node, ExprNodes.BytesNode):
 *         warning(node.pos,             # <<<<<<<<<<<<<<
 *                 "Python 3 requires docstrings to be unicode strings")
 *         doc = doc_node.value
*/
    __pyx_t_7 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_7);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Python_3_requires_docstrings_to};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4122
 *         warning(node.pos,
 *                 "Python 3 requires docstrings to be unicode strings")
 *         doc = doc_node.value             # <<<<<<<<<<<<<<
 *     else:
 *         doc = doc_node.value
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_doc_node, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_doc = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4119
 *     if doc_node is None:
 *         doc = None
 *     elif isinstance(doc_node, ExprNodes.BytesNode):             # <<<<<<<<<<<<<<
 *         warning(node.pos,
 *                 "Python 3 requires docstrings to be unicode strings")
*/
    goto __pyx_L9;
  }

  /* "Cython/Compiler/Parsing.py":4124
 *         doc = doc_node.value
 *     else:
 *         doc = doc_node.value             # <<<<<<<<<<<<<<
 *     return doc, node
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_doc_node, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_doc = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L9:;

  /* "Cython/Compiler/Parsing.py":4125
 *     else:
 *         doc = doc_node.value
 *     return doc, node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_doc);
  __Pyx_GIVEREF(__pyx_v_doc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_doc) != (0)) __PYX_ERR(0, 4125, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_node);
  __Pyx_GIVEREF(__pyx_v_node);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_node) != (0)) __PYX_ERR(0, 4125, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4096
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def _extract_docstring(node) -> tuple:
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing._extract_docstring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_doc_node);
  __Pyx_XDECREF(__pyx_v_stats);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4128
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_9p_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_code(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_code *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":4129
 * 
 * @cython.ccall
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):             # <<<<<<<<<<<<<<
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':
*/
  PyObject *__pyx_v_level = ((PyObject *)Py_None);
  PyObject *__pyx_v_ctx = __pyx_mstate_global->__pyx_k__54;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_code", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_level = __pyx_optional_args->level;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_ctx = __pyx_optional_args->ctx;
      }
    }
  }

  /* "Cython/Compiler/Parsing.py":4130
 * @cython.ccall
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)             # <<<<<<<<<<<<<<
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_3 = __pyx_v_ctx; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_v_level, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 4130, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.first_statement = 1;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(__pyx_v_s, __pyx_t_1, &__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_body = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4131
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
*/
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4131, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4132
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (             # <<<<<<<<<<<<<<
 *             repr(s.sy), repr(s.systring)))
 *     return body
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":4133
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))             # <<<<<<<<<<<<<<
 *     return body
 * 
*/
    __pyx_t_5 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = PyObject_Repr(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_8 = PyObject_Repr(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_statement;
    __pyx_t_9[1] = __pyx_t_5;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_;
    __pyx_t_9[3] = __pyx_t_2;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__30;

    /* "Cython/Compiler/Parsing.py":4132
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (             # <<<<<<<<<<<<<<
 *             repr(s.sy), repr(s.systring)))
 *     return body
*/
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4131
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
*/
  }

  /* "Cython/Compiler/Parsing.py":4134
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
 *     return body             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_body);
  __pyx_r = __pyx_v_body;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4128
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_9p_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_9p_code = {"p_code", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_9p_code, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_9p_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s = 0;
  PyObject *__pyx_v_level = 0;
  PyObject *__pyx_v_ctx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p_code (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s,&__pyx_mstate_global->__pyx_n_u_level,&__pyx_mstate_global->__pyx_n_u_ctx,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 4128, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4128, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4128, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4128, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "p_code", 0) < (0)) __PYX_ERR(0, 4128, __pyx_L3_error)

      /* "Cython/Compiler/Parsing.py":4129
 * 
 * @cython.ccall
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):             # <<<<<<<<<<<<<<
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__54);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("p_code", 0, 1, 3, i); __PYX_ERR(0, 4128, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4128, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4128, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4128, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__54);
    }
    __pyx_v_s = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)values[0]);
    __pyx_v_level = values[1];
    __pyx_v_ctx = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("p_code", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 4128, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "s", 0))) __PYX_ERR(0, 4129, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_8p_code(__pyx_self, __pyx_v_s, __pyx_v_level, __pyx_v_ctx);

  /* "Cython/Compiler/Parsing.py":4128
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_8p_code(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_level, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_code __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_code", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(((PyObject *)__pyx_v_s) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 4128, __pyx_L1_error)
  }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.level = __pyx_v_level;
  __pyx_t_2.ctx = __pyx_v_ctx;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_code(__pyx_v_s, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4141
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_compiler_directive_comments(s: PyrexScanner) -> dict:
 *     result = {}
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_compiler_directive_comments(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_v_directives_string = NULL;
  PyObject *__pyx_v_new_directives = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  Py_ssize_t __pyx_t_22;
  PyObject *(*__pyx_t_23)(PyObject *);
  PyObject *__pyx_t_24[6];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_compiler_directive_comments", 0);

  /* "Cython/Compiler/Parsing.py":4143
 * @cython.cfunc
 * def p_compiler_directive_comments(s: PyrexScanner) -> dict:
 *     result = {}             # <<<<<<<<<<<<<<
 *     while s.sy == 'commentline':
 *         pos = s.position()
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4144
 * def p_compiler_directive_comments(s: PyrexScanner) -> dict:
 *     result = {}
 *     while s.sy == 'commentline':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         m = _match_compiler_directive_comment(s.systring)
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_commentline, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4144, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":4145
 *     result = {}
 *     while s.sy == 'commentline':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         m = _match_compiler_directive_comment(s.systring)
 *         if m:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_pos, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4146
 *     while s.sy == 'commentline':
 *         pos = s.position()
 *         m = _match_compiler_directive_comment(s.systring)             # <<<<<<<<<<<<<<
 *         if m:
 *             directives_string = m.group(1).strip()
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment);
    __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_s->systring};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4147
 *         pos = s.position()
 *         m = _match_compiler_directive_comment(s.systring)
 *         if m:             # <<<<<<<<<<<<<<
 *             directives_string = m.group(1).strip()
 *             try:
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_m); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4147, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":4148
 *         m = _match_compiler_directive_comment(s.systring)
 *         if m:
 *             directives_string = m.group(1).strip()             # <<<<<<<<<<<<<<
 *             try:
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
*/
      __pyx_t_6 = __pyx_v_m;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_int_1};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_group, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4148, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_4 = __pyx_t_3;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4148, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_directives_string, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4149
 *         if m:
 *             directives_string = m.group(1).strip()
 *             try:             # <<<<<<<<<<<<<<
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {

          /* "Cython/Compiler/Parsing.py":4150
 *             directives_string = m.group(1).strip()
 *             try:
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)             # <<<<<<<<<<<<<<
 *             except ValueError as e:
 *                 s.error(e.args[0], fatal=False)
*/
          __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_Options;
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_directives_string};
            __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4150, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_unknown, Py_True, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4150, __pyx_L6_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_parse_directive_list, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4150, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_XDECREF_SET(__pyx_v_new_directives, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":4149
 *         if m:
 *             directives_string = m.group(1).strip()
 *             try:             # <<<<<<<<<<<<<<
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:
*/
        }
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L13_try_end;
        __pyx_L6_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":4151
 *             try:
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:             # <<<<<<<<<<<<<<
 *                 s.error(e.args[0], fatal=False)
 *                 s.next()
*/
        __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
        if (__pyx_t_10) {
          __Pyx_AddTraceback("Cython.Compiler.Parsing.p_compiler_directive_comments", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_3) < 0) __PYX_ERR(0, 4151, __pyx_L8_except_error)
          __Pyx_XGOTREF(__pyx_t_1);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __pyx_v_e = __pyx_t_4;
          /*try:*/ {

            /* "Cython/Compiler/Parsing.py":4152
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:
 *                 s.error(e.args[0], fatal=False)             # <<<<<<<<<<<<<<
 *                 s.next()
 *                 continue
*/
            __pyx_t_11 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_11);
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4152, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_13 = __Pyx_GetItemInt(__pyx_t_12, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4152, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_t_13};
              __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4152, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_fatal, Py_False, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4152, __pyx_L19_error)
              __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4152, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_6);
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4153
 *             except ValueError as e:
 *                 s.error(e.args[0], fatal=False)
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
            __pyx_t_12 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_12);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
              __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4153, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_6);
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4154
 *                 s.error(e.args[0], fatal=False)
 *                 s.next()
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             for name in new_directives:
*/
            goto __pyx_L16_continue;
          }

          /* "Cython/Compiler/Parsing.py":4151
 *             try:
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:             # <<<<<<<<<<<<<<
 *                 s.error(e.args[0], fatal=False)
 *                 s.next()
*/
          /*finally:*/ {
            __pyx_L19_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
               __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
              if ( unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __pyx_t_10 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
              }
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
              __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
              __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
              goto __pyx_L8_except_error;
            }
            __pyx_L16_continue: {
              __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
              goto __pyx_L14_except_continue;
            }
          }
          __pyx_L14_except_continue:;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L12_try_continue;
        }
        goto __pyx_L8_except_error;

        /* "Cython/Compiler/Parsing.py":4149
 *         if m:
 *             directives_string = m.group(1).strip()
 *             try:             # <<<<<<<<<<<<<<
 *                 new_directives = Options.parse_directive_list(directives_string, ignore_unknown=True)
 *             except ValueError as e:
*/
        __pyx_L8_except_error:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L12_try_continue:;
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
        goto __pyx_L3_continue;
        __pyx_L13_try_end:;
      }

      /* "Cython/Compiler/Parsing.py":4156
 *                 continue
 * 
 *             for name in new_directives:             # <<<<<<<<<<<<<<
 *                 if name not in result:
 *                     pass
*/
      if (likely(PyList_CheckExact(__pyx_v_new_directives)) || PyTuple_CheckExact(__pyx_v_new_directives)) {
        __pyx_t_3 = __pyx_v_new_directives; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_22 = 0;
        __pyx_t_23 = NULL;
      } else {
        __pyx_t_22 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_new_directives); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4156, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_23 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 4156, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_23)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4156, __pyx_L1_error)
              #endif
              if (__pyx_t_22 >= __pyx_temp) break;
            }
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_22, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_22;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4156, __pyx_L1_error)
              #endif
              if (__pyx_t_22 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_22));
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_22);
            #endif
            ++__pyx_t_22;
          }
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4156, __pyx_L1_error)
        } else {
          __pyx_t_4 = __pyx_t_23(__pyx_t_3);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 4156, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "Cython/Compiler/Parsing.py":4157
 * 
 *             for name in new_directives:
 *                 if name not in result:             # <<<<<<<<<<<<<<
 *                     pass
 *                 elif Options.directive_types.get(name) is list:
*/
        __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_result, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4157, __pyx_L1_error)
        if (__pyx_t_2) {
          goto __pyx_L27;
        }

        /* "Cython/Compiler/Parsing.py":4159
 *                 if name not in result:
 *                     pass
 *                 elif Options.directive_types.get(name) is list:             # <<<<<<<<<<<<<<
 *                     result[name] += new_directives[name]
 *                     new_directives[name] = result[name]
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Options, __pyx_mstate_global->__pyx_n_u_directive_types); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __pyx_t_6;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_name};
          __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4159, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __pyx_t_2 = (__pyx_t_4 == ((PyObject *)(&PyList_Type)));
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {

          /* "Cython/Compiler/Parsing.py":4160
 *                     pass
 *                 elif Options.directive_types.get(name) is list:
 *                     result[name] += new_directives[name]             # <<<<<<<<<<<<<<
 *                     new_directives[name] = result[name]
 *                 elif new_directives[name] == result[name]:
*/
          __Pyx_INCREF(__pyx_v_name);
          __pyx_t_4 = __pyx_v_name;
          __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_result, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4160, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_new_directives, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4160, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = PyNumber_InPlaceAdd(__pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4160, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely((PyDict_SetItem(__pyx_v_result, __pyx_t_4, __pyx_t_12) < 0))) __PYX_ERR(0, 4160, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "Cython/Compiler/Parsing.py":4161
 *                 elif Options.directive_types.get(name) is list:
 *                     result[name] += new_directives[name]
 *                     new_directives[name] = result[name]             # <<<<<<<<<<<<<<
 *                 elif new_directives[name] == result[name]:
 *                     warning(pos, "Duplicate directive found: %s" % (name,))
*/
          __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_result, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4161, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely((PyObject_SetItem(__pyx_v_new_directives, __pyx_v_name, __pyx_t_4) < 0))) __PYX_ERR(0, 4161, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "Cython/Compiler/Parsing.py":4159
 *                 if name not in result:
 *                     pass
 *                 elif Options.directive_types.get(name) is list:             # <<<<<<<<<<<<<<
 *                     result[name] += new_directives[name]
 *                     new_directives[name] = result[name]
*/
          goto __pyx_L27;
        }

        /* "Cython/Compiler/Parsing.py":4162
 *                     result[name] += new_directives[name]
 *                     new_directives[name] = result[name]
 *                 elif new_directives[name] == result[name]:             # <<<<<<<<<<<<<<
 *                     warning(pos, "Duplicate directive found: %s" % (name,))
 *                 else:
*/
        __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_new_directives, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4162, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = __Pyx_PyDict_GetItem(__pyx_v_result, __pyx_v_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4162, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_t_12, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4162, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4162, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_2) {

          /* "Cython/Compiler/Parsing.py":4163
 *                     new_directives[name] = result[name]
 *                 elif new_directives[name] == result[name]:
 *                     warning(pos, "Duplicate directive found: %s" % (name,))             # <<<<<<<<<<<<<<
 *                 else:
 *                     s.error("Conflicting settings found for top-level directive %s: %r and %r" % (
*/
          __pyx_t_12 = NULL;
          __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
          __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_warning; 
          __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_name), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4163, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_13 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Duplicate_directive_found, __pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4163, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
            assert(__pyx_t_12);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_v_pos, __pyx_t_13};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4163, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":4162
 *                     result[name] += new_directives[name]
 *                     new_directives[name] = result[name]
 *                 elif new_directives[name] == result[name]:             # <<<<<<<<<<<<<<
 *                     warning(pos, "Duplicate directive found: %s" % (name,))
 *                 else:
*/
          goto __pyx_L27;
        }

        /* "Cython/Compiler/Parsing.py":4165
 *                     warning(pos, "Duplicate directive found: %s" % (name,))
 *                 else:
 *                     s.error("Conflicting settings found for top-level directive %s: %r and %r" % (             # <<<<<<<<<<<<<<
 *                         name, result[name], new_directives[name]), pos=pos)
 * 
*/
        /*else*/ {
          __pyx_t_4 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_4);

          /* "Cython/Compiler/Parsing.py":4166
 *                 else:
 *                     s.error("Conflicting settings found for top-level directive %s: %r and %r" % (
 *                         name, result[name], new_directives[name]), pos=pos)             # <<<<<<<<<<<<<<
 * 
 *             if 'language_level' in new_directives:
*/
          __pyx_t_13 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_name), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_12 = __Pyx_PyDict_GetItem(__pyx_v_result, __pyx_v_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_12), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_v_new_directives, __pyx_v_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_11 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_12), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4166, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_24[0] = __pyx_mstate_global->__pyx_kp_u_Conflicting_settings_found_for_t;
          __pyx_t_24[1] = __pyx_t_13;
          __pyx_t_24[2] = __pyx_mstate_global->__pyx_kp_u__55;
          __pyx_t_24[3] = __pyx_t_6;
          __pyx_t_24[4] = __pyx_mstate_global->__pyx_kp_u_and_2;
          __pyx_t_24[5] = __pyx_t_11;

          /* "Cython/Compiler/Parsing.py":4165
 *                     warning(pos, "Duplicate directive found: %s" % (name,))
 *                 else:
 *                     s.error("Conflicting settings found for top-level directive %s: %r and %r" % (             # <<<<<<<<<<<<<<
 *                         name, result[name], new_directives[name]), pos=pos)
 * 
*/
          __pyx_t_12 = __Pyx_PyUnicode_Join(__pyx_t_24, 6, 51 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_13) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 5 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4165, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "Cython/Compiler/Parsing.py":4166
 *                 else:
 *                     s.error("Conflicting settings found for top-level directive %s: %r and %r" % (
 *                         name, result[name], new_directives[name]), pos=pos)             # <<<<<<<<<<<<<<
 * 
 *             if 'language_level' in new_directives:
*/
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_t_12};
            __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4165, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_v_pos, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4165, __pyx_L1_error)
            __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4165, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L27:;

        /* "Cython/Compiler/Parsing.py":4156
 *                 continue
 * 
 *             for name in new_directives:             # <<<<<<<<<<<<<<
 *                 if name not in result:
 *                     pass
*/
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":4168
 *                         name, result[name], new_directives[name]), pos=pos)
 * 
 *             if 'language_level' in new_directives:             # <<<<<<<<<<<<<<
 *                 # Make sure we apply the language level already to the first token that follows the comments.
 *                 s.context.set_language_level(new_directives['language_level'])
*/
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_language_level, __pyx_v_new_directives, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4168, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":4170
 *             if 'language_level' in new_directives:
 *                 # Make sure we apply the language level already to the first token that follows the comments.
 *                 s.context.set_language_level(new_directives['language_level'])             # <<<<<<<<<<<<<<
 *             if 'legacy_implicit_noexcept' in new_directives:
 *                 s.context.legacy_implicit_noexcept = new_directives['legacy_implicit_noexcept']
*/
        __pyx_t_1 = __pyx_v_s->context;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_11 = __Pyx_PyObject_Dict_GetItem(__pyx_v_new_directives, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4170, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_11};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set_language_level, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4170, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":4168
 *                         name, result[name], new_directives[name]), pos=pos)
 * 
 *             if 'language_level' in new_directives:             # <<<<<<<<<<<<<<
 *                 # Make sure we apply the language level already to the first token that follows the comments.
 *                 s.context.set_language_level(new_directives['language_level'])
*/
      }

      /* "Cython/Compiler/Parsing.py":4171
 *                 # Make sure we apply the language level already to the first token that follows the comments.
 *                 s.context.set_language_level(new_directives['language_level'])
 *             if 'legacy_implicit_noexcept' in new_directives:             # <<<<<<<<<<<<<<
 *                 s.context.legacy_implicit_noexcept = new_directives['legacy_implicit_noexcept']
 * 
*/
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_legacy_implicit_noexcept, __pyx_v_new_directives, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4171, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":4172
 *                 s.context.set_language_level(new_directives['language_level'])
 *             if 'legacy_implicit_noexcept' in new_directives:
 *                 s.context.legacy_implicit_noexcept = new_directives['legacy_implicit_noexcept']             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_new_directives, __pyx_mstate_global->__pyx_n_u_legacy_implicit_noexcept); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4172, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_legacy_implicit_noexcept, __pyx_t_3) < (0)) __PYX_ERR(0, 4172, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":4171
 *                 # Make sure we apply the language level already to the first token that follows the comments.
 *                 s.context.set_language_level(new_directives['language_level'])
 *             if 'legacy_implicit_noexcept' in new_directives:             # <<<<<<<<<<<<<<
 *                 s.context.legacy_implicit_noexcept = new_directives['legacy_implicit_noexcept']
 * 
*/
      }

      /* "Cython/Compiler/Parsing.py":4175
 * 
 * 
 *             result.update(new_directives)             # <<<<<<<<<<<<<<
 * 
 *         s.next()
*/
      __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type__update, __pyx_v_result, __pyx_v_new_directives); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4175, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":4147
 *         pos = s.position()
 *         m = _match_compiler_directive_comment(s.systring)
 *         if m:             # <<<<<<<<<<<<<<
 *             directives_string = m.group(1).strip()
 *             try:
*/
    }

    /* "Cython/Compiler/Parsing.py":4177
 *             result.update(new_directives)
 * 
 *         s.next()             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_L3_continue:;
  }

  /* "Cython/Compiler/Parsing.py":4178
 * 
 *         s.next()
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4141
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_compiler_directive_comments(s: PyrexScanner) -> dict:
 *     result = {}
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_compiler_directive_comments", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_v_directives_string);
  __Pyx_XDECREF(__pyx_v_new_directives);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4181
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):
 *     pos = s.position()
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_11p_module(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_module(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pxd, PyObject *__pyx_v_full_module_name, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_module *__pyx_optional_args) {
  PyObject *__pyx_v_ctx = __pyx_mstate_global->__pyx_k__56;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_directive_comments = NULL;
  PyObject *__pyx_v_level = NULL;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_statement_list __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_module", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_ctx = __pyx_optional_args->ctx;
    }
  }

  /* "Cython/Compiler/Parsing.py":4183
 * @cython.ccall
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 * 
 *     directive_comments = p_compiler_directive_comments(s)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4185
 *     pos = s.position()
 * 
 *     directive_comments = p_compiler_directive_comments(s)             # <<<<<<<<<<<<<<
 *     s.parse_comments = False
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_compiler_directive_comments(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_directive_comments = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4186
 * 
 *     directive_comments = p_compiler_directive_comments(s)
 *     s.parse_comments = False             # <<<<<<<<<<<<<<
 * 
 *     if s.context.language_level is None:
*/
  __pyx_v_s->parse_comments = 0;

  /* "Cython/Compiler/Parsing.py":4188
 *     s.parse_comments = False
 * 
 *     if s.context.language_level is None:             # <<<<<<<<<<<<<<
 *         s.context.set_language_level('3')
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s->context, __pyx_mstate_global->__pyx_n_u_language_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4189
 * 
 *     if s.context.language_level is None:
 *         s.context.set_language_level('3')             # <<<<<<<<<<<<<<
 * 
 *     level = 'module_pxd' if pxd else 'module'
*/
    __pyx_t_3 = __pyx_v_s->context;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_3};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set_language_level, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4189, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4188
 *     s.parse_comments = False
 * 
 *     if s.context.language_level is None:             # <<<<<<<<<<<<<<
 *         s.context.set_language_level('3')
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":4191
 *         s.context.set_language_level('3')
 * 
 *     level = 'module_pxd' if pxd else 'module'             # <<<<<<<<<<<<<<
 *     doc = p_doc_string(s)
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_pxd); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4191, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_module_pxd);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_module_pxd;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_module);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_module;
  }
  __pyx_v_level = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4192
 * 
 *     level = 'module_pxd' if pxd else 'module'
 *     doc = p_doc_string(s)             # <<<<<<<<<<<<<<
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
 *     if s.sy != 'EOF':
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_doc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4193
 *     level = 'module_pxd' if pxd else 'module'
 *     doc = p_doc_string(s)
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)             # <<<<<<<<<<<<<<
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (
*/
  __pyx_t_3 = NULL;
  __Pyx_INCREF(__pyx_v_ctx);
  __pyx_t_5 = __pyx_v_ctx; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_v_level, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 4193, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_7.__pyx_n = 1;
  __pyx_t_7.first_statement = 1;
  __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_statement_list(__pyx_v_s, __pyx_t_1, &__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_body = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":4194
 *     doc = p_doc_string(s)
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
 *     if s.sy != 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_EOF, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4194, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4195
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (             # <<<<<<<<<<<<<<
 *             repr(s.sy), repr(s.systring)))
 *     return ModuleNode(pos, doc = doc, body = body,
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":4196
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))             # <<<<<<<<<<<<<<
 *     return ModuleNode(pos, doc = doc, body = body,
 *                       full_module_name = full_module_name,
*/
    __pyx_t_6 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = PyObject_Repr(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_8 = PyObject_Repr(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_statement;
    __pyx_t_9[1] = __pyx_t_6;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_;
    __pyx_t_9[3] = __pyx_t_3;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__30;

    /* "Cython/Compiler/Parsing.py":4195
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
 *     if s.sy != 'EOF':
 *         s.error("Syntax error in statement [%s,%s]" % (             # <<<<<<<<<<<<<<
 *             repr(s.sy), repr(s.systring)))
 *     return ModuleNode(pos, doc = doc, body = body,
*/
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":4194
 *     doc = p_doc_string(s)
 *     body = p_statement_list(s, ctx(level=level), first_statement=True)
 *     if s.sy != 'EOF':             # <<<<<<<<<<<<<<
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
*/
  }

  /* "Cython/Compiler/Parsing.py":4197
 *         s.error("Syntax error in statement [%s,%s]" % (
 *             repr(s.sy), repr(s.systring)))
 *     return ModuleNode(pos, doc = doc, body = body,             # <<<<<<<<<<<<<<
 *                       full_module_name = full_module_name,
 *                       directive_comments = directive_comments)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = NULL;
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_ModuleNode);
  __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ModuleNode; 

  /* "Cython/Compiler/Parsing.py":4199
 *     return ModuleNode(pos, doc = doc, body = body,
 *                       full_module_name = full_module_name,
 *                       directive_comments = directive_comments)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_8, __pyx_v_pos};
    __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_doc, __pyx_v_doc, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4197, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4197, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_full_module_name, __pyx_v_full_module_name, __pyx_t_3, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4197, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_directive_comments, __pyx_v_directive_comments, __pyx_t_3, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 4197, __pyx_L1_error)
    __pyx_t_5 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4181
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_module", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_directive_comments);
  __Pyx_XDECREF(__pyx_v_level);
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_11p_module(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_11p_module = {"p_module", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_11p_module, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_11p_module(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s = 0;
  PyObject *__pyx_v_pxd = 0;
  PyObject *__pyx_v_full_module_name = 0;
  PyObject *__pyx_v_ctx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p_module (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_s,&__pyx_mstate_global->__pyx_n_u_pxd,&__pyx_mstate_global->__pyx_n_u_full_module_name,&__pyx_mstate_global->__pyx_n_u_ctx,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 4181, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 4181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "p_module", 0) < (0)) __PYX_ERR(0, 4181, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__56);
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("p_module", 0, 3, 4, i); __PYX_ERR(0, 4181, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 4181, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4181, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4181, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4181, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__56);
    }
    __pyx_v_s = ((struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *)values[0]);
    __pyx_v_pxd = values[1];
    __pyx_v_full_module_name = values[2];
    __pyx_v_ctx = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("p_module", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4181, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_module", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner, 0, "s", 0))) __PYX_ERR(0, 4182, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_10p_module(__pyx_self, __pyx_v_s, __pyx_v_pxd, __pyx_v_full_module_name, __pyx_v_ctx);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_10p_module(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pxd, PyObject *__pyx_v_full_module_name, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_module __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_module", 0);
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(((PyObject *)__pyx_v_s) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(0, 4181, __pyx_L1_error)
  }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.ctx = __pyx_v_ctx;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_module(__pyx_v_s, __pyx_v_pxd, __pyx_v_full_module_name, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_module", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4202
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_template_definition(s: PyrexScanner) -> tuple:
 *     name = p_ident(s)
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_template_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_name = NULL;
  int __pyx_v_required;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_template_definition", 0);

  /* "Cython/Compiler/Parsing.py":4204
 * @cython.cfunc
 * def p_template_definition(s: PyrexScanner) -> tuple:
 *     name = p_ident(s)             # <<<<<<<<<<<<<<
 *     if s.sy == '=':
 *         s.expect('=')
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4205
 * def p_template_definition(s: PyrexScanner) -> tuple:
 *     name = p_ident(s)
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.expect('=')
 *         s.expect('*')
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4205, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4206
 *     name = p_ident(s)
 *     if s.sy == '=':
 *         s.expect('=')             # <<<<<<<<<<<<<<
 *         s.expect('*')
 *         required = False
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__29};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4207
 *     if s.sy == '=':
 *         s.expect('=')
 *         s.expect('*')             # <<<<<<<<<<<<<<
 *         required = False
 *     else:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__6};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4208
 *         s.expect('=')
 *         s.expect('*')
 *         required = False             # <<<<<<<<<<<<<<
 *     else:
 *         required = True
*/
    __pyx_v_required = 0;

    /* "Cython/Compiler/Parsing.py":4205
 * def p_template_definition(s: PyrexScanner) -> tuple:
 *     name = p_ident(s)
 *     if s.sy == '=':             # <<<<<<<<<<<<<<
 *         s.expect('=')
 *         s.expect('*')
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Parsing.py":4210
 *         required = False
 *     else:
 *         required = True             # <<<<<<<<<<<<<<
 *     return name, required
 * 
*/
  /*else*/ {
    __pyx_v_required = 1;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Parsing.py":4211
 *     else:
 *         required = True
 *     return name, required             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_required); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_name) != (0)) __PYX_ERR(0, 4211, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 4211, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4202
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_template_definition(s: PyrexScanner) -> tuple:
 *     name = p_ident(s)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_template_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4214
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cpp_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'cppclass'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_definition(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_pos, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_class_name = NULL;
  PyObject *__pyx_v_cname = NULL;
  PyObject *__pyx_v_templates = NULL;
  PyObject *__pyx_v_template_names = NULL;
  PyObject *__pyx_v_base_classes = NULL;
  int __pyx_v_nogil;
  PyObject *__pyx_v_attributes = NULL;
  PyObject *__pyx_v_body_ctx = NULL;
  PyObject *__pyx_8genexpr5__pyx_v_name = NULL;
  CYTHON_UNUSED PyObject *__pyx_8genexpr5__pyx_v_required = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cpp_class_definition", 0);

  /* "Cython/Compiler/Parsing.py":4217
 * def p_cpp_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'cppclass'
 *     s.next()             # <<<<<<<<<<<<<<
 *     class_name = p_ident(s)
 *     cname = p_opt_cname(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4218
 *     # s.sy == 'cppclass'
 *     s.next()
 *     class_name = p_ident(s)             # <<<<<<<<<<<<<<
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_class_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4219
 *     s.next()
 *     class_name = p_ident(s)
 *     cname = p_opt_cname(s)             # <<<<<<<<<<<<<<
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + class_name
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_opt_cname(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cname = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4220
 *     class_name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + class_name
 *     if s.sy == '.':
*/
  __pyx_t_5 = (__pyx_v_cname == Py_None);
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4221
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + class_name             # <<<<<<<<<<<<<<
 *     if s.sy == '.':
 *         error(pos, "Qualified class name not allowed C++ class")
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_namespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__47); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_class_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_cname, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4220
 *     class_name = p_ident(s)
 *     cname = p_opt_cname(s)
 *     if cname is None and ctx.namespace is not None:             # <<<<<<<<<<<<<<
 *         cname = ctx.namespace + "::" + class_name
 *     if s.sy == '.':
*/
  }

  /* "Cython/Compiler/Parsing.py":4222
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + class_name
 *     if s.sy == '.':             # <<<<<<<<<<<<<<
 *         error(pos, "Qualified class name not allowed C++ class")
 *     if s.sy == '[':
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4222, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4223
 *         cname = ctx.namespace + "::" + class_name
 *     if s.sy == '.':
 *         error(pos, "Qualified class name not allowed C++ class")             # <<<<<<<<<<<<<<
 *     if s.sy == '[':
 *         s.next()
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_pos, __pyx_mstate_global->__pyx_kp_u_Qualified_class_name_not_allowed};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4223, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4222
 *     if cname is None and ctx.namespace is not None:
 *         cname = ctx.namespace + "::" + class_name
 *     if s.sy == '.':             # <<<<<<<<<<<<<<
 *         error(pos, "Qualified class name not allowed C++ class")
 *     if s.sy == '[':
*/
  }

  /* "Cython/Compiler/Parsing.py":4224
 *     if s.sy == '.':
 *         error(pos, "Qualified class name not allowed C++ class")
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         s.next()
 *         templates = [p_template_definition(s)]
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4224, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4225
 *         error(pos, "Qualified class name not allowed C++ class")
 *     if s.sy == '[':
 *         s.next()             # <<<<<<<<<<<<<<
 *         templates = [p_template_definition(s)]
 *         while s.sy == ',':
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4226
 *     if s.sy == '[':
 *         s.next()
 *         templates = [p_template_definition(s)]             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_template_definition(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 4226, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_v_templates = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":4227
 *         s.next()
 *         templates = [p_template_definition(s)]
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             templates.append(p_template_definition(s))
*/
    while (1) {
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4227, __pyx_L1_error)
      if (!__pyx_t_4) break;

      /* "Cython/Compiler/Parsing.py":4228
 *         templates = [p_template_definition(s)]
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             templates.append(p_template_definition(s))
 *         s.expect(']')
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4228, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":4229
 *         while s.sy == ',':
 *             s.next()
 *             templates.append(p_template_definition(s))             # <<<<<<<<<<<<<<
 *         s.expect(']')
 *         template_names = [name for name, required in templates]
*/
      __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_template_definition(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_templates, __pyx_t_6); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4229, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }

    /* "Cython/Compiler/Parsing.py":4230
 *             s.next()
 *             templates.append(p_template_definition(s))
 *         s.expect(']')             # <<<<<<<<<<<<<<
 *         template_names = [name for name, required in templates]
 *     else:
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__30};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":4231
 *             templates.append(p_template_definition(s))
 *         s.expect(']')
 *         template_names = [name for name, required in templates]             # <<<<<<<<<<<<<<
 *     else:
 *         templates = None
*/
    { /* enter inner scope */
      __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4231, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __pyx_v_templates; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_8 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4231, __pyx_L12_error)
          #endif
          if (__pyx_t_8 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_8;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4231, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_2);
        if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
          PyObject* sequence = __pyx_t_2;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 4231, __pyx_L12_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_10);
          } else {
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4231, __pyx_L12_error)
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4231, __pyx_L12_error)
            __Pyx_XGOTREF(__pyx_t_10);
          }
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4231, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4231, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_11 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4231, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
          index = 0; __pyx_t_9 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_9)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 1; __pyx_t_10 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_10)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 2) < (0)) __PYX_ERR(0, 4231, __pyx_L12_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L16_unpacking_done;
          __pyx_L15_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 4231, __pyx_L12_error)
          __pyx_L16_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_name, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_required, __pyx_t_10);
        __pyx_t_10 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_6, (PyObject*)__pyx_8genexpr5__pyx_v_name))) __PYX_ERR(0, 4231, __pyx_L12_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_name); __pyx_8genexpr5__pyx_v_name = 0;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_required); __pyx_8genexpr5__pyx_v_required = 0;
      goto __pyx_L18_exit_scope;
      __pyx_L12_error:;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_name); __pyx_8genexpr5__pyx_v_name = 0;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_required); __pyx_8genexpr5__pyx_v_required = 0;
      goto __pyx_L1_error;
      __pyx_L18_exit_scope:;
    } /* exit inner scope */
    __pyx_v_template_names = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":4224
 *     if s.sy == '.':
 *         error(pos, "Qualified class name not allowed C++ class")
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         s.next()
 *         templates = [p_template_definition(s)]
*/
    goto __pyx_L7;
  }

  /* "Cython/Compiler/Parsing.py":4233
 *         template_names = [name for name, required in templates]
 *     else:
 *         templates = None             # <<<<<<<<<<<<<<
 *         template_names = None
 *     if s.sy == '(':
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_templates = ((PyObject*)Py_None);

    /* "Cython/Compiler/Parsing.py":4234
 *     else:
 *         templates = None
 *         template_names = None             # <<<<<<<<<<<<<<
 *     if s.sy == '(':
 *         s.next()
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_template_names = ((PyObject*)Py_None);
  }
  __pyx_L7:;

  /* "Cython/Compiler/Parsing.py":4235
 *         templates = None
 *         template_names = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         base_classes = [p_c_base_type(s, templates = template_names)]
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4235, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4236
 *         template_names = None
 *     if s.sy == '(':
 *         s.next()             # <<<<<<<<<<<<<<
 *         base_classes = [p_c_base_type(s, templates = template_names)]
 *         while s.sy == ',':
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Parsing.py":4237
 *     if s.sy == '(':
 *         s.next()
 *         base_classes = [p_c_base_type(s, templates = template_names)]             # <<<<<<<<<<<<<<
 *         while s.sy == ',':
 *             s.next()
*/
    __pyx_t_1 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, ((PyObject *)__pyx_v_s)};
      __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4237, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_template_names, __pyx_t_10, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4237, __pyx_L1_error)
      __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4237, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_6) != (0)) __PYX_ERR(0, 4237, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_v_base_classes = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4238
 *         s.next()
 *         base_classes = [p_c_base_type(s, templates = template_names)]
 *         while s.sy == ',':             # <<<<<<<<<<<<<<
 *             s.next()
 *             base_classes.append(p_c_base_type(s, templates = template_names))
*/
    while (1) {
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4238, __pyx_L1_error)
      if (!__pyx_t_4) break;

      /* "Cython/Compiler/Parsing.py":4239
 *         base_classes = [p_c_base_type(s, templates = template_names)]
 *         while s.sy == ',':
 *             s.next()             # <<<<<<<<<<<<<<
 *             base_classes.append(p_c_base_type(s, templates = template_names))
 *         s.expect(')')
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4239, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4240
 *         while s.sy == ',':
 *             s.next()
 *             base_classes.append(p_c_base_type(s, templates = template_names))             # <<<<<<<<<<<<<<
 *         s.expect(')')
 *     else:
*/
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_p_c_base_type); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, ((PyObject *)__pyx_v_s)};
        __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_template_names, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4240, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4240, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_base_classes, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "Cython/Compiler/Parsing.py":4241
 *             s.next()
 *             base_classes.append(p_c_base_type(s, templates = template_names))
 *         s.expect(')')             # <<<<<<<<<<<<<<
 *     else:
 *         base_classes = []
*/
    __pyx_t_10 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u__24};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4241, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4235
 *         templates = None
 *         template_names = None
 *     if s.sy == '(':             # <<<<<<<<<<<<<<
 *         s.next()
 *         base_classes = [p_c_base_type(s, templates = template_names)]
*/
    goto __pyx_L19;
  }

  /* "Cython/Compiler/Parsing.py":4243
 *         s.expect(')')
 *     else:
 *         base_classes = []             # <<<<<<<<<<<<<<
 *     if s.sy == '[':
 *         error(s.position(), "Name options not allowed for C++ class")
*/
  /*else*/ {
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_base_classes = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L19:;

  /* "Cython/Compiler/Parsing.py":4244
 *     else:
 *         base_classes = []
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         error(s.position(), "Name options not allowed for C++ class")
 *     nogil = p_nogil(s)
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4244, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4245
 *         base_classes = []
 *     if s.sy == '[':
 *         error(s.position(), "Name options not allowed for C++ class")             # <<<<<<<<<<<<<<
 *     nogil = p_nogil(s)
 *     if s.sy == ':':
*/
    __pyx_t_10 = NULL;
    __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_error; 
    __pyx_t_6 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_10);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Name_options_not_allowed_for_C_c};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4244
 *     else:
 *         base_classes = []
 *     if s.sy == '[':             # <<<<<<<<<<<<<<
 *         error(s.position(), "Name options not allowed for C++ class")
 *     nogil = p_nogil(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":4246
 *     if s.sy == '[':
 *         error(s.position(), "Name options not allowed for C++ class")
 *     nogil = p_nogil(s)             # <<<<<<<<<<<<<<
 *     if s.sy == ':':
 *         s.next()
*/
  __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_nogil(__pyx_v_s); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4246, __pyx_L1_error)
  __pyx_v_nogil = __pyx_t_4;

  /* "Cython/Compiler/Parsing.py":4247
 *         error(s.position(), "Name options not allowed for C++ class")
 *     nogil = p_nogil(s)
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect('NEWLINE')
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4247, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4248
 *     nogil = p_nogil(s)
 *     if s.sy == ':':
 *         s.next()             # <<<<<<<<<<<<<<
 *         s.expect('NEWLINE')
 *         s.expect_indent()
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4249
 *     if s.sy == ':':
 *         s.next()
 *         s.expect('NEWLINE')             # <<<<<<<<<<<<<<
 *         s.expect_indent()
 *         # Allow a cppclass to have docstrings. It will be discarded as comment.
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_NEWLINE};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4249, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4250
 *         s.next()
 *         s.expect('NEWLINE')
 *         s.expect_indent()             # <<<<<<<<<<<<<<
 *         # Allow a cppclass to have docstrings. It will be discarded as comment.
 *         # The goal of this is consistency: we can make docstrings inside cppclass methods,
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4254
 *         # The goal of this is consistency: we can make docstrings inside cppclass methods,
 *         # so why not on the cppclass itself ?
 *         p_doc_string(s)             # <<<<<<<<<<<<<<
 *         attributes = []
 *         body_ctx = Ctx(visibility = ctx.visibility, level='cpp_class', nogil=nogil or ctx.nogil)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_doc_string(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4255
 *         # so why not on the cppclass itself ?
 *         p_doc_string(s)
 *         attributes = []             # <<<<<<<<<<<<<<
 *         body_ctx = Ctx(visibility = ctx.visibility, level='cpp_class', nogil=nogil or ctx.nogil)
 *         body_ctx.templates = template_names
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_attributes = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4256
 *         p_doc_string(s)
 *         attributes = []
 *         body_ctx = Ctx(visibility = ctx.visibility, level='cpp_class', nogil=nogil or ctx.nogil)             # <<<<<<<<<<<<<<
 *         body_ctx.templates = template_names
 *         while s.sy != 'DEDENT':
*/
    __pyx_t_1 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (!__pyx_v_nogil) {
    } else {
      __pyx_t_11 = __Pyx_PyBool_FromLong(__pyx_v_nogil); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_9 = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_nogil); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_9 = __pyx_t_11;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_L24_bool_binop_done:;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_1, NULL};
      __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_10, __pyx_t_11, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 4256, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_cpp_class, __pyx_t_11, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 4256, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_nogil, __pyx_t_9, __pyx_t_11, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 4256, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_body_ctx = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4257
 *         attributes = []
 *         body_ctx = Ctx(visibility = ctx.visibility, level='cpp_class', nogil=nogil or ctx.nogil)
 *         body_ctx.templates = template_names             # <<<<<<<<<<<<<<
 *         while s.sy != 'DEDENT':
 *             if s.sy != 'pass':
*/
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_body_ctx, __pyx_mstate_global->__pyx_n_u_templates, __pyx_v_template_names) < (0)) __PYX_ERR(0, 4257, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":4258
 *         body_ctx = Ctx(visibility = ctx.visibility, level='cpp_class', nogil=nogil or ctx.nogil)
 *         body_ctx.templates = template_names
 *         while s.sy != 'DEDENT':             # <<<<<<<<<<<<<<
 *             if s.sy != 'pass':
 *                 attributes.append(p_cpp_class_attribute(s, body_ctx))
*/
    while (1) {
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4258, __pyx_L1_error)
      if (!__pyx_t_4) break;

      /* "Cython/Compiler/Parsing.py":4259
 *         body_ctx.templates = template_names
 *         while s.sy != 'DEDENT':
 *             if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *                 attributes.append(p_cpp_class_attribute(s, body_ctx))
 *             else:
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_pass, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4259, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":4260
 *         while s.sy != 'DEDENT':
 *             if s.sy != 'pass':
 *                 attributes.append(p_cpp_class_attribute(s, body_ctx))             # <<<<<<<<<<<<<<
 *             else:
 *                 s.next()
*/
        __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_attribute(__pyx_v_s, __pyx_v_body_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4260, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_attributes, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4260, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":4259
 *         body_ctx.templates = template_names
 *         while s.sy != 'DEDENT':
 *             if s.sy != 'pass':             # <<<<<<<<<<<<<<
 *                 attributes.append(p_cpp_class_attribute(s, body_ctx))
 *             else:
*/
        goto __pyx_L28;
      }

      /* "Cython/Compiler/Parsing.py":4262
 *                 attributes.append(p_cpp_class_attribute(s, body_ctx))
 *             else:
 *                 s.next()             # <<<<<<<<<<<<<<
 *                 s.expect_newline("Expected a newline")
 *         s.expect_dedent()
*/
      /*else*/ {
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4262, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":4263
 *             else:
 *                 s.next()
 *                 s.expect_newline("Expected a newline")             # <<<<<<<<<<<<<<
 *         s.expect_dedent()
 *     else:
*/
        __pyx_t_6 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Expected_a_newline};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4263, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L28:;
    }

    /* "Cython/Compiler/Parsing.py":4264
 *                 s.next()
 *                 s.expect_newline("Expected a newline")
 *         s.expect_dedent()             # <<<<<<<<<<<<<<
 *     else:
 *         attributes = None
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4264, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4247
 *         error(s.position(), "Name options not allowed for C++ class")
 *     nogil = p_nogil(s)
 *     if s.sy == ':':             # <<<<<<<<<<<<<<
 *         s.next()
 *         s.expect('NEWLINE')
*/
    goto __pyx_L23;
  }

  /* "Cython/Compiler/Parsing.py":4266
 *         s.expect_dedent()
 *     else:
 *         attributes = None             # <<<<<<<<<<<<<<
 *         s.expect_newline("Syntax error in C++ class definition")
 *     return Nodes.CppClassNode(pos,
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_attributes = ((PyObject*)Py_None);

    /* "Cython/Compiler/Parsing.py":4267
 *     else:
 *         attributes = None
 *         s.expect_newline("Syntax error in C++ class definition")             # <<<<<<<<<<<<<<
 *     return Nodes.CppClassNode(pos,
 *         name = class_name,
*/
    __pyx_t_6 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Syntax_error_in_C_class_definiti_2};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L23:;

  /* "Cython/Compiler/Parsing.py":4268
 *         attributes = None
 *         s.expect_newline("Syntax error in C++ class definition")
 *     return Nodes.CppClassNode(pos,             # <<<<<<<<<<<<<<
 *         name = class_name,
 *         cname = cname,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
  __Pyx_INCREF(__pyx_t_6);

  /* "Cython/Compiler/Parsing.py":4272
 *         cname = cname,
 *         base_classes = base_classes,
 *         visibility = ctx.visibility,             # <<<<<<<<<<<<<<
 *         in_pxd = ctx.level == 'module_pxd',
 *         attributes = attributes,
*/
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_visibility); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);

  /* "Cython/Compiler/Parsing.py":4273
 *         base_classes = base_classes,
 *         visibility = ctx.visibility,
 *         in_pxd = ctx.level == 'module_pxd',             # <<<<<<<<<<<<<<
 *         attributes = attributes,
 *         templates = templates)
*/
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_level); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = PyObject_RichCompare(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_module_pxd, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "Cython/Compiler/Parsing.py":4275
 *         in_pxd = ctx.level == 'module_pxd',
 *         attributes = attributes,
 *         templates = templates)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 7 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_v_class_name, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cname, __pyx_v_cname, __pyx_t_9, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_base_classes, __pyx_v_base_classes, __pyx_t_9, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_visibility, __pyx_t_11, __pyx_t_9, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_in_pxd, __pyx_t_10, __pyx_t_9, __pyx_callargs+2, 4) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_attributes, __pyx_v_attributes, __pyx_t_9, __pyx_callargs+2, 5) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_templates, __pyx_v_templates, __pyx_t_9, __pyx_callargs+2, 6) < (0)) __PYX_ERR(0, 4268, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_CppClassNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4214
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cpp_class_definition(s: PyrexScanner, pos,  ctx):
 *     # s.sy == 'cppclass'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cpp_class_definition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_XDECREF(__pyx_v_cname);
  __Pyx_XDECREF(__pyx_v_templates);
  __Pyx_XDECREF(__pyx_v_template_names);
  __Pyx_XDECREF(__pyx_v_base_classes);
  __Pyx_XDECREF(__pyx_v_attributes);
  __Pyx_XDECREF(__pyx_v_body_ctx);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_name);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_required);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4278
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cpp_class_attribute(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_attribute(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_decorators = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_cpp_class_attribute", 0);

  /* "Cython/Compiler/Parsing.py":4280
 * @cython.cfunc
 * def p_cpp_class_attribute(s: PyrexScanner, ctx):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     decorators = None
 *     if s.sy == '@':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4281
 * def p_cpp_class_attribute(s: PyrexScanner, ctx):
 *     pos = s.position()
 *     decorators = None             # <<<<<<<<<<<<<<
 *     if s.sy == '@':
 *         decorators = p_decorators(s)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_decorators = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":4282
 *     pos = s.position()
 *     decorators = None
 *     if s.sy == '@':             # <<<<<<<<<<<<<<
 *         decorators = p_decorators(s)
 *     if s.systring == 'cppclass':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__16, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4282, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4283
 *     decorators = None
 *     if s.sy == '@':
 *         decorators = p_decorators(s)             # <<<<<<<<<<<<<<
 *     if s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_decorators(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_decorators, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4282
 *     pos = s.position()
 *     decorators = None
 *     if s.sy == '@':             # <<<<<<<<<<<<<<
 *         decorators = p_decorators(s)
 *     if s.systring == 'cppclass':
*/
  }

  /* "Cython/Compiler/Parsing.py":4284
 *     if s.sy == '@':
 *         decorators = p_decorators(s)
 *     if s.systring == 'cppclass':             # <<<<<<<<<<<<<<
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.systring == 'ctypedef':
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_cppclass, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4284, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4285
 *         decorators = p_decorators(s)
 *     if s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     elif s.systring == 'ctypedef':
 *         return p_ctypedef_statement(s, ctx)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4284
 *     if s.sy == '@':
 *         decorators = p_decorators(s)
 *     if s.systring == 'cppclass':             # <<<<<<<<<<<<<<
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.systring == 'ctypedef':
*/
  }

  /* "Cython/Compiler/Parsing.py":4286
 *     if s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.systring == 'ctypedef':             # <<<<<<<<<<<<<<
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_ctypedef, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4286, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4287
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.systring == 'ctypedef':
 *         return p_ctypedef_statement(s, ctx)             # <<<<<<<<<<<<<<
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if s.systring != 'enum':
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_ctypedef_statement(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4286
 *     if s.systring == 'cppclass':
 *         return p_cpp_class_definition(s, pos, ctx)
 *     elif s.systring == 'ctypedef':             # <<<<<<<<<<<<<<
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
*/
  }

  /* "Cython/Compiler/Parsing.py":4288
 *     elif s.systring == 'ctypedef':
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         if s.systring != 'enum':
 *             return p_cpp_class_definition(s, pos, ctx)
*/
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4288, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_s->systring, __pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4288, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4289
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if s.systring != 'enum':             # <<<<<<<<<<<<<<
 *             return p_cpp_class_definition(s, pos, ctx)
 *         else:
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_enum, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4289, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":4290
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if s.systring != 'enum':
 *             return p_cpp_class_definition(s, pos, ctx)             # <<<<<<<<<<<<<<
 *         else:
 *             return p_struct_enum(s, pos, ctx)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_cpp_class_definition(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":4289
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:
 *         if s.systring != 'enum':             # <<<<<<<<<<<<<<
 *             return p_cpp_class_definition(s, pos, ctx)
 *         else:
*/
    }

    /* "Cython/Compiler/Parsing.py":4292
 *             return p_cpp_class_definition(s, pos, ctx)
 *         else:
 *             return p_struct_enum(s, pos, ctx)             # <<<<<<<<<<<<<<
 *     else:
 *         node = p_c_func_or_var_declaration(s, pos, ctx)
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_struct_enum(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "Cython/Compiler/Parsing.py":4288
 *     elif s.systring == 'ctypedef':
 *         return p_ctypedef_statement(s, ctx)
 *     elif s.sy == 'IDENT' and s.systring in struct_enum_union:             # <<<<<<<<<<<<<<
 *         if s.systring != 'enum':
 *             return p_cpp_class_definition(s, pos, ctx)
*/
  }

  /* "Cython/Compiler/Parsing.py":4294
 *             return p_struct_enum(s, pos, ctx)
 *     else:
 *         node = p_c_func_or_var_declaration(s, pos, ctx)             # <<<<<<<<<<<<<<
 *         if decorators is not None:
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
*/
  /*else*/ {
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_c_func_or_var_declaration(__pyx_v_s, __pyx_v_pos, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4295
 *     else:
 *         node = p_c_func_or_var_declaration(s, pos, ctx)
 *         if decorators is not None:             # <<<<<<<<<<<<<<
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
 *             if ctx.allow_struct_enum_decorator:
*/
    __pyx_t_2 = (__pyx_v_decorators != ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "Cython/Compiler/Parsing.py":4296
 *         node = p_c_func_or_var_declaration(s, pos, ctx)
 *         if decorators is not None:
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode             # <<<<<<<<<<<<<<
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CFuncDefNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CVarDefNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CClassDefNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 4296, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 4296, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 4296, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_v_tup = ((PyObject*)__pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":4297
 *         if decorators is not None:
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
 *             if ctx.allow_struct_enum_decorator:             # <<<<<<<<<<<<<<
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
 *             if not isinstance(node, tup):
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_allow_struct_enum_decorator); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4297, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4297, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Parsing.py":4298
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode             # <<<<<<<<<<<<<<
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CStructOrUnionDefNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_CEnumDefNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6) != (0)) __PYX_ERR(0, 4298, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5) != (0)) __PYX_ERR(0, 4298, __pyx_L1_error);
        __pyx_t_6 = 0;
        __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_tup, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_tup, ((PyObject*)__pyx_t_5));
        __pyx_t_5 = 0;

        /* "Cython/Compiler/Parsing.py":4297
 *         if decorators is not None:
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
 *             if ctx.allow_struct_enum_decorator:             # <<<<<<<<<<<<<<
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
 *             if not isinstance(node, tup):
*/
      }

      /* "Cython/Compiler/Parsing.py":4299
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
 *             if not isinstance(node, tup):             # <<<<<<<<<<<<<<
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
*/
      __pyx_t_2 = PyObject_IsInstance(__pyx_v_node, __pyx_v_tup); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4299, __pyx_L1_error)
      __pyx_t_3 = (!__pyx_t_2);
      if (__pyx_t_3) {

        /* "Cython/Compiler/Parsing.py":4300
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")             # <<<<<<<<<<<<<<
 *             node.decorators = decorators
 *         return node
*/
        __pyx_t_4 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Decorators_can_only_be_followed};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "Cython/Compiler/Parsing.py":4299
 *             if ctx.allow_struct_enum_decorator:
 *                 tup += Nodes.CStructOrUnionDefNode, Nodes.CEnumDefNode
 *             if not isinstance(node, tup):             # <<<<<<<<<<<<<<
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
*/
      }

      /* "Cython/Compiler/Parsing.py":4301
 *             if not isinstance(node, tup):
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_decorators, __pyx_v_decorators) < (0)) __PYX_ERR(0, 4301, __pyx_L1_error)

      /* "Cython/Compiler/Parsing.py":4295
 *     else:
 *         node = p_c_func_or_var_declaration(s, pos, ctx)
 *         if decorators is not None:             # <<<<<<<<<<<<<<
 *             tup = Nodes.CFuncDefNode, Nodes.CVarDefNode, Nodes.CClassDefNode
 *             if ctx.allow_struct_enum_decorator:
*/
    }

    /* "Cython/Compiler/Parsing.py":4302
 *                 s.error("Decorators can only be followed by functions or classes")
 *             node.decorators = decorators
 *         return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":4278
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_cpp_class_attribute(s: PyrexScanner, ctx):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_cpp_class_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_decorators);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4305
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_match_statement(s: PyrexScanner, ctx):
 *     assert s.sy == "IDENT" and s.systring == "match"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_match_statement(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_subject = NULL;
  PyObject *__pyx_v_subjects = NULL;
  PyObject *__pyx_v_cases = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_match_statement", 0);

  /* "Cython/Compiler/Parsing.py":4307
 * @cython.cfunc
 * def p_match_statement(s: PyrexScanner, ctx):
 *     assert s.sy == "IDENT" and s.systring == "match"             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     with tentatively_scan(s) as errors:
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4307, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L3_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_match, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4307, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L3_bool_binop_done:;
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 4307, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 4307, __pyx_L1_error)
  #endif

  /* "Cython/Compiler/Parsing.py":4308
 * def p_match_statement(s: PyrexScanner, ctx):
 *     assert s.sy == "IDENT" and s.systring == "match"
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     with tentatively_scan(s) as errors:
 *         s.next()
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_pos = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4309
 *     assert s.sy == "IDENT" and s.systring == "match"
 *     pos = s.position()
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         s.next()
 *         subject = p_namedexpr_test(s)
*/
  /*with:*/ {
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_s)};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = NULL;
    __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4309, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4309, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_t_8 = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {
          __pyx_v_errors = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "Cython/Compiler/Parsing.py":4310
 *     pos = s.position()
 *     with tentatively_scan(s) as errors:
 *         s.next()             # <<<<<<<<<<<<<<
 *         subject = p_namedexpr_test(s)
 *         subjects = None
*/
          __pyx_t_3 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4310, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "Cython/Compiler/Parsing.py":4311
 *     with tentatively_scan(s) as errors:
 *         s.next()
 *         subject = p_namedexpr_test(s)             # <<<<<<<<<<<<<<
 *         subjects = None
 *         if s.sy == ",":
*/
          __pyx_t_8 = __pyx_f_6Cython_8Compiler_7Parsing_p_namedexpr_test(__pyx_v_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4311, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_v_subject = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "Cython/Compiler/Parsing.py":4312
 *         s.next()
 *         subject = p_namedexpr_test(s)
 *         subjects = None             # <<<<<<<<<<<<<<
 *         if s.sy == ",":
 *             subjects = [subject]
*/
          __Pyx_INCREF(Py_None);
          __pyx_v_subjects = ((PyObject*)Py_None);

          /* "Cython/Compiler/Parsing.py":4313
 *         subject = p_namedexpr_test(s)
 *         subjects = None
 *         if s.sy == ",":             # <<<<<<<<<<<<<<
 *             subjects = [subject]
 *         while s.sy == ",":
*/
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4313, __pyx_L9_error)
          if (__pyx_t_1) {

            /* "Cython/Compiler/Parsing.py":4314
 *         subjects = None
 *         if s.sy == ",":
 *             subjects = [subject]             # <<<<<<<<<<<<<<
 *         while s.sy == ",":
 *             s.next()
*/
            __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4314, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_INCREF(__pyx_v_subject);
            __Pyx_GIVEREF(__pyx_v_subject);
            if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_subject) != (0)) __PYX_ERR(0, 4314, __pyx_L9_error);
            __Pyx_DECREF_SET(__pyx_v_subjects, ((PyObject*)__pyx_t_8));
            __pyx_t_8 = 0;

            /* "Cython/Compiler/Parsing.py":4313
 *         subject = p_namedexpr_test(s)
 *         subjects = None
 *         if s.sy == ",":             # <<<<<<<<<<<<<<
 *             subjects = [subject]
 *         while s.sy == ",":
*/
          }

          /* "Cython/Compiler/Parsing.py":4315
 *         if s.sy == ",":
 *             subjects = [subject]
 *         while s.sy == ",":             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy == ":":
*/
          while (1) {
            __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4315, __pyx_L9_error)
            if (!__pyx_t_1) break;

            /* "Cython/Compiler/Parsing.py":4316
 *             subjects = [subject]
 *         while s.sy == ",":
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy == ":":
 *                 break
*/
            __pyx_t_3 = ((PyObject *)__pyx_v_s);
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
              __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4316, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

            /* "Cython/Compiler/Parsing.py":4317
 *         while s.sy == ",":
 *             s.next()
 *             if s.sy == ":":             # <<<<<<<<<<<<<<
 *                 break
 *             subjects.append(p_test(s))
*/
            __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4317, __pyx_L9_error)
            if (__pyx_t_1) {

              /* "Cython/Compiler/Parsing.py":4318
 *             s.next()
 *             if s.sy == ":":
 *                 break             # <<<<<<<<<<<<<<
 *             subjects.append(p_test(s))
 *         if subjects is not None:
*/
              goto __pyx_L17_break;

              /* "Cython/Compiler/Parsing.py":4317
 *         while s.sy == ",":
 *             s.next()
 *             if s.sy == ":":             # <<<<<<<<<<<<<<
 *                 break
 *             subjects.append(p_test(s))
*/
            }

            /* "Cython/Compiler/Parsing.py":4319
 *             if s.sy == ":":
 *                 break
 *             subjects.append(p_test(s))             # <<<<<<<<<<<<<<
 *         if subjects is not None:
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
*/
            if (unlikely(__pyx_v_subjects == Py_None)) {
              PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
              __PYX_ERR(0, 4319, __pyx_L9_error)
            }
            __pyx_t_8 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4319, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_subjects, __pyx_t_8); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 4319, __pyx_L9_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_L17_break:;

          /* "Cython/Compiler/Parsing.py":4320
 *                 break
 *             subjects.append(p_test(s))
 *         if subjects is not None:             # <<<<<<<<<<<<<<
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
 *         s.expect(":")
*/
          __pyx_t_1 = (__pyx_v_subjects != ((PyObject*)Py_None));
          if (__pyx_t_1) {

            /* "Cython/Compiler/Parsing.py":4321
 *             subjects.append(p_test(s))
 *         if subjects is not None:
 *             subject = ExprNodes.TupleNode(pos, args=subjects)             # <<<<<<<<<<<<<<
 *         s.expect(":")
 *     if errors:
*/
            __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
              __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4321, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_5);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_args, __pyx_v_subjects, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4321, __pyx_L9_error)
              __pyx_t_8 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_TupleNode, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4321, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __Pyx_DECREF_SET(__pyx_v_subject, __pyx_t_8);
            __pyx_t_8 = 0;

            /* "Cython/Compiler/Parsing.py":4320
 *                 break
 *             subjects.append(p_test(s))
 *         if subjects is not None:             # <<<<<<<<<<<<<<
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
 *         s.expect(":")
*/
          }

          /* "Cython/Compiler/Parsing.py":4322
 *         if subjects is not None:
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
 *         s.expect(":")             # <<<<<<<<<<<<<<
 *     if errors:
 *         return None
*/
          __pyx_t_5 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_5);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__3};
            __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4322, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "Cython/Compiler/Parsing.py":4309
 *     assert s.sy == "IDENT" and s.systring == "match"
 *     pos = s.position()
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         s.next()
 *         subject = p_namedexpr_test(s)
*/
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L14_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Compiler.Parsing.p_match_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 4309, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_4 = PyTuple_Pack(3, __pyx_t_8, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4309, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, NULL);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4309, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_1 < (0)) __PYX_ERR(0, 4309, __pyx_L11_except_error)
          __pyx_t_2 = (!__pyx_t_1);
          if (unlikely(__pyx_t_2)) {
            __Pyx_GIVEREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_5);
            __Pyx_XGIVEREF(__pyx_t_3);
            __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_5, __pyx_t_3);
            __pyx_t_8 = 0;  __pyx_t_5 = 0;  __pyx_t_3 = 0; 
            __PYX_ERR(0, 4309, __pyx_L11_except_error)
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L10_exception_handled;
        }
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L1_error;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_L14_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_7) {
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4309, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    goto __pyx_L23;
    __pyx_L5_error:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L1_error;
    __pyx_L23:;
  }

  /* "Cython/Compiler/Parsing.py":4323
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
 *         s.expect(":")
 *     if errors:             # <<<<<<<<<<<<<<
 *         return None
 * 
*/
  if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4323, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4323, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4324
 *         s.expect(":")
 *     if errors:
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     # at this stage we are committed to it being a match block so continue
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4323
 *             subject = ExprNodes.TupleNode(pos, args=subjects)
 *         s.expect(":")
 *     if errors:             # <<<<<<<<<<<<<<
 *         return None
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":4330
 *     # (I think this deviates from the PEG parser slightly, and it'd
 *     # backtrack on the whole thing)
 *     s.expect_newline()             # <<<<<<<<<<<<<<
 *     s.expect_indent()
 *     cases = []
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_newline, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4331
 *     # backtrack on the whole thing)
 *     s.expect_newline()
 *     s.expect_indent()             # <<<<<<<<<<<<<<
 *     cases = []
 *     while s.sy != "DEDENT":
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_indent, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4331, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4332
 *     s.expect_newline()
 *     s.expect_indent()
 *     cases = []             # <<<<<<<<<<<<<<
 *     while s.sy != "DEDENT":
 *         cases.append(p_case_block(s, ctx))
*/
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_cases = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4333
 *     s.expect_indent()
 *     cases = []
 *     while s.sy != "DEDENT":             # <<<<<<<<<<<<<<
 *         cases.append(p_case_block(s, ctx))
 *     s.expect_dedent()
*/
  while (1) {
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_DEDENT, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4333, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "Cython/Compiler/Parsing.py":4334
 *     cases = []
 *     while s.sy != "DEDENT":
 *         cases.append(p_case_block(s, ctx))             # <<<<<<<<<<<<<<
 *     s.expect_dedent()
 *     return MatchCaseNodes.MatchNode(pos, subject=subject, cases=cases)
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_case_block(__pyx_v_s, __pyx_v_ctx); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_cases, __pyx_t_3); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 4334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }

  /* "Cython/Compiler/Parsing.py":4335
 *     while s.sy != "DEDENT":
 *         cases.append(p_case_block(s, ctx))
 *     s.expect_dedent()             # <<<<<<<<<<<<<<
 *     return MatchCaseNodes.MatchNode(pos, subject=subject, cases=cases)
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect_dedent, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4336
 *         cases.append(p_case_block(s, ctx))
 *     s.expect_dedent()
 *     return MatchCaseNodes.MatchNode(pos, subject=subject, cases=cases)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_MatchNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_v_subject)) { __Pyx_RaiseUnboundLocalError("subject"); __PYX_ERR(0, 4336, __pyx_L1_error) }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_subject, __pyx_v_subject, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4336, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cases, __pyx_v_cases, __pyx_t_8, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4336, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4305
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_match_statement(s: PyrexScanner, ctx):
 *     assert s.sy == "IDENT" and s.systring == "match"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_match_statement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_subject);
  __Pyx_XDECREF(__pyx_v_subjects);
  __Pyx_XDECREF(__pyx_v_cases);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4339
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_case_block(s: PyrexScanner, ctx):
 *     if not (s.sy == "IDENT" and s.systring == "case"):
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_case_block(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_guard = NULL;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_p_suite __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_case_block", 0);

  /* "Cython/Compiler/Parsing.py":4341
 * @cython.cfunc
 * def p_case_block(s: PyrexScanner, ctx):
 *     if not (s.sy == "IDENT" and s.systring == "case"):             # <<<<<<<<<<<<<<
 *         s.expected("case")
 *     s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4341, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_case, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4341, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4342
 * def p_case_block(s: PyrexScanner, ctx):
 *     if not (s.sy == "IDENT" and s.systring == "case"):
 *         s.expected("case")             # <<<<<<<<<<<<<<
 *     s.next()
 *     pos = s.position()
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_case};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expected, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4342, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4341
 * @cython.cfunc
 * def p_case_block(s: PyrexScanner, ctx):
 *     if not (s.sy == "IDENT" and s.systring == "case"):             # <<<<<<<<<<<<<<
 *         s.expected("case")
 *     s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4343
 *     if not (s.sy == "IDENT" and s.systring == "case"):
 *         s.expected("case")
 *     s.next()             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     pattern = p_patterns(s)
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4344
 *         s.expected("case")
 *     s.next()
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     pattern = p_patterns(s)
 *     guard = None
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_pos = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4345
 *     s.next()
 *     pos = s.position()
 *     pattern = p_patterns(s)             # <<<<<<<<<<<<<<
 *     guard = None
 *     if s.sy == 'if':
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_patterns(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_pattern = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4346
 *     pos = s.position()
 *     pattern = p_patterns(s)
 *     guard = None             # <<<<<<<<<<<<<<
 *     if s.sy == 'if':
 *         s.next()
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_guard = Py_None;

  /* "Cython/Compiler/Parsing.py":4347
 *     pattern = p_patterns(s)
 *     guard = None
 *     if s.sy == 'if':             # <<<<<<<<<<<<<<
 *         s.next()
 *         guard = p_test(s)
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_if, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4347, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "Cython/Compiler/Parsing.py":4348
 *     guard = None
 *     if s.sy == 'if':
 *         s.next()             # <<<<<<<<<<<<<<
 *         guard = p_test(s)
 *     body = p_suite(s, ctx)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4348, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4349
 *     if s.sy == 'if':
 *         s.next()
 *         guard = p_test(s)             # <<<<<<<<<<<<<<
 *     body = p_suite(s, ctx)
 * 
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4349, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_guard, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4347
 *     pattern = p_patterns(s)
 *     guard = None
 *     if s.sy == 'if':             # <<<<<<<<<<<<<<
 *         s.next()
 *         guard = p_test(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":4350
 *         s.next()
 *         guard = p_test(s)
 *     body = p_suite(s, ctx)             # <<<<<<<<<<<<<<
 * 
 *     return MatchCaseNodes.MatchCaseNode(pos, pattern=pattern, body=body, guard=guard)
*/
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.ctx = __pyx_v_ctx;
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_suite(__pyx_v_s, &__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_body = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4352
 *     body = p_suite(s, ctx)
 * 
 *     return MatchCaseNodes.MatchCaseNode(pos, pattern=pattern, body=body, guard=guard)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_MatchCaseNode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_4, __pyx_v_pos};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pattern, __pyx_v_pattern, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_guard, __pyx_v_guard, __pyx_t_7, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4352, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4339
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_case_block(s: PyrexScanner, ctx):
 *     if not (s.sy == "IDENT" and s.systring == "case"):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_case_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_guard);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4355
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_patterns(s: PyrexScanner):
 *     # note - in slight contrast to the name (which comes from the Python grammar),
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_patterns(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_patterns = NULL;
  int __pyx_v_seq;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_patterns", 0);

  /* "Cython/Compiler/Parsing.py":4359
 *     # note - in slight contrast to the name (which comes from the Python grammar),
 *     # returns a single pattern
 *     patterns = []             # <<<<<<<<<<<<<<
 *     seq = False
 *     pos = s.position()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_patterns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4360
 *     # returns a single pattern
 *     patterns = []
 *     seq = False             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     while True:
*/
  __pyx_v_seq = 0;

  /* "Cython/Compiler/Parsing.py":4361
 *     patterns = []
 *     seq = False
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     while True:
 *         with tentatively_scan(s) as errors:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4362
 *     seq = False
 *     pos = s.position()
 *     while True:             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             pattern = p_maybe_star_pattern(s)
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":4363
 *     pos = s.position()
 *     while True:
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:
*/
    /*with:*/ {
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = NULL;
      __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4363, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4363, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_6 = __pyx_t_3;
      __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          /*try:*/ {
            __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_6);
            __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4364
 *     while True:
 *         with tentatively_scan(s) as errors:
 *             pattern = p_maybe_star_pattern(s)             # <<<<<<<<<<<<<<
 *         if errors:
 *             if patterns:
*/
            __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_maybe_star_pattern(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4364, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_XDECREF_SET(__pyx_v_pattern, __pyx_t_6);
            __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4363
 *     pos = s.position()
 *     while True:
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:
*/
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L18_try_end;
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_patterns", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 4363, __pyx_L13_except_error)
            __Pyx_XGOTREF(__pyx_t_6);
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_3);
            __pyx_t_2 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4363, __pyx_L13_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4363, __pyx_L13_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (__pyx_t_11 < (0)) __PYX_ERR(0, 4363, __pyx_L13_except_error)
            __pyx_t_12 = (!__pyx_t_11);
            if (unlikely(__pyx_t_12)) {
              __Pyx_GIVEREF(__pyx_t_6);
              __Pyx_GIVEREF(__pyx_t_1);
              __Pyx_XGIVEREF(__pyx_t_3);
              __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_1, __pyx_t_3);
              __pyx_t_6 = 0;  __pyx_t_1 = 0;  __pyx_t_3 = 0; 
              __PYX_ERR(0, 4363, __pyx_L13_except_error)
            }
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            goto __pyx_L12_exception_handled;
          }
          __pyx_L13_except_error:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L1_error;
          __pyx_L12_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          __pyx_L18_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_5) {
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4363, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
      goto __pyx_L22;
      __pyx_L5_error:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L1_error;
      __pyx_L22:;
    }

    /* "Cython/Compiler/Parsing.py":4365
 *         with tentatively_scan(s) as errors:
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:             # <<<<<<<<<<<<<<
 *             if patterns:
 *                 break  # all is good provided we have at least 1 pattern
*/
    if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4365, __pyx_L1_error) }
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 4365, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "Cython/Compiler/Parsing.py":4366
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:
 *             if patterns:             # <<<<<<<<<<<<<<
 *                 break  # all is good provided we have at least 1 pattern
 *             else:
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_patterns);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 4366, __pyx_L1_error)
        __pyx_t_12 = (__pyx_temp != 0);
      }

      if (__pyx_t_12) {

        /* "Cython/Compiler/Parsing.py":4367
 *         if errors:
 *             if patterns:
 *                 break  # all is good provided we have at least 1 pattern             # <<<<<<<<<<<<<<
 *             else:
 *                 e = errors[0]
*/
        goto __pyx_L4_break;

        /* "Cython/Compiler/Parsing.py":4366
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:
 *             if patterns:             # <<<<<<<<<<<<<<
 *                 break  # all is good provided we have at least 1 pattern
 *             else:
*/
      }

      /* "Cython/Compiler/Parsing.py":4369
 *                 break  # all is good provided we have at least 1 pattern
 *             else:
 *                 e = errors[0]             # <<<<<<<<<<<<<<
 *                 s.error(e.args[1], pos=e.args[0])
 *         patterns.append(pattern)
*/
      /*else*/ {
        if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4369, __pyx_L1_error) }
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_errors, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4369, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Compiler/Parsing.py":4370
 *             else:
 *                 e = errors[0]
 *                 s.error(e.args[1], pos=e.args[0])             # <<<<<<<<<<<<<<
 *         patterns.append(pattern)
 * 
*/
        __pyx_t_1 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4370, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_6, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4370, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4370, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_13 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4370, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_4 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_t_2};
          __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4370, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pos, __pyx_t_13, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4370, __pyx_L1_error)
          __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4370, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }

      /* "Cython/Compiler/Parsing.py":4365
 *         with tentatively_scan(s) as errors:
 *             pattern = p_maybe_star_pattern(s)
 *         if errors:             # <<<<<<<<<<<<<<
 *             if patterns:
 *                 break  # all is good provided we have at least 1 pattern
*/
    }

    /* "Cython/Compiler/Parsing.py":4371
 *                 e = errors[0]
 *                 s.error(e.args[1], pos=e.args[0])
 *         patterns.append(pattern)             # <<<<<<<<<<<<<<
 * 
 *         if s.sy == ",":
*/
    if (unlikely(!__pyx_v_pattern)) { __Pyx_RaiseUnboundLocalError("pattern"); __PYX_ERR(0, 4371, __pyx_L1_error) }
    __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_patterns, __pyx_v_pattern); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 4371, __pyx_L1_error)

    /* "Cython/Compiler/Parsing.py":4373
 *         patterns.append(pattern)
 * 
 *         if s.sy == ",":             # <<<<<<<<<<<<<<
 *             seq = True
 *             s.next()
*/
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 4373, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "Cython/Compiler/Parsing.py":4374
 * 
 *         if s.sy == ",":
 *             seq = True             # <<<<<<<<<<<<<<
 *             s.next()
 *             if s.sy in [":", "if"]:
*/
      __pyx_v_seq = 1;

      /* "Cython/Compiler/Parsing.py":4375
 *         if s.sy == ",":
 *             seq = True
 *             s.next()             # <<<<<<<<<<<<<<
 *             if s.sy in [":", "if"]:
 *                 break  # common reasons to break
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4375, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "Cython/Compiler/Parsing.py":4376
 *             seq = True
 *             s.next()
 *             if s.sy in [":", "if"]:             # <<<<<<<<<<<<<<
 *                 break  # common reasons to break
 *         else:
*/
      __Pyx_INCREF(__pyx_v_s->sy);
      __pyx_t_15 = __pyx_v_s->sy;
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_mstate_global->__pyx_kp_u__3, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 4376, __pyx_L1_error)
      if (!__pyx_t_11) {
      } else {
        __pyx_t_12 = __pyx_t_11;
        goto __pyx_L27_bool_binop_done;
      }
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_if, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 4376, __pyx_L1_error)
      __pyx_t_12 = __pyx_t_11;
      __pyx_L27_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_11 = __pyx_t_12;
      if (__pyx_t_11) {

        /* "Cython/Compiler/Parsing.py":4377
 *             s.next()
 *             if s.sy in [":", "if"]:
 *                 break  # common reasons to break             # <<<<<<<<<<<<<<
 *         else:
 *             break
*/
        goto __pyx_L4_break;

        /* "Cython/Compiler/Parsing.py":4376
 *             seq = True
 *             s.next()
 *             if s.sy in [":", "if"]:             # <<<<<<<<<<<<<<
 *                 break  # common reasons to break
 *         else:
*/
      }

      /* "Cython/Compiler/Parsing.py":4373
 *         patterns.append(pattern)
 * 
 *         if s.sy == ",":             # <<<<<<<<<<<<<<
 *             seq = True
 *             s.next()
*/
      goto __pyx_L25;
    }

    /* "Cython/Compiler/Parsing.py":4379
 *                 break  # common reasons to break
 *         else:
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if seq:
*/
    /*else*/ {
      goto __pyx_L4_break;
    }
    __pyx_L25:;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":4381
 *             break
 * 
 *     if seq:             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
 *     else:
*/
  if (__pyx_v_seq) {

    /* "Cython/Compiler/Parsing.py":4382
 * 
 *     if seq:
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)             # <<<<<<<<<<<<<<
 *     else:
 *         return patterns[0]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_MatchSequencePatternNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, __pyx_v_pos};
      __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_patterns, __pyx_v_patterns, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4382, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4381
 *             break
 * 
 *     if seq:             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
 *     else:
*/
  }

  /* "Cython/Compiler/Parsing.py":4384
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
 *     else:
 *         return patterns[0]             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_patterns, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":4355
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_patterns(s: PyrexScanner):
 *     # note - in slight contrast to the name (which comes from the Python grammar),
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_patterns", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_patterns);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4387
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_maybe_star_pattern(s: PyrexScanner):
 *     # For match case. Either star_pattern or pattern
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_maybe_star_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_maybe_star_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4390
 * def p_maybe_star_pattern(s: PyrexScanner):
 *     # For match case. Either star_pattern or pattern
 *     if s.sy == "*":             # <<<<<<<<<<<<<<
 *         # star pattern
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4390, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4392
 *     if s.sy == "*":
 *         # star pattern
 *         s.next()             # <<<<<<<<<<<<<<
 *         target = None
 *         if s.systring != "_":  # for match-case '_' is treated as a special wildcard
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4393
 *         # star pattern
 *         s.next()
 *         target = None             # <<<<<<<<<<<<<<
 *         if s.systring != "_":  # for match-case '_' is treated as a special wildcard
 *             target = p_pattern_capture_target(s)
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_target = Py_None;

    /* "Cython/Compiler/Parsing.py":4394
 *         s.next()
 *         target = None
 *         if s.systring != "_":  # for match-case '_' is treated as a special wildcard             # <<<<<<<<<<<<<<
 *             target = p_pattern_capture_target(s)
 *         else:
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u__57, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4394, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4395
 *         target = None
 *         if s.systring != "_":  # for match-case '_' is treated as a special wildcard
 *             target = p_pattern_capture_target(s)             # <<<<<<<<<<<<<<
 *         else:
 *             s.next()
*/
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_target, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4394
 *         s.next()
 *         target = None
 *         if s.systring != "_":  # for match-case '_' is treated as a special wildcard             # <<<<<<<<<<<<<<
 *             target = p_pattern_capture_target(s)
 *         else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Parsing.py":4397
 *             target = p_pattern_capture_target(s)
 *         else:
 *             s.next()             # <<<<<<<<<<<<<<
 *         pattern = MatchCaseNodes.MatchAndAssignPatternNode(
 *             s.position(), target=target, is_star=True
*/
    /*else*/ {
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Parsing.py":4398
 *         else:
 *             s.next()
 *         pattern = MatchCaseNodes.MatchAndAssignPatternNode(             # <<<<<<<<<<<<<<
 *             s.position(), target=target, is_star=True
 *         )
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchAndAssignPatternNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Parsing.py":4399
 *             s.next()
 *         pattern = MatchCaseNodes.MatchAndAssignPatternNode(
 *             s.position(), target=target, is_star=True             # <<<<<<<<<<<<<<
 *         )
 *         return pattern
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_target, __pyx_v_target, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4398, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_star, Py_True, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4398, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_pattern = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4401
 *             s.position(), target=target, is_star=True
 *         )
 *         return pattern             # <<<<<<<<<<<<<<
 *     else:
 *         pattern = p_pattern(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_pattern);
    __pyx_r = __pyx_v_pattern;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4390
 * def p_maybe_star_pattern(s: PyrexScanner):
 *     # For match case. Either star_pattern or pattern
 *     if s.sy == "*":             # <<<<<<<<<<<<<<
 *         # star pattern
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4403
 *         return pattern
 *     else:
 *         pattern = p_pattern(s)             # <<<<<<<<<<<<<<
 *         return pattern
 * 
*/
  /*else*/ {
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_pattern = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4404
 *     else:
 *         pattern = p_pattern(s)
 *         return pattern             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_pattern);
    __pyx_r = __pyx_v_pattern;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Parsing.py":4387
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_maybe_star_pattern(s: PyrexScanner):
 *     # For match case. Either star_pattern or pattern
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_maybe_star_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4407
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pattern(s: PyrexScanner):
 *     # try "as_pattern" then "or_pattern"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_patterns = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4411
 *     # try "as_pattern" then "or_pattern"
 *     # (but practically "as_pattern" starts with "or_pattern" too)
 *     patterns = []             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     while True:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_patterns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4412
 *     # (but practically "as_pattern" starts with "or_pattern" too)
 *     patterns = []
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     while True:
 *         patterns.append(p_closed_pattern(s))
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4413
 *     patterns = []
 *     pos = s.position()
 *     while True:             # <<<<<<<<<<<<<<
 *         patterns.append(p_closed_pattern(s))
 *         if s.sy != "|":
*/
  while (1) {

    /* "Cython/Compiler/Parsing.py":4414
 *     pos = s.position()
 *     while True:
 *         patterns.append(p_closed_pattern(s))             # <<<<<<<<<<<<<<
 *         if s.sy != "|":
 *             break
*/
    __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_closed_pattern(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_patterns, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4415
 *     while True:
 *         patterns.append(p_closed_pattern(s))
 *         if s.sy != "|":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__9, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4415, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Parsing.py":4416
 *         patterns.append(p_closed_pattern(s))
 *         if s.sy != "|":
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 * 
*/
      goto __pyx_L4_break;

      /* "Cython/Compiler/Parsing.py":4415
 *     while True:
 *         patterns.append(p_closed_pattern(s))
 *         if s.sy != "|":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":4417
 *         if s.sy != "|":
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 * 
 *     if len(patterns) > 1:
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "Cython/Compiler/Parsing.py":4419
 *         s.next()
 * 
 *     if len(patterns) > 1:             # <<<<<<<<<<<<<<
 *         pattern = MatchCaseNodes.OrPatternNode(
 *             pos,
*/
  __pyx_t_6 = __Pyx_PyList_GET_SIZE(__pyx_v_patterns); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4419, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_6 > 1);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":4420
 * 
 *     if len(patterns) > 1:
 *         pattern = MatchCaseNodes.OrPatternNode(             # <<<<<<<<<<<<<<
 *             pos,
 *             alternatives=patterns
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_OrPatternNode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "Cython/Compiler/Parsing.py":4422
 *         pattern = MatchCaseNodes.OrPatternNode(
 *             pos,
 *             alternatives=patterns             # <<<<<<<<<<<<<<
 *         )
 *     else:
*/
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_alternatives, __pyx_v_patterns, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4420, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_pattern = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4419
 *         s.next()
 * 
 *     if len(patterns) > 1:             # <<<<<<<<<<<<<<
 *         pattern = MatchCaseNodes.OrPatternNode(
 *             pos,
*/
    goto __pyx_L6;
  }

  /* "Cython/Compiler/Parsing.py":4425
 *         )
 *     else:
 *         pattern = patterns[0]             # <<<<<<<<<<<<<<
 * 
 *     if s.sy == 'IDENT' and s.systring == 'as':
*/
  /*else*/ {
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_patterns, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_pattern = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L6:;

  /* "Cython/Compiler/Parsing.py":4427
 *         pattern = patterns[0]
 * 
 *     if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         with tentatively_scan(s) as errors:
*/
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4427, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_3 = __pyx_t_9;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u_as, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4427, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_9;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Parsing.py":4428
 * 
 *     if s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             pattern.as_targets.append(p_pattern_capture_target(s))
*/
    __pyx_t_8 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4429
 *     if s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             pattern.as_targets.append(p_pattern_capture_target(s))
 *         if errors and s.sy == "_":
*/
    /*with:*/ {
      __pyx_t_8 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, ((PyObject *)__pyx_v_s)};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4429, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_8 = NULL;
      __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4429, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4429, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_4 = __pyx_t_7;
      __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          /*try:*/ {
            __pyx_v_errors = __pyx_t_4;
            __pyx_t_4 = 0;

            /* "Cython/Compiler/Parsing.py":4430
 *         s.next()
 *         with tentatively_scan(s) as errors:
 *             pattern.as_targets.append(p_pattern_capture_target(s))             # <<<<<<<<<<<<<<
 *         if errors and s.sy == "_":
 *             s.next()
*/
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern, __pyx_mstate_global->__pyx_n_u_as_targets); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4430, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4430, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_2 = __Pyx_PyObject_Append(__pyx_t_4, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 4430, __pyx_L14_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "Cython/Compiler/Parsing.py":4429
 *     if s.sy == 'IDENT' and s.systring == 'as':
 *         s.next()
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             pattern.as_targets.append(p_pattern_capture_target(s))
 *         if errors and s.sy == "_":
*/
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L19_try_end;
          __pyx_L14_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 4429, __pyx_L16_except_error)
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_7);
            __pyx_t_8 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4429, __pyx_L16_except_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4429, __pyx_L16_except_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (__pyx_t_3 < (0)) __PYX_ERR(0, 4429, __pyx_L16_except_error)
            __pyx_t_9 = (!__pyx_t_3);
            if (unlikely(__pyx_t_9)) {
              __Pyx_GIVEREF(__pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_4);
              __Pyx_XGIVEREF(__pyx_t_7);
              __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_7);
              __pyx_t_1 = 0;  __pyx_t_4 = 0;  __pyx_t_7 = 0; 
              __PYX_ERR(0, 4429, __pyx_L16_except_error)
            }
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            goto __pyx_L15_exception_handled;
          }
          __pyx_L16_except_error:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          goto __pyx_L1_error;
          __pyx_L15_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_L19_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_10) {
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4429, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          goto __pyx_L13;
        }
        __pyx_L13:;
      }
      goto __pyx_L23;
      __pyx_L10_error:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L1_error;
      __pyx_L23:;
    }

    /* "Cython/Compiler/Parsing.py":4431
 *         with tentatively_scan(s) as errors:
 *             pattern.as_targets.append(p_pattern_capture_target(s))
 *         if errors and s.sy == "_":             # <<<<<<<<<<<<<<
 *             s.next()
 *             # make this a specific error
*/
    if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4431, __pyx_L1_error) }
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4431, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_9 = __pyx_t_3;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u__57, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4431, __pyx_L1_error)
    __pyx_t_9 = __pyx_t_3;
    __pyx_L25_bool_binop_done:;
    if (__pyx_t_9) {

      /* "Cython/Compiler/Parsing.py":4432
 *             pattern.as_targets.append(p_pattern_capture_target(s))
 *         if errors and s.sy == "_":
 *             s.next()             # <<<<<<<<<<<<<<
 *             # make this a specific error
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])
*/
      __pyx_t_4 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4432, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Parsing.py":4434
 *             s.next()
 *             # make this a specific error
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])             # <<<<<<<<<<<<<<
 *         elif errors:
 *             with tentatively_scan(s):
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
      __Pyx_INCREF(__pyx_t_4);
      if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4434, __pyx_L1_error) }
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_errors, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_8, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4434, __pyx_L1_error) }
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_errors, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_15, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_t_1};
        __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4434, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_what, __pyx_t_8, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4434, __pyx_L1_error)
        __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ErrorNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4434, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":4431
 *         with tentatively_scan(s) as errors:
 *             pattern.as_targets.append(p_pattern_capture_target(s))
 *         if errors and s.sy == "_":             # <<<<<<<<<<<<<<
 *             s.next()
 *             # make this a specific error
*/
    }

    /* "Cython/Compiler/Parsing.py":4435
 *             # make this a specific error
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])
 *         elif errors:             # <<<<<<<<<<<<<<
 *             with tentatively_scan(s):
 *                 expr = p_test(s)
*/
    if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4435, __pyx_L1_error) }
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 4435, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "Cython/Compiler/Parsing.py":4436
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])
 *         elif errors:
 *             with tentatively_scan(s):             # <<<<<<<<<<<<<<
 *                 expr = p_test(s)
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")
*/
      /*with:*/ {
        __pyx_t_15 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4436, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_15);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_15, ((PyObject *)__pyx_v_s)};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4436, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4436, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_15 = NULL;
        __pyx_t_1 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4436, __pyx_L27_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_15);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
          __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4436, __pyx_L27_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_12, &__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_11);
            /*try:*/ {

              /* "Cython/Compiler/Parsing.py":4437
 *         elif errors:
 *             with tentatively_scan(s):
 *                 expr = p_test(s)             # <<<<<<<<<<<<<<
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")
 *             s.error(errors[0])
*/
              __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_test(__pyx_v_s); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4437, __pyx_L31_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_v_expr = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "Cython/Compiler/Parsing.py":4438
 *             with tentatively_scan(s):
 *                 expr = p_test(s)
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")             # <<<<<<<<<<<<<<
 *             s.error(errors[0])
 *     return pattern
*/
              __Pyx_XDECREF(__pyx_r);
              __pyx_t_8 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
              __Pyx_INCREF(__pyx_t_8);
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4438, __pyx_L31_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_5 = 0;
              {
                PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_t_1};
                __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4438, __pyx_L31_error)
                __Pyx_GOTREF(__pyx_t_15);
                if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_what, __pyx_mstate_global->__pyx_kp_u_Invalid_pattern_target, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4438, __pyx_L31_error)
                __pyx_t_7 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ErrorNode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4438, __pyx_L31_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __pyx_r = __pyx_t_7;
              __pyx_t_7 = 0;
              goto __pyx_L35_try_return;

              /* "Cython/Compiler/Parsing.py":4436
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])
 *         elif errors:
 *             with tentatively_scan(s):             # <<<<<<<<<<<<<<
 *                 expr = p_test(s)
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")
*/
            }
            __pyx_L31_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("Cython.Compiler.Parsing.p_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_15, &__pyx_t_1) < 0) __PYX_ERR(0, 4436, __pyx_L33_except_error)
              __Pyx_XGOTREF(__pyx_t_7);
              __Pyx_XGOTREF(__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_1);
              __pyx_t_8 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_15, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4436, __pyx_L33_except_error)
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4436, __pyx_L33_except_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (__pyx_t_9 < (0)) __PYX_ERR(0, 4436, __pyx_L33_except_error)
              __pyx_t_3 = (!__pyx_t_9);
              if (unlikely(__pyx_t_3)) {
                __Pyx_GIVEREF(__pyx_t_7);
                __Pyx_GIVEREF(__pyx_t_15);
                __Pyx_XGIVEREF(__pyx_t_1);
                __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_15, __pyx_t_1);
                __pyx_t_7 = 0;  __pyx_t_15 = 0;  __pyx_t_1 = 0; 
                __PYX_ERR(0, 4436, __pyx_L33_except_error)
              }
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              goto __pyx_L32_exception_handled;
            }
            __pyx_L33_except_error:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_12, __pyx_t_11);
            goto __pyx_L1_error;
            __pyx_L35_try_return:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_12, __pyx_t_11);
            goto __pyx_L28_return;
            __pyx_L32_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_12, __pyx_t_11);
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_10) {
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[8], NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4436, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
            goto __pyx_L30;
          }
          __pyx_L28_return: {
            __pyx_t_11 = __pyx_r;
            __pyx_r = 0;
            if (__pyx_t_10) {
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[8], NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4436, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            __pyx_r = __pyx_t_11;
            __pyx_t_11 = 0;
            goto __pyx_L0;
          }
          __pyx_L30:;
        }
        goto __pyx_L40;
        __pyx_L27_error:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L1_error;
        __pyx_L40:;
      }

      /* "Cython/Compiler/Parsing.py":4439
 *                 expr = p_test(s)
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")
 *             s.error(errors[0])             # <<<<<<<<<<<<<<
 *     return pattern
 * 
*/
      __pyx_t_15 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_15);
      if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4439, __pyx_L1_error) }
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_errors, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4435
 *             # make this a specific error
 *             return Nodes.ErrorNode(errors[0].args[0], what=errors[0].args[1])
 *         elif errors:             # <<<<<<<<<<<<<<
 *             with tentatively_scan(s):
 *                 expr = p_test(s)
*/
    }

    /* "Cython/Compiler/Parsing.py":4427
 *         pattern = patterns[0]
 * 
 *     if s.sy == 'IDENT' and s.systring == 'as':             # <<<<<<<<<<<<<<
 *         s.next()
 *         with tentatively_scan(s) as errors:
*/
  }

  /* "Cython/Compiler/Parsing.py":4440
 *                 return Nodes.ErrorNode(expr.pos, what="Invalid pattern target")
 *             s.error(errors[0])
 *     return pattern             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pattern);
  __pyx_r = __pyx_v_pattern;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4407
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pattern(s: PyrexScanner):
 *     # try "as_pattern" then "or_pattern"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_patterns);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4443
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_closed_pattern(s: PyrexScanner):
 *     """
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_closed_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_closed_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4463
 *     The rest are then tried in order with backtracking
 *     """
 *     if s.sy == 'IDENT' and s.systring == '_':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u__57, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4463, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4464
 *     """
 *     if s.sy == 'IDENT' and s.systring == '_':
 *         pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_pos = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4465
 *     if s.sy == 'IDENT' and s.systring == '_':
 *         pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)
 *     elif s.sy == '{':
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4466
 *         pos = s.position()
 *         s.next()
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)             # <<<<<<<<<<<<<<
 *     elif s.sy == '{':
 *         return p_mapping_pattern(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_MatchAndAssignPatternNode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_pos};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4463
 *     The rest are then tried in order with backtracking
 *     """
 *     if s.sy == 'IDENT' and s.systring == '_':             # <<<<<<<<<<<<<<
 *         pos = s.position()
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4467
 *         s.next()
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)
 *     elif s.sy == '{':             # <<<<<<<<<<<<<<
 *         return p_mapping_pattern(s)
 *     elif s.sy == '[':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__32, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4467, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4468
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)
 *     elif s.sy == '{':
 *         return p_mapping_pattern(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == '[':
 *         return p_sequence_pattern(s)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_mapping_pattern(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4468, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4467
 *         s.next()
 *         return MatchCaseNodes.MatchAndAssignPatternNode(pos)
 *     elif s.sy == '{':             # <<<<<<<<<<<<<<
 *         return p_mapping_pattern(s)
 *     elif s.sy == '[':
*/
  }

  /* "Cython/Compiler/Parsing.py":4469
 *     elif s.sy == '{':
 *         return p_mapping_pattern(s)
 *     elif s.sy == '[':             # <<<<<<<<<<<<<<
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4469, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4470
 *         return p_mapping_pattern(s)
 *     elif s.sy == '[':
 *         return p_sequence_pattern(s)             # <<<<<<<<<<<<<<
 *     elif s.sy == '(':
 *         with tentatively_scan(s) as errors:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_sequence_pattern(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4470, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4469
 *     elif s.sy == '{':
 *         return p_mapping_pattern(s)
 *     elif s.sy == '[':             # <<<<<<<<<<<<<<
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':
*/
  }

  /* "Cython/Compiler/Parsing.py":4471
 *     elif s.sy == '[':
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             result = p_group_pattern(s)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4471, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4472
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             result = p_group_pattern(s)
 *             if not errors:
*/
    /*with:*/ {
      __pyx_t_7 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_s)};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4472, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = NULL;
      __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4472, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4472, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_6 = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          /*try:*/ {
            __pyx_v_errors = __pyx_t_6;
            __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4473
 *     elif s.sy == '(':
 *         with tentatively_scan(s) as errors:
 *             result = p_group_pattern(s)             # <<<<<<<<<<<<<<
 *             if not errors:
 *                 return result
*/
            __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_group_pattern(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4473, __pyx_L10_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_v_result = __pyx_t_6;
            __pyx_t_6 = 0;

            /* "Cython/Compiler/Parsing.py":4474
 *         with tentatively_scan(s) as errors:
 *             result = p_group_pattern(s)
 *             if not errors:             # <<<<<<<<<<<<<<
 *                 return result
 *         return p_sequence_pattern(s)
*/
            __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4474, __pyx_L10_error)
            __pyx_t_2 = (!__pyx_t_1);
            if (__pyx_t_2) {

              /* "Cython/Compiler/Parsing.py":4475
 *             result = p_group_pattern(s)
 *             if not errors:
 *                 return result             # <<<<<<<<<<<<<<
 *         return p_sequence_pattern(s)
 * 
*/
              __Pyx_XDECREF(__pyx_r);
              __Pyx_INCREF(__pyx_v_result);
              __pyx_r = __pyx_v_result;
              goto __pyx_L14_try_return;

              /* "Cython/Compiler/Parsing.py":4474
 *         with tentatively_scan(s) as errors:
 *             result = p_group_pattern(s)
 *             if not errors:             # <<<<<<<<<<<<<<
 *                 return result
 *         return p_sequence_pattern(s)
*/
            }

            /* "Cython/Compiler/Parsing.py":4472
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             result = p_group_pattern(s)
 *             if not errors:
*/
          }
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L15_try_end;
          __pyx_L10_error:;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_closed_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 4472, __pyx_L12_except_error)
            __Pyx_XGOTREF(__pyx_t_6);
            __Pyx_XGOTREF(__pyx_t_3);
            __Pyx_XGOTREF(__pyx_t_4);
            __pyx_t_7 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4472, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_7, NULL);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4472, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (__pyx_t_2 < (0)) __PYX_ERR(0, 4472, __pyx_L12_except_error)
            __pyx_t_1 = (!__pyx_t_2);
            if (unlikely(__pyx_t_1)) {
              __Pyx_GIVEREF(__pyx_t_6);
              __Pyx_GIVEREF(__pyx_t_3);
              __Pyx_XGIVEREF(__pyx_t_4);
              __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_3, __pyx_t_4);
              __pyx_t_6 = 0;  __pyx_t_3 = 0;  __pyx_t_4 = 0; 
              __PYX_ERR(0, 4472, __pyx_L12_except_error)
            }
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            goto __pyx_L11_exception_handled;
          }
          __pyx_L12_except_error:;
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
          goto __pyx_L1_error;
          __pyx_L14_try_return:;
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
          goto __pyx_L7_return;
          __pyx_L11_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
          __pyx_L15_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_8) {
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4472, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          goto __pyx_L9;
        }
        __pyx_L7_return: {
          __pyx_t_11 = __pyx_r;
          __pyx_r = 0;
          if (__pyx_t_8) {
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4472, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __pyx_r = __pyx_t_11;
          __pyx_t_11 = 0;
          goto __pyx_L0;
        }
        __pyx_L9:;
      }
      goto __pyx_L20;
      __pyx_L6_error:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L1_error;
      __pyx_L20:;
    }

    /* "Cython/Compiler/Parsing.py":4476
 *             if not errors:
 *                 return result
 *         return p_sequence_pattern(s)             # <<<<<<<<<<<<<<
 * 
 *     with tentatively_scan(s) as errors:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_sequence_pattern(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4471
 *     elif s.sy == '[':
 *         return p_sequence_pattern(s)
 *     elif s.sy == '(':             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             result = p_group_pattern(s)
*/
  }

  /* "Cython/Compiler/Parsing.py":4478
 *         return p_sequence_pattern(s)
 * 
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_literal_pattern(s)
 *         if not errors:
*/
  /*with:*/ {
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_s)};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = NULL;
    __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4478, __pyx_L21_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4478, __pyx_L21_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_7 = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {
          __pyx_v_errors = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Parsing.py":4479
 * 
 *     with tentatively_scan(s) as errors:
 *         result = p_literal_pattern(s)             # <<<<<<<<<<<<<<
 *         if not errors:
 *             return result
*/
          __pyx_t_7 = __pyx_f_6Cython_8Compiler_7Parsing_p_literal_pattern(__pyx_v_s); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4479, __pyx_L25_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_v_result = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Parsing.py":4480
 *     with tentatively_scan(s) as errors:
 *         result = p_literal_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     with tentatively_scan(s) as errors:
*/
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4480, __pyx_L25_error)
          __pyx_t_2 = (!__pyx_t_1);
          if (__pyx_t_2) {

            /* "Cython/Compiler/Parsing.py":4481
 *         result = p_literal_pattern(s)
 *         if not errors:
 *             return result             # <<<<<<<<<<<<<<
 *     with tentatively_scan(s) as errors:
 *         result = p_capture_pattern(s)
*/
            __Pyx_XDECREF(__pyx_r);
            __Pyx_INCREF(__pyx_v_result);
            __pyx_r = __pyx_v_result;
            goto __pyx_L29_try_return;

            /* "Cython/Compiler/Parsing.py":4480
 *     with tentatively_scan(s) as errors:
 *         result = p_literal_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     with tentatively_scan(s) as errors:
*/
          }

          /* "Cython/Compiler/Parsing.py":4478
 *         return p_sequence_pattern(s)
 * 
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_literal_pattern(s)
 *         if not errors:
*/
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L30_try_end;
        __pyx_L25_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Compiler.Parsing.p_closed_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_4, &__pyx_t_6) < 0) __PYX_ERR(0, 4478, __pyx_L27_except_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_3 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4478, __pyx_L27_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_3, NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4478, __pyx_L27_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_2 < (0)) __PYX_ERR(0, 4478, __pyx_L27_except_error)
          __pyx_t_1 = (!__pyx_t_2);
          if (unlikely(__pyx_t_1)) {
            __Pyx_GIVEREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_XGIVEREF(__pyx_t_6);
            __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_4, __pyx_t_6);
            __pyx_t_7 = 0;  __pyx_t_4 = 0;  __pyx_t_6 = 0; 
            __PYX_ERR(0, 4478, __pyx_L27_except_error)
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L26_exception_handled;
        }
        __pyx_L27_except_error:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L29_try_return:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        goto __pyx_L22_return;
        __pyx_L26_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        __pyx_L30_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_8) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4478, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L24;
      }
      __pyx_L22_return: {
        __pyx_t_9 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_8) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4478, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_r = __pyx_t_9;
        __pyx_t_9 = 0;
        goto __pyx_L0;
      }
      __pyx_L24:;
    }
    goto __pyx_L35;
    __pyx_L21_error:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L1_error;
    __pyx_L35:;
  }

  /* "Cython/Compiler/Parsing.py":4482
 *         if not errors:
 *             return result
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_capture_pattern(s)
 *         if not errors:
*/
  /*with:*/ {
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_s)};
      __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = NULL;
    __pyx_t_3 = __Pyx_PyObject_LookupSpecial(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4482, __pyx_L36_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4482, __pyx_L36_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_t_3 = __pyx_t_7;
    __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {
          __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "Cython/Compiler/Parsing.py":4483
 *             return result
 *     with tentatively_scan(s) as errors:
 *         result = p_capture_pattern(s)             # <<<<<<<<<<<<<<
 *         if not errors:
 *             return result
*/
          __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_capture_pattern(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4483, __pyx_L40_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "Cython/Compiler/Parsing.py":4484
 *     with tentatively_scan(s) as errors:
 *         result = p_capture_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     with tentatively_scan(s) as errors:
*/
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4484, __pyx_L40_error)
          __pyx_t_2 = (!__pyx_t_1);
          if (__pyx_t_2) {

            /* "Cython/Compiler/Parsing.py":4485
 *         result = p_capture_pattern(s)
 *         if not errors:
 *             return result             # <<<<<<<<<<<<<<
 *     with tentatively_scan(s) as errors:
 *         result = p_value_pattern(s)
*/
            __Pyx_XDECREF(__pyx_r);
            __Pyx_INCREF(__pyx_v_result);
            __pyx_r = __pyx_v_result;
            goto __pyx_L44_try_return;

            /* "Cython/Compiler/Parsing.py":4484
 *     with tentatively_scan(s) as errors:
 *         result = p_capture_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     with tentatively_scan(s) as errors:
*/
          }

          /* "Cython/Compiler/Parsing.py":4482
 *         if not errors:
 *             return result
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_capture_pattern(s)
 *         if not errors:
*/
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L45_try_end;
        __pyx_L40_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Compiler.Parsing.p_closed_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 4482, __pyx_L42_except_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_4 = PyTuple_Pack(3, __pyx_t_3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4482, __pyx_L42_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_4, NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4482, __pyx_L42_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_2 < (0)) __PYX_ERR(0, 4482, __pyx_L42_except_error)
          __pyx_t_1 = (!__pyx_t_2);
          if (unlikely(__pyx_t_1)) {
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_6);
            __Pyx_XGIVEREF(__pyx_t_7);
            __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_6, __pyx_t_7);
            __pyx_t_3 = 0;  __pyx_t_6 = 0;  __pyx_t_7 = 0; 
            __PYX_ERR(0, 4482, __pyx_L42_except_error)
          }
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L41_exception_handled;
        }
        __pyx_L42_except_error:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L1_error;
        __pyx_L44_try_return:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L37_return;
        __pyx_L41_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_L45_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_8) {
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4482, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        goto __pyx_L39;
      }
      __pyx_L37_return: {
        __pyx_t_11 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_8) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4482, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;
      }
      __pyx_L39:;
    }
    goto __pyx_L50;
    __pyx_L36_error:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L1_error;
    __pyx_L50:;
  }

  /* "Cython/Compiler/Parsing.py":4486
 *         if not errors:
 *             return result
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_value_pattern(s)
 *         if not errors:
*/
  /*with:*/ {
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_s)};
      __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_t_8 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = NULL;
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L51_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4486, __pyx_L51_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_4 = __pyx_t_3;
    __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {
          __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Compiler/Parsing.py":4487
 *             return result
 *     with tentatively_scan(s) as errors:
 *         result = p_value_pattern(s)             # <<<<<<<<<<<<<<
 *         if not errors:
 *             return result
*/
          __pyx_t_4 = __pyx_f_6Cython_8Compiler_7Parsing_p_value_pattern(__pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4487, __pyx_L55_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "Cython/Compiler/Parsing.py":4488
 *     with tentatively_scan(s) as errors:
 *         result = p_value_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     return p_class_pattern(s)
*/
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4488, __pyx_L55_error)
          __pyx_t_2 = (!__pyx_t_1);
          if (__pyx_t_2) {

            /* "Cython/Compiler/Parsing.py":4489
 *         result = p_value_pattern(s)
 *         if not errors:
 *             return result             # <<<<<<<<<<<<<<
 *     return p_class_pattern(s)
 * 
*/
            __Pyx_XDECREF(__pyx_r);
            __Pyx_INCREF(__pyx_v_result);
            __pyx_r = __pyx_v_result;
            goto __pyx_L59_try_return;

            /* "Cython/Compiler/Parsing.py":4488
 *     with tentatively_scan(s) as errors:
 *         result = p_value_pattern(s)
 *         if not errors:             # <<<<<<<<<<<<<<
 *             return result
 *     return p_class_pattern(s)
*/
          }

          /* "Cython/Compiler/Parsing.py":4486
 *         if not errors:
 *             return result
 *     with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *         result = p_value_pattern(s)
 *         if not errors:
*/
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L60_try_end;
        __pyx_L55_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("Cython.Compiler.Parsing.p_closed_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_3) < 0) __PYX_ERR(0, 4486, __pyx_L57_except_error)
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_6 = PyTuple_Pack(3, __pyx_t_4, __pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4486, __pyx_L57_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_6, NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4486, __pyx_L57_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_2 < (0)) __PYX_ERR(0, 4486, __pyx_L57_except_error)
          __pyx_t_1 = (!__pyx_t_2);
          if (unlikely(__pyx_t_1)) {
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_7);
            __Pyx_XGIVEREF(__pyx_t_3);
            __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_7, __pyx_t_3);
            __pyx_t_4 = 0;  __pyx_t_7 = 0;  __pyx_t_3 = 0; 
            __PYX_ERR(0, 4486, __pyx_L57_except_error)
          }
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L56_exception_handled;
        }
        __pyx_L57_except_error:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L59_try_return:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        goto __pyx_L52_return;
        __pyx_L56_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        __pyx_L60_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_8) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4486, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L54;
      }
      __pyx_L52_return: {
        __pyx_t_9 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_8) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_mstate_global->__pyx_tuple[8], NULL);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4486, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_r = __pyx_t_9;
        __pyx_t_9 = 0;
        goto __pyx_L0;
      }
      __pyx_L54:;
    }
    goto __pyx_L65;
    __pyx_L51_error:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L1_error;
    __pyx_L65:;
  }

  /* "Cython/Compiler/Parsing.py":4490
 *         if not errors:
 *             return result
 *     return p_class_pattern(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_class_pattern(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4443
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_closed_pattern(s: PyrexScanner):
 *     """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_closed_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4493
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_literal_pattern(s: PyrexScanner):
 *     # a lot of duplication in this function with "p_atom"
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_literal_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  int __pyx_v_next_must_be_a_number;
  PyObject *__pyx_v_sign = NULL;
  PyObject *__pyx_v_sign_pos = NULL;
  PyObject *__pyx_v_sy = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_add_pos = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_literal_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4496
 * def p_literal_pattern(s: PyrexScanner):
 *     # a lot of duplication in this function with "p_atom"
 *     next_must_be_a_number = False             # <<<<<<<<<<<<<<
 *     sign = ''
 *     if s.sy == '-':
*/
  __pyx_v_next_must_be_a_number = 0;

  /* "Cython/Compiler/Parsing.py":4497
 *     # a lot of duplication in this function with "p_atom"
 *     next_must_be_a_number = False
 *     sign = ''             # <<<<<<<<<<<<<<
 *     if s.sy == '-':
 *         sign = s.sy
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__35);
  __pyx_v_sign = __pyx_mstate_global->__pyx_kp_u__35;

  /* "Cython/Compiler/Parsing.py":4498
 *     next_must_be_a_number = False
 *     sign = ''
 *     if s.sy == '-':             # <<<<<<<<<<<<<<
 *         sign = s.sy
 *         sign_pos = s.position()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4498, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4499
 *     sign = ''
 *     if s.sy == '-':
 *         sign = s.sy             # <<<<<<<<<<<<<<
 *         sign_pos = s.position()
 *         s.next()
*/
    __pyx_t_2 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_sign, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4500
 *     if s.sy == '-':
 *         sign = s.sy
 *         sign_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         next_must_be_a_number = True
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_sign_pos = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4501
 *         sign = s.sy
 *         sign_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         next_must_be_a_number = True
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4502
 *         sign_pos = s.position()
 *         s.next()
 *         next_must_be_a_number = True             # <<<<<<<<<<<<<<
 * 
 *     sy = s.sy
*/
    __pyx_v_next_must_be_a_number = 1;

    /* "Cython/Compiler/Parsing.py":4498
 *     next_must_be_a_number = False
 *     sign = ''
 *     if s.sy == '-':             # <<<<<<<<<<<<<<
 *         sign = s.sy
 *         sign_pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":4504
 *         next_must_be_a_number = True
 * 
 *     sy = s.sy             # <<<<<<<<<<<<<<
 *     pos = s.position()
 * 
*/
  __pyx_t_2 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_sy = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4505
 * 
 *     sy = s.sy
 *     pos = s.position()             # <<<<<<<<<<<<<<
 * 
 *     res = None
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pos = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4507
 *     pos = s.position()
 * 
 *     res = None             # <<<<<<<<<<<<<<
 *     if sy == 'INT':
 *         res = p_int_literal(s)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_res = Py_None;

  /* "Cython/Compiler/Parsing.py":4508
 * 
 *     res = None
 *     if sy == 'INT':             # <<<<<<<<<<<<<<
 *         res = p_int_literal(s)
 *     elif sy == 'FLOAT':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_INT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4508, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4509
 *     res = None
 *     if sy == 'INT':
 *         res = p_int_literal(s)             # <<<<<<<<<<<<<<
 *     elif sy == 'FLOAT':
 *         value = s.systring
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_int_literal(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4508
 * 
 *     res = None
 *     if sy == 'INT':             # <<<<<<<<<<<<<<
 *         res = p_int_literal(s)
 *     elif sy == 'FLOAT':
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":4510
 *     if sy == 'INT':
 *         res = p_int_literal(s)
 *     elif sy == 'FLOAT':             # <<<<<<<<<<<<<<
 *         value = s.systring
 *         s.next()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_FLOAT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4510, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4511
 *         res = p_int_literal(s)
 *     elif sy == 'FLOAT':
 *         value = s.systring             # <<<<<<<<<<<<<<
 *         s.next()
 *         res = ExprNodes.FloatNode(pos, value=value)
*/
    __pyx_t_2 = __pyx_v_s->systring;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4512
 *     elif sy == 'FLOAT':
 *         value = s.systring
 *         s.next()             # <<<<<<<<<<<<<<
 *         res = ExprNodes.FloatNode(pos, value=value)
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4513
 *         value = s.systring
 *         s.next()
 *         res = ExprNodes.FloatNode(pos, value=value)             # <<<<<<<<<<<<<<
 * 
 *     if res is not None and sign == "-":
*/
    __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4513, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_FloatNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4510
 *     if sy == 'INT':
 *         res = p_int_literal(s)
 *     elif sy == 'FLOAT':             # <<<<<<<<<<<<<<
 *         value = s.systring
 *         s.next()
*/
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":4515
 *         res = ExprNodes.FloatNode(pos, value=value)
 * 
 *     if res is not None and sign == "-":             # <<<<<<<<<<<<<<
 *         res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
*/
  __pyx_t_6 = (__pyx_v_res != Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_sign, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4515, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4516
 * 
 *     if res is not None and sign == "-":
 *         res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)             # <<<<<<<<<<<<<<
 * 
 *     if res is not None and s.sy in ['+', '-']:
*/
    __pyx_t_5 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_5);
    if (unlikely(!__pyx_v_sign_pos)) { __Pyx_RaiseUnboundLocalError("sign_pos"); __PYX_ERR(0, 4516, __pyx_L1_error) }
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_sign_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_res, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4516, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnaryMinusNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4515
 *         res = ExprNodes.FloatNode(pos, value=value)
 * 
 *     if res is not None and sign == "-":             # <<<<<<<<<<<<<<
 *         res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":4518
 *         res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
 *     if res is not None and s.sy in ['+', '-']:             # <<<<<<<<<<<<<<
 *         sign = s.sy
 *         s.next()
*/
  __pyx_t_6 = (__pyx_v_res != Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L9_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_7 = __pyx_v_s->sy;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__14, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4518, __pyx_L1_error)
  if (!__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4518, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_8;
  __pyx_L11_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_8 = __pyx_t_6;
  __pyx_t_1 = __pyx_t_8;
  __pyx_L9_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4519
 * 
 *     if res is not None and s.sy in ['+', '-']:
 *         sign = s.sy             # <<<<<<<<<<<<<<
 *         s.next()
 *         if s.sy != 'IMAG':
*/
    __pyx_t_2 = __pyx_v_s->sy;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_sign, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4520
 *     if res is not None and s.sy in ['+', '-']:
 *         sign = s.sy
 *         s.next()             # <<<<<<<<<<<<<<
 *         if s.sy != 'IMAG':
 *             s.error("Expected imaginary number")
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4521
 *         sign = s.sy
 *         s.next()
 *         if s.sy != 'IMAG':             # <<<<<<<<<<<<<<
 *             s.error("Expected imaginary number")
 *         else:
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IMAG, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4521, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4522
 *         s.next()
 *         if s.sy != 'IMAG':
 *             s.error("Expected imaginary number")             # <<<<<<<<<<<<<<
 *         else:
 *             add_pos = s.position()
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_imaginary_number};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4521
 *         sign = s.sy
 *         s.next()
 *         if s.sy != 'IMAG':             # <<<<<<<<<<<<<<
 *             s.error("Expected imaginary number")
 *         else:
*/
      goto __pyx_L13;
    }

    /* "Cython/Compiler/Parsing.py":4524
 *             s.error("Expected imaginary number")
 *         else:
 *             add_pos = s.position()             # <<<<<<<<<<<<<<
 *             value = s.systring[:-1]
 *             s.next()
*/
    /*else*/ {
      __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_add_pos = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4525
 *         else:
 *             add_pos = s.position()
 *             value = s.systring[:-1]             # <<<<<<<<<<<<<<
 *             s.next()
 *             res = ExprNodes.binop_node(
*/
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_s->systring, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4526
 *             add_pos = s.position()
 *             value = s.systring[:-1]
 *             s.next()             # <<<<<<<<<<<<<<
 *             res = ExprNodes.binop_node(
 *                 add_pos,
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4526, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4527
 *             value = s.systring[:-1]
 *             s.next()
 *             res = ExprNodes.binop_node(             # <<<<<<<<<<<<<<
 *                 add_pos,
 *                 sign,
*/
      __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_3);

      /* "Cython/Compiler/Parsing.py":4531
 *                 sign,
 *                 operand1=res,
 *                 operand2=ExprNodes.ImagNode(s.position(), value=value)             # <<<<<<<<<<<<<<
 *             )
 * 
*/
      __pyx_t_9 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_10 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, __pyx_t_10};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_value, __pyx_t_11, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4531, __pyx_L1_error)
        __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImagNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_3, __pyx_v_add_pos, __pyx_v_sign};
        __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand1, __pyx_v_res, __pyx_t_11, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 4527, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand2, __pyx_t_5, __pyx_t_11, __pyx_callargs+3, 1) < (0)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_binop_node, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
      __pyx_t_2 = 0;
    }
    __pyx_L13:;

    /* "Cython/Compiler/Parsing.py":4518
 *         res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
 *     if res is not None and s.sy in ['+', '-']:             # <<<<<<<<<<<<<<
 *         sign = s.sy
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4534
 *             )
 * 
 *     if res is None and sy == 'IMAG':             # <<<<<<<<<<<<<<
 *         value = s.systring[:-1]
 *         s.next()
*/
  __pyx_t_8 = (__pyx_v_res == Py_None);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_IMAG, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4534, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_8;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4535
 * 
 *     if res is None and sy == 'IMAG':
 *         value = s.systring[:-1]             # <<<<<<<<<<<<<<
 *         s.next()
 *         res = ExprNodes.ImagNode(pos, value=sign+value)
*/
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_s->systring, 0, -1L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4536
 *     if res is None and sy == 'IMAG':
 *         value = s.systring[:-1]
 *         s.next()             # <<<<<<<<<<<<<<
 *         res = ExprNodes.ImagNode(pos, value=sign+value)
 *         if sign == "-":
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4537
 *         value = s.systring[:-1]
 *         s.next()
 *         res = ExprNodes.ImagNode(pos, value=sign+value)             # <<<<<<<<<<<<<<
 *         if sign == "-":
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
*/
    __pyx_t_11 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_5 = PyNumber_Add(__pyx_v_sign, __pyx_v_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_t_5, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4537, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ImagNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4538
 *         s.next()
 *         res = ExprNodes.ImagNode(pos, value=sign+value)
 *         if sign == "-":             # <<<<<<<<<<<<<<
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_sign, __pyx_mstate_global->__pyx_kp_u__15, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4538, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4539
 *         res = ExprNodes.ImagNode(pos, value=sign+value)
 *         if sign == "-":
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)             # <<<<<<<<<<<<<<
 * 
 *     if res is not None:
*/
      __pyx_t_3 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
      __Pyx_INCREF(__pyx_t_3);
      if (unlikely(!__pyx_v_sign_pos)) { __Pyx_RaiseUnboundLocalError("sign_pos"); __PYX_ERR(0, 4539, __pyx_L1_error) }
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_sign_pos};
        __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_operand, __pyx_v_res, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4539, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_UnaryMinusNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4538
 *         s.next()
 *         res = ExprNodes.ImagNode(pos, value=sign+value)
 *         if sign == "-":             # <<<<<<<<<<<<<<
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":4534
 *             )
 * 
 *     if res is None and sy == 'IMAG':             # <<<<<<<<<<<<<<
 *         value = s.systring[:-1]
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4541
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
 *     if res is not None:             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 * 
*/
  __pyx_t_1 = (__pyx_v_res != Py_None);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4542
 * 
 *     if res is not None:
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)             # <<<<<<<<<<<<<<
 * 
 *     if next_must_be_a_number:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchValuePatternNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_res, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4542, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4541
 *             res = ExprNodes.UnaryMinusNode(sign_pos, operand=res)
 * 
 *     if res is not None:             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 * 
*/
  }

  /* "Cython/Compiler/Parsing.py":4544
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 * 
 *     if next_must_be_a_number:             # <<<<<<<<<<<<<<
 *         s.error("Expected a number")
 *     if sy == 'BEGIN_STRING':
*/
  if (__pyx_v_next_must_be_a_number) {

    /* "Cython/Compiler/Parsing.py":4545
 * 
 *     if next_must_be_a_number:
 *         s.error("Expected a number")             # <<<<<<<<<<<<<<
 *     if sy == 'BEGIN_STRING':
 *         res = p_atom_string(s)
*/
    __pyx_t_11 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_Expected_a_number};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4544
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 * 
 *     if next_must_be_a_number:             # <<<<<<<<<<<<<<
 *         s.error("Expected a number")
 *     if sy == 'BEGIN_STRING':
*/
  }

  /* "Cython/Compiler/Parsing.py":4546
 *     if next_must_be_a_number:
 *         s.error("Expected a number")
 *     if sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         res = p_atom_string(s)
 *         # Whether f-strings are suitable is validated in PostParse.
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_BEGIN_STRING, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4546, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4547
 *         s.error("Expected a number")
 *     if sy == 'BEGIN_STRING':
 *         res = p_atom_string(s)             # <<<<<<<<<<<<<<
 *         # Whether f-strings are suitable is validated in PostParse.
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom_string(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4549
 *         res = p_atom_string(s)
 *         # Whether f-strings are suitable is validated in PostParse.
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)             # <<<<<<<<<<<<<<
 *     elif sy == 'IDENT':
 *         # Note that p_atom_ident_constants includes NULL.
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_11 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchValuePatternNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_11);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_v_pos};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_res, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4549, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4546
 *     if next_must_be_a_number:
 *         s.error("Expected a number")
 *     if sy == 'BEGIN_STRING':             # <<<<<<<<<<<<<<
 *         res = p_atom_string(s)
 *         # Whether f-strings are suitable is validated in PostParse.
*/
  }

  /* "Cython/Compiler/Parsing.py":4550
 *         # Whether f-strings are suitable is validated in PostParse.
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 *     elif sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         # Note that p_atom_ident_constants includes NULL.
 *         # This is a deliberate Cython addition to the pattern matching specification
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4550, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4553
 *         # Note that p_atom_ident_constants includes NULL.
 *         # This is a deliberate Cython addition to the pattern matching specification
 *         result = p_atom_ident_constants(s)             # <<<<<<<<<<<<<<
 *         if result:
 *             return MatchCaseNodes.MatchValuePatternNode(pos, value=result, is_is_check=True)
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_atom_ident_constants(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4554
 *         # This is a deliberate Cython addition to the pattern matching specification
 *         result = p_atom_ident_constants(s)
 *         if result:             # <<<<<<<<<<<<<<
 *             return MatchCaseNodes.MatchValuePatternNode(pos, value=result, is_is_check=True)
 * 
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4554, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "Cython/Compiler/Parsing.py":4555
 *         result = p_atom_ident_constants(s)
 *         if result:
 *             return MatchCaseNodes.MatchValuePatternNode(pos, value=result, is_is_check=True)             # <<<<<<<<<<<<<<
 * 
 *     s.error("Failed to match literal")
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchValuePatternNode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_11);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_pos};
        __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4555, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_result, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4555, __pyx_L1_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_is_check, Py_True, __pyx_t_3, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4555, __pyx_L1_error)
        __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4555, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Parsing.py":4554
 *         # This is a deliberate Cython addition to the pattern matching specification
 *         result = p_atom_ident_constants(s)
 *         if result:             # <<<<<<<<<<<<<<
 *             return MatchCaseNodes.MatchValuePatternNode(pos, value=result, is_is_check=True)
 * 
*/
    }

    /* "Cython/Compiler/Parsing.py":4550
 *         # Whether f-strings are suitable is validated in PostParse.
 *         return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 *     elif sy == 'IDENT':             # <<<<<<<<<<<<<<
 *         # Note that p_atom_ident_constants includes NULL.
 *         # This is a deliberate Cython addition to the pattern matching specification
*/
  }

  /* "Cython/Compiler/Parsing.py":4557
 *             return MatchCaseNodes.MatchValuePatternNode(pos, value=result, is_is_check=True)
 * 
 *     s.error("Failed to match literal")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_11 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_11);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_Failed_to_match_literal};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4493
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_literal_pattern(s: PyrexScanner):
 *     # a lot of duplication in this function with "p_atom"
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_literal_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sign);
  __Pyx_XDECREF(__pyx_v_sign_pos);
  __Pyx_XDECREF(__pyx_v_sy);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_add_pos);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4560
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_capture_pattern(s: PyrexScanner):
 *     return MatchCaseNodes.MatchAndAssignPatternNode(
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_capture_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_capture_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4562
 * @cython.cfunc
 * def p_capture_pattern(s: PyrexScanner):
 *     return MatchCaseNodes.MatchAndAssignPatternNode(             # <<<<<<<<<<<<<<
 *         s.position(),
 *         target=p_pattern_capture_target(s)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_MatchAndAssignPatternNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4563
 * def p_capture_pattern(s: PyrexScanner):
 *     return MatchCaseNodes.MatchAndAssignPatternNode(
 *         s.position(),             # <<<<<<<<<<<<<<
 *         target=p_pattern_capture_target(s)
 *     )
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "Cython/Compiler/Parsing.py":4564
 *     return MatchCaseNodes.MatchAndAssignPatternNode(
 *         s.position(),
 *         target=p_pattern_capture_target(s)             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(__pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_target, __pyx_t_5, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4562, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4560
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_capture_pattern(s: PyrexScanner):
 *     return MatchCaseNodes.MatchAndAssignPatternNode(
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_capture_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4568
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_value_pattern(s: PyrexScanner):
 *     if s.sy != "IDENT":
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_value_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_attr_pos = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_value_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4570
 * @cython.cfunc
 * def p_value_pattern(s: PyrexScanner):
 *     if s.sy != "IDENT":             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     pos = s.position()
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4570, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4571
 * def p_value_pattern(s: PyrexScanner):
 *     if s.sy != "IDENT":
 *         s.error("Expected identifier")             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     res = p_name(s, s.systring)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_identifier};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4570
 * @cython.cfunc
 * def p_value_pattern(s: PyrexScanner):
 *     if s.sy != "IDENT":             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     pos = s.position()
*/
  }

  /* "Cython/Compiler/Parsing.py":4572
 *     if s.sy != "IDENT":
 *         s.error("Expected identifier")
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     res = p_name(s, s.systring)
 *     s.next()
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pos = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4573
 *         s.error("Expected identifier")
 *     pos = s.position()
 *     res = p_name(s, s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy != '.':
*/
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4574
 *     pos = s.position()
 *     res = p_name(s, s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy != '.':
 *         s.error(".")
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4575
 *     res = p_name(s, s.systring)
 *     s.next()
 *     if s.sy != '.':             # <<<<<<<<<<<<<<
 *         s.error(".")
 *     while s.sy == '.':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4575, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4576
 *     s.next()
 *     if s.sy != '.':
 *         s.error(".")             # <<<<<<<<<<<<<<
 *     while s.sy == '.':
 *         attr_pos = s.position()
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__27};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4575
 *     res = p_name(s, s.systring)
 *     s.next()
 *     if s.sy != '.':             # <<<<<<<<<<<<<<
 *         s.error(".")
 *     while s.sy == '.':
*/
  }

  /* "Cython/Compiler/Parsing.py":4577
 *     if s.sy != '.':
 *         s.error(".")
 *     while s.sy == '.':             # <<<<<<<<<<<<<<
 *         attr_pos = s.position()
 *         s.next()
*/
  while (1) {
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4577, __pyx_L1_error)
    if (!__pyx_t_1) break;

    /* "Cython/Compiler/Parsing.py":4578
 *         s.error(".")
 *     while s.sy == '.':
 *         attr_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         attr = p_ident(s)
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_attr_pos, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4579
 *     while s.sy == '.':
 *         attr_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4579, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4580
 *         attr_pos = s.position()
 *         s.next()
 *         attr = p_ident(s)             # <<<<<<<<<<<<<<
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     if s.sy in ['(', '=']:
*/
    __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4581
 *         s.next()
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)             # <<<<<<<<<<<<<<
 *     if s.sy in ['(', '=']:
 *         s.error("Unexpected symbol '%s'" % s.sy)
*/
    __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, __pyx_v_attr_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_obj, __pyx_v_res, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4581, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_attribute, __pyx_v_attr, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4581, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AttributeNode, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_3);
    __pyx_t_3 = 0;
  }

  /* "Cython/Compiler/Parsing.py":4582
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     if s.sy in ['(', '=']:             # <<<<<<<<<<<<<<
 *         s.error("Unexpected symbol '%s'" % s.sy)
 *     return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_6 = __pyx_v_s->sy;
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4582, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_1 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4582, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_7;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = __pyx_t_1;
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4583
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     if s.sy in ['(', '=']:
 *         s.error("Unexpected symbol '%s'" % s.sy)             # <<<<<<<<<<<<<<
 *     return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
 * 
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Unexpected_symbol_s, __pyx_v_s->sy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4582
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     if s.sy in ['(', '=']:             # <<<<<<<<<<<<<<
 *         s.error("Unexpected symbol '%s'" % s.sy)
 *     return MatchCaseNodes.MatchValuePatternNode(pos, value=res)
*/
  }

  /* "Cython/Compiler/Parsing.py":4584
 *     if s.sy in ['(', '=']:
 *         s.error("Unexpected symbol '%s'" % s.sy)
 *     return MatchCaseNodes.MatchValuePatternNode(pos, value=res)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchValuePatternNode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_pos};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value, __pyx_v_res, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4584, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4568
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_value_pattern(s: PyrexScanner):
 *     if s.sy != "IDENT":
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_value_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_attr_pos);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4587
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_group_pattern(s: PyrexScanner):
 *     s.expect("(")
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_group_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_group_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4589
 * @cython.cfunc
 * def p_group_pattern(s: PyrexScanner):
 *     s.expect("(")             # <<<<<<<<<<<<<<
 *     pattern = p_pattern(s)
 *     s.expect(")")
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__23};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4590
 * def p_group_pattern(s: PyrexScanner):
 *     s.expect("(")
 *     pattern = p_pattern(s)             # <<<<<<<<<<<<<<
 *     s.expect(")")
 *     return pattern
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pattern = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4591
 *     s.expect("(")
 *     pattern = p_pattern(s)
 *     s.expect(")")             # <<<<<<<<<<<<<<
 *     return pattern
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4592
 *     pattern = p_pattern(s)
 *     s.expect(")")
 *     return pattern             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pattern);
  __pyx_r = __pyx_v_pattern;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4587
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_group_pattern(s: PyrexScanner):
 *     s.expect("(")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_group_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4595
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sequence_pattern(s: PyrexScanner):
 *     opener = s.sy
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_sequence_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_opener = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_closer = NULL;
  PyObject *__pyx_v_patterns = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_sequence_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4597
 * @cython.cfunc
 * def p_sequence_pattern(s: PyrexScanner):
 *     opener = s.sy             # <<<<<<<<<<<<<<
 *     pos = s.position()
 *     if opener in ['[', '(']:
*/
  __pyx_t_1 = __pyx_v_s->sy;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_opener = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4598
 * def p_sequence_pattern(s: PyrexScanner):
 *     opener = s.sy
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     if opener in ['[', '(']:
 *         closer = ']' if opener == '[' else ')'
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4599
 *     opener = s.sy
 *     pos = s.position()
 *     if opener in ['[', '(']:             # <<<<<<<<<<<<<<
 *         closer = ']' if opener == '[' else ')'
 *         s.next()
*/
  __Pyx_INCREF(__pyx_v_opener);
  __pyx_t_2 = __pyx_v_opener;
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4599, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4599, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_3;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4600
 *     pos = s.position()
 *     if opener in ['[', '(']:
 *         closer = ']' if opener == '[' else ')'             # <<<<<<<<<<<<<<
 *         s.next()
 *         # maybe_sequence_pattern and open_sequence_pattern
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_opener, __pyx_mstate_global->__pyx_kp_u__26, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4600, __pyx_L1_error)
    if (__pyx_t_4) {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__30);
      __pyx_t_1 = __pyx_mstate_global->__pyx_kp_u__30;
    } else {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__24);
      __pyx_t_1 = __pyx_mstate_global->__pyx_kp_u__24;
    }
    __pyx_v_closer = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4601
 *     if opener in ['[', '(']:
 *         closer = ']' if opener == '[' else ')'
 *         s.next()             # <<<<<<<<<<<<<<
 *         # maybe_sequence_pattern and open_sequence_pattern
 *         patterns = []
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4603
 *         s.next()
 *         # maybe_sequence_pattern and open_sequence_pattern
 *         patterns = []             # <<<<<<<<<<<<<<
 *         while s.sy != closer:
 *             patterns.append(p_maybe_star_pattern(s))
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_patterns = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4604
 *         # maybe_sequence_pattern and open_sequence_pattern
 *         patterns = []
 *         while s.sy != closer:             # <<<<<<<<<<<<<<
 *             patterns.append(p_maybe_star_pattern(s))
 *             if s.sy == ",":
*/
    while (1) {
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_v_closer, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4604, __pyx_L1_error)
      if (!__pyx_t_4) break;

      /* "Cython/Compiler/Parsing.py":4605
 *         patterns = []
 *         while s.sy != closer:
 *             patterns.append(p_maybe_star_pattern(s))             # <<<<<<<<<<<<<<
 *             if s.sy == ",":
 *                 s.next()
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_maybe_star_pattern(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_patterns, __pyx_t_1); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4605, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4606
 *         while s.sy != closer:
 *             patterns.append(p_maybe_star_pattern(s))
 *             if s.sy == ",":             # <<<<<<<<<<<<<<
 *                 s.next()
 *             else:
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4606, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":4607
 *             patterns.append(p_maybe_star_pattern(s))
 *             if s.sy == ",":
 *                 s.next()             # <<<<<<<<<<<<<<
 *             else:
 *                 if opener == '(' and len(patterns) == 1:
*/
        __pyx_t_5 = ((PyObject *)__pyx_v_s);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4607, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":4606
 *         while s.sy != closer:
 *             patterns.append(p_maybe_star_pattern(s))
 *             if s.sy == ",":             # <<<<<<<<<<<<<<
 *                 s.next()
 *             else:
*/
        goto __pyx_L8;
      }

      /* "Cython/Compiler/Parsing.py":4609
 *                 s.next()
 *             else:
 *                 if opener == '(' and len(patterns) == 1:             # <<<<<<<<<<<<<<
 *                     s.error("tuple-like pattern of length 1 must finish with ','")
 *                 break
*/
      /*else*/ {
        __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_opener, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4609, __pyx_L1_error)
        if (__pyx_t_3) {
        } else {
          __pyx_t_4 = __pyx_t_3;
          goto __pyx_L10_bool_binop_done;
        }
        __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_v_patterns); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4609, __pyx_L1_error)
        __pyx_t_3 = (__pyx_t_8 == 1);
        __pyx_t_4 = __pyx_t_3;
        __pyx_L10_bool_binop_done:;
        if (__pyx_t_4) {

          /* "Cython/Compiler/Parsing.py":4610
 *             else:
 *                 if opener == '(' and len(patterns) == 1:
 *                     s.error("tuple-like pattern of length 1 must finish with ','")             # <<<<<<<<<<<<<<
 *                 break
 *         s.expect(closer)
*/
          __pyx_t_5 = ((PyObject *)__pyx_v_s);
          __Pyx_INCREF(__pyx_t_5);
          __pyx_t_6 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_tuple_like_pattern_of_length_1_m};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4610, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "Cython/Compiler/Parsing.py":4609
 *                 s.next()
 *             else:
 *                 if opener == '(' and len(patterns) == 1:             # <<<<<<<<<<<<<<
 *                     s.error("tuple-like pattern of length 1 must finish with ','")
 *                 break
*/
        }

        /* "Cython/Compiler/Parsing.py":4611
 *                 if opener == '(' and len(patterns) == 1:
 *                     s.error("tuple-like pattern of length 1 must finish with ','")
 *                 break             # <<<<<<<<<<<<<<
 *         s.expect(closer)
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
*/
        goto __pyx_L7_break;
      }
      __pyx_L8:;
    }
    __pyx_L7_break:;

    /* "Cython/Compiler/Parsing.py":4612
 *                     s.error("tuple-like pattern of length 1 must finish with ','")
 *                 break
 *         s.expect(closer)             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
 *     else:
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_closer};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4612, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4613
 *                 break
 *         s.expect(closer)
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)             # <<<<<<<<<<<<<<
 *     else:
 *         s.error("Expected '[' or '('")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_MatchSequencePatternNode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_patterns, __pyx_v_patterns, __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4613, __pyx_L1_error)
      __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4613, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4599
 *     opener = s.sy
 *     pos = s.position()
 *     if opener in ['[', '(']:             # <<<<<<<<<<<<<<
 *         closer = ']' if opener == '[' else ')'
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4615
 *         return MatchCaseNodes.MatchSequencePatternNode(pos, patterns=patterns)
 *     else:
 *         s.error("Expected '[' or '('")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_10 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_Expected_or};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "Cython/Compiler/Parsing.py":4595
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_sequence_pattern(s: PyrexScanner):
 *     opener = s.sy
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_sequence_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_opener);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_closer);
  __Pyx_XDECREF(__pyx_v_patterns);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4618
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_mapping_pattern(s: PyrexScanner):
 *     pos = s.position()
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_mapping_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_double_star_capture_target = NULL;
  PyObject *__pyx_v_items_patterns = NULL;
  PyObject *__pyx_v_star_star_arg_pos = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_8genexpr6__pyx_v_kv = NULL;
  PyObject *__pyx_8genexpr7__pyx_v_kv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  Py_ssize_t __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_mapping_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4620
 * @cython.cfunc
 * def p_mapping_pattern(s: PyrexScanner):
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     s.expect('{')
 *     if s.sy == '}':
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4621
 * def p_mapping_pattern(s: PyrexScanner):
 *     pos = s.position()
 *     s.expect('{')             # <<<<<<<<<<<<<<
 *     if s.sy == '}':
 *         # trivial empty mapping
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__32};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4622
 *     pos = s.position()
 *     s.expect('{')
 *     if s.sy == '}':             # <<<<<<<<<<<<<<
 *         # trivial empty mapping
 *         s.next()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4622, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4624
 *     if s.sy == '}':
 *         # trivial empty mapping
 *         s.next()             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.MatchMappingPatternNode(pos)
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4625
 *         # trivial empty mapping
 *         s.next()
 *         return MatchCaseNodes.MatchMappingPatternNode(pos)             # <<<<<<<<<<<<<<
 * 
 *     double_star_capture_target = None
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_MatchMappingPatternNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_pos};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4625, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4622
 *     pos = s.position()
 *     s.expect('{')
 *     if s.sy == '}':             # <<<<<<<<<<<<<<
 *         # trivial empty mapping
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4627
 *         return MatchCaseNodes.MatchMappingPatternNode(pos)
 * 
 *     double_star_capture_target = None             # <<<<<<<<<<<<<<
 *     items_patterns = []
 *     star_star_arg_pos = None
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_double_star_capture_target = Py_None;

  /* "Cython/Compiler/Parsing.py":4628
 * 
 *     double_star_capture_target = None
 *     items_patterns = []             # <<<<<<<<<<<<<<
 *     star_star_arg_pos = None
 *     while s.sy != '}':
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_items_patterns = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4629
 *     double_star_capture_target = None
 *     items_patterns = []
 *     star_star_arg_pos = None             # <<<<<<<<<<<<<<
 *     while s.sy != '}':
 *         if double_star_capture_target and not star_star_arg_pos:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_star_star_arg_pos = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":4630
 *     items_patterns = []
 *     star_star_arg_pos = None
 *     while s.sy != '}':             # <<<<<<<<<<<<<<
 *         if double_star_capture_target and not star_star_arg_pos:
 *             star_star_arg_pos = s.position()
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__39, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4630, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":4631
 *     star_star_arg_pos = None
 *     while s.sy != '}':
 *         if double_star_capture_target and not star_star_arg_pos:             # <<<<<<<<<<<<<<
 *             star_star_arg_pos = s.position()
 *         if s.sy == '**':
*/
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_double_star_capture_target); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 4631, __pyx_L1_error)
    if (__pyx_t_7) {
    } else {
      __pyx_t_4 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    if (__pyx_v_star_star_arg_pos == Py_None) __pyx_t_7 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_star_star_arg_pos);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 4631, __pyx_L1_error)
      __pyx_t_7 = (__pyx_temp != 0);
    }

    __pyx_t_8 = (!__pyx_t_7);
    __pyx_t_4 = __pyx_t_8;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4632
 *     while s.sy != '}':
 *         if double_star_capture_target and not star_star_arg_pos:
 *             star_star_arg_pos = s.position()             # <<<<<<<<<<<<<<
 *         if s.sy == '**':
 *             s.next()
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_star_star_arg_pos, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4631
 *     star_star_arg_pos = None
 *     while s.sy != '}':
 *         if double_star_capture_target and not star_star_arg_pos:             # <<<<<<<<<<<<<<
 *             star_star_arg_pos = s.position()
 *         if s.sy == '**':
*/
    }

    /* "Cython/Compiler/Parsing.py":4633
 *         if double_star_capture_target and not star_star_arg_pos:
 *             star_star_arg_pos = s.position()
 *         if s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             double_star_capture_target = p_pattern_capture_target(s)
*/
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__28, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4633, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4634
 *             star_star_arg_pos = s.position()
 *         if s.sy == '**':
 *             s.next()             # <<<<<<<<<<<<<<
 *             double_star_capture_target = p_pattern_capture_target(s)
 *         else:
*/
      __pyx_t_6 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4634, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4635
 *         if s.sy == '**':
 *             s.next()
 *             double_star_capture_target = p_pattern_capture_target(s)             # <<<<<<<<<<<<<<
 *         else:
 *             # key=(literal_expr | attr)
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4635, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_double_star_capture_target, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4633
 *         if double_star_capture_target and not star_star_arg_pos:
 *             star_star_arg_pos = s.position()
 *         if s.sy == '**':             # <<<<<<<<<<<<<<
 *             s.next()
 *             double_star_capture_target = p_pattern_capture_target(s)
*/
      goto __pyx_L9;
    }

    /* "Cython/Compiler/Parsing.py":4638
 *         else:
 *             # key=(literal_expr | attr)
 *             with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *                 pattern = p_literal_pattern(s)
 *                 key = pattern.value
*/
    /*else*/ {
      /*with:*/ {
        __pyx_t_6 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_6);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_s)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4638, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_9 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = NULL;
        __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4638, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_6);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4638, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_5 = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_12);
            /*try:*/ {
              __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "Cython/Compiler/Parsing.py":4639
 *             # key=(literal_expr | attr)
 *             with tentatively_scan(s) as errors:
 *                 pattern = p_literal_pattern(s)             # <<<<<<<<<<<<<<
 *                 key = pattern.value
 *             if errors:
*/
              __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_literal_pattern(__pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4639, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_XDECREF_SET(__pyx_v_pattern, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "Cython/Compiler/Parsing.py":4640
 *             with tentatively_scan(s) as errors:
 *                 pattern = p_literal_pattern(s)
 *                 key = pattern.value             # <<<<<<<<<<<<<<
 *             if errors:
 *                 pattern = p_value_pattern(s)
*/
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4640, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "Cython/Compiler/Parsing.py":4638
 *         else:
 *             # key=(literal_expr | attr)
 *             with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *                 pattern = p_literal_pattern(s)
 *                 key = pattern.value
*/
            }
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            goto __pyx_L23_try_end;
            __pyx_L16_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("Cython.Compiler.Parsing.p_mapping_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 4638, __pyx_L18_except_error)
              __Pyx_XGOTREF(__pyx_t_5);
              __Pyx_XGOTREF(__pyx_t_1);
              __Pyx_XGOTREF(__pyx_t_2);
              __pyx_t_6 = PyTuple_Pack(3, __pyx_t_5, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4638, __pyx_L18_except_error)
              __Pyx_GOTREF(__pyx_t_6);
              __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_6, NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4638, __pyx_L18_except_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (__pyx_t_4 < (0)) __PYX_ERR(0, 4638, __pyx_L18_except_error)
              __pyx_t_8 = (!__pyx_t_4);
              if (unlikely(__pyx_t_8)) {
                __Pyx_GIVEREF(__pyx_t_5);
                __Pyx_GIVEREF(__pyx_t_1);
                __Pyx_XGIVEREF(__pyx_t_2);
                __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_1, __pyx_t_2);
                __pyx_t_5 = 0;  __pyx_t_1 = 0;  __pyx_t_2 = 0; 
                __PYX_ERR(0, 4638, __pyx_L18_except_error)
              }
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              goto __pyx_L17_exception_handled;
            }
            __pyx_L18_except_error:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            goto __pyx_L1_error;
            __pyx_L17_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            __pyx_L23_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_9) {
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_mstate_global->__pyx_tuple[8], NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4638, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            goto __pyx_L15;
          }
          __pyx_L15:;
        }
        goto __pyx_L27;
        __pyx_L10_error:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L1_error;
        __pyx_L27:;
      }

      /* "Cython/Compiler/Parsing.py":4641
 *                 pattern = p_literal_pattern(s)
 *                 key = pattern.value
 *             if errors:             # <<<<<<<<<<<<<<
 *                 pattern = p_value_pattern(s)
 *                 key = pattern.value
*/
      if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4641, __pyx_L1_error) }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4641, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "Cython/Compiler/Parsing.py":4642
 *                 key = pattern.value
 *             if errors:
 *                 pattern = p_value_pattern(s)             # <<<<<<<<<<<<<<
 *                 key = pattern.value
 *             s.expect(':')
*/
        __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_value_pattern(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4642, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_pattern, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":4643
 *             if errors:
 *                 pattern = p_value_pattern(s)
 *                 key = pattern.value             # <<<<<<<<<<<<<<
 *             s.expect(':')
 *             value = p_pattern(s)
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4643, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":4641
 *                 pattern = p_literal_pattern(s)
 *                 key = pattern.value
 *             if errors:             # <<<<<<<<<<<<<<
 *                 pattern = p_value_pattern(s)
 *                 key = pattern.value
*/
      }

      /* "Cython/Compiler/Parsing.py":4644
 *                 pattern = p_value_pattern(s)
 *                 key = pattern.value
 *             s.expect(':')             # <<<<<<<<<<<<<<
 *             value = p_pattern(s)
 *             items_patterns.append((key, value))
*/
      __pyx_t_1 = ((PyObject *)__pyx_v_s);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__3};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4644, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4645
 *                 key = pattern.value
 *             s.expect(':')
 *             value = p_pattern(s)             # <<<<<<<<<<<<<<
 *             items_patterns.append((key, value))
 *         if s.sy != ',':
*/
      __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Parsing.py":4646
 *             s.expect(':')
 *             value = p_pattern(s)
 *             items_patterns.append((key, value))             # <<<<<<<<<<<<<<
 *         if s.sy != ',':
 *             break
*/
      if (unlikely(!__pyx_v_key)) { __Pyx_RaiseUnboundLocalError("key"); __PYX_ERR(0, 4646, __pyx_L1_error) }
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_key) != (0)) __PYX_ERR(0, 4646, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_value) != (0)) __PYX_ERR(0, 4646, __pyx_L1_error);
      __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_items_patterns, __pyx_t_2); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 4646, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L9:;

    /* "Cython/Compiler/Parsing.py":4647
 *             value = p_pattern(s)
 *             items_patterns.append((key, value))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4647, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "Cython/Compiler/Parsing.py":4648
 *             items_patterns.append((key, value))
 *         if s.sy != ',':
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     s.expect('}')
*/
      goto __pyx_L5_break;

      /* "Cython/Compiler/Parsing.py":4647
 *             value = p_pattern(s)
 *             items_patterns.append((key, value))
 *         if s.sy != ',':             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":4649
 *         if s.sy != ',':
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     s.expect('}')
 * 
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4649, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L5_break:;

  /* "Cython/Compiler/Parsing.py":4650
 *             break
 *         s.next()
 *     s.expect('}')             # <<<<<<<<<<<<<<
 * 
 *     if star_star_arg_pos is not None:
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__39};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4652
 *     s.expect('}')
 * 
 *     if star_star_arg_pos is not None:             # <<<<<<<<<<<<<<
 *         return Nodes.ErrorNode(
 *             star_star_arg_pos,
*/
  __pyx_t_8 = (__pyx_v_star_star_arg_pos != ((PyObject*)Py_None));
  if (__pyx_t_8) {

    /* "Cython/Compiler/Parsing.py":4653
 * 
 *     if star_star_arg_pos is not None:
 *         return Nodes.ErrorNode(             # <<<<<<<<<<<<<<
 *             star_star_arg_pos,
 *             what = "** pattern must be the final part of a mapping pattern."
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":4654
 *     if star_star_arg_pos is not None:
 *         return Nodes.ErrorNode(
 *             star_star_arg_pos,             # <<<<<<<<<<<<<<
 *             what = "** pattern must be the final part of a mapping pattern."
 *         )
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_star_star_arg_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_what, __pyx_mstate_global->__pyx_kp_u_pattern_must_be_the_final_part, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4653, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ErrorNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4652
 *     s.expect('}')
 * 
 *     if star_star_arg_pos is not None:             # <<<<<<<<<<<<<<
 *         return Nodes.ErrorNode(
 *             star_star_arg_pos,
*/
  }

  /* "Cython/Compiler/Parsing.py":4657
 *             what = "** pattern must be the final part of a mapping pattern."
 *         )
 *     return MatchCaseNodes.MatchMappingPatternNode(             # <<<<<<<<<<<<<<
 *         pos,
 *         keys = [kv[0] for kv in items_patterns],
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchMappingPatternNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4658
 *         )
 *     return MatchCaseNodes.MatchMappingPatternNode(
 *         pos,             # <<<<<<<<<<<<<<
 *         keys = [kv[0] for kv in items_patterns],
 *         value_patterns = [kv[1] for kv in items_patterns],
*/
  { /* enter inner scope */

    /* "Cython/Compiler/Parsing.py":4659
 *     return MatchCaseNodes.MatchMappingPatternNode(
 *         pos,
 *         keys = [kv[0] for kv in items_patterns],             # <<<<<<<<<<<<<<
 *         value_patterns = [kv[1] for kv in items_patterns],
 *         double_star_capture_target = double_star_capture_target
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4659, __pyx_L33_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __pyx_v_items_patterns; __Pyx_INCREF(__pyx_t_15);
    __pyx_t_16 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_15);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4659, __pyx_L33_error)
        #endif
        if (__pyx_t_16 >= __pyx_temp) break;
      }
      __pyx_t_17 = __Pyx_PyList_GetItemRefFast(__pyx_t_15, __pyx_t_16, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_16;
      if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4659, __pyx_L33_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_kv, __pyx_t_17);
      __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_GetItemInt(__pyx_8genexpr6__pyx_v_kv, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4659, __pyx_L33_error)
      __Pyx_GOTREF(__pyx_t_17);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_17))) __PYX_ERR(0, 4659, __pyx_L33_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_kv); __pyx_8genexpr6__pyx_v_kv = 0;
    goto __pyx_L37_exit_scope;
    __pyx_L33_error:;
    __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_kv); __pyx_8genexpr6__pyx_v_kv = 0;
    goto __pyx_L1_error;
    __pyx_L37_exit_scope:;
  } /* exit inner scope */
  { /* enter inner scope */

    /* "Cython/Compiler/Parsing.py":4660
 *         pos,
 *         keys = [kv[0] for kv in items_patterns],
 *         value_patterns = [kv[1] for kv in items_patterns],             # <<<<<<<<<<<<<<
 *         double_star_capture_target = double_star_capture_target
 *     )
*/
    __pyx_t_15 = PyList_New(0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4660, __pyx_L40_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_17 = __pyx_v_items_patterns; __Pyx_INCREF(__pyx_t_17);
    __pyx_t_16 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_17);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4660, __pyx_L40_error)
        #endif
        if (__pyx_t_16 >= __pyx_temp) break;
      }
      __pyx_t_18 = __Pyx_PyList_GetItemRefFast(__pyx_t_17, __pyx_t_16, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_16;
      if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 4660, __pyx_L40_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_XDECREF_SET(__pyx_8genexpr7__pyx_v_kv, __pyx_t_18);
      __pyx_t_18 = 0;
      __pyx_t_18 = __Pyx_GetItemInt(__pyx_8genexpr7__pyx_v_kv, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 4660, __pyx_L40_error)
      __Pyx_GOTREF(__pyx_t_18);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_15, (PyObject*)__pyx_t_18))) __PYX_ERR(0, 4660, __pyx_L40_error)
      __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
    }
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_kv); __pyx_8genexpr7__pyx_v_kv = 0;
    goto __pyx_L44_exit_scope;
    __pyx_L40_error:;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_kv); __pyx_8genexpr7__pyx_v_kv = 0;
    goto __pyx_L1_error;
    __pyx_L44_exit_scope:;
  } /* exit inner scope */

  /* "Cython/Compiler/Parsing.py":4661
 *         keys = [kv[0] for kv in items_patterns],
 *         value_patterns = [kv[1] for kv in items_patterns],
 *         double_star_capture_target = double_star_capture_target             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_5, __pyx_v_pos};
    __pyx_t_17 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keys, __pyx_t_1, __pyx_t_17, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4657, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_value_patterns, __pyx_t_15, __pyx_t_17, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4657, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_double_star_capture_target, __pyx_v_double_star_capture_target, __pyx_t_17, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4657, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_17);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4618
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_mapping_pattern(s: PyrexScanner):
 *     pos = s.position()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_mapping_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_double_star_capture_target);
  __Pyx_XDECREF(__pyx_v_items_patterns);
  __Pyx_XDECREF(__pyx_v_star_star_arg_pos);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_kv);
  __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_kv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4665
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_class_pattern(s: PyrexScanner):
 *     # start by parsing the class as name_or_attr
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_class_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_attr_pos = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_class_ = NULL;
  PyObject *__pyx_v_positional_patterns = NULL;
  PyObject *__pyx_v_keyword_patterns = NULL;
  PyObject *__pyx_v_keyword_patterns_error = NULL;
  PyObject *__pyx_v_errors = NULL;
  PyObject *__pyx_8genexpr8__pyx_v_kv = NULL;
  PyObject *__pyx_8genexpr9__pyx_v_kv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_class_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4668
 * def p_class_pattern(s: PyrexScanner):
 *     # start by parsing the class as name_or_attr
 *     pos = s.position()             # <<<<<<<<<<<<<<
 *     res = p_name(s, s.systring)
 *     s.next()
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pos = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4669
 *     # start by parsing the class as name_or_attr
 *     pos = s.position()
 *     res = p_name(s, s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     while s.sy == '.':
*/
  __pyx_t_1 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_res = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4670
 *     pos = s.position()
 *     res = p_name(s, s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     while s.sy == '.':
 *         attr_pos = s.position()
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4671
 *     res = p_name(s, s.systring)
 *     s.next()
 *     while s.sy == '.':             # <<<<<<<<<<<<<<
 *         attr_pos = s.position()
 *         s.next()
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4671, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":4672
 *     s.next()
 *     while s.sy == '.':
 *         attr_pos = s.position()             # <<<<<<<<<<<<<<
 *         s.next()
 *         attr = p_ident(s)
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_attr_pos, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4673
 *     while s.sy == '.':
 *         attr_pos = s.position()
 *         s.next()             # <<<<<<<<<<<<<<
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4673, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4674
 *         attr_pos = s.position()
 *         s.next()
 *         attr = p_ident(s)             # <<<<<<<<<<<<<<
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     class_ = res
*/
    __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Parsing_p_ident(__pyx_v_s, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4675
 *         s.next()
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)             # <<<<<<<<<<<<<<
 *     class_ = res
 * 
*/
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_1, __pyx_v_attr_pos};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_obj, __pyx_v_res, __pyx_t_5, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4675, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_attribute, __pyx_v_attr, __pyx_t_5, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4675, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_AttributeNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "Cython/Compiler/Parsing.py":4676
 *         attr = p_ident(s)
 *         res = ExprNodes.AttributeNode(attr_pos, obj=res, attribute=attr)
 *     class_ = res             # <<<<<<<<<<<<<<
 * 
 *     s.expect("(")
*/
  __Pyx_INCREF(__pyx_v_res);
  __pyx_v_class_ = __pyx_v_res;

  /* "Cython/Compiler/Parsing.py":4678
 *     class_ = res
 * 
 *     s.expect("(")             # <<<<<<<<<<<<<<
 *     if s.sy == ")":
 *         # trivial case with no arguments matched
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__23};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4679
 * 
 *     s.expect("(")
 *     if s.sy == ")":             # <<<<<<<<<<<<<<
 *         # trivial case with no arguments matched
 *         s.next()
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4679, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4681
 *     if s.sy == ")":
 *         # trivial case with no arguments matched
 *         s.next()             # <<<<<<<<<<<<<<
 *         return MatchCaseNodes.ClassPatternNode(pos, class_=class_)
 * 
*/
    __pyx_t_5 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4682
 *         # trivial case with no arguments matched
 *         s.next()
 *         return MatchCaseNodes.ClassPatternNode(pos, class_=class_)             # <<<<<<<<<<<<<<
 * 
 *     # parse the arguments
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ClassPatternNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_v_pos};
      __pyx_t_1 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_class_3, __pyx_v_class_, __pyx_t_1, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4682, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4679
 * 
 *     s.expect("(")
 *     if s.sy == ")":             # <<<<<<<<<<<<<<
 *         # trivial case with no arguments matched
 *         s.next()
*/
  }

  /* "Cython/Compiler/Parsing.py":4685
 * 
 *     # parse the arguments
 *     positional_patterns = []             # <<<<<<<<<<<<<<
 *     keyword_patterns = []
 *     keyword_patterns_error = None
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_positional_patterns = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4686
 *     # parse the arguments
 *     positional_patterns = []
 *     keyword_patterns = []             # <<<<<<<<<<<<<<
 *     keyword_patterns_error = None
 *     while s.sy != ')':
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_keyword_patterns = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4687
 *     positional_patterns = []
 *     keyword_patterns = []
 *     keyword_patterns_error = None             # <<<<<<<<<<<<<<
 *     while s.sy != ')':
 *         with tentatively_scan(s) as errors:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_keyword_patterns_error = ((PyObject*)Py_None);

  /* "Cython/Compiler/Parsing.py":4688
 *     keyword_patterns = []
 *     keyword_patterns_error = None
 *     while s.sy != ')':             # <<<<<<<<<<<<<<
 *         with tentatively_scan(s) as errors:
 *             positional_patterns.append(p_pattern(s))
*/
  while (1) {
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u__24, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4688, __pyx_L1_error)
    if (!__pyx_t_4) break;

    /* "Cython/Compiler/Parsing.py":4689
 *     keyword_patterns_error = None
 *     while s.sy != ')':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:
*/
    /*with:*/ {
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_s)};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = NULL;
      __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4689, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4689, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_5 = __pyx_t_1;
      __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          /*try:*/ {
            __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "Cython/Compiler/Parsing.py":4690
 *     while s.sy != ')':
 *         with tentatively_scan(s) as errors:
 *             positional_patterns.append(p_pattern(s))             # <<<<<<<<<<<<<<
 *         if not errors:
 *             if keyword_patterns:
*/
            __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern(__pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4690, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_positional_patterns, __pyx_t_5); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 4690, __pyx_L14_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "Cython/Compiler/Parsing.py":4689
 *     keyword_patterns_error = None
 *     while s.sy != ')':
 *         with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:
*/
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L21_try_end;
          __pyx_L14_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("Cython.Compiler.Parsing.p_class_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_2, &__pyx_t_1) < 0) __PYX_ERR(0, 4689, __pyx_L16_except_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_XGOTREF(__pyx_t_2);
            __Pyx_XGOTREF(__pyx_t_1);
            __pyx_t_6 = PyTuple_Pack(3, __pyx_t_5, __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4689, __pyx_L16_except_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, NULL);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4689, __pyx_L16_except_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (__pyx_t_4 < (0)) __PYX_ERR(0, 4689, __pyx_L16_except_error)
            __pyx_t_13 = (!__pyx_t_4);
            if (unlikely(__pyx_t_13)) {
              __Pyx_GIVEREF(__pyx_t_5);
              __Pyx_GIVEREF(__pyx_t_2);
              __Pyx_XGIVEREF(__pyx_t_1);
              __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_2, __pyx_t_1);
              __pyx_t_5 = 0;  __pyx_t_2 = 0;  __pyx_t_1 = 0; 
              __PYX_ERR(0, 4689, __pyx_L16_except_error)
            }
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            goto __pyx_L15_exception_handled;
          }
          __pyx_L16_except_error:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          goto __pyx_L1_error;
          __pyx_L15_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          __pyx_L21_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_7) {
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[8], NULL);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4689, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          goto __pyx_L13;
        }
        __pyx_L13:;
      }
      goto __pyx_L25;
      __pyx_L8_error:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L1_error;
      __pyx_L25:;
    }

    /* "Cython/Compiler/Parsing.py":4691
 *         with tentatively_scan(s) as errors:
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:             # <<<<<<<<<<<<<<
 *             if keyword_patterns:
 *                 keyword_patterns_error = s.position()
*/
    if (unlikely(!__pyx_v_errors)) { __Pyx_RaiseUnboundLocalError("errors"); __PYX_ERR(0, 4691, __pyx_L1_error) }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_v_errors); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 4691, __pyx_L1_error)
    __pyx_t_4 = (!__pyx_t_13);
    if (__pyx_t_4) {

      /* "Cython/Compiler/Parsing.py":4692
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:
 *             if keyword_patterns:             # <<<<<<<<<<<<<<
 *                 keyword_patterns_error = s.position()
 *         else:
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_keyword_patterns);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 4692, __pyx_L1_error)
        __pyx_t_4 = (__pyx_temp != 0);
      }

      if (__pyx_t_4) {

        /* "Cython/Compiler/Parsing.py":4693
 *         if not errors:
 *             if keyword_patterns:
 *                 keyword_patterns_error = s.position()             # <<<<<<<<<<<<<<
 *         else:
 *             with tentatively_scan(s) as errors:
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner *)__pyx_v_s->__pyx_base.__pyx_vtab)->__pyx_base.position(((struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner *)__pyx_v_s), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_keyword_patterns_error, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Parsing.py":4692
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:
 *             if keyword_patterns:             # <<<<<<<<<<<<<<
 *                 keyword_patterns_error = s.position()
 *         else:
*/
      }

      /* "Cython/Compiler/Parsing.py":4691
 *         with tentatively_scan(s) as errors:
 *             positional_patterns.append(p_pattern(s))
 *         if not errors:             # <<<<<<<<<<<<<<
 *             if keyword_patterns:
 *                 keyword_patterns_error = s.position()
*/
      goto __pyx_L26;
    }

    /* "Cython/Compiler/Parsing.py":4695
 *                 keyword_patterns_error = s.position()
 *         else:
 *             with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *                 keyword_patterns.append(p_keyword_pattern(s))
 *         if s.sy != ",":
*/
    /*else*/ {
      /*with:*/ {
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_tentatively_scan); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_s)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4695, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_2 = NULL;
        __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4695, __pyx_L28_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4695, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __pyx_t_6 = __pyx_t_5;
        __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_9);
            __Pyx_XGOTREF(__pyx_t_8);
            /*try:*/ {
              __Pyx_XDECREF_SET(__pyx_v_errors, __pyx_t_6);
              __pyx_t_6 = 0;

              /* "Cython/Compiler/Parsing.py":4696
 *         else:
 *             with tentatively_scan(s) as errors:
 *                 keyword_patterns.append(p_keyword_pattern(s))             # <<<<<<<<<<<<<<
 *         if s.sy != ",":
 *             break
*/
              __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_p_keyword_pattern(__pyx_v_s); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4696, __pyx_L34_error)
              __Pyx_GOTREF(__pyx_t_6);
              __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_keyword_patterns, __pyx_t_6); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 4696, __pyx_L34_error)
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "Cython/Compiler/Parsing.py":4695
 *                 keyword_patterns_error = s.position()
 *         else:
 *             with tentatively_scan(s) as errors:             # <<<<<<<<<<<<<<
 *                 keyword_patterns.append(p_keyword_pattern(s))
 *         if s.sy != ",":
*/
            }
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            goto __pyx_L41_try_end;
            __pyx_L34_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("Cython.Compiler.Parsing.p_class_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 4695, __pyx_L36_except_error)
              __Pyx_XGOTREF(__pyx_t_6);
              __Pyx_XGOTREF(__pyx_t_1);
              __Pyx_XGOTREF(__pyx_t_5);
              __pyx_t_2 = PyTuple_Pack(3, __pyx_t_6, __pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4695, __pyx_L36_except_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_2, NULL);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4695, __pyx_L36_except_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (__pyx_t_4 < (0)) __PYX_ERR(0, 4695, __pyx_L36_except_error)
              __pyx_t_13 = (!__pyx_t_4);
              if (unlikely(__pyx_t_13)) {
                __Pyx_GIVEREF(__pyx_t_6);
                __Pyx_GIVEREF(__pyx_t_1);
                __Pyx_XGIVEREF(__pyx_t_5);
                __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_1, __pyx_t_5);
                __pyx_t_6 = 0;  __pyx_t_1 = 0;  __pyx_t_5 = 0; 
                __PYX_ERR(0, 4695, __pyx_L36_except_error)
              }
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              goto __pyx_L35_exception_handled;
            }
            __pyx_L36_except_error:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_9);
            __Pyx_XGIVEREF(__pyx_t_8);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
            goto __pyx_L1_error;
            __pyx_L35_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_9);
            __Pyx_XGIVEREF(__pyx_t_8);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
            __pyx_L41_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_7) {
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[8], NULL);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4695, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            goto __pyx_L33;
          }
          __pyx_L33:;
        }
        goto __pyx_L45;
        __pyx_L28_error:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L1_error;
        __pyx_L45:;
      }
    }
    __pyx_L26:;

    /* "Cython/Compiler/Parsing.py":4697
 *             with tentatively_scan(s) as errors:
 *                 keyword_patterns.append(p_keyword_pattern(s))
 *         if s.sy != ",":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    __pyx_t_13 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_kp_u_, Py_NE)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 4697, __pyx_L1_error)
    if (__pyx_t_13) {

      /* "Cython/Compiler/Parsing.py":4698
 *                 keyword_patterns.append(p_keyword_pattern(s))
 *         if s.sy != ",":
 *             break             # <<<<<<<<<<<<<<
 *         s.next()
 *     s.expect(")")
*/
      goto __pyx_L7_break;

      /* "Cython/Compiler/Parsing.py":4697
 *             with tentatively_scan(s) as errors:
 *                 keyword_patterns.append(p_keyword_pattern(s))
 *         if s.sy != ",":             # <<<<<<<<<<<<<<
 *             break
 *         s.next()
*/
    }

    /* "Cython/Compiler/Parsing.py":4699
 *         if s.sy != ",":
 *             break
 *         s.next()             # <<<<<<<<<<<<<<
 *     s.expect(")")
 * 
*/
    __pyx_t_1 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L7_break:;

  /* "Cython/Compiler/Parsing.py":4700
 *             break
 *         s.next()
 *     s.expect(")")             # <<<<<<<<<<<<<<
 * 
 *     if keyword_patterns_error is not None:
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__24};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":4702
 *     s.expect(")")
 * 
 *     if keyword_patterns_error is not None:             # <<<<<<<<<<<<<<
 *         return Nodes.ErrorNode(
 *             keyword_patterns_error,
*/
  __pyx_t_13 = (__pyx_v_keyword_patterns_error != ((PyObject*)Py_None));
  if (__pyx_t_13) {

    /* "Cython/Compiler/Parsing.py":4703
 * 
 *     if keyword_patterns_error is not None:
 *         return Nodes.ErrorNode(             # <<<<<<<<<<<<<<
 *             keyword_patterns_error,
 *             what="Positional patterns follow keyword patterns"
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_v_6Cython_8Compiler_7Parsing_Nodes;
    __Pyx_INCREF(__pyx_t_1);

    /* "Cython/Compiler/Parsing.py":4704
 *     if keyword_patterns_error is not None:
 *         return Nodes.ErrorNode(
 *             keyword_patterns_error,             # <<<<<<<<<<<<<<
 *             what="Positional patterns follow keyword patterns"
 *         )
*/
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_v_keyword_patterns_error};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4703, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_what, __pyx_mstate_global->__pyx_kp_u_Positional_patterns_follow_keywo, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4703, __pyx_L1_error)
      __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_ErrorNode, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4703, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Parsing.py":4702
 *     s.expect(")")
 * 
 *     if keyword_patterns_error is not None:             # <<<<<<<<<<<<<<
 *         return Nodes.ErrorNode(
 *             keyword_patterns_error,
*/
  }

  /* "Cython/Compiler/Parsing.py":4707
 *             what="Positional patterns follow keyword patterns"
 *         )
 *     return MatchCaseNodes.ClassPatternNode(             # <<<<<<<<<<<<<<
 *         pos, class_ = class_,
 *         positional_patterns = positional_patterns,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_MatchCaseNodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ClassPatternNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4709
 *     return MatchCaseNodes.ClassPatternNode(
 *         pos, class_ = class_,
 *         positional_patterns = positional_patterns,             # <<<<<<<<<<<<<<
 *         keyword_pattern_names = [kv[0] for kv in keyword_patterns],
 *         keyword_pattern_patterns = [kv[1] for kv in keyword_patterns],
*/
  { /* enter inner scope */

    /* "Cython/Compiler/Parsing.py":4710
 *         pos, class_ = class_,
 *         positional_patterns = positional_patterns,
 *         keyword_pattern_names = [kv[0] for kv in keyword_patterns],             # <<<<<<<<<<<<<<
 *         keyword_pattern_patterns = [kv[1] for kv in keyword_patterns],
 *     )
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4710, __pyx_L50_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_14 = __pyx_v_keyword_patterns; __Pyx_INCREF(__pyx_t_14);
    __pyx_t_15 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_14);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4710, __pyx_L50_error)
        #endif
        if (__pyx_t_15 >= __pyx_temp) break;
      }
      __pyx_t_16 = __Pyx_PyList_GetItemRefFast(__pyx_t_14, __pyx_t_15, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_15;
      if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4710, __pyx_L50_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_kv, __pyx_t_16);
      __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_GetItemInt(__pyx_8genexpr8__pyx_v_kv, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4710, __pyx_L50_error)
      __Pyx_GOTREF(__pyx_t_16);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_16))) __PYX_ERR(0, 4710, __pyx_L50_error)
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_kv); __pyx_8genexpr8__pyx_v_kv = 0;
    goto __pyx_L54_exit_scope;
    __pyx_L50_error:;
    __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_kv); __pyx_8genexpr8__pyx_v_kv = 0;
    goto __pyx_L1_error;
    __pyx_L54_exit_scope:;
  } /* exit inner scope */
  { /* enter inner scope */

    /* "Cython/Compiler/Parsing.py":4711
 *         positional_patterns = positional_patterns,
 *         keyword_pattern_names = [kv[0] for kv in keyword_patterns],
 *         keyword_pattern_patterns = [kv[1] for kv in keyword_patterns],             # <<<<<<<<<<<<<<
 *     )
 * 
*/
    __pyx_t_14 = PyList_New(0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4711, __pyx_L57_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_16 = __pyx_v_keyword_patterns; __Pyx_INCREF(__pyx_t_16);
    __pyx_t_15 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_16);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4711, __pyx_L57_error)
        #endif
        if (__pyx_t_15 >= __pyx_temp) break;
      }
      __pyx_t_17 = __Pyx_PyList_GetItemRefFast(__pyx_t_16, __pyx_t_15, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_15;
      if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4711, __pyx_L57_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_XDECREF_SET(__pyx_8genexpr9__pyx_v_kv, __pyx_t_17);
      __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_GetItemInt(__pyx_8genexpr9__pyx_v_kv, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4711, __pyx_L57_error)
      __Pyx_GOTREF(__pyx_t_17);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_14, (PyObject*)__pyx_t_17))) __PYX_ERR(0, 4711, __pyx_L57_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    }
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_kv); __pyx_8genexpr9__pyx_v_kv = 0;
    goto __pyx_L61_exit_scope;
    __pyx_L57_error:;
    __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_kv); __pyx_8genexpr9__pyx_v_kv = 0;
    goto __pyx_L1_error;
    __pyx_L61_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_6, __pyx_v_pos};
    __pyx_t_16 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_class_3, __pyx_v_class_, __pyx_t_16, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 4707, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_positional_patterns, __pyx_v_positional_patterns, __pyx_t_16, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 4707, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_pattern_names, __pyx_t_1, __pyx_t_16, __pyx_callargs+2, 2) < (0)) __PYX_ERR(0, 4707, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_keyword_pattern_patterns, __pyx_t_14, __pyx_t_16, __pyx_callargs+2, 3) < (0)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __pyx_t_5 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4665
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_class_pattern(s: PyrexScanner):
 *     # start by parsing the class as name_or_attr
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_class_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_attr_pos);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_class_);
  __Pyx_XDECREF(__pyx_v_positional_patterns);
  __Pyx_XDECREF(__pyx_v_keyword_patterns);
  __Pyx_XDECREF(__pyx_v_keyword_patterns_error);
  __Pyx_XDECREF(__pyx_v_errors);
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_kv);
  __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_kv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4715
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_keyword_pattern(s: PyrexScanner) -> tuple:
 *     if s.sy != "IDENT":
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_keyword_pattern(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_keyword_pattern", 0);

  /* "Cython/Compiler/Parsing.py":4717
 * @cython.cfunc
 * def p_keyword_pattern(s: PyrexScanner) -> tuple:
 *     if s.sy != "IDENT":             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     arg = p_name(s, s.systring)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4717, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4718
 * def p_keyword_pattern(s: PyrexScanner) -> tuple:
 *     if s.sy != "IDENT":
 *         s.error("Expected identifier")             # <<<<<<<<<<<<<<
 *     arg = p_name(s, s.systring)
 *     s.next()
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_identifier};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4717
 * @cython.cfunc
 * def p_keyword_pattern(s: PyrexScanner) -> tuple:
 *     if s.sy != "IDENT":             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     arg = p_name(s, s.systring)
*/
  }

  /* "Cython/Compiler/Parsing.py":4719
 *     if s.sy != "IDENT":
 *         s.error("Expected identifier")
 *     arg = p_name(s, s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     s.expect("=")
*/
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_arg = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4720
 *         s.error("Expected identifier")
 *     arg = p_name(s, s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     s.expect("=")
 *     value = p_pattern(s)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4721
 *     arg = p_name(s, s.systring)
 *     s.next()
 *     s.expect("=")             # <<<<<<<<<<<<<<
 *     value = p_pattern(s)
 *     return arg, value
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__29};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expect, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4722
 *     s.next()
 *     s.expect("=")
 *     value = p_pattern(s)             # <<<<<<<<<<<<<<
 *     return arg, value
 * 
*/
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_pattern(__pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_value = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4723
 *     s.expect("=")
 *     value = p_pattern(s)
 *     return arg, value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_arg);
  __Pyx_GIVEREF(__pyx_v_arg);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_arg) != (0)) __PYX_ERR(0, 4723, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_value) != (0)) __PYX_ERR(0, 4723, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4715
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_keyword_pattern(s: PyrexScanner) -> tuple:
 *     if s.sy != "IDENT":
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_keyword_pattern", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4726
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pattern_capture_target(s: PyrexScanner):
 *     # any name but '_', and with some constraints on what follows
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_p_pattern_capture_target(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *__pyx_v_s) {
  PyObject *__pyx_v_target = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p_pattern_capture_target", 0);

  /* "Cython/Compiler/Parsing.py":4729
 * def p_pattern_capture_target(s: PyrexScanner):
 *     # any name but '_', and with some constraints on what follows
 *     if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     if s.systring == '_':
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->sy, __pyx_mstate_global->__pyx_n_u_IDENT, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4729, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4730
 *     # any name but '_', and with some constraints on what follows
 *     if s.sy != 'IDENT':
 *         s.error("Expected identifier")             # <<<<<<<<<<<<<<
 *     if s.systring == '_':
 *         s.error("Pattern capture target cannot be '_'")
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Expected_identifier};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4729
 * def p_pattern_capture_target(s: PyrexScanner):
 *     # any name but '_', and with some constraints on what follows
 *     if s.sy != 'IDENT':             # <<<<<<<<<<<<<<
 *         s.error("Expected identifier")
 *     if s.systring == '_':
*/
  }

  /* "Cython/Compiler/Parsing.py":4731
 *     if s.sy != 'IDENT':
 *         s.error("Expected identifier")
 *     if s.systring == '_':             # <<<<<<<<<<<<<<
 *         s.error("Pattern capture target cannot be '_'")
 *     target = p_name(s, s.systring)
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_s->systring, __pyx_mstate_global->__pyx_n_u__57, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4731, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "Cython/Compiler/Parsing.py":4732
 *         s.error("Expected identifier")
 *     if s.systring == '_':
 *         s.error("Pattern capture target cannot be '_'")             # <<<<<<<<<<<<<<
 *     target = p_name(s, s.systring)
 *     s.next()
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Pattern_capture_target_cannot_be};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4731
 *     if s.sy != 'IDENT':
 *         s.error("Expected identifier")
 *     if s.systring == '_':             # <<<<<<<<<<<<<<
 *         s.error("Pattern capture target cannot be '_'")
 *     target = p_name(s, s.systring)
*/
  }

  /* "Cython/Compiler/Parsing.py":4733
 *     if s.systring == '_':
 *         s.error("Pattern capture target cannot be '_'")
 *     target = p_name(s, s.systring)             # <<<<<<<<<<<<<<
 *     s.next()
 *     if s.sy in ['.', '(', '=']:
*/
  __pyx_t_2 = __pyx_v_s->systring;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_6Cython_8Compiler_7Parsing_p_name(__pyx_v_s, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_target = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4734
 *         s.error("Pattern capture target cannot be '_'")
 *     target = p_name(s, s.systring)
 *     s.next()             # <<<<<<<<<<<<<<
 *     if s.sy in ['.', '(', '=']:
 *         s.error("Illegal next symbol '%s'" % s.sy)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_s);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_next, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Parsing.py":4735
 *     target = p_name(s, s.systring)
 *     s.next()
 *     if s.sy in ['.', '(', '=']:             # <<<<<<<<<<<<<<
 *         s.error("Illegal next symbol '%s'" % s.sy)
 *     return target
*/
  __Pyx_INCREF(__pyx_v_s->sy);
  __pyx_t_5 = __pyx_v_s->sy;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__27, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4735, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__23, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4735, __pyx_L1_error)
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__29, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 4735, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __pyx_t_1;
  if (__pyx_t_6) {

    /* "Cython/Compiler/Parsing.py":4736
 *     s.next()
 *     if s.sy in ['.', '(', '=']:
 *         s.error("Illegal next symbol '%s'" % s.sy)             # <<<<<<<<<<<<<<
 *     return target
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_s);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_Illegal_next_symbol_s, __pyx_v_s->sy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "Cython/Compiler/Parsing.py":4735
 *     target = p_name(s, s.systring)
 *     s.next()
 *     if s.sy in ['.', '(', '=']:             # <<<<<<<<<<<<<<
 *         s.error("Illegal next symbol '%s'" % s.sy)
 *     return target
*/
  }

  /* "Cython/Compiler/Parsing.py":4737
 *     if s.sy in ['.', '(', '=']:
 *         s.error("Illegal next symbol '%s'" % s.sy)
 *     return target             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_target);
  __pyx_r = __pyx_v_target;
  goto __pyx_L0;

  /* "Cython/Compiler/Parsing.py":4726
 * 
 * 
 * @cython.cfunc             # <<<<<<<<<<<<<<
 * def p_pattern_capture_target(s: PyrexScanner):
 *     # any name but '_', and with some constraints on what follows
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.p_pattern_capture_target", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_target);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_13print_parse_tree(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(PyObject *__pyx_v_f, PyObject *__pyx_v_node, long __pyx_v_level, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree *__pyx_optional_args) {

  /* "Cython/Compiler/Parsing.py":4748
 * 
 * @cython.ccall
 * def print_parse_tree(f, node, level: cython.long, key = None):             # <<<<<<<<<<<<<<
 *     ind: str = "  " * level
 *     f.write(ind)
*/
  PyObject *__pyx_v_key = ((PyObject *)Py_None);
  PyObject *__pyx_v_ind = 0;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16[4];
  PyObject *(*__pyx_t_17)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree __pyx_t_18;
  PyObject *__pyx_t_19[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("print_parse_tree", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_key = __pyx_optional_args->key;
    }
  }

  /* "Cython/Compiler/Parsing.py":4749
 * @cython.ccall
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level             # <<<<<<<<<<<<<<
 *     f.write(ind)
 *     if key:
*/
  __pyx_t_1 = __Pyx_PySequence_Multiply(__pyx_mstate_global->__pyx_kp_u__58, __pyx_v_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ind = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4750
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
 *     f.write(ind)             # <<<<<<<<<<<<<<
 *     if key:
 *         f.write(f"{key}: ")
*/
  __pyx_t_2 = __pyx_v_f;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_ind};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Parsing.py":4751
 *     ind: str = "  " * level
 *     f.write(ind)
 *     if key:             # <<<<<<<<<<<<<<
 *         f.write(f"{key}: ")
 *     if not node:
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_key); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4751, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "Cython/Compiler/Parsing.py":4752
 *     f.write(ind)
 *     if key:
 *         f.write(f"{key}: ")             # <<<<<<<<<<<<<<
 *     if not node:
 *         f.write("None\n")
*/
    __pyx_t_2 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_key, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__55); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4752, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4751
 *     ind: str = "  " * level
 *     f.write(ind)
 *     if key:             # <<<<<<<<<<<<<<
 *         f.write(f"{key}: ")
 *     if not node:
*/
  }

  /* "Cython/Compiler/Parsing.py":4753
 *     if key:
 *         f.write(f"{key}: ")
 *     if not node:             # <<<<<<<<<<<<<<
 *         f.write("None\n")
 *     elif type(node) is tuple:
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_node); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4753, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_4);
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4754
 *         f.write(f"{key}: ")
 *     if not node:
 *         f.write("None\n")             # <<<<<<<<<<<<<<
 *     elif type(node) is tuple:
 *         f.write(f"({node[0]} @ {node[1]}\n")
*/
    __pyx_t_6 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_n_u_None_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4754, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4753
 *     if key:
 *         f.write(f"{key}: ")
 *     if not node:             # <<<<<<<<<<<<<<
 *         f.write("None\n")
 *     elif type(node) is tuple:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":4755
 *     if not node:
 *         f.write("None\n")
 *     elif type(node) is tuple:             # <<<<<<<<<<<<<<
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:
*/
  __pyx_t_7 = (((PyObject *)Py_TYPE(__pyx_v_node)) == ((PyObject *)(&PyTuple_Type)));
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4756
 *         f.write("None\n")
 *     elif type(node) is tuple:
 *         f.write(f"({node[0]} @ {node[1]}\n")             # <<<<<<<<<<<<<<
 *         for item in node[2:]:
 *             print_parse_tree(f, item, level+1)
*/
    __pyx_t_6 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_node, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_node, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u__23;
    __pyx_t_9[1] = __pyx_t_5;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__59;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__37;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4756, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4757
 *     elif type(node) is tuple:
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:             # <<<<<<<<<<<<<<
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")
*/
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_node, 2, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[2], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_10 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4757, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4757, __pyx_L1_error)
            #endif
            if (__pyx_t_10 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_10;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4757, __pyx_L1_error)
            #endif
            if (__pyx_t_10 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_10));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_10);
          #endif
          ++__pyx_t_10;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4757, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_11(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 4757, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4758
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:
 *             print_parse_tree(f, item, level+1)             # <<<<<<<<<<<<<<
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):
*/
      __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(__pyx_v_f, __pyx_v_item, (__pyx_v_level + 1), 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "Cython/Compiler/Parsing.py":4757
 *     elif type(node) is tuple:
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:             # <<<<<<<<<<<<<<
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4759
 *         for item in node[2:]:
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")             # <<<<<<<<<<<<<<
 *     elif isinstance(node, Nodes.Node):
 *         try:
*/
    __pyx_t_1 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_v_ind, __pyx_mstate_global->__pyx_kp_u__60); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4759, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Parsing.py":4755
 *     if not node:
 *         f.write("None\n")
 *     elif type(node) is tuple:             # <<<<<<<<<<<<<<
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":4760
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):             # <<<<<<<<<<<<<<
 *         try:
 *             tag = node.tag
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 4760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4761
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):
 *         try:             # <<<<<<<<<<<<<<
 *             tag = node.tag
 *         except AttributeError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      /*try:*/ {

        /* "Cython/Compiler/Parsing.py":4762
 *     elif isinstance(node, Nodes.Node):
 *         try:
 *             tag = node.tag             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             tag = node.__class__.__name__
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_tag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4762, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_tag = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Parsing.py":4761
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):
 *         try:             # <<<<<<<<<<<<<<
 *             tag = node.tag
 *         except AttributeError:
*/
      }
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "Cython/Compiler/Parsing.py":4763
 *         try:
 *             tag = node.tag
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             tag = node.__class__.__name__
 *         f.write(f"{tag} @ {node.pos}\n")
*/
      __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
      if (__pyx_t_15) {
        __Pyx_AddTraceback("Cython.Compiler.Parsing.print_parse_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(0, 4763, __pyx_L10_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);

        /* "Cython/Compiler/Parsing.py":4764
 *             tag = node.tag
 *         except AttributeError:
 *             tag = node.__class__.__name__             # <<<<<<<<<<<<<<
 *         f.write(f"{tag} @ {node.pos}\n")
 *         for name, value in sorted(node.__dict__.items()):
*/
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4764, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4764, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tag, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L9_exception_handled;
      }
      goto __pyx_L10_except_error;

      /* "Cython/Compiler/Parsing.py":4761
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):
 *         try:             # <<<<<<<<<<<<<<
 *             tag = node.tag
 *         except AttributeError:
*/
      __pyx_L10_except_error:;
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      goto __pyx_L1_error;
      __pyx_L9_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      __pyx_L13_try_end:;
    }

    /* "Cython/Compiler/Parsing.py":4765
 *         except AttributeError:
 *             tag = node.__class__.__name__
 *         f.write(f"{tag} @ {node.pos}\n")             # <<<<<<<<<<<<<<
 *         for name, value in sorted(node.__dict__.items()):
 *             if name != 'tag' and name != 'pos':
*/
    __pyx_t_6 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_tag, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_16[0] = __pyx_t_2;
    __pyx_t_16[1] = __pyx_mstate_global->__pyx_kp_u__59;
    __pyx_t_16[2] = __pyx_t_8;
    __pyx_t_16[3] = __pyx_mstate_global->__pyx_kp_u__37;
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_16, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4766
 *             tag = node.__class__.__name__
 *         f.write(f"{tag} @ {node.pos}\n")
 *         for name, value in sorted(node.__dict__.items()):             # <<<<<<<<<<<<<<
 *             if name != 'tag' and name != 'pos':
 *                 print_parse_tree(f, value, level+1, name)
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_items, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_6 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyList_Sort(__pyx_t_6) < 0))) __PYX_ERR(0, 4766, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_6; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4766, __pyx_L1_error)
        #endif
        if (__pyx_t_10 >= __pyx_temp) break;
      }
      __pyx_t_6 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_10;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 4766, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_5);
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_8);
        } else {
          __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4766, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_5);
          __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4766, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_8);
        }
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_2 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_17 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
        index = 0; __pyx_t_5 = __pyx_t_17(__pyx_t_2); if (unlikely(!__pyx_t_5)) goto __pyx_L18_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_8 = __pyx_t_17(__pyx_t_2); if (unlikely(!__pyx_t_8)) goto __pyx_L18_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_2), 2) < (0)) __PYX_ERR(0, 4766, __pyx_L1_error)
        __pyx_t_17 = NULL;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L19_unpacking_done;
        __pyx_L18_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_17 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 4766, __pyx_L1_error)
        __pyx_L19_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "Cython/Compiler/Parsing.py":4767
 *         f.write(f"{tag} @ {node.pos}\n")
 *         for name, value in sorted(node.__dict__.items()):
 *             if name != 'tag' and name != 'pos':             # <<<<<<<<<<<<<<
 *                 print_parse_tree(f, value, level+1, name)
 *     elif type(node) is list:
*/
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_tag, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4767, __pyx_L1_error)
      if (__pyx_t_4) {
      } else {
        __pyx_t_7 = __pyx_t_4;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_pos, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4767, __pyx_L1_error)
      __pyx_t_7 = __pyx_t_4;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_7) {

        /* "Cython/Compiler/Parsing.py":4768
 *         for name, value in sorted(node.__dict__.items()):
 *             if name != 'tag' and name != 'pos':
 *                 print_parse_tree(f, value, level+1, name)             # <<<<<<<<<<<<<<
 *     elif type(node) is list:
 *         f.write("[\n")
*/
        __pyx_t_18.__pyx_n = 1;
        __pyx_t_18.key = __pyx_v_name;
        __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(__pyx_v_f, __pyx_v_value, (__pyx_v_level + 1), 0, &__pyx_t_18); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4768, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "Cython/Compiler/Parsing.py":4767
 *         f.write(f"{tag} @ {node.pos}\n")
 *         for name, value in sorted(node.__dict__.items()):
 *             if name != 'tag' and name != 'pos':             # <<<<<<<<<<<<<<
 *                 print_parse_tree(f, value, level+1, name)
 *     elif type(node) is list:
*/
      }

      /* "Cython/Compiler/Parsing.py":4766
 *             tag = node.__class__.__name__
 *         f.write(f"{tag} @ {node.pos}\n")
 *         for name, value in sorted(node.__dict__.items()):             # <<<<<<<<<<<<<<
 *             if name != 'tag' and name != 'pos':
 *                 print_parse_tree(f, value, level+1, name)
*/
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4760
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")
 *     elif isinstance(node, Nodes.Node):             # <<<<<<<<<<<<<<
 *         try:
 *             tag = node.tag
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":4769
 *             if name != 'tag' and name != 'pos':
 *                 print_parse_tree(f, value, level+1, name)
 *     elif type(node) is list:             # <<<<<<<<<<<<<<
 *         f.write("[\n")
 *         for item in node:
*/
  __pyx_t_7 = (((PyObject *)Py_TYPE(__pyx_v_node)) == ((PyObject *)(&PyList_Type)));
  if (__pyx_t_7) {

    /* "Cython/Compiler/Parsing.py":4770
 *                 print_parse_tree(f, value, level+1, name)
 *     elif type(node) is list:
 *         f.write("[\n")             # <<<<<<<<<<<<<<
 *         for item in node:
 *             print_parse_tree(f, item, level+1)
*/
    __pyx_t_6 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__61};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4770, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4771
 *     elif type(node) is list:
 *         f.write("[\n")
 *         for item in node:             # <<<<<<<<<<<<<<
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind}]\n")
*/
    if (likely(PyList_CheckExact(__pyx_v_node)) || PyTuple_CheckExact(__pyx_v_node)) {
      __pyx_t_1 = __pyx_v_node; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_10 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4771, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4771, __pyx_L1_error)
            #endif
            if (__pyx_t_10 >= __pyx_temp) break;
          }
          __pyx_t_6 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_10, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_10;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4771, __pyx_L1_error)
            #endif
            if (__pyx_t_10 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_10));
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_10);
          #endif
          ++__pyx_t_10;
        }
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4771, __pyx_L1_error)
      } else {
        __pyx_t_6 = __pyx_t_11(__pyx_t_1);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 4771, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":4772
 *         f.write("[\n")
 *         for item in node:
 *             print_parse_tree(f, item, level+1)             # <<<<<<<<<<<<<<
 *         f.write(f"{ind}]\n")
 *     else:
*/
      __pyx_t_6 = __pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(__pyx_v_f, __pyx_v_item, (__pyx_v_level + 1), 0, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "Cython/Compiler/Parsing.py":4771
 *     elif type(node) is list:
 *         f.write("[\n")
 *         for item in node:             # <<<<<<<<<<<<<<
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind}]\n")
*/
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4773
 *         for item in node:
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind}]\n")             # <<<<<<<<<<<<<<
 *     else:
 *         f.write(f"{ind}{node}\n")
*/
    __pyx_t_6 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_v_ind, __pyx_mstate_global->__pyx_kp_u__62); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4773, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Parsing.py":4769
 *             if name != 'tag' and name != 'pos':
 *                 print_parse_tree(f, value, level+1, name)
 *     elif type(node) is list:             # <<<<<<<<<<<<<<
 *         f.write("[\n")
 *         for item in node:
*/
    goto __pyx_L4;
  }

  /* "Cython/Compiler/Parsing.py":4775
 *         f.write(f"{ind}]\n")
 *     else:
 *         f.write(f"{ind}{node}\n")             # <<<<<<<<<<<<<<
*/
  /*else*/ {
    __pyx_t_8 = __pyx_v_f;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_v_node, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4775, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_19[0] = __pyx_v_ind;
    __pyx_t_19[1] = __pyx_t_6;
    __pyx_t_19[2] = __pyx_mstate_global->__pyx_kp_u__37;
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_19, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_v_ind) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_ind) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4775, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_write, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4775, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.print_parse_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ind);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_13print_parse_tree(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Parsing_13print_parse_tree = {"print_parse_tree", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Parsing_13print_parse_tree, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Parsing_13print_parse_tree(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_f = 0;
  PyObject *__pyx_v_node = 0;
  long __pyx_v_level;
  PyObject *__pyx_v_key = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("print_parse_tree (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_f,&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_level,&__pyx_mstate_global->__pyx_n_u_key,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 4747, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 4747, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4747, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4747, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4747, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "print_parse_tree", 0) < (0)) __PYX_ERR(0, 4747, __pyx_L3_error)

      /* "Cython/Compiler/Parsing.py":4748
 * 
 * @cython.ccall
 * def print_parse_tree(f, node, level: cython.long, key = None):             # <<<<<<<<<<<<<<
 *     ind: str = "  " * level
 *     f.write(ind)
*/
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("print_parse_tree", 0, 3, 4, i); __PYX_ERR(0, 4747, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 4747, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 4747, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 4747, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 4747, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_f = values[0];
    __pyx_v_node = values[1];
    __pyx_v_level = __Pyx_PyLong_As_long(values[2]); if (unlikely((__pyx_v_level == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 4748, __pyx_L3_error)
    __pyx_v_key = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("print_parse_tree", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4747, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Parsing.print_parse_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Parsing_12print_parse_tree(__pyx_self, __pyx_v_f, __pyx_v_node, __pyx_v_level, __pyx_v_key);

  /* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Parsing_12print_parse_tree(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f, PyObject *__pyx_v_node, long __pyx_v_level, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Parsing_print_parse_tree __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("print_parse_tree", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.key = __pyx_v_key;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Parsing_print_parse_tree(__pyx_v_f, __pyx_v_node, __pyx_v_level, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Parsing.print_parse_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6Cython_8Compiler_7Parsing_Nodes = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_ExprNodes = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_EncodedString = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_bytes_literal = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_StringEncoding = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_Future = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_Options = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_error = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_warning = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_Builtin = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_ModuleNode = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_Utils = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_re = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_partial = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_reduce = Py_None; Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing__CDEF_MODIFIERS = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_statement_terminators = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_comparison_ops = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_expr_terminators = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_inequality_relations = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing_c_arg_list_terminators = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_struct___pyx_obj_6Cytho);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 137;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6Cython_8Compiler_7Parsing_p_binop_expr, (void (*)(void))&__pyx_f_6Cython_8Compiler_7Parsing_p_rassoc_binop_expr, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Cython.Plex.Actions"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Action",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Action), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Action),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Action = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Action*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Action); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Action)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Return",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Return), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Return),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return) __PYX_ERR(1, 4, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Return = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Return*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Return); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Return)) __PYX_ERR(1, 4, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Call",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Call), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Call),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call) __PYX_ERR(1, 8, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Call = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Call*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Call); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Call)) __PYX_ERR(1, 8, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Method",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Method),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Method = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Method*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Method); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Method)) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Begin",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Begin), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Begin),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin) __PYX_ERR(1, 16, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Begin = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Begin*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Begin); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Begin)) __PYX_ERR(1, 16, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Ignore",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Ignore),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore) __PYX_ERR(1, 20, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Ignore = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Ignore*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Ignore); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Ignore)) __PYX_ERR(1, 20, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Actions", "Text",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_7Actions_Text), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_7Actions_Text),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text) __PYX_ERR(1, 23, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_7Actions_Text = (struct __pyx_vtabstruct_6Cython_4Plex_7Actions_Text*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_7Actions_Text); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_7Actions_Text)) __PYX_ERR(1, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Cython.Plex.Scanners"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Plex.Scanners", "Scanner",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #else
  sizeof(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_4Plex_8Scanners_Scanner),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner = (struct __pyx_vtabstruct_6Cython_4Plex_8Scanners_Scanner*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_4Plex_8Scanners_Scanner); if (unlikely(!__pyx_vtabptr_6Cython_4Plex_8Scanners_Scanner)) __PYX_ERR(2, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("Cython.Compiler.Scanning"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Scanning", "CompileTimeScope",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_CompileTimeScope),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_CompileTimeScope) __PYX_ERR(3, 12, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Scanning", "PyrexScanner",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner) __PYX_ERR(3, 20, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner = (struct __pyx_vtabstruct_6Cython_8Compiler_8Scanning_PyrexScanner*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_PyrexScanner); if (unlikely(!__pyx_vtabptr_6Cython_8Compiler_8Scanning_PyrexScanner)) __PYX_ERR(3, 20, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState = __Pyx_ImportType_3_2_4(__pyx_t_1, "Cython.Compiler.Scanning", "FTStringState",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState),
  #else
  sizeof(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6Cython_8Compiler_8Scanning_FTStringState),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_8Scanning_FTStringState) __PYX_ERR(3, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("Cython.Compiler.Scanning"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_IDENT_any_string_prefix);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 12;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6Cython_8Compiler_8Scanning_IDENT, (void **)&__pyx_vp_6Cython_8Compiler_8Scanning_any_string_prefix, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_Parsing(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_Parsing},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "Parsing",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_Parsing(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_Parsing(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_Parsing(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'Parsing' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "Parsing" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_Parsing", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_Cython__Compiler__Parsing) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Cython.Compiler.Parsing")) {
      if (unlikely((PyDict_SetItemString(modules, "Cython.Compiler.Parsing", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "Cython/Compiler/Parsing.py":18
 *                _CDEF_MODIFIERS=tuple, COMMON_BINOP_MISTAKES=dict)
 * 
 * from io import StringIO             # <<<<<<<<<<<<<<
 * import re
 * from unicodedata import lookup as lookup_unicodechar
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringIO};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_io, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringIO};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 18, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 18, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":19
 * 
 * from io import StringIO
 * import re             # <<<<<<<<<<<<<<
 * from unicodedata import lookup as lookup_unicodechar
 * from functools import partial, reduce
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_re, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_re);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_re, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":20
 * from io import StringIO
 * import re
 * from unicodedata import lookup as lookup_unicodechar             # <<<<<<<<<<<<<<
 * from functools import partial, reduce
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_lookup};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_unicodedata, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_lookup};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_lookup_unicodechar, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":21
 * import re
 * from unicodedata import lookup as lookup_unicodechar
 * from functools import partial, reduce             # <<<<<<<<<<<<<<
 * 
 * from .Scanning import PyrexScanner, FileSourceDescriptor, tentatively_scan
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_partial,__pyx_mstate_global->__pyx_n_u_reduce};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_functools, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_partial,__pyx_mstate_global->__pyx_n_u_reduce};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 21, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_partial);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_partial, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_reduce);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_reduce, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":23
 * from functools import partial, reduce
 * 
 * from .Scanning import PyrexScanner, FileSourceDescriptor, tentatively_scan             # <<<<<<<<<<<<<<
 * from . import Nodes
 * from . import ExprNodes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PyrexScanner,__pyx_mstate_global->__pyx_n_u_FileSourceDescriptor,__pyx_mstate_global->__pyx_n_u_tentatively_scan};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Scanning, __pyx_imported_names, 3, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Scanning, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_FileSourceDescriptor,__pyx_mstate_global->__pyx_n_u_tentatively_scan};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_FileSourceDescriptor, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 23, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":24
 * 
 * from .Scanning import PyrexScanner, FileSourceDescriptor, tentatively_scan
 * from . import Nodes             # <<<<<<<<<<<<<<
 * from . import ExprNodes
 * from . import MatchCaseNodes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_Nodes);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_Nodes, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":25
 * from .Scanning import PyrexScanner, FileSourceDescriptor, tentatively_scan
 * from . import Nodes
 * from . import ExprNodes             # <<<<<<<<<<<<<<
 * from . import MatchCaseNodes
 * from . import Builtin
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_ExprNodes, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":26
 * from . import Nodes
 * from . import ExprNodes
 * from . import MatchCaseNodes             # <<<<<<<<<<<<<<
 * from . import Builtin
 * from . import StringEncoding
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_MatchCaseNodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_MatchCaseNodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 26, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 26, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":27
 * from . import ExprNodes
 * from . import MatchCaseNodes
 * from . import Builtin             # <<<<<<<<<<<<<<
 * from . import StringEncoding
 * from .StringEncoding import EncodedString, bytes_literal
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 27, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 27, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_Builtin);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_Builtin, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":28
 * from . import MatchCaseNodes
 * from . import Builtin
 * from . import StringEncoding             # <<<<<<<<<<<<<<
 * from .StringEncoding import EncodedString, bytes_literal
 * from .ModuleNode import ModuleNode
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringEncoding};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_StringEncoding};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 28, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_StringEncoding);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_StringEncoding, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":29
 * from . import Builtin
 * from . import StringEncoding
 * from .StringEncoding import EncodedString, bytes_literal             # <<<<<<<<<<<<<<
 * from .ModuleNode import ModuleNode
 * from .Errors import error, warning, CompileError
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_EncodedString,__pyx_mstate_global->__pyx_n_u_bytes_literal};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_StringEncoding, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_StringEncoding, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 29, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_EncodedString,__pyx_mstate_global->__pyx_n_u_bytes_literal};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 29, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_EncodedString, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_bytes_literal);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_bytes_literal, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":30
 * from . import StringEncoding
 * from .StringEncoding import EncodedString, bytes_literal
 * from .ModuleNode import ModuleNode             # <<<<<<<<<<<<<<
 * from .Errors import error, warning, CompileError
 * from .. import Utils
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ModuleNode};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_ModuleNode, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_ModuleNode, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ModuleNode};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_ModuleNode);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_ModuleNode, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":31
 * from .StringEncoding import EncodedString, bytes_literal
 * from .ModuleNode import ModuleNode
 * from .Errors import error, warning, CompileError             # <<<<<<<<<<<<<<
 * from .. import Utils
 * from . import Future
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_CompileError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_Errors, __pyx_imported_names, 3, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_Errors, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_error,__pyx_mstate_global->__pyx_n_u_warning,__pyx_mstate_global->__pyx_n_u_CompileError};
    for (__pyx_t_3=0; __pyx_t_3 < 3; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_error);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_error, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_warning);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_warning, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 31, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":32
 * from .ModuleNode import ModuleNode
 * from .Errors import error, warning, CompileError
 * from .. import Utils             # <<<<<<<<<<<<<<
 * from . import Future
 * from . import Options
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Utils};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Utils};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_Utils);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_Utils, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":33
 * from .Errors import error, warning, CompileError
 * from .. import Utils
 * from . import Future             # <<<<<<<<<<<<<<
 * from . import Options
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Future};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 33, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Future};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 33, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_Future);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_Future, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":34
 * from .. import Utils
 * from . import Future
 * from . import Options             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Options};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__35, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Options};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 34, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_Options);
        __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_Options, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":37
 * 
 * 
 * _CDEF_MODIFIERS = ('inline', 'nogil', 'api')             # <<<<<<<<<<<<<<
 * statement_terminators = cython.declare(frozenset, frozenset((
 *     ';', 'NEWLINE', 'EOF')))
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_tuple[14]);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing__CDEF_MODIFIERS);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing__CDEF_MODIFIERS, __pyx_mstate_global->__pyx_tuple[14]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[14]);

  /* "Cython/Compiler/Parsing.py":38
 * 
 * _CDEF_MODIFIERS = ('inline', 'nogil', 'api')
 * statement_terminators = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     ';', 'NEWLINE', 'EOF')))
 * 
*/
  __pyx_t_2 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[15]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":41
 *     ';', 'NEWLINE', 'EOF')))
 * 
 * class Ctx:             # <<<<<<<<<<<<<<
 *     #  Parsing context
 *     level = 'other'
*/
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_Ctx, __pyx_mstate_global->__pyx_n_u_Ctx, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "Cython/Compiler/Parsing.py":43
 * class Ctx:
 *     #  Parsing context
 *     level = 'other'             # <<<<<<<<<<<<<<
 *     visibility = 'private'
 *     cdef_flag = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_n_u_other) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":44
 *     #  Parsing context
 *     level = 'other'
 *     visibility = 'private'             # <<<<<<<<<<<<<<
 *     cdef_flag = False
 *     typedef_flag = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_visibility, __pyx_mstate_global->__pyx_n_u_private) < (0)) __PYX_ERR(0, 44, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":45
 *     level = 'other'
 *     visibility = 'private'
 *     cdef_flag = False             # <<<<<<<<<<<<<<
 *     typedef_flag = False
 *     api = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_cdef_flag, Py_False) < (0)) __PYX_ERR(0, 45, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":46
 *     visibility = 'private'
 *     cdef_flag = False
 *     typedef_flag = False             # <<<<<<<<<<<<<<
 *     api = False
 *     overridable = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_typedef_flag, Py_False) < (0)) __PYX_ERR(0, 46, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":47
 *     cdef_flag = False
 *     typedef_flag = False
 *     api = False             # <<<<<<<<<<<<<<
 *     overridable = False
 *     nogil = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_api, Py_False) < (0)) __PYX_ERR(0, 47, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":48
 *     typedef_flag = False
 *     api = False
 *     overridable = False             # <<<<<<<<<<<<<<
 *     nogil = False
 *     namespace = None
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_overridable, Py_False) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":49
 *     api = False
 *     overridable = False
 *     nogil = False             # <<<<<<<<<<<<<<
 *     namespace = None
 *     templates = None
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_nogil, Py_False) < (0)) __PYX_ERR(0, 49, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":50
 *     overridable = False
 *     nogil = False
 *     namespace = None             # <<<<<<<<<<<<<<
 *     templates = None
 *     allow_struct_enum_decorator = False
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_namespace, Py_None) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":51
 *     nogil = False
 *     namespace = None
 *     templates = None             # <<<<<<<<<<<<<<
 *     allow_struct_enum_decorator = False
 * 
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_templates, Py_None) < (0)) __PYX_ERR(0, 51, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":52
 *     namespace = None
 *     templates = None
 *     allow_struct_enum_decorator = False             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, **kwds):
*/
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_allow_struct_enum_decorator, Py_False) < (0)) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":54
 *     allow_struct_enum_decorator = False
 * 
 *     def __init__(self, **kwds):             # <<<<<<<<<<<<<<
 *         self.__dict__.update(kwds)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_3Ctx_1__init__, 0, __pyx_mstate_global->__pyx_n_u_Ctx___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_4) < (0)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":57
 *         self.__dict__.update(kwds)
 * 
 *     def __call__(self, **kwds):             # <<<<<<<<<<<<<<
 *         ctx = Ctx()
 *         d = ctx.__dict__
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_3Ctx_3__call__, 0, __pyx_mstate_global->__pyx_n_u_Ctx___call, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_call, __pyx_t_4) < (0)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":41
 *     ';', 'NEWLINE', 'EOF')))
 * 
 * class Ctx:             # <<<<<<<<<<<<<<
 *     #  Parsing context
 *     level = 'other'
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_Ctx, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Ctx, __pyx_t_4) < (0)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":190
 * #or_test: and_test ('or' and_test)*
 * 
 * COMMON_BINOP_MISTAKES = {'||': 'or', '&&': 'and'}             # <<<<<<<<<<<<<<
 * 
 * @cython.cfunc
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__63, __pyx_mstate_global->__pyx_n_u_or) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__46, __pyx_mstate_global->__pyx_n_u_and) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_COMMON_BINOP_MISTAKES, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":314
 * 
 * 
 * comparison_ops = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     '<', '>', '==', '>=', '<=', '<>', '!=',
 *     'in', 'is', 'not'
*/
  __pyx_t_2 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[16]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_comparison_ops);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_comparison_ops, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":445
 * 
 * @cython.cfunc
 * def p_yield_expression(s: PyrexScanner, statement_terminators: frozenset = statement_terminators):             # <<<<<<<<<<<<<<
 *     # s.sy == "yield"
 *     pos = s.position()
*/
  __Pyx_INCREF(__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators);
  __pyx_mstate_global->__pyx_k__25 = __pyx_v_6Cython_8Compiler_7Parsing_statement_terminators;
  __Pyx_GIVEREF(__pyx_v_6Cython_8Compiler_7Parsing_statement_terminators);

  /* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_1make_slice_node, 0, __pyx_mstate_global->__pyx_n_u_make_slice_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[17]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_make_slice_node, __pyx_t_2) < (0)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":1662
 * 
 * 
 * expr_terminators = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     ')', ']', '}', ':', '=', 'NEWLINE', 'EOF')))
 * 
*/
  __pyx_t_2 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[18]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_expr_terminators);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_expr_terminators, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2157
 * 
 * 
 * inequality_relations = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     '<', '<=', '>', '>=')))
 * 
*/
  __pyx_t_2 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[19]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_inequality_relations);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_inequality_relations, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2658
 * 
 * @cython.cfunc
 * def p_suite(s: PyrexScanner, ctx=Ctx()):             # <<<<<<<<<<<<<<
 *     return p_suite_with_docstring(s, ctx, with_doc_only=False)[1]
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_mstate_global->__pyx_k__44 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_s, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 2744, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_nonempty, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_3p_c_base_type, 0, __pyx_mstate_global->__pyx_n_u_p_c_base_type, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[20]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_p_c_base_type, __pyx_t_5) < (0)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":2762
 * 
 * 
 * calling_convention_words = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     "__stdcall", "__cdecl", "__fastcall")))
 * 
*/
  __pyx_t_5 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[21]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_calling_convention_words, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3030
 * 
 * 
 * basic_c_type_names = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     "void", "char", "int", "float", "double", "bint")))
 * 
*/
  __pyx_t_5 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[22]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3035
 * special_basic_c_types = cython.declare(dict, {
 *     # name : (signed, longness)
 *     "Py_UNICODE" : (0, 0),             # <<<<<<<<<<<<<<
 *     "Py_UCS4"    : (0, 0),
 *     "Py_hash_t"  : (2, 0),
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Py_UNICODE, __pyx_mstate_global->__pyx_tuple[23]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3036
 *     # name : (signed, longness)
 *     "Py_UNICODE" : (0, 0),
 *     "Py_UCS4"    : (0, 0),             # <<<<<<<<<<<<<<
 *     "Py_hash_t"  : (2, 0),
 *     "Py_ssize_t" : (2, 0),
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Py_UCS4, __pyx_mstate_global->__pyx_tuple[23]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3037
 *     "Py_UNICODE" : (0, 0),
 *     "Py_UCS4"    : (0, 0),
 *     "Py_hash_t"  : (2, 0),             # <<<<<<<<<<<<<<
 *     "Py_ssize_t" : (2, 0),
 *     "ssize_t"    : (2, 0),
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Py_hash_t, __pyx_mstate_global->__pyx_tuple[24]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3038
 *     "Py_UCS4"    : (0, 0),
 *     "Py_hash_t"  : (2, 0),
 *     "Py_ssize_t" : (2, 0),             # <<<<<<<<<<<<<<
 *     "ssize_t"    : (2, 0),
 *     "size_t"     : (0, 0),
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Py_ssize_t, __pyx_mstate_global->__pyx_tuple[24]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3039
 *     "Py_hash_t"  : (2, 0),
 *     "Py_ssize_t" : (2, 0),
 *     "ssize_t"    : (2, 0),             # <<<<<<<<<<<<<<
 *     "size_t"     : (0, 0),
 *     "ptrdiff_t"  : (2, 0),
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ssize_t, __pyx_mstate_global->__pyx_tuple[24]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3040
 *     "Py_ssize_t" : (2, 0),
 *     "ssize_t"    : (2, 0),
 *     "size_t"     : (0, 0),             # <<<<<<<<<<<<<<
 *     "ptrdiff_t"  : (2, 0),
 *     "Py_tss_t"   : (1, 0),
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_size_t, __pyx_mstate_global->__pyx_tuple[23]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3041
 *     "ssize_t"    : (2, 0),
 *     "size_t"     : (0, 0),
 *     "ptrdiff_t"  : (2, 0),             # <<<<<<<<<<<<<<
 *     "Py_tss_t"   : (1, 0),
 * })
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ptrdiff_t, __pyx_mstate_global->__pyx_tuple[24]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "Cython/Compiler/Parsing.py":3042
 *     "size_t"     : (0, 0),
 *     "ptrdiff_t"  : (2, 0),
 *     "Py_tss_t"   : (1, 0),             # <<<<<<<<<<<<<<
 * })
 * 
*/
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Py_tss_t, __pyx_mstate_global->__pyx_tuple[25]) < (0)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3045
 * })
 * 
 * sign_and_longness_words = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     "short", "long", "signed", "unsigned")))
 * 
*/
  __pyx_t_5 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[26]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3051
 *     frozenset,
 *     basic_c_type_names
 *     | sign_and_longness_words             # <<<<<<<<<<<<<<
 *     | frozenset(special_basic_c_types))
 * 
*/
  __pyx_t_5 = PyNumber_Or(__pyx_v_6Cython_8Compiler_7Parsing_basic_c_type_names, __pyx_v_6Cython_8Compiler_7Parsing_sign_and_longness_words); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "Cython/Compiler/Parsing.py":3052
 *     basic_c_type_names
 *     | sign_and_longness_words
 *     | frozenset(special_basic_c_types))             # <<<<<<<<<<<<<<
 * 
 * struct_enum_union = cython.declare(frozenset, frozenset((
*/
  __pyx_t_2 = __Pyx_PyFrozenSet_New(__pyx_v_6Cython_8Compiler_7Parsing_special_basic_c_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Or(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_base_type_start_words, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3054
 *     | frozenset(special_basic_c_types))
 * 
 * struct_enum_union = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     "struct", "union", "enum", "packed")))
 * 
*/
  __pyx_t_4 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[27]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_struct_enum_union, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3087
 * 
 * @cython.ccall
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),             # <<<<<<<<<<<<<<
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3087, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_mstate_global->__pyx_k__45 = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/
  __pyx_t_5 = NULL;

  /* "Cython/Compiler/Parsing.py":3087
 * 
 * @cython.ccall
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),             # <<<<<<<<<<<<<<
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
 *                    assignable: cython.bint = False, nonempty: cython.bint = False,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3087, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }

  /* "Cython/Compiler/Parsing.py":3086
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_declarator(s: PyrexScanner, ctx = Ctx(),
 *                    empty: cython.bint = False, is_type: cython.bint = False, cmethod_flag: cython.bint = False,
*/
  __pyx_t_2 = PyTuple_Pack(7, __pyx_t_4, Py_False, Py_False, Py_False, Py_False, Py_False, Py_False); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_s, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_empty, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_is_type, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_assignable, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_nonempty, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_calling_convention_allowed, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_5p_c_declarator, 0, __pyx_mstate_global->__pyx_n_u_p_c_declarator, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_p_c_declarator, __pyx_t_5) < (0)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3162
 * 
 * 
 * supported_overloaded_operators = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     '+', '-', '*', '/', '%',
 *     '++', '--', '~', '|', '&', '^', '<<', '>>', ',',
*/
  __pyx_t_5 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[28]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_supported_overloaded_operators, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3342
 * 
 * 
 * c_arg_list_terminators = cython.declare(frozenset, frozenset((             # <<<<<<<<<<<<<<
 *     '*', '**', '...', ')', ':', '/')))
 * 
*/
  __pyx_t_5 = __Pyx_PyFrozenSet_New(__pyx_mstate_global->__pyx_tuple[29]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing_c_arg_list_terminators);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing_c_arg_list_terminators, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3347
 * 
 * @cython.ccall
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),             # <<<<<<<<<<<<<<
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_mstate_global->__pyx_k__52 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/
  __pyx_t_2 = NULL;

  /* "Cython/Compiler/Parsing.py":3347
 * 
 * @cython.ccall
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),             # <<<<<<<<<<<<<<
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
 *                  nonempty_declarators: cython.bint = False, kw_only: cython.bint = False,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }

  /* "Cython/Compiler/Parsing.py":3346
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_arg_list(s: PyrexScanner, ctx = Ctx(),
 *                  in_pyfunc: cython.bint = False, cmethod_flag: cython.bint = False,
*/
  __pyx_t_4 = PyTuple_Pack(6, __pyx_t_5, Py_False, Py_False, Py_False, Py_False, Py_True); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_s, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_in_pyfunc, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_cmethod_flag, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_nonempty_declarators, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_kw_only, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_annotated, __pyx_mstate_global->__pyx_kp_u_cython_bint) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_7p_c_arg_list, 0, __pyx_mstate_global->__pyx_n_u_p_c_arg_list, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_p_c_arg_list, __pyx_t_2) < (0)) __PYX_ERR(0, 3346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4129
 * 
 * @cython.ccall
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):             # <<<<<<<<<<<<<<
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
 *     if s.sy != 'EOF':
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate_global->__pyx_k__54 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4128
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_code(s: PyrexScanner, level=None, ctx=Ctx):
 *     body = p_statement_list(s, ctx(level = level), first_statement=True)
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyTuple_Pack(2, Py_None, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_s, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_9p_code, 0, __pyx_mstate_global->__pyx_n_u_p_code, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_p_code, __pyx_t_4) < (0)) __PYX_ERR(0, 4128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Parsing.py":4137
 * 
 * 
 * _match_compiler_directive_comment = cython.declare(object, re.compile(             # <<<<<<<<<<<<<<
 *     r"^#\s*cython\s*:\s*((\w|[.])+\s*=.*)$").match)
 * 
*/
  __pyx_t_2 = __pyx_v_6Cython_8Compiler_7Parsing_re;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_s_cython_s_s_w_s};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_compile, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }

  /* "Cython/Compiler/Parsing.py":4138
 * 
 * _match_compiler_directive_comment = cython.declare(object, re.compile(
 *     r"^#\s*cython\s*:\s*((\w|[.])+\s*=.*)$").match)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Parsing__match_compiler_directive_comment, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4182
 * 
 * @cython.ccall
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):             # <<<<<<<<<<<<<<
 *     pos = s.position()
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate_global->__pyx_k__56 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Parsing.py":4181
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_module(s: PyrexScanner, pxd, full_module_name, ctx=Ctx):
 *     pos = s.position()
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_s, __pyx_mstate_global->__pyx_n_u_PyrexScanner) < (0)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_11p_module, 0, __pyx_mstate_global->__pyx_n_u_p_module, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_p_module, __pyx_t_5) < (0)) __PYX_ERR(0, 4181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_level, __pyx_mstate_global->__pyx_kp_u_cython_long) < (0)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Parsing_13print_parse_tree, 0, __pyx_mstate_global->__pyx_n_u_print_parse_tree, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Parsing, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[30]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_print_parse_tree, __pyx_t_2) < (0)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init Cython.Compiler.Parsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Cython.Compiler.Parsing");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(0, 902, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 975, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 2313, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyDict_Type__update.type = (PyObject*)(&PyDict_Type);
  __pyx_mstate->__pyx_umethod_PyDict_Type__update.method_name = &__pyx_mstate->__pyx_n_u_update;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__rsplit.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__rsplit.method_name = &__pyx_mstate->__pyx_n_u_rsplit;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__rstrip.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__rstrip.method_name = &__pyx_mstate->__pyx_n_u_rstrip;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "Cython/Compiler/Parsing.py":324
 * @cython.cfunc
 * def p_bit_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('|',), p_xor_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_kp_u__9); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "Cython/Compiler/Parsing.py":331
 * @cython.cfunc
 * def p_xor_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('^',), p_and_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_kp_u__10); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Compiler/Parsing.py":338
 * @cython.cfunc
 * def p_and_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('&',), p_shift_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_kp_u__11); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "Cython/Compiler/Parsing.py":345
 * @cython.cfunc
 * def p_shift_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('<<', '>>'), p_arith_expr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__12, __pyx_mstate_global->__pyx_kp_u__13); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "Cython/Compiler/Parsing.py":352
 * @cython.cfunc
 * def p_arith_expr(s: PyrexScanner):
 *     return p_binop_expr(s, ('+', '-'), p_term)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__14, __pyx_mstate_global->__pyx_kp_u__15); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "Cython/Compiler/Parsing.py":359
 * @cython.cfunc
 * def p_term(s: PyrexScanner):
 *     return p_binop_expr(s, ('*', '@', '/', '%', '//'), p_factor)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(5, __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_kp_u__16, __pyx_mstate_global->__pyx_kp_u__2, __pyx_mstate_global->__pyx_kp_u__17, __pyx_mstate_global->__pyx_kp_u__18); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "Cython/Compiler/Parsing.py":706
 *     # 1, 2 or 3 ExprNodes, depending on how
 *     # many slice elements were encountered.
 *     start = p_slice_element(s, (':',))             # <<<<<<<<<<<<<<
 *     if s.sy != ':':
 *         return [start]
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_kp_u__3); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "Cython/Compiler/Parsing.py":710
 *         return [start]
 *     s.next()
 *     stop = p_slice_element(s, (':', ',', ']'))             # <<<<<<<<<<<<<<
 *     if s.sy != ':':
 *         return [start, stop]
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_kp_u__3, __pyx_mstate_global->__pyx_kp_u_, __pyx_mstate_global->__pyx_kp_u__30); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);

  /* "Cython/Compiler/Parsing.py":792
 *         return ExprNodes.FloatNode(pos, value = value)
 *     elif sy == 'IMAG':
 *         value = s.systring[:-1]             # <<<<<<<<<<<<<<
 *         s.next()
 *         return ExprNodes.ImagNode(pos, value = value)
*/
  __pyx_mstate_global->__pyx_slice[0] = PySlice_New(Py_None, __pyx_mstate_global->__pyx_int_neg_1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[0])) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[0]);

  /* "Cython/Compiler/Parsing.py":2266
 *             s.included_files.append(include_file_name)
 *             source_desc = FileSourceDescriptor(include_file_path)
 *             with source_desc.get_file_object() as f:             # <<<<<<<<<<<<<<
 *                 s2 = PyrexScanner(f, source_desc, s, source_encoding=f.encoding, parse_comments=s.parse_comments)
 *                 tree = p_statement_list(s2, ctx)
*/
  __pyx_mstate_global->__pyx_tuple[8] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[8])) __PYX_ERR(0, 2266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[8]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[8]);

  /* "Cython/Compiler/Parsing.py":2530
 *         # We used to dep-warn about this but removed the warning again since
 *         # we don't have a good answer yet for all use cases.
 *         if s.context.compiler_directives.get("warn.deprecated.DEF", False):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'DEF' statement  will be removed in a future Cython version. "
*/
  __pyx_mstate_global->__pyx_tuple[9] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_warn_deprecated_DEF, Py_False); if (unlikely(!__pyx_mstate_global->__pyx_tuple[9])) __PYX_ERR(0, 2530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[9]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[9]);

  /* "Cython/Compiler/Parsing.py":2537
 *         return p_DEF_statement(s)
 *     elif s.sy == 'IF':
 *         if s.context.compiler_directives.get("warn.deprecated.IF", True):             # <<<<<<<<<<<<<<
 *             warning(pos,
 *                     "The 'IF' statement is deprecated and will be removed in a future Cython version. "
*/
  __pyx_mstate_global->__pyx_tuple[10] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_warn_deprecated_IF, Py_True); if (unlikely(!__pyx_mstate_global->__pyx_tuple[10])) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[10]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[10]);

  /* "Cython/Compiler/Parsing.py":2903
 *     # For templated types, all parameters are types.
 *     positional_args, keyword_args = (
 *         p_positional_and_keyword_args(s, (']',), templates)             # <<<<<<<<<<<<<<
 *     )
 *     s.expect(']')
*/
  __pyx_mstate_global->__pyx_tuple[11] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_kp_u__30); if (unlikely(!__pyx_mstate_global->__pyx_tuple[11])) __PYX_ERR(0, 2903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[11]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[11]);

  /* "Cython/Compiler/Parsing.py":2939
 *             retval = True
 * 
 *     for sv in saved[::-1]:             # <<<<<<<<<<<<<<
 *         s.put_back(*sv)
 * 
*/
  __pyx_mstate_global->__pyx_slice[1] = PySlice_New(Py_None, Py_None, __pyx_mstate_global->__pyx_int_neg_1); if (unlikely(!__pyx_mstate_global->__pyx_slice[1])) __PYX_ERR(0, 2939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[1]);

  /* "Cython/Compiler/Parsing.py":3002
 *         dotted_path.reverse()
 *         for p in dotted_path:
 *             s.put_back('IDENT', *p)             # <<<<<<<<<<<<<<
 *             s.put_back('.', '.', p[1])  # gets the position slightly wrong
 * 
*/
  __pyx_mstate_global->__pyx_tuple[12] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_IDENT); if (unlikely(!__pyx_mstate_global->__pyx_tuple[12])) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[12]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[12]);

  /* "Cython/Compiler/Parsing.py":4055
 *             break
 *         s.next()
 *     s.expect(']', "Expected 'object', 'type' or 'check_size'")             # <<<<<<<<<<<<<<
 *     return objstruct_name, typeobj_name, check_size
 * 
*/
  __pyx_mstate_global->__pyx_tuple[13] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u__30, __pyx_mstate_global->__pyx_kp_u_Expected_object_type_or_check_si); if (unlikely(!__pyx_mstate_global->__pyx_tuple[13])) __PYX_ERR(0, 4055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[13]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[13]);

  /* "Cython/Compiler/Parsing.py":4757
 *     elif type(node) is tuple:
 *         f.write(f"({node[0]} @ {node[1]}\n")
 *         for item in node[2:]:             # <<<<<<<<<<<<<<
 *             print_parse_tree(f, item, level+1)
 *         f.write(f"{ind})\n")
*/
  __pyx_mstate_global->__pyx_slice[2] = PySlice_New(__pyx_mstate_global->__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[2])) __PYX_ERR(0, 4757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[2]);

  /* "Cython/Compiler/Parsing.py":37
 * 
 * 
 * _CDEF_MODIFIERS = ('inline', 'nogil', 'api')             # <<<<<<<<<<<<<<
 * statement_terminators = cython.declare(frozenset, frozenset((
 *     ';', 'NEWLINE', 'EOF')))
*/
  __pyx_mstate_global->__pyx_tuple[14] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_n_u_inline, __pyx_mstate_global->__pyx_n_u_nogil, __pyx_mstate_global->__pyx_n_u_api); if (unlikely(!__pyx_mstate_global->__pyx_tuple[14])) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[14]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[14]);

  /* "Cython/Compiler/Parsing.py":39
 * _CDEF_MODIFIERS = ('inline', 'nogil', 'api')
 * statement_terminators = cython.declare(frozenset, frozenset((
 *     ';', 'NEWLINE', 'EOF')))             # <<<<<<<<<<<<<<
 * 
 * class Ctx:
*/
  __pyx_mstate_global->__pyx_tuple[15] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_kp_u__43, __pyx_mstate_global->__pyx_n_u_NEWLINE, __pyx_mstate_global->__pyx_n_u_EOF); if (unlikely(!__pyx_mstate_global->__pyx_tuple[15])) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[15]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[15]);

  /* "Cython/Compiler/Parsing.py":315
 * 
 * comparison_ops = cython.declare(frozenset, frozenset((
 *     '<', '>', '==', '>=', '<=', '<>', '!=',             # <<<<<<<<<<<<<<
 *     'in', 'is', 'not'
 * )))
*/
  __pyx_mstate_global->__pyx_tuple[16] = PyTuple_Pack(10, __pyx_mstate_global->__pyx_kp_u__20, __pyx_mstate_global->__pyx_kp_u__22, __pyx_mstate_global->__pyx_kp_u__64, __pyx_mstate_global->__pyx_kp_u__65, __pyx_mstate_global->__pyx_kp_u__66, __pyx_mstate_global->__pyx_kp_u__7, __pyx_mstate_global->__pyx_kp_u__8, __pyx_mstate_global->__pyx_n_u_in, __pyx_mstate_global->__pyx_n_u_is, __pyx_mstate_global->__pyx_n_u_not); if (unlikely(!__pyx_mstate_global->__pyx_tuple[16])) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[16]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[16]);

  /* "Cython/Compiler/Parsing.py":748
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def make_slice_node(pos, start, stop = None, step = None):
 *     if not start:
*/
  __pyx_mstate_global->__pyx_tuple[17] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[17])) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[17]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[17]);

  /* "Cython/Compiler/Parsing.py":1663
 * 
 * expr_terminators = cython.declare(frozenset, frozenset((
 *     ')', ']', '}', ':', '=', 'NEWLINE', 'EOF')))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[18] = PyTuple_Pack(7, __pyx_mstate_global->__pyx_kp_u__24, __pyx_mstate_global->__pyx_kp_u__30, __pyx_mstate_global->__pyx_kp_u__39, __pyx_mstate_global->__pyx_kp_u__3, __pyx_mstate_global->__pyx_kp_u__29, __pyx_mstate_global->__pyx_n_u_NEWLINE, __pyx_mstate_global->__pyx_n_u_EOF); if (unlikely(!__pyx_mstate_global->__pyx_tuple[18])) __PYX_ERR(0, 1663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[18]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[18]);

  /* "Cython/Compiler/Parsing.py":2158
 * 
 * inequality_relations = cython.declare(frozenset, frozenset((
 *     '<', '<=', '>', '>=')))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[19] = PyTuple_Pack(4, __pyx_mstate_global->__pyx_kp_u__20, __pyx_mstate_global->__pyx_kp_u__66, __pyx_mstate_global->__pyx_kp_u__22, __pyx_mstate_global->__pyx_kp_u__65); if (unlikely(!__pyx_mstate_global->__pyx_tuple[19])) __PYX_ERR(0, 2158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[19]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[19]);

  /* "Cython/Compiler/Parsing.py":2744
 * 
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def p_c_base_type(s: PyrexScanner, nonempty: cython.bint = False, templates=None):
 *     if s.sy == '(':
*/
  __pyx_mstate_global->__pyx_tuple[20] = PyTuple_Pack(2, Py_False, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[20])) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[20]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[20]);

  /* "Cython/Compiler/Parsing.py":2763
 * 
 * calling_convention_words = cython.declare(frozenset, frozenset((
 *     "__stdcall", "__cdecl", "__fastcall")))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[21] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_n_u_stdcall, __pyx_mstate_global->__pyx_n_u_cdecl, __pyx_mstate_global->__pyx_n_u_fastcall); if (unlikely(!__pyx_mstate_global->__pyx_tuple[21])) __PYX_ERR(0, 2763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[21]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[21]);

  /* "Cython/Compiler/Parsing.py":3031
 * 
 * basic_c_type_names = cython.declare(frozenset, frozenset((
 *     "void", "char", "int", "float", "double", "bint")))             # <<<<<<<<<<<<<<
 * 
 * special_basic_c_types = cython.declare(dict, {
*/
  __pyx_mstate_global->__pyx_tuple[22] = PyTuple_Pack(6, __pyx_mstate_global->__pyx_n_u_void, __pyx_mstate_global->__pyx_n_u_char, __pyx_mstate_global->__pyx_n_u_int, __pyx_mstate_global->__pyx_n_u_float, __pyx_mstate_global->__pyx_n_u_double, __pyx_mstate_global->__pyx_n_u_bint); if (unlikely(!__pyx_mstate_global->__pyx_tuple[22])) __PYX_ERR(0, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[22]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[22]);

  /* "Cython/Compiler/Parsing.py":3035
 * special_basic_c_types = cython.declare(dict, {
 *     # name : (signed, longness)
 *     "Py_UNICODE" : (0, 0),             # <<<<<<<<<<<<<<
 *     "Py_UCS4"    : (0, 0),
 *     "Py_hash_t"  : (2, 0),
*/
  __pyx_mstate_global->__pyx_tuple[23] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_int_0, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[23])) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[23]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[23]);

  /* "Cython/Compiler/Parsing.py":3037
 *     "Py_UNICODE" : (0, 0),
 *     "Py_UCS4"    : (0, 0),
 *     "Py_hash_t"  : (2, 0),             # <<<<<<<<<<<<<<
 *     "Py_ssize_t" : (2, 0),
 *     "ssize_t"    : (2, 0),
*/
  __pyx_mstate_global->__pyx_tuple[24] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_int_2, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[24])) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[24]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[24]);

  /* "Cython/Compiler/Parsing.py":3042
 *     "size_t"     : (0, 0),
 *     "ptrdiff_t"  : (2, 0),
 *     "Py_tss_t"   : (1, 0),             # <<<<<<<<<<<<<<
 * })
 * 
*/
  __pyx_mstate_global->__pyx_tuple[25] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_int_1, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[25])) __PYX_ERR(0, 3042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[25]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[25]);

  /* "Cython/Compiler/Parsing.py":3046
 * 
 * sign_and_longness_words = cython.declare(frozenset, frozenset((
 *     "short", "long", "signed", "unsigned")))             # <<<<<<<<<<<<<<
 * 
 * base_type_start_words = cython.declare(
*/
  __pyx_mstate_global->__pyx_tuple[26] = PyTuple_Pack(4, __pyx_mstate_global->__pyx_n_u_short, __pyx_mstate_global->__pyx_n_u_long, __pyx_mstate_global->__pyx_n_u_signed, __pyx_mstate_global->__pyx_n_u_unsigned); if (unlikely(!__pyx_mstate_global->__pyx_tuple[26])) __PYX_ERR(0, 3046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[26]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[26]);

  /* "Cython/Compiler/Parsing.py":3055
 * 
 * struct_enum_union = cython.declare(frozenset, frozenset((
 *     "struct", "union", "enum", "packed")))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[27] = PyTuple_Pack(4, __pyx_mstate_global->__pyx_n_u_struct, __pyx_mstate_global->__pyx_n_u_union, __pyx_mstate_global->__pyx_n_u_enum, __pyx_mstate_global->__pyx_n_u_packed); if (unlikely(!__pyx_mstate_global->__pyx_tuple[27])) __PYX_ERR(0, 3055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[27]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[27]);

  /* "Cython/Compiler/Parsing.py":3163
 * 
 * supported_overloaded_operators = cython.declare(frozenset, frozenset((
 *     '+', '-', '*', '/', '%',             # <<<<<<<<<<<<<<
 *     '++', '--', '~', '|', '&', '^', '<<', '>>', ',',
 *     '==', '!=', '>=', '>', '<=', '<',
*/
  __pyx_mstate_global->__pyx_tuple[28] = PyTuple_Pack(25, __pyx_mstate_global->__pyx_kp_u__14, __pyx_mstate_global->__pyx_kp_u__15, __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_kp_u__2, __pyx_mstate_global->__pyx_kp_u__17, __pyx_mstate_global->__pyx_kp_u__67, __pyx_mstate_global->__pyx_kp_u__68, __pyx_mstate_global->__pyx_kp_u__19, __pyx_mstate_global->__pyx_kp_u__9, __pyx_mstate_global->__pyx_kp_u__11, __pyx_mstate_global->__pyx_kp_u__10, __pyx_mstate_global->__pyx_kp_u__12, __pyx_mstate_global->__pyx_kp_u__13, __pyx_mstate_global->__pyx_kp_u_, __pyx_mstate_global->__pyx_kp_u__64, __pyx_mstate_global->__pyx_kp_u__8, __pyx_mstate_global->__pyx_kp_u__65, __pyx_mstate_global->__pyx_kp_u__22, __pyx_mstate_global->__pyx_kp_u__66, __pyx_mstate_global->__pyx_kp_u__20, __pyx_mstate_global->__pyx_kp_u__50, __pyx_mstate_global->__pyx_kp_u__49, __pyx_mstate_global->__pyx_kp_u__40, __pyx_mstate_global->__pyx_kp_u__29, __pyx_mstate_global->__pyx_n_u_bool); if (unlikely(!__pyx_mstate_global->__pyx_tuple[28])) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[28]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[28]);

  /* "Cython/Compiler/Parsing.py":3343
 * 
 * c_arg_list_terminators = cython.declare(frozenset, frozenset((
 *     '*', '**', '...', ')', ':', '/')))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_mstate_global->__pyx_tuple[29] = PyTuple_Pack(6, __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_kp_u__28, __pyx_mstate_global->__pyx_kp_u__31, __pyx_mstate_global->__pyx_kp_u__24, __pyx_mstate_global->__pyx_kp_u__3, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[29])) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[29]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[29]);

  /* "Cython/Compiler/Parsing.py":4747
 * #----------------------------------------------
 * 
 * @cython.ccall             # <<<<<<<<<<<<<<
 * def print_parse_tree(f, node, level: cython.long, key = None):
 *     ind: str = "  " * level
*/
  __pyx_mstate_global->__pyx_tuple[30] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[30])) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[30]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[30]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<31; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_slice;
    for (Py_ssize_t i=0; i<3; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{1},{1},{68},{36},{36},{38},{39},{47},{30},{67},{56},{84},{51},{32},{7},{16},{22},{26},{26},{24},{30},{26},{55},{17},{27},{33},{20},{16},{68},{79},{37},{15},{18},{34},{17},{22},{33},{34},{33},{30},{126},{19},{25},{30},{41},{35},{47},{19},{42},{40},{23},{22},{38},{84},{24},{38},{29},{23},{22},{22},{43},{40},{27},{61},{41},{38},{66},{22},{37},{4},{179},{62},{59},{44},{36},{43},{50},{42},{54},{44},{126},{16},{34},{36},{38},{45},{34},{28},{26},{30},{33},{37},{27},{22},{42},{45},{52},{188},{184},{64},{167},{63},{60},{57},{23},{28},{22},{17},{33},{12},{12},{31},{53},{1},{1},{2},{2},{1},{1},{1},{1},{2},{1},{1},{1},{1},{1},{1},{1},{1},{1},{2},{1},{1},{1},{3},{1},{1},{1},{0},{2},{1},{2},{1},{2},{1},{1},{29},{1},{2},{2},{16},{2},{2},{2},{1},{2},{2},{2},{3},{1},{2},{2},{2},{2},{2},{2},{2},{2},{2},{2},{2},{1},{113},{8},{5},{7},{37},{48},{19},{58},{36},{43},{31},{33},{35},{11},{11},{26},{30},{59},{37},{32},{102},{30},{50},{46},{68},{25},{63},{32},{8},{52},{4},{18},{34},{35},{29},{33},{21},{14},{65},{14},{50},{8},{28},{12},{4},{55},{42},{36},{38},{7},{20},{15},{51},{64},{7},{11},{19},{18},{30},{39},{13},{14},{11},{14},{24},{17},{13},{13},{15},{12},{13},{8},{13},{7},{19},{9},{12},{20},{13},{20},{20},{24},{14},{16},{12},{19},{12},{5},{15},{19},{19},{18},{24},{19},{21},{18},{12},{11},{22},{15},{8},{16},{12},{23},{17},{12},{16},{12},{32},{3},{12},{12},{15},{23},{6},{3},{13},{7},{11},{27},{12},{8},{4},{4},{13},{18},{10},{3},{6},{8},{12},{13},{9},{6},{16},{12},{9},{12},{5},{5},{20},{9},{11},{18},{19},{18},{13},{6},{11},{15},{23},{10},{5},{2},{4},{6},{3},{20},{12},{10},{8},{10},{21},{9},{7},{12},{13},{1},{2},{10},{8},{25},{13},{14},{23},{9},{24},{21},{23},{14},{18},{10},{7},{4},{8},{11},{4},{5},{4},{8},{5},{12},{7},{8},{7},{13},{12},{14},{13},{12},{13},{14},{7},{10},{9},{10},{8},{12},{20},{13},{15},{14},{8},{7},{14},{20},{14},{13},{14},{9},{20},{12},{17},{14},{8},{24},{18},{17},{4},{17},{18},{9},{12},{1},{14},{21},{11},{5},{2},{13},{12},{13},{17},{0},{1},{15},{3},{27},{12},{3},{9},{10},{3},{6},{14},{14},{14},{3},{9},{4},{2},{7},{10},{5},{6},{10},{5},{18},{9},{10},{5},{4},{1},{4},{12},{9},{14},{5},{10},{4},{4},{4},{6},{6},{6},{5},{2},{13},{11},{1},{7},{11},{8},{18},{26},{7},{4},{5},{5},{7},{4},{9},{4},{25},{5},{10},{7},{9},{5},{6},{17},{10},{18},{12},{5},{11},{7},{18},{19},{7},{10},{9},{5},{15},{8},{15},{5},{3},{9},{8},{14},{3},{8},{1},{10},{11},{7},{9},{10},{3},{7},{3},{8},{4},{9},{9},{18},{15},{7},{8},{3},{7},{6},{26},{4},{4},{11},{5},{8},{9},{11},{4},{5},{6},{8},{9},{6},{14},{15},{15},{4},{8},{10},{6},{13},{13},{14},{14},{8},{4},{14},{6},{6},{1},{9},{10},{5},{7},{14},{20},{17},{5},{5},{3},{19},{11},{4},{16},{8},{8},{9},{5},{10},{17},{3},{15},{7},{9},{10},{3},{6},{5},{5},{23},{15},{11},{2},{10},{6},{16},{14},{4},{6},{14},{2},{6},{9},{7},{12},{5},{8},{11},{6},{3},{14},{2},{2},{11},{8},{12},{12},{15},{12},{8},{15},{13},{15},{12},{17},{11},{7},{6},{11},{14},{7},{10},{17},{12},{7},{11},{5},{8},{4},{3},{8},{15},{4},{12},{21},{24},{4},{7},{4},{6},{14},{24},{5},{3},{8},{9},{4},{8},{6},{11},{4},{5},{6},{8},{15},{7},{5},{13},{9},{6},{10},{11},{11},{10},{4},{8},{5},{9},{3},{4},{4},{8},{5},{8},{20},{8},{3},{6},{8},{3},{6},{14},{7},{8},{8},{8},{2},{7},{5},{11},{12},{13},{14},{6},{8},{6},{14},{14},{20},{7},{4},{7},{8},{4},{3},{3},{8},{15},{19},{11},{5},{16},{7},{8},{9},{6},{8},{3},{12},{14},{12},{1},{10},{5},{9},{2},{8},{4},{6},{17},{9},{9},{14},{11},{6},{22},{8},{3},{6},{6},{1},{6},{4},{8},{3},{18},{12},{8},{10},{5},{6},{6},{6},{15},{7},{8},{12},{5},{10},{5},{5},{9},{4},{4},{6},{5},{6},{7},{1},{3},{6},{8},{9},{16},{4},{8},{12},{3},{4},{9},{12},{12},{5},{1},{2},{15},{16},{11},{5},{9},{8},{6},{5},{10},{14},{6},{16},{10},{4},{8},{4},{7},{4},{5},{4},{8},{5},{5},{3},{35},{169},{0},{116},{85},{305},{164},{72},{13},{41},{50},{330}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (5884 bytes) */
const char* const cstring = "(\265/\375`\2505\225\267\000\372\274\024%N\320\254\212\332\000_|\203^\303\nh\r7\250\227f\321kX\001O\314)\334\003\203\021K4\353-\331\337\275\334\200\264F)\205\315l%R\207*\210\"F\307\277\352\303Q\220U}\277\311\334@\021\310I\211\001\261I?\307\372\002\323\204\2668j\375\001A\002\005\002'8\3765\2060\210\331\217\330\255&z\034\252+\335Y\266\377\275\347\017\">lT@*\317r\3253Z\351+\351\215\376\350\365i\017\301$\255\331\306\030\010\310'\345a\230g\272M\236\243}\277\267\217\245\215\326\034\305G\264\215\3177\2527\332\265\216\330q\224\357/\345\245Ik<Y\021\307e\254\330\322z\263\315\276\032I^\253\010\353H\353\357\232\342\377\270\251\361/~7\273\007%\246\377\016a^\322\241\222\324q{WW\032CO\337\272\366x\351\2709\273\315\021\365BJ0\223\022\022\022\314=\240\017a\244\227\260\016\262+\363\305\033\305\270L\212\033\3757m\234#b*j\313\375\276\334\233\364\344q0\017\214\3030\215]\246\374\206`%\223>\353\331\266\263k->\267\264\242\334\276\210\271\275)\030\250fQo\351)\030yk\366\260\355\346\354:\345\223\276\336w>\020\346\225\352X\357)\273\2261E5\317\370\215`ZV\274O\236\313\256\306U{\337\t\247\361\346\263\356[\372\223y\245\005\2158\314\371\034U:\035\2377\305\353\236\327\304\347\2333({\245x\273\234\017\366\036\337\307iZiF\237\236<W?y\335\340\253_\236v_\355\275\366\327\222V\315\336\017gF\327\237\257\216\371\306\347\357\3628\236\267\216\226D\337\336\222\346T\262\323\273\275\337o\272\226\036\362\2169\235]\323\350|\332}\237\242[\276\217di\2541\273\246\365\345X\222\317\272\216\322b\337\201\275\222\246\250\207Q\034\261\347\226f\333\225\333\266\336\301\3223\273;Z\356\254\377}4\265Tsi\267\026\2637\363Eq\016\363\034&j\033\345{\377\177\037\216g/\275\351\250[k|\033q\312\237\266\276mR\366p\260\021\354\305\347\247Xz\372\332\367~g\216U\372|(\247'.\337\315\267g\351\263\227\352(\251F\245\343\177OS\361Y\217\207\2205J\0109)\315\202\261\357i\035c\317\007o\237\3513\312\217.#\351,Y\253L\327\357\037\026\017\006\241m\333\026\004B\221O\350\267\376\221D\352j~\362\341b\316\236\354\023\205\004L\364\\\357u}\267\251D\212\210\245e""\004[B0ET\002D\202F\224\336\031\315Zk\021h\244\263\177\313{\246\215\237\035o\2368\253S\256\023\022q8\333\003\2333>\351)\267XH\351E\034\206\326\315\033)i\3378|h8% \037+8/1(\025\036\036#R\363*\"`\361\217\203q\334^\324\270\264\377t+\375\206\221\021\333=Ba:\336\010\335$\252e\377\234e\336\367IN1l~GtJ\362lKy\377A\010!L\216\333\026\253.\221\350\2106;\364%\275\020\017\023\220\254Wi\271\217\030\346\230\206\363\352\203\274I\347\013\3014#B|W]w$\331[\365F\313\311\021\211>#\317\2634j\327\\\366\264\2441\327\327\3029\343+y+$x\031I\371\2147\372\346\031\267\331:\307\230\022\016\023\222\315\006\004\244\204\244\304\244\244$&\246\302\212\n/\025>4\357\2027b\262y+^F`\037\036!!\260x\361\210\351\320\301aRB\322\321l@FF:t\260\240\344\343\202\230N'F\243B\243\"\306\304$\206\204$fEL\007\026\035\035\r\310\346\305C\005G\311\010\010\030\004\0250\014\343\340\003\016\207\263b\244D\243\341\274|x\230\214 \351\204\320\351t\\\260\00111!!\351\300\302I6f\024\323\361\225\323\255\313w\240\256\205\261\016s\365[\227\277UZ\227\226\247\363Z\031\335N\353\361\345\350\030G\254R\322\265\330\307\244)\334Iq\330\343\275WJ\261\233e\334\336\207N\273\363\024I \342\341C\347}\377S\331\331\256\344d\273\244)\251\323\031y\254u\351\271\217\336\306\306\220\2571\273\225\364\037Ow\363\\+\026\002\235\264h\267E\277\324\367\271\253\244\362\276\324O\353\2439\236\336\350\275\217>\361\205h\372\\\245c)}ykg\331Tg\251q\257x\366\362zx\025\014b*\234\351X;\027o\315~\n9\353\254\345\235\263\334\242C\232\313&\221\261\344\\\3436\351\023\204\024\352\2155\324\262\306\330u<\271g\r=c\010\377b|1\214;\376\377\210\377\241\266\236#\236\216'\315WO r\255\205\366Z\235r\3532\342\237\251\022\374\010\363C\207\2614n\020\342\2321\304\033\346\336\372\357\026~\211\223~\362\n\235dc\255?Q0\020\005\363\377\231F\014\263\245\267\003\372\331\236\236\241V\375\257\245\037\241\204\222\302\247O/\335\220^L9K-\375\351\333\336\252Q\215B\251)\374X\2329n\022\3367\223*%=\324\036n\260\326\255A\355%\3256n\376\320\003\207\241\313|5M\177\246\020N\255F\0355\375Q\203\360k\324\264l""\251\365\351\023j\232\222\376\231\206\016\241W\367\257\256\321\352^\263\r\241\274\364D\347\314\0177:}j\376s\246\264\314\031\205q\335\357\031\332+\037f\270\335ye\246\241\245P:\t\376C\010I\261jPV\377-\241\205PJ\310e2\346l\002\221\254\336\233q\363f\032_K\347\265\020\372\307,{O\305\250\367\345\\\032)\2250>\3345\236`\244\330k\204\020\316\031\241\353]\357g\021V\247\033\2244MQi)\305v\371J\365oKM\270\270|\224!n\347\226zq\313\tQ\326.\332\255#\037egy\032Yt\312S`\212S\2010{\312\363\277~\rK\037K\240\223\023\037Q\312\207\321\307\005r\234\326\226\313q\243\371?\2378\261u\215\362\326\n\363Q\216\202\342\222\002J\021\241\244\000\245L'eI\353\010\305\310\304\273\365\230x\032g\266E\024Ko\0066n\232\307\204($\022\325j\275\004\212\250D\010\305\334\356\255\241|5\246Y\276\237\214\274\322P\213\347\004J\350\3757\350\247\264O\037\323ZA \025\317g\004\n\235`Q\321\000\004OR@\240\021\n($B\001iIkK\n\350\004t\002a\r\"*\013\031/S\227\300L\311\345\005\006\306\nD\247=\006p\252\250\342\032\271@\300\005\206\213\223\016\255\311\352`\301\205\275L3T\006\325\352h=+\262:l\2706&\274X\351<]\n\025\207\227\251\325\341\360\022\221\361\300\341\265\322bd\246\204\014\006\255\315\372\260\3504h\274\360\314h2\032d@\255\014-\214\226\207\006\227\006\215\227\n\027\227\213\212\313\344\342B\213\t3&\231\016\031\227\226\247\025\242\200\013D\227A\343\305\321\332huVoA\000\t\025FX\231)\351\330\031\223\215k\363\300\253\003\352\242/\256\227\220\313\200\031\021\036.\017\006\"hi6xZ\234H\340Ba\211\260\"x\341\221\201\027\\\036\027(\026\270X\2646\032L\033+\035\002\tltRe@\212N\344\021i\361\001q\211\320\260 0\000d\303\307\206\327J\213\024b\345\335J7\262Z\311Xu\3506:\214\016\203\206\352\243\312h\341\371p\205\370\325g%\262j\300\202\313\324\305.D\344\322\310x\301a\303\245\000+\000\327\004\325\013S\227\200\000.\223L\224\t\261\200k\201\214\027\236\215\231\n0\2740D\300X\231\272\017/<\030\031d0d@<\014\257\215\226di`\265\254N\032\257\025\231S\213\2628\204X}t\241\017+\216\025\005\030\254\0160\\\340\320\035\240\361Zu\254B\031(\274<-\221\226\263\006`""\215V\236\225\003\032\257\r\014VX\036V\006\313\264\332\260\302X\235t\335\247\323T+\252\002(\2740:\216\016\200\316\244\332`B!\202\000$\272\255\272\220\361\302\230\021\321\321*\301\322V\250\216\000\323*\2562\350*\340`m\260(\2548\325\005\021\026\007k\201\025\205\016\303\004-\002\001\031\037\260\214\r*\r*\n\023^\005h\274D\272\000\272\023\225\210\312\302\204\327\002\n\274L2\024$\360\362\3104\320\002\2612\2600X(\235HWB\2451\341\025;\224\352\203\212CU!\343\305\321\035\220\361\022Qi\010 a\200\0218Z-#\027\213\026 \020.\020\330k\305E\0103#4.\215\003/\221V\000-\017\004^\030\"\310\373\0373\304\022$|`H\201\016y!\232\007E|D\300\020\317\203\263Q\202\004\t\032N\005S\017\\\323\214\202%MK(\035K\250I\357i\243:f\357xo{\243\216\363\271\232}\332\235\355\315e\315Um5)j\275\177\273\372\261\353\237\372\265\333\034\365C\355N\327\371\226\036j\377\317\372\363\227\362t\317\3714\201\210\347\237P\356\351\271\316\350\331\003\206q\250s\250\252\034\226\020\311\320H\222\222$\215\001C0P\200\301\251L,\233\317\251\365\001\243\002\023\243|\240e\221#D\210D$\020\221\024\244\250 \205\326\375\000r\226P`\361m!\342v\215\311\037\006\224\342\374cJ8 \313\310\233\343\2653 \0201H\351Z\3601\345\320h#v\236w\177\242.l\262\321\"OVY(\245%\201;\337\333\273*\322\324\321(f5\207\027RA\374\017\010^\253\300x:\217\260\231\330\367\201#\231\260\376\264\206\034ubR:\350a\002\225\257\260\377\346\376q\362!]\270!\226\001s\225.\356\001\006(\317\274mb\013\247\r%X\017\214\020&S\321\200#{~,\237\241jM\252\206\274\345\211P\225\2458\2501\262\217@=\033\2435#v\367\230*0\203#6V\000\024\333\352C\031\342ed\262)\366d\353L\346\211\317{?\262\345:%H\302\377\001\243^\230\350\230-\227\2135\316\335*\262\2472\300\266\004s{\213`\367|\033\303z{d\272.Qi\242H\250\272\"\344\251\313\302\331\241\264\317\005\277\223\312\031z,Z\373\202\014\311\303\360s\017\3132\212}cS\010\313\034\255\266>\215\036-\2232 \230cb\\JRM\253\003Z\255\r\222`\276_\375\344\354\177F\373if\315,\222\264\034\013,\365\206\343\334\n\255\371\261\204\32109y\316.\003\013-\333\221j\306Sc\224\007B""\212\312\326\242S\375\017+\200\205\312\036\263W/\013T\"/z\355\3178~\013J\307y\325|V\307\036\315\274\377\014\032=\017\003\020\363\254\371\033#\371\313\275\354CS'Zd\274\026\312\332;\345\342\227/\333\275N\377\357p\376\236\262&\205\210\300\263\n\320\026rC\322\2640\273w\2525\304\266\326\276|\201\323b\250\025z\234\347\270\346 \375\267\020\231^\000V\243\321l8\203\346\366\327v\016(\005\221^4ym\370\234xhK\207\224\2025\256\212t\273\350?\236\344j\"\206t\350\371\203\177]4\256\301\304\205\\ \006\201\366m;\231\\Y\317l\272\207\340J/\245p\r\305o\335\222\2573\210T\243v\001jU\262~\002\242\023M\274\253H{H\320\031#Z\210\203\010w\215\276\302!\030\007\275\260irp\322*Xw\307\234\257\227\261ZE\007u\225\355N\010\nHB\000\370\334\354\200\002\337Yz\254q\224\327\004!\247\212\323\262#\037m\002\2753\274S\314 \212\356]U@Yb\345%\251\276.\037\330\240(\237NW\255p\314(\336\300\001\360\326\374\036Z\263\243\232\326\200Kn\317\333\300|W/<}\244u\246D\022C\265\252\216[G\215>\244J@\271\270\362\364\237\273\361\032\005\001 \2306\004\r\\\212i>\222n\372r<\3500\020)\024)gv\241\242.\266j\034P\377[Hqz&\262\007^\331\314]T\261\201\311Ni\010\274\332^\376t\026\363[{\210\206)\013:]\365\223\204\273\240\010\260k\271,\0337]\216\013\236\tzt\354Q\363\210L?\352\366L\273\270\323\305{\016\227r\276U\014\247\273\023V-\373\225\325\255\345\205\341\256\346\240yW\033\214w\330\220^Z\3201\026\r|\270\324\235\333OE\271\245\211\213{e;\360*\004\205\033\317%\366\243\271c\036\032\347\n\300\265\2206\224\257\335\201\263\214\266e\305k\177\243\027\301\275cYP_\310\206\270sx!W\344\355_Y\377\013Z\256\030\224\246f%\250\350\037\0241\343\212L\366c\031\022\022~\226\304G\333\0029\0227\351\3504\310v\216\030ITv\314H~\001`\257\030\303Nj2:\353WD\224#\253h\214\220\304v\010\035o\341*.1!\307e\237\312J\225\247aL\310p\304\n\235\032\264'\301\217\253\223\354\377\367 \344\003\255\377\346J\273\tm\226\377\334\301\212r\\m\272Uk\242\354\2307\342\307\335\305+\231\350\201\264\034\314\213\200\226\3053\366\372\333\350\"\313\235j\317\213\204d\232\004\242H\000ji\037\214(\210|""\243\336F\256\365\254\005\270\234\210\245Zv\231\221\245\245\205\302\257\232\361\330\304\214\226#\273\220H\345\251\236\343\250\003\026\035 (\303j\377\372\310\206\025\310\345A7v=V\350T\177\306%\200\210@\304\222\363C\266\320@\274[\270\017\236\305\357\214\2325\307!\014Q\252G\251o\020.(\024\307\275\242\345\010\270\273\313\354\207\360\223\t\262A\002!q\316\242\351@\321\361\276\t\222G\305:8\364\225\205\231gV\374\257 \373Q\316\236\213\341f\214\003\266\355+\325%#\"h\203\276\321\004\023W(\351\nBL\350\340\212\200\220j\216\270\"\330\304\363\2066\376@\205\001\247\204\023\002\233C}\007,\321\314{\231\316\021\250\321\241\271$\366\316F\357\004\204:;\200\275\332\306\036\032\030\335\220(\215\275(\222\266\225\220|H\332#\216\317\007\010\231]L\236j\221\002P\207\006\342\036C\336\233I\376\225EFR\321\353\272\235\364\333\037\310C{\221\344\311\003\307\0236\303\010\210\324\311\2149\355\3040\264\364\366\177\032\3272W\200.\245\220\241\231GU\035. \253\215^\371P~\235`\334(1\332vZ\000]\232\323l\274q\332\020\234\201\240\240\271\341<A\364#\236\021A\207H\226{j]\022\314z\311u?\220\233\314\273i\032\020\276\007\220\254\317\000\217\237\323\277-\003\272\032\371\235\254\350\374\307\210\035AU\230. ]\3762\216\313\337/b\346\021M]\331f\204K\364Q\304v\307\034qI!#\227\237\301\347h\316\035\241\256\367|w\343Oz\351\300\030\367<\321D\312?sx\025a\331\003\030|[\347\217Og\210\017Z\347\331\226\372\025\343\244\020X\334j\371*U\305\213\361\204\337\177m\357\211\222\314\030\257-\316\204\272^\205,z\230\351\351Fi\213\237o\243Z\203\272\010\233$=I\376\013\372\367\235\213\255\363\204\235,\260\010\226\250\000y\253$QI\t\323\305x\234\005L\203zS\036\276aH\347P\374d\351\031\021\027\262\\\373l\201\226D\206tEq\370\276\017.\213\341q?\303)h\345\265\251Qj\225Z\003\030&\005)\211A\260\322\204\272\034G\254a\023\007\254\371|T\227\302\346\332\206\347\210J2\025\324xL\236\312\236\365\254W\222p\002\277\277\324\213\3301\256L\031G\356\302i\262\323\014P\003KQjk:\364/5!F\364\002\226}\375V\230\202\337\267$\300\340\257X\000\3728\023\334\266\002\323%\271DV""3\225\331\252?{\346\333~(\355\243\t;\242;\014\005\264D\234\237\202*H\032t\326\200p5fF\217\3215\350\177{\t\344\235B=\007\023\334\223t\366\253f\247r\203X%S=\317NGH\225\364\231\016g\320\3574\253\004\005\233\355\246\030\000\223\036\251\263\336s\343\265\036\014\342\301\361\255\224\000\206\340l]\001\335\226\227\375\314h\313\000\327\230\303\031\253JSD\247\010e\2661\226I\341c\376\344\014\037\226?\036g\227[\026>\366J\242\273\346\001v\236R\337\364d\301<\203x\217\327\227\216\341\321{\032\342\270\354\2224zo\315r\307\273&\343\2140h8(\270\205\264\360\264B\037uH\250]Ig\322\343\245@?\246\330\021;hI\004\024/\376\371k\376\233\233\2129\252\375\203\311P\013\000t\232|o\307\305\235&\300\241H\362RA\232|\030(H\317\346\254\367\354\376\242,\220\r\320\020\014\235r \214\020\000\242(\3378=\363\271~y\217D\331&\355W\005\211M\345\000;\323\\\332\001\016\231U\307\210\313\315\025O\006\322\340;\365\223\345\026\300%\323AA\366C\203\006\226X\2147B\270\\\221\211(!G\237\014Yd\276\312\254\000`Q\241\362\365:\363\370\234]\316\226\0372\010f\030\364\345\322I\355\r\"\273\235\301`o\302\205\333i\316-%\361 \326.3.\204\215`\210\303(\3330\030\264\027\"E\263\340\252\032\350s\001$\216/\361\203\234wm\307]y\300\003\344\177?<\007\233\244\276>*s\214\350K\316\t\222\325\316\020\304\026\345\323\343RW}p\376(%B\32777\34414\372$\203\n3\322\3563,S\371\275\257\325J\\\243F$K\221\265\001\336\254\201\204\372*\376\036\301\2308\325\216\023N\205\001D\033\243Bu\350\253#\230\261`/fn\363\267\223-!1\306\353\220\245\032\336\355\342\344\353\365#\022s\210\204\340\322\235\243\"D8h\004\216\350\007\017\006\035ap\030H\354\201\305\217\314\321\0040\373\257\302PF\255\335\302tU\361/\277\343\310\2313\2464\266H\":@3\205\363\347 X\\\033+\201\010\357BD\273\305;KZ\017\332Zj\215\230\0241Z\337\231o\2034\303\006\252\021}aB\217\304\2236}\377)\300\324\034\330\315'\226\254\325\276\206R\203\027u\032\345\202\re\254\227\025\270Wh\"\224\344\247\324\305\265\301hZ9\222\262\022\213`\000\240\035Zo\250\212%x\t\336\001m\350O\026\233\377\344\010\251\001\200r\331I4\200\317m""l\021\372\2444\025\316\316\204\013\272C\355\n#\363\014\277\362G\275Y 2\376\260\304\".\r\325\236\030\263\255\233-\372\344~|\261\022H\313$+\023\305S\364\014?\365 f\0046\020\277+\337\217\263E\276\010m\222\246Ew\225\351\313E\201c\222\002\223\322\207`\254\0343\023\031\"\230\027\026\014[#iu\375\372)fw\026\t[\214\226G\240\033x3\352W\242=hG\216\315$\2443>\2252\345\317D\233 \364r\222\273\200\003Wl\2149!\305i\357Mg\204\177\n\226\263g\311\316\360\243\006\312\374;2\023X\245\247\340\313\337\271\344Sd\253\273t\352\345\006\272N\n<\251\347\221\004R\361.\305\245\000\3373\375\245\310\233T\355\310\227\227\330\276\232\375\310\363v\2576=\355\247\2116\243\276\340\244\246\231`\221g\t\330.\035\240\023\\;-\324\202\257\032\254\354\256\223\377\230\3440\365\272\263\272\344\016\2566\n\275\3260\n\344\370\243I}\337\236i\020\332I,\202\241\234N2\310\312_\344\361\340\275\177)\274\214\317.\207\253\264\373#f#y\240\244\236\233vA\n\331\"\347\007\026\232\315\t>\260\3161]\343yR\013\334\354bT\353\263u\271\230\302n\231\352\236\206<1\332\235Y@\262 \266\320\200\211@7W\025\032\016\2032\336\337D\007g\201\344\355N+\266j\235V/\340x5\344\234fd\211\355\243\215\355\247n(\244ri\320\231\242\367\304\331#\267l\261Cq.\262\017\225\273:\265J)\232v;\035-\224\211Ae\033\032\321\326k\377\244\222`\035\230\222\221\265\331\244\304Y \301\023D\036H\321'\347\263\212]k\374\252\222\204\335F!\200Z\357\367\024\355\301\247\314<\312\260\331+7I\215\021\177\232\206\tD@k\301\3721\363\302)\216\000\\\276\316\000/\tX\322\315\241\234\000\213_\352$?\265\244\331J\352\003\r\211\024\372\t\005\271D\354\277H\030t\276d\022]U\227\201!\032i\017\266\035\252\350\260\270!\024\222t\217(\354Hs\306\237Zo\265! 8\253\222\272\224p)\016+3\327>{)\257\325\304\304\330\010\235\234X\210\035[\002F\3741z\204\277\350\252\234\303\200rc>\031&\377\211\363O\347\241\233\334Dg-\025\r\325H\315\256\274H\332\3567\327\3036t\017\277\300r\301\264&/\006/\207?\234\203\336\001\276\301\363\032\255\232\226\306\2523\236\355\265\216\223\300\356\224\262\240A\330\375R\264s\005GJ\274>B\375""\000h\004\2630v\374\211\027T\376\237i\010?\206\014sj\016\245su\340\306\004W\317-\203\013O\244]\0018C\343\207)l\024_%\247\257\037\016$\251I\n\231\320p\263\213\037\r\215\035'\314\304;f\306\356I\260^\n\025\253v\263\014\275\2744\007\213\216\2062{\213\267\300\223\321\227]\002\202-\007\rV\365<\215\267MH\254[z\363\262\233d+\234D57\023|\366\332!\242\371\254\321\362\006\317C\306\2704tU\n.\311\350Z<3\241\321(\237\206\250\314\307\203dtQ\032\263\224\305*\206M\006#\306N\252\354?KPMsm2\244\306\342\350\0236\221\330\017\027R\230JP\006d\346\0246\034\306\275\363\014\240PY\010P\r\216z\224\371\325i&\314\320\220\342\266L\240\221\322L\330\365\363\240\255\020\3010\315\263T\362\264\214\201YP\001\300/\310\347 0\365\366\347\355\374\203\243\033${\302F\356-\244\315\020\354\330\211\224$\032\376\233[\326k\227\245\372\177\232\212K\354\327\250$\260\022_9\033\323\313\007b-\221\215!\2574\354\234\315\200\3332'a{\204\303\254$\013F\377\260\343\333\023\016\365\246\300\303\260\304\322\237\007EJ\223\360\014\013*\2420\235jP\255I\024L\224;wn\251\006\236|\240M\364\2409?z\305IO\t/\330\202\326\272\001";
    PyObject *data = __Pyx_DecompressString(cstring, 5884, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (5977 bytes) */
const char* const cstring = "BZh91AY&SY\304\336\r\275\000\002\374\377\377\377\377\377\374\377\377\377\377\377\367\377\357\377\377\377\377@@@@@@@@@@@@@\000@\000`\031\336\370\360\360}\032\276=\000\2401\003\215\\\000\036\222\2279]g5{z\357\031v\241\313B\"\220\252\222J@J\210\3348\256\315\242\200kv}\320}\340\320\201\001\014@#\001\242S\362\031\006\210\323\021\033\024\364L&\232i\2201\r4\323F\200\006\233B4hh4\320\214\201 \"\247\355T\374\246\247\250z\215\000\321\3520\217P\000\000\000\365\000\000\000\000\000\000\003S\310!&\232&F\246\247\352M\r\032\032h\320\000\000\000\r\000\000\000\r\0004\r\006\203A\240\223J\024\3224\t\204\247\224\375\024h44z\201\241\240\r\000\000\000\000\000\000\000\001\240\0004H\223@\000\007\246\23256\240\320\323 \321\240\006\200\320\r\000\000\320\000\000\321\243F\231=F\232\t\022\010\000\215&@CSF\320L@'\251\251\342\236SF\324\311\352\003@\006\200\000\001\246\201\240\r<\245\215\214\374\343\226\220\241\243\267pH\220\001\217\241$J\374e6\223Fe\366Dd\002Me\202\3762\000\033\037\341\013\0252>\236\203\352\231\t\027\334\221sH\033M\230\337\013\261%L\010\273\325\375}\037\307\374\271\006\213\301\n\344\303L\2206\212R\202\243\365\217]VDn\225\204\353H>\246R\216d\217\034\315\347\005\304\245\267\320\216\0240\274\305\334L\350\312\356\214\224\271\026\332*\025\036\216(2\305\2306\226\263\230\317\327GN2C\n\036\212\234\216_3\357\345?\010!\322\002\347\227\315\200\241\3010\271_\207\213S\304\375\332M\201\010\030U\014\201\252Y\3455\004\266\005\235\005Gca\235\317\260\202\244q4z\332\0065\211a\240\000\354\324X\206\344\007\301\206\207\315\373.kh\263\215:\232\2279\240N.\030{Y\371\207\013\322Y\024\006XS\010\215\014\314:\211(\210A\010\324\001\322\215>:PrT\273E\242\373\343\204.\361e\322\001\326\267f\004r5\"21cj\356\021n0\340\177\022\267\007\232\313Y[g{|\237\262\310T\241(#2V\025\230\361\341\233k\212\201o\362d\210P7]F8\327\255\306U\224\022\232\344\334+\006\036\013\177\"2\333r\010\232e\242\234kFL\360\242U!\326\230Z\272\001f]\030\023p'QAR\274H]\370\3232u\275\303\355`\211!\200W\2238\362\265z9\222\274\367\240f\223!\254\\q4\360""\262\230.\205\352\307\030\2655<h\254q\315\244l)\301\244\376\035 \342dbTh\363\275:\\x\377\300v\033oV'\037G:e\006\210(\263\201\313\266)U)\004\022d\356,\3451\305\223qn\231\272I\022\253P\241X\213uP\245\035\204\324i\343\213\335\305S\241\035\346\372W\2603\277\032g\031\306\216\367\007\274(\336p\"\372\245\203\002F^\313LB\214]\305\265!\254\350\270NOj\027\311\224$\304XGwL\274\036\365[\220\226\330\\:G\034\250\313\330\316N/\246\032\260\301\255 \341\026v\250\251\2503B\014\020\3451pvk\235\367\200\327(\323\244\321\010\212\214Q\323\266\211I\367.3\202DW@w\306\034\300m\014\331\300C\325C\340\350\362o,s\265\311\303\244\307\373[-\356Y+'\361!\020AJ=\376\377rN\341\310$\335z\032\370\006\247\235\020\323\005%e\023\342<3\243\312\303\306xI\346\370\202\235\273\021\020\245\346\306\240<8\346\245\006m\256\3641\3016\272a#\013\3138/\346\367\342'\244<*wP#\344\210FM%\236\350\002l\017m\251~\365F\262\347\027\233\375\216\007\037lv\376X\330\033\307\261\r\265\351\301\335\211\363\222d\027\314\314pq,6)\224}\3509h\361>\3778\264o\262\304W\236\206\220*\"\215\303Q\316\207\252\234\006\266'\253\217\327\351\305K\\\377j\253\225tK\035/\356\216\300Vv?\254\263m\337\002\305:\2149\302\324\244\2654\030\260\007\336y\340O\234\210f\021\026j5\232\337\350\207\225\350\036\322\006\234\254\267\025\361\253\315\2142\356x!\255\270\024Y\301\215\r\271\264C\007?\202\360\304,Z\305\244-\n\033\341`\265\212\021\230,vV\256\026\2042Q1i\003\341\364\035a\271\275z_\266\230\313\345\242#\022\275UR\032\271\241\203\303ML\360\310\242\303\272\330\213\253\271z\275\213\227u\022]<\203\243\352\324\331\243\361\246\203\356\314\213\271s\211\017\r\004mD\214o\252\005\301\324\201\024\367a\321)\214y\214\255\033\035\027u\257~\374\377\033\374\2265\272\273\364C\331\267QK\027\214\314\206\316\236\251\r\"\313k]\235\331\363\251\245\336\n}h\324\217\026?\346y\264\220|\276u\033\376;\372\220q\032\247\307\001\365\244\t\237\034\037\262\317\367h\301\232H\345\013`\355[\366Uz9\230\272 \265w\203\363>\320\330\211\201EWq\026\003\006\322\241\333\225\253w\346/\220\260WF\036\204""\020x(hy\017\313\250d\342\222\247^Z\306;L\257z\271\273\003\2366\031\013OY[&Ur\256?A\227\223\027Y\013\220P\232\306O;@\260\247\224\325\337t\262K\351\213@Y\010\226\321\325\221\257#\331\rJ4\006\r\306\202\325\237\001\333t,s\227\216}\201\344\226s9\315\325\013\205\374\030\231V\202\n\2071\272\270\221B\204s\317\240\003<\315\nP\014\2506`P\253\003\267\336\213\360\232\324\030/\033' \325\013\351b\001\0000\370\272\2006\026\013\216\260u\325\221\352z\211fK\036\204\013\316\225\031^\213b\236\342\241\357\333{i\204\343\005}\352\252lDhd(\250\0043\016\026)\"6|\031\225\"D\243=\257d\374\364#<\373\271\252\202\013\022\033\262y\271Ou\271eh\255\325bX\002A8\\\360\235\321\035\201\221\311U\223\274BcH\"\314]dr|\230\004f\270,\317t\314\t\305!4@t;TO%\251\273\273\263f\232[~\25383\305\317\324\177G\265\2773\004\374\322,L\250\004\313)\014h\327\252\325\373\222\314\034q\264\211H'\302X\020_C\331\313\224m\357\261\253\337v\251\013s\330\222\265I\017\t\327]W\363OX\205\355\001r\r\355\021\222\205\352\r\005\264e.\331\246Mz\241bJ\325\224\341\2051\252\201\321\224@\224\254\251\222K\tB\"y\013\336E\316/\355\r\023.a\016Vru\002\335\036\304j*TR\232\005(\2053\254\211J;\264Mw|[p\333\257\230\335d#\024q\250\224\254\2711\266\344\323*\354>\3069#\213Qj\033Ru\364x\341\247[\250\324\257{\252\367K\333\237\213\317\006\234\207\245\211\350/iv\035c\007/\021Yw\246\314\300\3308q\361\207r\265\333\260\323i\351\005\214\032\257\302\261\360\262\245|\217-\347p\272\217\346\r\330Vyo&\355\216\021\342\347\353u\000\0236\013\202\344\325q\345Et0%UA\252\341J*\357MUqcVJ\203\030\034^\371\245\004\r\342\353\023\302\315z\031\311QEP\2654`o\360\255Hz\263\014\340\334SD\013\360\275\313X[8\2244u\021B\3312\311\303\273\315\034\215'\010O\0002\2661\276\317\025%\014\236\333\223\333\266-\006\2439e\246DR\200\262bT\356\230\370\222\026\243\304\032!h)e|\335\270\302\344\226\342\327t.t2\030\310\252`b4\272\"\262\252\354.\375\347;\200\000\034C\206\325\227\027\204\347\261\305Wg\035\022O\350\273\246\240p\324:\251\237\005\367i \267\023\3407H\266~\324KO\2333\254\300\255n\246\212""\024np4\021\244}38O\232t\272\311\002\324\232>\022\304Y\275\010\352b\345<B\313e\216\223\r\216\3102\177\204\204\216?\230\360\017\020\322cH.\355\321,\211q\234\326\014\207\006\342P\\X\222\3311\355g\2168H\351\341\227\"\354\343t\202\364=n\303+\257\317\017\271qMN\r\360\321I\004^ \202\274\267M\0173\177F\027\235\314/t\236\220\026\00695]:\221\n\354C\344R\206\334\270U\335#\237\014\245-\374\344N\017\000v\"\214u\2138#&\0136\205\311\243L\203j\345\207_Mp\243(\362&\256\003\276\304\266\273\252\016\24462\343\231\350\3360\242\335\032\024\2718\231v\032\3106v\226Y\204\"S\034\342\010\007\021\204\204\224SkA\211\240\343\2772\320\337\271]\201\213D\355\232A\277#/\214\364|\276/\236D\211\303\371\343\264\366\036\375\271(4\227-'-)a\241T\203\312\302\016\315\355Aie\335\330\237a4\306\260g\345\212\033c\014\003\013\314y}\337\356\313[\257/\215B=8\306\030k\235\213\260R\220\343y)\345\327\351\245\\\r\315T\221\205#\266x\237d\261\250A7\020\325n8M\270\005\226\311\234o\335\217\033\3078\253[\315\324upU/\n\256\033\224\233\321%\264\244\262\325\"\365c\003\315\234\351\031g\004\246\300\224\342\333\231\211\2412ccd\020\262`,\022V\337V/\014\372\207!T\275.9\342L:\241{M\246\332-\23490T\346\325\347x\261LR\315\256\351`]\377\023A\334\347\333\257\226\316\345\351\341:\225Tb`\024\245Km\022\023!\014 \2034\020\306\201\271\273\235\372\362\225\257\\\303\345\355\365\361\253\006\330<,\250\035\354\024m\346b$\344`h\315\204\312C\010\351\260\3061\207\025\024\266\024kG\\%S$A\3342\201\225\254\215\033\234tL\216\213\234\345F\370i\006\007\007u\305\343\330\201\000\014j{\004\307\\\026\003\253\251{\013\345k\"\302\220\203c\010Ga`Xm\271\303\227\316\020$\355\rq]\373\302|g\247@\343\251+D\241\263\001\302\313\342l\214\231c)\035|\230\007\002\365\320E]\267\240\027B\320\024\240,\320\344\0169\270\240-\241\264o\327?\017t.(\332`\352\325\014\327v\343@KX{X\253\\o\275\240E_0\314\200\201a-\332fNn\241\3432\343\200\305s\252z\014c\022\220\251\003%\351BA\214\\:!\201P\346\351\3267\301\352L'w\\\353\313\207CF\000c\010\002\r\034\320P[a7d\337\202\260\322kk]\222V,""\232H\032\340m\013\273\276\310\031{\326\361\006\036K\030$\322*\205\t\240\022B\220\315b,`\210\241J\262I\002\324\2443\005\nC\322\203$R&\242\327\336$>\005\345d\222\266}\237N\271`R\316\263\255 t\n5qf(\364\356\315\243C\242\026hL-Z\014\267#\324Z\206\332M\005\217#,\357&\252\323~\244\027\266$\235\250\032y;\364\027CA.iK\234\230[(S\030\322P5\260\315\365\207\241\032]\264\335\0061\245S\"w\203(|\306Y\007\207\214I\004\274&\334\303z\364\272\257\302{\321:\024\213I\336\222\340\332\017$$2\310B\301\332\216\204\376\211\243'\234\323AYXTB\324\024@\325\273\236\353<St\014Dc#\tW\333\014h&\250@\216-cx/81\206\374\221\032\353YH_\025@\307~\tA;\230/W)\242`2\224\001\213\001\312/(\203\201%\253<\271*\341\225}ede;\343\030[d\\\222\357\035F\351;\372^6\346\370\314\307M8\314p\"\334xr\246\027&\375\025\3601I\2103\013\030JJ8a\027\213\026\226o\255u\226x3\327\004\001\302\334\245g\032R\233\305\206O@5\351\0145\360\365ah\340\326\037\211F\026\222a\214\205\246\244\2223]^\347\236\207K<\367\363\2234\241\336\006\263\000\r\005\364D0\2669\247z\353\332B\201\205S%\220\206({E\205\250sy\344\202\257\325\242\343d\017\326\312*\017%\355\356\357\201\322\231~\316=\372\206\301\244\005\204\302\353\311\302\202c\244\245Pm,\005x=\022@\255\353\221\014\027\243\304h\214\232i\203lL\362AK`\223?!\210\212\033\271\246xM\323\222\r)\005#6$9\324m\255;-\267f\250\320\025V\033\246\200$\247\032\243\365:#x\321Rm\027\332=@\035\320\233X\000\244m\225\020]=Rx}~\323\225$\210\311\301+\001b\357\013\203\002S\026\303\240x\370\251\332\354\333DedYq}\226\371\010\267t^\003`\244JJ\215\246\313!6v\342\033\261\333\315'Z\274\315\221F\267\263\205<\244\223\267\234\350\330\3626\361\030R\016\301EA\315\n\261\037r\311!\006\013y\2575\205\027\035\221\345u\t\2168[r\230B\206\216\3011s%\327\026\371Q\300-\230\224JV\254\204\316\233\327g\3228H\363}x\303\003\234P8y(`\357\305\200c\317\254\256\267\355_\304^eLy\217\213\331\224\346v\302\224\204A\023\263\331]kYR\362#I\356\222\337\273\320w\373\270\020V\373\226\347@\000iI\263a]#Q\027\327x\336\305q\252\024C\353\254\232\003\301f\0319Q\271""\251\226m\327\2454\351Ca\002o\260\273\271\225,)\201\210v\t`\032N\3226]R\266W-\351\210\326[Or\331\027\020E\373\023\203\332\203\227\201\361\276\271\342A\003\024*,\021\024\210(\225*\226\330\310\250\310\"\t\307\265n\303\r\310:R\351\333\237p\264\214\026{\252\315\264\312%\025\216wM\324\323H\235$f\267v#\217\203\306]\356\r.\005\266\360ob]y\325\347\026\205\311\2107\353\330\227\260\366\036i\033U\014\260,\301\"G\025\274eQ\330?'\213\361\274\t\033\330\331\203\364\370\371\034\230\333\207\035/\303f\331s\371\230B\357\322R\261Ue\010\270\341|\030qY]\230\024\021`gm`k\254R\325\254\355=\231\335\233\2719\367\030\204\236!\212(Chq\207\034\\\231\2065}\001\251\311\035\272\360\345\300\216\027\301er6g\001R\334r\364\347\"\234\340\230\230\335\211\n\365\363\035\256E\306\027e\023\215g;\225Q\322\251\004\267\226\002\2530}y\275\3177\307N:\005\241hYE\010\033`\320\336Z\212\233\232yK\322NL\372\01606\t6\225\037G\223n\177}\357\321\361\017{*c\257<\371s\000\023z\023kV\241\273'\254\366\007p\327y\030M\306y@\337\276.\374Mo\035U\240\"Ymxp\203R\244\311[\t\333|J\013\213\216\262V\014RbQB\022qi[H\206\224\020\302\027l\206V\030_nQ)W+\311&SF\251\343\210\016\361\361v$\3049\245\025;\200\222\207|\312\303\223\204\2324\223\010x5a\235\375U\305\021\024\025w4\301C\020qiQp\3028-\305\r%D0\345\270\233\234&\002\321B\244\021$\254\2420{8\361\2002\205)[W;\2563`\207\020NO\003\253[\270B[\335\266\373\332a\220q9\223n\306\351\243D\233\230\313-\026\312\205\225\204\331\027T\243\224\252\253\325\254fhJ\335=#\215K\252\26511\246+\315\360\244\215\n\216E\035\014\312b\257\236\332^\026\244\204\360\262\2147\314\027~\361\023[g\200o\320ns$\245\273\2411\300\007z\233\0206d\303\025\330\375\227\227\223\355\353B\273q\264\346\305k\240n\274\005\275!\203\033\035\360\005\272;\375\225v\373\260{\r\244\330\331=\3671L\230\024\006\340\223*\254;\035#\213\247\240\201\232\210\232\326\r[&\332\311\211m2\314\010wG\234u\223e\024D\262qm\355\272'}\313\26795\277\005\302_^v\\\271\255V\260\227Y\324\275HH\033Bm\010\037!\214p\243\274\244\036\332\204\275k\025\025\311,T\013\332""\377\3557\353\304\274u\367\231\353\313\271k\034\016R`A\226\320\361\321\200\254gg ,\210\"\300\024\235\312X\217b\026E\"\211\026A\214\223N\2329\3200\334`\312T\257\020\255,\017#\0379\306\304\213K\230\300n\006\225\307\313\267\t<\003S\207\027\227\336\300y}'_O\036\242\275\205-\250\214AE]\022\\a)c\2068\204_\025\274 g\322\300\300\331\312\032\256n\354cp\324\rZ%\307\254\234\265~\206\213\304\203\3060<\3750!\370\243fw\007\023#p\267r#N\303\320\340\342lF\302\003\025\313j\035P\376m\334\234\356\260\332pW\275\224\360%\360K\205\325\246\206/I@2pAs\310\313\244^3\222\004\346\340\265\2603I-d\207(\206\250&B\010\337\004\200\266\304\246%I\272\366\341DX66\332cE\321I]\244\375\233\241\003j\271fc*z\306\213OH\322\310\3134\034\026\013\027\220DM\006\322\244\233R8\251Y\020\205\013\346\224\207\256\005\340yU\271\343\355e\263!\373o\355\265\324f\221_\305\374\3241\036\377\313\352\374\347\"m\224\213\241s\360=v\274<}\365X\244\213\036\3375q\004`\r[EQPDX\300{1\214{\273X\231\267rMZ\031\270go\215uU2\220\014m\271\316U\356\240\022\373\r\002\243GG\246\234\247\031D\003U id\265\255-\025\3440d3\223\026\005c\307\234\014\025f\206\3317&\345\356a\337\263\2635_\002\006a\200I\021\022#\272\312\242l0\203Oc\334\367'1\253\354\222W\340jM\006;\274uz\231\327H\267\016\341\206C\000\206\036V\212\242\374\375\311\000\016\362\376\211\256\005\274\253W,T\233b\207\223D\014\225\024*T\225\364\362z\210\2346\345\200oE8\374\234\033\324\352\356\034'7\026\200=\210\210\354(\352\214\250 w\\w\363\235\263\206i\205jW\231.\014\310x\023\257\267\\\023C\266\347=\355\371\356\323\245D\364Br\345B%\253\2532\333\212\3155\270\274\020\340V]\310\"fn\253ZP|\300L\320d\201\240\260\032\314\250\310Kv3`\203\205E\346\251\201\227d8\260\t\263\250\360\335\303\227\033\231B\026WU\032f\314\260J\272u\206\002\016&\225x\346\322G:@\252\370\270\022\206\327\014\024`\020\024\264\"\242\220\332(\356\251\216\342,|\365m\244\027 \211\033jR\301\217L\256\373\332`23\006\342)\200\300;\260\002\035pb\247\244\025\243dCq\003\201\267\003\213\316a\341\351\261\032Y\271\306W\367\264\313+y\255\272""\332\270\3467.\024\306\226P\013\351nX\313\r\001+\331\271\234\230\233C\r\365\003\033b\204\315\222\210\304dD&\332\273\033L\235\323rB\270\266\312\260a\316Z\331 \326|$\002\205\001\004(\306z\335\257~\277W@\223\347cfqe\346&_B4pjob\200\361yO\222\315\313\"\311K\221\277\224\000\263\030\233o\211\315p\233KK\274\264A\316\370Xk}\316\014\206\261\353.\261\261Lt\"p\223f\351\275\304\245V\271|>\000b\024\200,\302\257z \255(\300\221E\342\232\220+z)'\301h\234J\250Y^\305tm\320\332+\n\267*+L&\236\265\277\325\027q\267[\255\024\006gT\217\201\205\260$e!&+b\330@f\355fs!\301\274\371\271\307>\215\354\336\336v\327`\272$\303 \2343y\261s}K\347q\361\016\020\264\235\323\236\313\010w\360L\033\300\250\205x\354\265\2150m\20139ViN\017\000\262\301M\234)%v4\312\233PcKD\226\342\220V\014\022J\201\272\360(\035\256;\374)\274\324\314\335b\205j\334\324<\022aA%\025\316k\202\\\\\3436\323\030\270\275\316\214\364\364h7\"$\355\262\262\263r*\333\245\210(\320\210,\274\317\273\211\026V\035\001\211M\215&\013\\\341)5=nU\3060\322\007MJ\341FE\013-\266L\020\372\016\311,+\251\360e\205rOX\206\021\006\000\376\262\273u\023f\215`.\334`\301_i\334\344\216\227D\312t\301~\036\350{\257\240==\230\037I\365GA\316\026\034\0029ysH\350A\327\020\233\" \274\035M\320f\274\256\211`\\#\341\365\373/\031\212\rP\347\342\032J\321\030t.\213\276\031\016\375o\235wi\327\256=\241\351O\354\204\351\231\337\332\320\261%{\014\262\r\023\330\332H\221\350K\177F<\334\355\263 \270/kN\361\346\277]\001G\317\317\023a\255\263\2110\3557\261dQ\021qg\301JL\261\261\225^\031\016\301\274\027\350|\257:.Gj\372}\331\035[DB\"'wt#\024\2026\360J\n\002w\204i\323\356\364o\337\302\347\274J\"\006h_)\311\223d\333\006\203\336\030\211\367\211p\272\335\224\314\231\"\310\214T\006D\210\300FE\221\232\2244\341mL\t\257\034:\264;\321\231\251\016\202j\267B\353|\275v\341m\226\315\262\322o\255\"\276q(\013\002B\360\2461\r\r\241\024o\022\313\316\341\222<\3556\230\215F\301\266n-\260Fua\3108\001\226\357\213\367>\327\362~W\355\371\357\270\032\304\324V+X0d\325\277z\231@\216\311\020hBA\021P\010\306""\014\263L\276\027\003t\004\204\367\314\323e\207\372\207\231\315\372\312S\314\375\304<\210}\354\017\222S\363\237\240\353\003\336\210\340P=0\310\375\3141$b\376\313\334l\220%SJ$\314\377Di$\r'\0013\352\224\357e\177x+\277\214\301\272]\323\001\t!\343\014\014\277[\260\202\256\017\242\272\2050/\027)\325\270\222\rp\207\004\"t6\n\267\344l\335Q\331\013\224\326\322\n\017uF\232>\025\027$\316Dg\027F\033\331\005\237\2774>rN\337\034\300\211\265U\347(N\360MA\265U\014\035f\237\206\023\320\242/&\352\205X\301\341X)\325O\256\362\362\242\240cz\207\32408q\240<`]P\261\177\036\344\361\326y\253\311\257Y\036Z\302\327\034e\267B\330\\R\263a\354k\r\035d\305\0237nJ\313\026\371\213\207/i\271\257s\373<x\225\261\343\027\3622\377.\232\004\034H\206\212\351\261\241f\214\274\345{\346\206J5\207\"\317\201\025\273\246\232\224\242\242A\220\360\320Z\\x\376\246nI\255\255[\262\245\312|\037\311\257\224Y\352J\226I\312\006\353\377\027rE8P\220\304\336\r\275";
    PyObject *data = __Pyx_DecompressString(cstring, 5977, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (5959 bytes) */
const char* const cstring = "x\332\245ZKw\333F\226\266&N\267\343(\017w\342<\246\373\234\201;\226)\313\022\025%N:\255\266\234\320\022\345\250\217\"\313\226\224\314\034'\306\200@QD\004\002\020\n\220\304\214''K-\271\324\222K.\265\3642\313,\271\344\322?\241\177\302|\367V\025\000Rr\272{\332\026\201z?n\335\373\335Ga\366\343Zh9G\276\264d,\\\277\351\273N\352G\241\345\207V[\264\243\244s\340\213C\313\023n\340$\252\306\213\204\264\302(\265Z\316\201\260\034\253\262X\251\326\222\335\254-\302\324\022G\261\023JjF-\234 \210\016\205g\265D\"\252\313\026\306\220\022\235]'\244\332\324\331\023\326\236\350\034F\211g5\034\324\240M3\013]5\215h\372\241\237\2367\324\262%\323$s\323\371,\244j=\\C\350e\242\225\033\243\373h\263y\021f\355_\035U\r\343F\355\206\037\n\253\342\304~\305:\364\323\226U\231\222\225\2746\004\201D\210\237\345\266\234\304\n\374T$N\240\032:h\202\241h^?\334\265\242d\244\215\036\242\355\037\231\006\272BZQ\323\362\374f\023\253\000\r\323N,\344,\221R\270)\026\247\373e\022Sb\375V;B[\037\323\320\272\350\2406;i\013\033\312I'\375],0\003\315\255\035IG\004\272D8=\254\307\017e*\034\257\272\034\205\315\300Gs\254B\212\224\336\322jFY\350\341\231Xi\024\317\005\342@\004XV\202U\3708\351r\227\003_\372\r\037\313\357XQLsJ\253\262\314\253\250\232W\324\216\375@$g\362\365$\211\0229^\372U\344e\201\330\210<\241j\346M\315\374\246\223HLY\215;\343}\266\350\340Qu\246\234\211[\017]\320)\334]\321\254\213]\311V\224\005\0361\212h\307ig\305P\2059\322\212\302\240Cu\315H3E\243\223\223T\362Y*\366]\311\342\200\244\004,\002n\220i\245((\210\305\244\\\264\212*}\342q\002\006<b\266pp\270Ii\260\203(\200\200\005\242R\247\305\345\"\027%*\377k\354\033e\251\364=\026F\346\020q\204\241\301\020I\324\256X\215 r\367\324\030J\036h/Jr\376\377\303\035\t7K\235F@\033\303\352Y\366\307\005\252n\030\270\262\021\205\330\226\311:V(\016\003\310\330\331\022\313ib\252\202_\313-\262vC\224\n\000Q\036feI8\277\024\207\t^\006e\227*\3477\230\325\034Or\364\202!\242\\z\213\335\210#W\304i\205\352*\240\037\266\334)\272W\246+\345a\253\326\212\357Y\235(+\304Wv\302\3249\"\271u\214""\344\226\340\365s\026Y\257`M\007#\351f\004\014\026\203\201\243\230\322Hs>\3739$\361\333\316.\026\231t\306)X\361\333q\224\350}\270:S\324F\215\357\221\302f*4\255n\325\022\356\236-\375\037J\247\211\243%\370\252\334\241\246w\226\350y\267\202\337\322\231&@%\034\307\254u\350\200\2310\234 $0\304\232*-\354\261\232m\032#\000jY\233\360\326\177\005\274G[\312\027\352\204U\007\022\346\001\337\254\266\223\272-s\270\253\274\006`\267\265\014@\023\n.*\25383\357\357N}\037\371\037D\022Yq$\271\205\023\3141\2268Z)J\364\2261&\"\351\227\"t\231\032\343\255\265\372%X\237\257\254\005\201\330\205V\t!z`\230v#\n\230\235L9\257Qc\265\037\306\201Cc\362\2721bu-<p\002\260\035\003V\031\253y\010]\331\022G\226\220\256\203\315\225\213c'eaO\261z\221\232\322Q\364:\277\264\251\325\035\343\232!\254i\312D\344\026\n\245\347R\277-,\306O'L\027\363!\201K\200mQ^\331\272h\246s-\332-\203\022H\207]\201\227\214\275\001\232\362\301\2673\311\007>\"\300J\257X\241\203\331\022\261\237\371\304\t\264\216\212\002\265\212\245\315\222\rjatY\371\210\251\361\362\255[\347\264R\207\\jV\211\263\006\320\234D\200\214\207Y\353\274y\004aLj\005\302\301rI2\2104\000\3109c\t\201\360Z\007\021qK\245\204\242\033\021\330(ma\000\245\365,\237\270+\360\033t\366\"`\210\367\371\000\320\010\226A}s\356\366g\267\031D\022A\002\r;/k\030C\014\264ld~\000\225\256\304\246j\2555\031\254B\241\204$&\006*u\200\204\204d/\260\250T\n(\262\321\035\253\255\2244 z\257\302\264\021\325\007\014$F\367\360I\214\232\232\243\347\242ih\350\365O\366f\243\315t=\020I\0209\036\233b\271P\223\315D\347\333\301.d\026\023\352\t\257\272\251\331\036\\G\206\223f\377\022\214T\354\312f.\261FJ\244>\250\374\224L\271\006\354\217\315\352pH\221\253\304E\022e0\240\341t]\3720\003\377\203c\215\324\362N\313|\230\363\340\271-\317\362\342\030\337=\022\2016\337\325\t)\365AM\347H\257c}<\033\243\342#\001\032\234Q7\304j\345\005\2417\351\263y\306\325\302\346\004\023m\022sk\314\024\226\237\032ELL\223\033\251\264\354Y\2102\215\263\\\356\276UF\025PnK\351K\326\026\252\261\332w\001\311gZ\030R\375Z\033\353""\300I|\266`J\332w\274\325\270em \035\360&\323\361\306.\021\214iaL\242\361\026\245\231\344\231\272\310\325\2740^\303\226\037\340\264}\356\254~\350\006\231'^<\251\204j\037\261\323\316\033\245\250}|\266\352\274E\275\330\224\034o\211q\241\240RQv\355r2l+9\003\020\345\234X,%G\364\342\254\210k\266\t{V\352\253\225RS\370_A@m\0238\255\007\212;\035\314\310\302\254\241\022p@\212\242J\236\014\251\022,\235<\013k7\210\032\220i3\007\\/\243\227\220$\344\364\3039\245bs\177\315\030^\326\226\020V+Mc\2718?\277\013\0270kT\241\341\346]\345\304\350\227/e&\344\374\355\217\027>\344\265\257\215,\235\021\034\334N^\200\307\363\375\013{I\262\320hV\317\317=\227e\310\265\233D\377\352\272I\334+9\326\371c\032\220\204J\213\013\024\274\264\246\343\316\321||\344\343\347\335\244\376\246c%\214v\375\240b\3341'\216\005\234dG)\025\201\375\203\033F\240\"\007\007\213|\004\302\027\307\245\315\026\3102b\223\207\221\311\031Bz\276,\2552\247\245&\"\315\247}\310m\202<e\371\236\247k\306\355\202q\220\375;\335\177U\321\375S}\313jn\007\000\020\221\241:\032T\330\t\363\000Bn\225I\355_\225\352J\306e\2514\215\366\240\350w\302\2750:\244\267RU\205u\307\013\234\222\246\001\001\337N\310\272\003\235\251\234\032`p\027z\327S\000V\242\335\327ei\036\321B0jwE\021aR6\272\322\305On\334\271s\367\356\255\271/\246\346\347\177\234\277\363\371\335\351\233\217\25333K\213\337U\253\325\377\371\357J\245r\371\217\225\377]\\\272\366\355\364\343\271[3\363SOn<\375\356\351\235;O\357\336}\372\355\314\2673O\347\347\237~qs\351/7n,.\336\232\233\231\277\263t\367\332\324\215\247\323\217\237\3748;}\263\362\371\343\357\254\271\273\213\026\376}a\315\334\274\374\370\362w\227\237>]Z\272\273tg\351\326\255\271\271;w\257-=uHl\023:\205\222\t\252M\005\003V\314`\004\261\304\213iF\320;\207\215tPE\226U[8\324'b\177\220L\325\320\203!^\014\267H8\364\370\303\357\254%\013\373r<\317\016\311\344#X\250\250\247:\3742+r\354)mQ\014\317\240J\243\223\212RX\003p\220:XYmkym-\217Y\025|Q-Y::\000\346\271E\270*\235\033\017X\361\224E\230KMgj\331\315\3458\301\213\035\261r`\341\037i\372""\3420\303\270\246?\333\340\214^>\333D\211?\366\235\352d\020\205\273E\330l\274\375\257\217\206Z'\013R\234d\220\215\370\242\306\307c\030\002,*\244\234e^\370\234\3508\003\247\301\323\001\003\342\024\306Am\204\024&\254P\001\241\302\365\0313\3134\032Z\2674\320*C\214B\t\226\252\241>\344Q\005t|\006fU\2600\357k\351\316\034\016$\364\327y\023}\254\346`Q,$\217|\314T\304x|\200t\007\034#\014G/\342\237\212F\243\212#;\241[\364PB\203>\201\010w\301f\037\021e>\236\265v\243\324\024MyM\315\222\213\304\333\006\310\331beA\004\023C\177\372\273\255TO\302\272\345\010\274\322Vx\332v\222=3\306\231\003d,\262m\245&l\333R\301\021\251\206\216\\7\313\325UC\354\372\034\204\314\225\026NT\253\227\246PJkJ\032\323Y\035\204W\251\250\315\370\332\233\007\327\211\335\302g.E\210\364\321\313(K\\56\225\026V\231\351r\306\010<\263%\232#Q\256K\"\005\371\341a\323\337\315tL\237\2155\337\204\r\306\235\370Ek\252\250,\250]\264#\355\341\217\006\005\366|\342\203\274\220w4\232[|\201\037?\306\314\214k\204_\000\0136\202\025\213\221\345K\213#5\222\205\261\343\356\321\254\205\250q\350\206\214\362\250\215\221[:8\2447\324\206e\303\315\317\331\014OOY\216\323@$g\362\230\210\201xu\316\232\230l\274:\340\2478f\267E\265\255\202$\026\207=\317\030Ic>\205|\362\301\267rF\241\016\022\213\370MO\177{\370\364q\365\273\233\267\220Y\252\316\334\274>E\266\026\330\240-@\016\314\302\021\000\343\217\345Civ6\\]\320t\321\032\003p\026\261\271\300\337\023\371\346\ny[P\033%<\225-}\0032[QR\311Fr\310{\026G\302-T\265v\245-h,\343$\343\364+\245 \3304KgV\030\031\024\007\254\026\246o\025&\375x\321\332*O\017\340\231g\370)\035\260\002\215\216/`B\252\310t\356k;F`\314\344\2656\260S\002\360\350\202\241\226{\264\234\223\333\2641\225\204`\244[\250\3239\315\234\365\234\216\252\034\363\256\245\n\213\271 \005i\033Y\252\3068t|\356@\231{\365\373k\033\366\352\266\275\265\375hm\343\276\312\3524\030v?\213T\247{Q\024\360;\021\316\236\231\377\236\n\314\334#\315\272\256N\215\212`\352s\021_\225\324\022\276\336\320\351\304\351\024\227\035\\\266L\252qE4U&\"?\360\350\036\\\363m""\0169q\031\034\202\361NT\366 \371Z_G\344m1N\235\3655\347\352\260\351P\002B\264\313yN\257\202\037\307\006UE\252\372\313\332#\230!\014\251f\263\313\024X\033\353\262!\340\253x#\313\335L\223\261F\217\004_\232\271\343\235\267\330\351\035\351\274\305\036\353\203d\207\374U\263\026>\374\221f\2240\2650TM\322\221\256\343\t\257\340\212r\351r;\346,0\204\337Dv\035Q\342\274\212y\362\315\327r\031\217jp}\024S\216\024\253\202\3203|\20448!\0239\265\342\230\247\320\351Glg\274\210\022\351\021\376\252\266\355\002\202l[\245\311RB\2321\207\371\246\270x+\256\321\364\305\333J}\245\276\261\r\331\314\257\313\250\261&\313\212\010\314\242V|7}\301\346\250\3120\n\245\351]__[\255\257o\325\353\033+\205\204\214d\354\372\177n>\242\022]\367`\265\276\265\\\333\254\327\203\300\217\245/\315\233G\243\313>\341\351\233?\2423\227\362Uc\235\r\032\020\014*\201K\201[f\321\206\302\222\022\246pu\375Am\233c\227\253 \304\026C\311\212\220n\342\307\330\375j\020\351fQ\321#J\332t\334\360lp\022\\\002D\032\343q*\032+!%e\030o\225\215\206\373k\353\246\366\276\010\325\255q\020\024Yu'V\202\243\373\034\274\240\324\032\235\323\332\352\332W5\300\014\247\361\227\007\302\025i\270]\263\240\305Z\323\314\266\326vT-\257\220S!\371\331b\224\343\327\310]Q\t\225/\001\341_#2n0\021e\326\361\317i7<\2073p\207\350\375\025\371s\265PKQIB\270\002\322$\316d$\347\276R\332u\274G\236\330\002\364\023\357\2177\340\363(\027\362'\r_\373\342p\013\276w.\364_\t\270p\236aM\2253CrI~;\275Q\377f}m\243\276\261\263\276N\220\305E\342\320\260\221\371I\025\252\017uA(.\343\001'G\035\324F\304\323ld\352`\037\250\353\204\007Ii\235\233\220ns2\233\211\017c\265\2431\006\2710-\252\310)HY|7;%m\260\331)C\377f\307\336Y\336\272M\257\215\265\345\007+u\244Z\216l\331)\022\222\256\3638\225JI\357D\034\361\315\272Hl{\263s\204\037\021\306\336\200\375\005\214y\344\3702\007\242G8\374\221,\305\215M\316\\\317o\t\225eD6\334\274\205\212`\214\267\266\260\220\250i\316D\345\276V\210\312\247\225\363\036\3478\241\274\361\035c\377\351\262\324\360\033xqTu\216~\032\240rk\017\266u\202L\3448\nr\333`""[G.\013\3311%\271\324n'\031~\035\2051f\347(XU\367\302y\211\2611\250\237\353\250\325\355\354\320\265\354W@v\3060\035e\031]\260.\344zhc\271\223}\323\"P\322\343~\003\353\310\244\377\213L!\303\211\234!\3041\005\266\323\220Q\000+\305V\316\014\3544\266Im\025\310\265)Fc\347\016/,D\362\026\350\"\207\314&}\t \274\3426\300\211}\207\001^=m\262\237\241\207tN_\347\353\\\246n\363`\215\341\317fC\022\t\351\340\277M! \274T\020\005\005\256\357;l\207)\347\200\354{\266\364\370\341GU,0\312Rrg\035cw\345\t\351\220\365\345\034\t\331\240\317\211\350g\353\233+N\223\001\232'\354\020T\341\257\216\340\365G\261\312B\266\032\221\327i\300 k\220\233\261\300\317\217\032p\r\320\216\314\263F\207c\035\2666\244U\206\025\260\353\252\311\364\313\206\177o\264.=\301A6\373\033!\221\357l\211\255]\004W\331\024x\361\017\031`5\206\240\230\210\253\243!v3pv\211\342\364\263\311\372\265\025\211m\251Q\213*dq]\257\257\367m\2754\275P\225\326e ?\271W&K\347\342\322\031\302X\260S\332\177\0032\346\222\003\022yj~n\022\265I|\251\241\276\331\325/\233\302\320\2320\332\242\260\363\313A\351*[\224^@Gx\007y\274\232C\357&\376nC\321e\001e\331\376)\3345f7\025\034\212c\374\351\r!\315o\034\024\030\3750!\376K\334\364\310D\200\274\342\243\232\"%M\264\3110\177\361\361\005uQ\261\034O\340\030=\302A~r\212\007\305.\331\332\311\367fk\222\310\242\204\357V=\037'\224\300;\242\373x\264\217\\\014\245\036\031\230\\=m\212/\332\372\022R\013\205\010\374\246\2001B?\332'\330\201\003@B\243\230\r\331M\t\254\325\213\005\205\244\231}z\320\330N\033\374\304\"\350\315G\242\202<\352\251\307\224yh\310f\276)\262\272\207\300Z\305\021\031\216\374T\363(_\216\237@\017\2626t\206\342\232yFG\376uN\203\203\361\003\331M\315m\032\302#\n\013\022\326\023\0065\233d\210\321\032l\273\t\340$\301i:\251\023\350/o\364Ko\0029\317.\261\ty\306\\\246\003$6\207g\374D\246M2\343\232Q\202?W\330q\347c\210N\033,\347\273\262\311\326\234M\301:\022\255&\364\264\335f\013\200\245\302\346Q\325\223\350\303o\000\206l\2229WD\215\364\273`z\234%\376x\t\266\n\364#K\214L\310\307*&OH\370\272\352Zj\027p""\027\357f\340\034hlP\236>\027\003\365\351$\325\226\251\230M\013\233\243\355\224\205\223N\370\n\273\257i\016W}{\243\236\264Sh\225 \nu>Sa|\376R\210qB=\261\031\332/\234\000@\000\320\214\236\035\332\255&f\231\246\034\3066\216\005\007b\261 \372\304%\244\243\366I~\3514\355L\355\317\217 \0042\327I\224d|\327o\233\002eH\033`G\032H\355c\313\314\306\310\272\006\200)Mha\336\266F(\316kU\2014\013l\321Es\276C\213\320\320\250u\021\025H%\001~^\002\245\207\247\024A\323\006a9Y\036\215\204V\277\000#\234\242M\226[d\r\345? \255w`>\367#\320\225\2766\243\277\207\t\ra\301\037\035uBo\226>;v\300\264\310J-J\264\216<\255C8\352\264\306\013\315'\t\024\220\333;\264)\032\265w\350\311\200\215\363\300\t\301[\273\302\346\217=)\032\351v\210 \212\311\314E\232\252lI\374\331t\263A?\336\006\005\311\351\007m,\203(\332\203f\347\247M\021G$c\322hI@\344\210m\273\355\200\203\360\334\003\007\222\005\307*\0272\207\371\023\276\351\261\351\360\034\255\226L\234Yj\321\263\307\336\264Y\235\304\026[&y\344)\031-\236\222\037\260\020\341@\035\322\007U4\255\331\032G\225B\350 BT\363\266K\312!\324\206;X\000\177`mzRCH\260\022b<\265\rE\023\351/\263\364kA\277?2\301{\372\257\272\323\207\302\021p*\361=2r\240\302\350L\231\276\224\316\355\024\312\024\353A\016\253\2175\021\310\354\025^\354\320g\303\020\1776\3329\276\233+!\225+T\021\017\357$$\236\364m\217f\016\303#\320\020{q\024Cn\361\307\254R|\245\306\034W\312\232>\266\r\350\246%P\002R\316\017[\315\013(\027\310\037@\033\307\332U\211\323\204\276t\266Su\375\031g\251M\206\005\033K1\274\r\350>\0376\t\247\017\370\013S\312\355g8\001>\321$y\324\270\227\3554W\323m\366=\222F\222%\315$\205\344A\353{\264f\274\003\310a\346\n\365\311\223\355\231\217le\242\277\202Y0\211\217T\342@K\200\2627X\366\022vf\324S\031\214\205\361\233\010R0\302KZ2\221\030;M\230\305\245\272\357$\2340v\030\200\202\261bD\316l\306\017\265\037J\261} Rmj\310\026\3355\000\2321\022\273f\222=!\025\322\264\215\326\327n\033\333\013t2x\227\323\\A\030\005\321$\313\235\0368*\231z\244@%\316C\246QL\272\326i\253\2653\013\003\247\210bi\352""\354*\343\303|\274a\336\350\031\246L0\350\\\3428*BW\326\320\3646\366M\232th[\364c0\325\026\030[\216\224\206\3240\005x\357Y\326\200\231\r\244\350\020lR\221\376:\312@\250\324y\017\232\237\2777\311\214\311\236\205\212TY\214:\301`\251\020\223\316\320`\247\342Tu\035\207\223k`\003mc\022\024\237G\036D\276gP\231\002\321\364\303z\016[NzHN\027\205\242\351g\0032\016\023,\214\203\317?\370\361fG\177\2456s\341\002Ga.8a\307(\001\365\035S\321dZ\1779\243X\234\310\360\251\212\274\331\237\231\320\233\375\231\361\235\355\262;n\315\314Z\3058\263z\204\364\234\376\177\322\261;;&\315\303\244`s\345\346\205\013\261\255\334\035*C&\001\010\300\010-\312~\232\030\276=\335\177\251\2770\374\303\314`\346\363g?\376\362pX\371d\360I\375\347'\203\255m\024\366\257\375\3557\027^\236<^\030^\374]\367\332\360\342\345\343k\307\267\217\017\273\316\360\322\344\361\375\356Bw\2757\321{\253W\357\377\376\2646|\367O\247\373\303\367\336\037^z\365x\341x\245\373Rwa8\371\332\360\322+\307W\217\321\376\035t\272\210\032\314Y\271\215\326\027\177\373S\212q/\275\331}\345\344\375\336\265\336B^\362\306q\347\344\225\336\225\336\265\363J^=\376s\367\257'\316\311>\365\374m\367\360\244\331\273\337\247A\247>{61\274\370\306q\326\275G3\275\374\323\327X\005O\263Okx\347x\277\373o\335k\335b\032U61|\345\265\343\207\307\315\356r7o\207\225wWN&N\3369\331\357]\354\325z\017i\267_r\321\225\341\344\037Nj'[\275\337\364D\177\241_+u\031\276\362\026\372\255\236L\321\332^\031N\376\256{\035\013y\343M\225\372\2767Q^\306\237N\256\235\334\246\206\223\307\253\335\233'\237bs\327{~\377\340\364\341p\222\366\260\334=8\331\356]\355\271\375+\3037-&\362\375\376'\247\023\247o\201tgW<\241VX{\361\352\236\347\311\333\335\375\223\t\020\354\315\077\077\273\242N\364\317\335\332\363\213\357\017\336\377\364\324\301\t^|y\360\362\273\335\375\347D\271\343K\003\314\376R\217\311\365\336\340\312u\242\306\363\213\223\003\314\263\006\272\240\373l\327\301:.\276:x\365\367'\013'\313'\022g\371\351\340f\355\347+L\373\343\213\307\313\307\245uN\276\331\235\350^\351\3368\271\210\205><a""\236X\354>\354\n\320\340jo\267\377p\370\316M\354\371\235[|\250\257\377\2617\203m\214\216\376\331\340\326\362\317\013\377\360\350\013?\325\210:k\335o\250\2142\257\037\273\335+T\246\373\276\213Now\037\232\344\025b\270}\314~u\256\377d\360\227\365_j#s\2751x\203\310`\237\326\236S\372\203\336Bo}\360\341\312\3175\364xg\246\377\001\266\360\357\323\203\351\317\236\275>X}<x\354\017\374\357\207\37717\230\273\373,\304H\363K\317\036\376\355\362\205\227_Ut\037\333\005K\212\021\237\333]y2\337\277\322\2776\234|\253\373\311\340\275\331~\255\277s:u\272\377\354\322\317o\374\262?\330\334\031\354`\202o\207\223W\007W\247\373\023\375\267\372\365\323\253\247\315g\265\347\223W\273O\260\256\345^\326\377\362\364\376\263\305\237\037\016\257\177|\2720\274>\337\337\037^\247\263\231|\355\370\233n\255\373\360\371\245+\203+7zNO\366\247\372\207\247\376\263\375a\205Z\222\224\014^\275\321\363\3727hs+\277L\374\362\366/[\203MP\211\270\317\201D\202\306\303\311\327\301\2105\003\014i\367\223\223\t\242/UO\214\000\001\226\210s%\352<\307\324;\000\223\321U\267\236a\347\3572'\035/\374\037+\034\346p";
    PyObject *data = __Pyx_DecompressString(cstring, 5959, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (13992 bytes) */
const char* const bytes = ",3An axis specification in memoryview declaration does not have a ':'.Argument expansion not allowed here.C classes cannot take keyword bases.C function definition not allowed hereC struct/union cannot be declared cpdefC struct/union/enum definition not allowed hereCannot combine 'api' with '%s'Cannot concatenate char literal with another string or char literalCannot mix string literals of different types, expected Cannot use cdef modifier '%s' in Python function signature. Use a decorator instead.Conflicting settings found for top-level directive Conflicting visibility options 'Cython.Cython.Compiler.Cython.Compiler.ErrorsCython.Compiler.ModuleNodeCython/Compiler/Parsing.pyCython.Compiler.ScanningCython.Compiler.StringEncodingDeclarator should be emptyDecorators can only be followed by functions or classesDuplicate 'const'Duplicate directive found: Duplicate string prefix characterDuplicate 'volatile'Empty declaratorEmpty enum definition not allowed outside a 'cdef extern from' blockEmpty struct or union definition not allowed outside a 'cdef extern from' blockExecutable statement not allowed hereExpected 'None'Expected a newlineExpected a newline after decoratorExpected a numberExpected an identifierExpected an identifier before '='Expected an identifier, found '%s'Expected an identifier or literalExpected 'except' or 'finally'Expected '(', found '%s'. Did you use cdef syntax in a Python declaration? Use decorators and Python type annotations instead.Expected identifierExpected imaginary numberExpected 'import' or 'cimport'Expected 'object', 'type' or 'check_size'Expected one of '<', '<=', '>' '>='Expected one of ignore, warn or error, found %rExpected '[' or '('Extension type definition not allowed hereExtension types cannot be declared cpdefFailed to match literalFound the C operator 'Fused type definition not allowed hereGot zero positional-only arguments despite presence of positional-only specifier '/'Illegal next symbol '%s'Illegal operand for inplace operat""ion.Invalid class visibility '%s'Invalid hex escape '%s'Invalid pattern targetInvalid string prefix Invalid string prefix for character literalInvalid type for compile-time constant: Invalid unicode escape '%s'Left-hand side of assignment expression must be an identifierModule name required for 'extern' C className options not allowed for C++ className options only allowed for 'public', 'api', or 'extern' C classNeed at least one typeNon-keyword arg following keyword argNoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Object struct name specification required for 'public' C classObject struct name specification required for 'api' C classOverloading operator '%s' not yet supported.Pattern capture target cannot be '_'Positional patterns follow keyword patternsPython 3 requires docstrings to be unicode stringsQualified class name not allowed C++ classQualified class name only allowed for 'extern' C classRelation directions in for-from do not matchReturn type annotation is not allowed in cdef/cpdef signatures. Please define it before the function name, as in C signatures.String prefixes Syntax error in C class definitionSyntax error in C++ class definitionSyntax error in C variable declarationSyntax error in Python function argument listSyntax error in ctypedef statementSyntax error in declarationsSyntax error in doc stringSyntax error in enum item listSyntax error in include statementSyntax error in simple statement listSyntax error in statement [Syntax error in stringSyntax error in struct or union definitionSyntax error in template function declarationTarget of for-from statement must be a variable nameThe 'DEF' statement  will be removed in a future Cython version. Consider using global variables, constants, and in-place literals instead. See https://github.com/cython/cython/issues/4310The 'IF' statement is deprecated and will be remo""ved in a future Cython version. Consider using runtime conditions or C macros instead. See https://github.com/cython/cython/issues/4310The 'cdef' keyword is only allowed in Cython files (pyx/pxi/pxd)The keyword 'nogil' should appear at the end of the function signature line. Placing it before 'except' or 'noexcept' will be disallowed in a future version of Cython.Type object name specification not allowed for 'extern' C classType object name specification required for 'public' C classType object name specification required for 'api' C classUnclosed string literalUnexpected characters after Unexpected symbol '%s'Unexpected token Unknown Unicode character name %sUnknown typeUnmatched %sUnnamed scoped enum not allowedVariable name in for-from range does not match target^&<<>>+-@%//~/<?>()[.**=:]...{`'''\n\"'}:=!\\([-+*/%^&|]|<<|>>|\\*\\*|//|@)=;&&::+-*/<=>!%&|([^~,()'?[] ->:    @ *)\n[\n]\n||==>=<=++--<>!=|a starred assignment target must be in a list or tuple - maybe you meant to use an index assignment: var[0] = ...add_note and ' and ''api' not allowed with this statementbytes can only contain ASCII literal characters. cannot be combinedcannot mix t-string literals with string or bytes literalscdef blocks cannot be declared cpdefcdef extern blocks cannot be declared cpdefcdef statement not allowed hereclass definition not allowed herectypedef statement not allowed herecython.bintcython.longdecorator not allowed heredef statement not allowed heredefault values cannot be specified in pxd files, use ? or *', did you mean the Python operator 'empty expression not allowed in 'except +nogil' defines an exception handling function. Use 'except + nogil' for the 'nogil' modifier.expected expression, found '*'expected one of 'def', 'for', 'with' after 'async'expected tuple of length 2 or 3, got length %df-string: conversion type must come right after the exclamation markf-string not allowed herefrom __future__ imports must occur at the beginning of the filefuture feature %s is"" not defined'', got illegal integer literal syntax in Python source file in  in string literalinclude statement not allowed hereinternal parser configuration errorinvalid character literal: %rinvalid conversion character '%s'invalid string kind 'invalid syntaxinvalid syntax: assignment expression not allowed in this contextitem found in iterable unpacking cannot be used in comprehension literalmissing conversion characternot a chance or ** pattern must be the final part of a mapping pattern.'%s None' only allowed in Python functions^#\\s*cython\\s*:\\s*((\\w|[.])+\\s*=.*)$%s on something that is not a function-string-string expression: -string literaltuple-like pattern of length 1 must finish with ','tuple variant of exec does not support additional 'in' arguments (type unexpected warn.deprecated.DEFwarn.deprecated.IFwith gil/nogil cannot be async'yield from' requires a source argumentAmpersandNodeAnnotationNodeAsTupleNodeAssertStatNodeAssignmentExpressionNodeAsyncIteratorNodeAttributeNodeAwaitExprNodeBEGIN_FT_STRINGBEGIN_STRINGBackquoteNodeBoolNodeBreakStatNodeBuiltinBytesLiteralBuilderBytesNodeCArgDeclNodeCArrayDeclaratorNodeCClassDefNodeCComplexBaseTypeNodeCConstDeclaratorNodeCConstOrVolatileTypeNodeCDefExternNodeCEnumDefItemNodeCEnumDefNodeCFuncDeclaratorNodeCFuncDefNodeCHARSCImportStatNodeCNameDeclaratorNodeCNestedBaseTypeNodeCPtrDeclaratorNodeCReferenceDeclaratorNodeCSimpleBaseTypeNodeCStructOrUnionDefNodeCTupleBaseTypeNodeCTypeDefNodeCVarDefNodeCascadedAssignmentNodeCascadedCmpNodeCharNodeClassPatternNodeCompileErrorComprehensionAppendNodeComprehensionNodeCondExprNodeContinueStatNodeCppClassNodeCppRvalueReferenceDeclaratorNodeCtxCtx.__call__Ctx.__init__CythonArrayNodeCython.Compiler.ParsingDEDENTDEFDecoratorNodeDefNodeDelStatNodeDictComprehensionAppendNodeDictItemNodeDictNodeELIFELSEEND_FT_STRINGEND_FT_STRING_EXPREND_STRINGEOFESCAPEEllipsisEllipsisNodeEncodedStringErrorNodeErrorsExceptClauseNodeExecStatNodeExprNodesExprStatNodeFLOATFalseFileSourceDescriptorFl""oatNodeForStatNodeFormattedValueNodeFromCImportStatNodeFromImportStatNodeFusedTypeNodeFutureGILStatNodeGeneralCallNodeGeneratorExpressionNodeGlobalNodeIDENTIFIMAGINDENTINTIdentifierStringNodeIfClauseNodeIfStatNodeImagNodeImportNodeInPlaceAssignmentNodeIndexNodeIntNodeIteratorNodeJoinedStrNodeLLLLambdaNodeListNodeMatchAndAssignPatternNodeMatchCaseNodeMatchCaseNodesMatchMappingPatternNodeMatchNodeMatchSequencePatternNodeMatchValuePatternNodeMemoryViewSliceTypeNodeMergedDictNodeMergedSequenceNodeModuleNodeNEWLINENULLNameNodeNewExprNodeNodeNodesNoneNoneNodeNone\nNonlocalNodeNotNodeNullNodeOptionsOrPatternNodePassStatNodePrimaryCmpNodePrintStatNodePropertyNodePyArgDeclNodePyClassDefNodePy_UCS4Py_UNICODEPy_hash_tPy_ssize_tPy_tss_tPyrexScanner__Pyx_PyDict_NextRefRaiseStatNodeReraiseStatNodeReturnStatNodeScanningSetNodeSimpleCallNodeSingleAssignmentNodeSizeofTypeNodeSizeofVarNodeSliceIndexNodeSliceNodeStarredUnpackingNodeStatListNodeStrLiteralBuilderStringEncodingStringIOTStringInterpolationNodeTemplateStringNodeTemplatedTypeNodeTrueTryExceptStatNodeTryFinallyStatNodeTupleNodeTypecastNodeUUnaryMinusNodeUnicodeLiteralBuilderUnicodeNodeUtilsUuWhileStatNodeWithStatNodeYieldExprNodeYieldFromExprNode_absolute_importaddallow_struct_enum_decoratoralternativesandannotatedannotationapiappendappend_charvalappend_newlineappend_uescapeargarg_tupleargsasas_nameas_targetsasciiassertassignableasyncasyncio.coroutinesattributeattributesawaitaxesbbasebase_classesbase_typebase_type_nodebasesbinop_nodebintbodyboolbound1bound2bracesbreakbybytes_literalbytes_valuecc_classc_class_pxd__call__calling_conventioncalling_convention_allowedcascadecasecasescause__cdeclcdefcdef_flagcharchar_from_escape_sequencecharscheck_sizecimport__class__classclass___class_getitem__class_namecline_in_tracebackcmethod_flagcnamecommentlinecompilecompile_time_valuecompiler_directivescomplexcomponentsconditionconstconstant_resultcontinueconversion_charcpdefcppcpp_classcppclasscreate_wrapperctxctypedefddeclaratordeclarator""sdeclaredecoratordecoratorsdefdefaultdel__dict__dictdict_typedimensiondirective_commentsdirective_typesdiscarddivisiondoc__doc__doubledouble_star_capture_targetelifelseelse_clauseemptyencoding__enter__enter_asyncenumerrorexc_tbexc_typeexc_valueexceptexcept_clausesexception_checkexception_valueexec__exit__exit_asyncexpectexpect_dedentexpect_indentexpect_keywordexpect_newlineexpectedexprexpression_strextendexternffalse_val__fastcallfatalfinallyfinally_clausefind_conversion_funcfind_include_filefirstfloatforforce_py3_semanticsformat_specfromfull_module_name__func__functionfunctoolsfused__future__future_directivesgetget_file_objectgetchargetstringgetstringsgilglobalgroupguardhas_explicit_exc_clausehas_local_scopehas_varargsifif_clausesignoreignore_semicolonignore_unknownimagimportimported_namesinin_pxdin_pyfuncincludeinclude_fileindex__init__initial_posinlineintintern_ustringioisis_absoluteis_asyncis_async_defis_attributeis_basic_c_typeis_c_literalis_constis_const_method_is_coroutineis_dict_literalis_except_asis_import_as_nameis_is_checkis_nameis_notis_self_argis_set_literalis_staris_starredis_string_literalis_subscriptis_typeis_volatileitemsiteratorjoinkeykey_exprkey_value_pairskeyskeyword_argskeyword_pattern_nameskeyword_pattern_patternskindkw_onlykwdslambdalanguage_levellegacy_implicit_noexceptlevellhslhs_listlist_typelonglongnesslookuplookup_herelooplowerlstrip__main__make_slice_nodemanagermatch__metaclass__modifiersmodule__module__module_namemodule_pathmodule_pxdname__name__namesnamespacenewnextnodenoexceptnogilnonemptynonempty_declaratorsnonlocalnotnot_innot_noneobjobjectobjstruct_nameoperandoperand1operand2operatororor_noneotheroverridablep_c_arg_listp_c_base_typep_c_declaratorp_codep_modulepackedparent_scannerparse_commentsparse_directive_listpartialpasspatternpatternspeekpoppospos_onlypositional_argspositional_patterns__prepare__printprint_parse_treeprivatepropertyptrdiff_tpublicput_backpxd__pyx_capi____pyx_vtable____qualname__rrRbBuUfFtTraiserbrurfrtrrereadonl""yrealreducereject_duplicatesrelation1relation2relative_levelresult_exprreturnreturn_type_annotationreversedrhsrsplitrstripsscopedselfsequencesetset_language_level__set_name__set_typesetdefaultshortsignedsize_tsizeofsource_encodingssize_tstar_argstarstar_argstartstart_linestatestats__stdcallstepstopstreamstripstructsubjectttagtargettemplatetemplatestentatively_scantesttrue_valtruedivisiontrytypetypechecktypedef_flagtypeobj_nametypesuubunderlying_typeunicode_literalsunicodedataunionunop_nodeunsignedupdatevaluevalue_exprvalue_patternsvaluesverbatim_includevisibilityvoidvolatilewarnwarningwhatwhilewithwith_gilwriteyieldzipPyObject *\000\000IDENT\000any_string_prefixPyObject *(struct __pyx_obj_6Cython_8Compiler_8Scanning_PyrexScanner *, PyObject *, __pyx_t_6Cython_8Compiler_7Parsing_p_sub_expr_func)\000\000p_binop_expr\000p_rassoc_binop_expr\200\001\330\024(\250\003\2501\330\034*\320*?\270~\310Q\330'5\3205E\300^\320ST\330\034*\250!\360\006\000\005\014\2101\330\004\022\220!\330\004\n\210!\2104\210w\220a\330\010\014\210G\2201\220L\240\001\240\023\240E\250\033\260A\330\0277\260q\330\030\031\330\010\013\2101\210D\220\003\2201\330\014\r\330\010\t\210\025\210a\330\010\026\220a\330\004\013\2101\200\001\330'4\260A\330\004\007\200t\2101\330\010\020\220\t\230\031\240!\2401\330\004\007\200t\2101\330\010\017\210y\230\t\240\021\240!\330\004\007\200t\2101\330\010\017\210y\230\t\240\021\240!\330\004\013\2109\220J\230a\230q\330\010\020\220\007\220w\230f\240G\2501\200\001\330%8\270\001\330\004\017\210u\220B\220a\330\004\005\200V\2101\210A\330\004\007\200q\330\010\t\210\026\210q\220\002\220!\2201\330\004\007\200t\2101\330\010\t\210\026\210q\220\001\330\t\r\210Q\210f\220C\220q\330\010\t\210\026\210q\220\003\2201\220D\230\001\230\026\230q\240\004\240A\240Q\330\010\014\210H\220D\230\001\230\021\330\014\034\230A\230S\240\006\240e\2501\250A\330\010\t\210\026\210q\220\003\2201\330\t\023\2201\220F\230%\230q\330\010\t\330\014\022\220$\220a\330\017\020\330\014\022\220$\220j\240\001\330\010\t\210""\026\210q\220\002\220!\2207\230!\2304\230q\330\010\014\210F\220)\2306\240\021\240$\240i\250v\260Q\330\014\017\210u\220C\220v\230T\240\025\240c\250\021\330\020 \240\001\240\023\240G\2505\260\001\260\023\260A\330\t\r\210Q\210f\220C\220q\330\010\t\210\026\210q\220\001\330\010\014\210H\220A\330\014\034\230A\230S\240\006\240e\2501\250A\330\010\t\210\026\210q\220\003\2201\340\010\t\210\026\210q\220\003\2204\220q\230\001\200\001\330\0209\270\021\330\004\n\210!\2109\220A\340\004\031\320\0316\260a\260q\330\004\005\320\005\027\220q\340\004\007\200q\210\010\320\020 \240\003\2401\330\010\t\210\030\320\021$\240A\240Q\340\004\014\320\014\034\230I\240Q\330\004\n\210,\220a\220q\330\004\013\320\013\033\2301\230C\230s\240!\2406\320)A\300\021\330\004\007\200q\210\004\210C\210q\330\010\t\210\026\210q\220\001\330\014\020\220\001\220\021\220&\230\004\230A\230Q\230a\330\004\013\210:\220Q\220e\2306\240\025\240g\250Q\330\026)\250\021\330\026+\2501\200\001\330\016\"\240*\250A\330\004\013\320\013\033\2301\230C\230s\240!\2408\320+C\3001\330\004\007\200q\210\004\210C\210q\330\010\t\210\026\210q\220\001\330\014\020\220\001\220\021\220&\230\004\230A\230Q\230a\330\004\013\2101\200A\330\010\014\210I\220W\230A\230Q\200A\330\010\016\210c\220\021\330\010\014\210C\210q\330\010\t\210\027\220\001\220\024\220Q\330\010\t\210\027\220\001\220\021\330\010\017\210q\200\001\330\025-\250^\320;L\310A\330\004\007\200q\210\004\210C\210q\330\010\017\320\017$\240A\240_\260A\340\010\017\320\017#\2401\240L\3200D\300A\200\001\330\026*\250#\250Q\330\032(\320(8\270\016\320F[\320[i\320ij\330\037-\320->\270n\310A\330/=\270Q\360\n\000\005\013\210!\2109\220A\330\004\007\200q\210\004\210C\210q\330\010\t\210\025\210a\330\010\013\2101\210D\220\003\2204\220s\230/\250\021\250!\330\014\023\2205\320\030,\250A\250U\260%\260q\270\010\300\017\310q\320PU\320U[\320[\\\330\014\025\320\025(\250\001\250\023\250E\260\025\260f\270A\340\014\025\220^\2401\240C\240u\250H\260G\270:\300Q\330$3\2601\330$/\250q\330$A\300\021\330\014\r\210W\220A\220Q""\340\010\021\320\021&\240a\240s\250%\250w\260i\270q\330'3\2601\330\004\007\200t\320\013&\240d\250&\3200D\300D\310\001\310\024\310S\320PQ\330\010\r\210Q\210a\210y\230\004\230A\330\014\016\210f\220A\330\004\n\210!\2104\210t\2205\230\001\330\010\016\210a\210y\230\001\330\010\013\2101\210D\220\003\2201\330\014\025\320\025)\250\021\250#\250Q\340\014\r\210U\220!\330\014\025\320\025(\250\001\250\023\250E\260\025\260h\270a\330\010\027\220q\330\004\013\2101";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 816; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 233) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 816; i < 828; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 828; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 816;
      for (Py_ssize_t i=0; i<12; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab;
    double const c_constants[] = {0.0};
    for (int i = 0; i < 1; i++) {
      numbertab[i] = PyFloat_FromDouble(c_constants[i]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 1;
    int8_t const cint_constants_1[] = {0,-1,1,2,3,8,16};
    int32_t const cint_constants_4[] = {1114111L};
    for (int i = 0; i < 8; i++) {
      numbertab[i] = PyLong_FromLong((i < 7 ? cint_constants_1[i - 0] : cint_constants_4[i - 7]));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<9; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 4;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 13;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS), 54};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_kwds};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_IWAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS), 57};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_kwds, __pyx_mstate->__pyx_n_u_ctx, __pyx_mstate->__pyx_n_u_d};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_call, __pyx_mstate->__pyx_kp_b_iso88591_A_c_Cq_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 748};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_n_u_stop, __pyx_mstate->__pyx_n_u_step};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_make_slice_node, __pyx_mstate->__pyx_kp_b_iso88591_4A_t1_1_t1_y_t1_y_9Jaq_wfG1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2744};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_nonempty, __pyx_mstate->__pyx_n_u_templates};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_p_c_base_type, __pyx_mstate->__pyx_kp_b_iso88591_LA_q_Cq_A_A_1L0DA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {8, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3086};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_ctx, __pyx_mstate->__pyx_n_u_empty, __pyx_mstate->__pyx_n_u_is_type, __pyx_mstate->__pyx_n_u_cmethod_flag, __pyx_mstate->__pyx_n_u_assignable, __pyx_mstate->__pyx_n_u_nonempty, __pyx_mstate->__pyx_n_u_calling_convention_allowed};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_p_c_declarator, __pyx_mstate->__pyx_kp_b_iso88591_Q_8_F_iij_nA_Q_9A_q_Cq_a_1D_4s, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {7, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3346};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_ctx, __pyx_mstate->__pyx_n_u_in_pyfunc, __pyx_mstate->__pyx_n_u_cmethod_flag, __pyx_mstate->__pyx_n_u_nonempty_declarators, __pyx_mstate->__pyx_n_u_kw_only, __pyx_mstate->__pyx_n_u_annotated};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_p_c_arg_list, __pyx_mstate->__pyx_kp_b_iso88591_1_Q_55E_ST_1_4wa_G1L_E_A_7q_1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4128};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_level, __pyx_mstate->__pyx_n_u_ctx};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_p_code, __pyx_mstate->__pyx_kp_b_iso88591_A_1Cs_8_C1_q_Cq_q_AQa_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4181};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_pxd, __pyx_mstate->__pyx_n_u_full_module_name, __pyx_mstate->__pyx_n_u_ctx};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_p_module, __pyx_mstate->__pyx_kp_b_iso88591_9_9A_6aq_q_q_1_AQ_IQ_aq_1Cs_6_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4747};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_f, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_level, __pyx_mstate->__pyx_n_u_key};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Parsing_py, __pyx_mstate->__pyx_n_u_print_parse_tree, __pyx_mstate->__pyx_kp_b_iso88591_8_uBa_V1A_q_q_1_t1_q_QfCq_q_1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod1 (used by append) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyLong_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyLong_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* SetStringIndexingError (used by GetItemIntUnicode) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil) {
    if (!has_gil) {
        PyGILState_STATE gil_state = PyGILState_Ensure();
        PyErr_SetString(PyExc_IndexError, message);
        PyGILState_Release(gil_state);
    } else
        PyErr_SetString(PyExc_IndexError, message);
}

/* GetItemIntUnicode */
static CYTHON_INLINE Py_UCS4 __Pyx_GetItemInt_Unicode_Fast(PyObject* ustring, Py_ssize_t i,
                                                           int wraparound, int boundscheck, int has_gil) {
    Py_ssize_t length;
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return (Py_UCS4)-1;
    if (wraparound | boundscheck) {
        length = __Pyx_PyUnicode_GET_LENGTH(ustring);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return (Py_UCS4)-1;
        #endif
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely(__Pyx_is_valid_index(i, length))) {
            return __Pyx_PyUnicode_READ_CHAR(ustring, i);
        } else {
            __Pyx_SetStringIndexingError("string index out of range", has_gil);
            return (Py_UCS4)-1;
        }
    } else {
        return __Pyx_PyUnicode_READ_CHAR(ustring, i);
    }
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    #if !CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    #endif
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(length < 0)) return NULL;
    #endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    if (start == 0 && stop == length)
        return __Pyx_NewRef(text);
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyUnicode_Substring(text, start, stop);
#else
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#endif
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* StringJoin */
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    (void) __Pyx_PyObject_CallMethod1;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030e0000 || defined(PyBytes_Join)
    return PyBytes_Join(sep, values);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyBytes_Join)
    return _PyBytes_Join(sep, values);
#else
    return __Pyx_PyObject_CallMethod1(sep, __pyx_mstate_global->__pyx_n_u_join, values);
#endif
}

/* unicode_iter */
static CYTHON_INLINE int __Pyx_init_unicode_iteration(
    PyObject* ustring, Py_ssize_t *length, void** data, int *kind) {
#if CYTHON_COMPILING_IN_LIMITED_API
    *kind   = 0;
    *length = PyUnicode_GetLength(ustring);
    *data   = (void*)ustring;
#else
    if (unlikely(__Pyx_PyUnicode_READY(ustring) < 0)) return -1;
    *kind   = PyUnicode_KIND(ustring);
    *length = PyUnicode_GET_LENGTH(ustring);
    *data   = PyUnicode_DATA(ustring);
#endif
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    int was_initialized =  __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return __Pyx_CallCFunction(cfunc, self, arg);
        } else if (flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, &arg, 1);
        } else if (flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, &arg, 1, NULL);
        }
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod1(&tmp_cfunc, self, arg);
    }
#endif
    PyObject* result = __Pyx__CallUnboundCMethod1(cfunc, self, arg);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *args = PyTuple_New(1);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
    } else
#endif
    {
        result = __Pyx_PyObject_Call2Args(cfunc->method, self, arg);
    }
    return result;
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* UnicodeAsUCS4 (used by object_ord) */
static void __Pyx_PyUnicode_AsPy_UCS4_error(Py_ssize_t length) {
    if (likely(length >= 0)) {
        PyErr_Format(PyExc_ValueError,
                     "only single character unicode strings can be converted to Py_UCS4, "
                     "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
    }
}
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
    Py_ssize_t length = __Pyx_PyUnicode_GET_LENGTH(x);
    if (unlikely(length != 1)) {
        __Pyx_PyUnicode_AsPy_UCS4_error(length);
        return (Py_UCS4)-1;
    }
    return __Pyx_PyUnicode_READ_CHAR(x, 0);
}

/* object_ord */
static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = __Pyx_PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
#if CYTHON_ASSUME_SAFE_MACROS
            return (unsigned char) PyBytes_AS_STRING(c)[0];
#else
            char *data = PyBytes_AsString(c);
            if (unlikely(!data)) return -1;
            return (unsigned char) data[0];
#endif
        }
#if !CYTHON_ASSUME_SAFE_SIZE
        else if (unlikely(size < 0)) return -1;
#endif
    } else if (PyByteArray_Check(c)) {
        size = __Pyx_PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
#if CYTHON_ASSUME_SAFE_MACROS
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
#else
            char *data = PyByteArray_AsString(c);
            if (unlikely(!data)) return -1;
            return (unsigned char) data[0];
#endif
        }
#if !CYTHON_ASSUME_SAFE_SIZE
        else if (unlikely(size < 0)) return -1;
#endif
    } else {
        __Pyx_TypeName c_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(c));
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but " __Pyx_FMT_TYPENAME " found",
            c_type_name);
        __Pyx_DECREF_TypeName(c_type_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* pybuiltin_invalid (used by pyint_simplify) */
static void __Pyx_PyBuiltin_Invalid(PyObject *obj, const char *type_name, const char *argname) {
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    if (argname) {
        PyErr_Format(PyExc_TypeError,
            "Argument '%.200s' has incorrect type (expected %.200s, got " __Pyx_FMT_TYPENAME ")",
            argname, type_name, obj_type_name
        );
    } else {
        PyErr_Format(PyExc_TypeError,
            "Expected %.200s, got " __Pyx_FMT_TYPENAME,
            type_name, obj_type_name
        );
    }
    __Pyx_DECREF_TypeName(obj_type_name);
}

/* pyint_simplify */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none) {
    PyObject *number = *number_var;
    if (likely((accept_none && number == Py_None) || PyLong_CheckExact(number))) {
        return 0;
    }
    PyObject *int_object;
    if (likely(PyNumber_Check(number))) {
        int_object = PyNumber_Long(number);
        if (unlikely(!int_object)) goto bad;
    } else {
        __Pyx_PyBuiltin_Invalid(number, "int", argname);
        goto bad;
    }
    *number_var = int_object;
    Py_DECREF(number);
    return 0;
bad:
    *number_var = NULL;
    Py_DECREF(number);
    return -1;
}

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice_locked(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(src);
    result = __Pyx_PyList_GetSlice_locked(src, start, stop);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
#endif // CYTHON_COMPILING_IN_CPYTHON

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* PyLongCompare */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = __Pyx_PyFloat_AS_DOUBLE(op1);
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter (used by MergeKeywords) */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* MergeKeywords */
static int __Pyx_MergeKeywords_dict(PyObject *kwdict, PyObject *source_dict) {
    Py_ssize_t len1, len2;
    len2 = PyDict_Size(source_dict);
    if (unlikely(len2 == -1)) return -1;
    if (len2 == 0) {
        return 0;
    }
    len1 = PyDict_Size(kwdict);
    if (unlikely(len1 == -1)) return -1;
    if (len1 > 0) {
        PyObject *key, *smaller_dict, *larger_dict;
        #if CYTHON_AVOID_BORROWED_REFS
        PyObject *ppos = NULL;
        #else
        Py_ssize_t ppos = 0;
        #endif
        int duplicates_found = 0;
        if (len1 <= len2) {
            smaller_dict = kwdict;
            larger_dict = source_dict;
        } else {
            smaller_dict = source_dict;
            larger_dict = kwdict;
        }
        __Pyx_BEGIN_CRITICAL_SECTION(smaller_dict);
        while (
            #if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
            __Pyx_PyDict_NextRef(smaller_dict, &ppos, &key, NULL)
            #else
            PyDict_Next(smaller_dict, &ppos, &key, NULL)
            #endif
        ) {
            if (unlikely(PyDict_Contains(larger_dict, key))) {
                __Pyx_RaiseDoubleKeywordsError("function", key);
                #if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
                Py_DECREF(key);
                #endif
                duplicates_found = 1;
                break;
            };
            #if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
            Py_DECREF(key);
            #endif
        }
        __Pyx_END_CRITICAL_SECTION();
        #if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(ppos);
        #endif
        if (unlikely(duplicates_found))
            return -1;
    }
    return PyDict_Update(kwdict, source_dict);
}
static int __Pyx_MergeKeywords_any(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_mstate_global->__pyx_n_u_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError))) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                result = __Pyx_MergeKeywords_dict(kwdict, fallback);
                Py_DECREF(fallback);
                return result;
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        {
            int inserted = PyDict_SetDefaultRef(kwdict, key, value, NULL);
            if (unlikely(inserted != 0)) {
                if (inserted == 1) __Pyx_RaiseDoubleKeywordsError("function", key);
                result = -1;
            }
        }
    #else
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
    #endif
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}
static CYTHON_INLINE int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    assert(PyDict_Check(kwdict));
    if (likely(PyDict_Check(source_mapping))) {
        return __Pyx_MergeKeywords_dict(kwdict, source_mapping);
    } else {
        return __Pyx_MergeKeywords_any(kwdict, source_mapping);
    }
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* DelItemInt */
static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_DelItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, CYTHON_NCP_UNUSED int wraparound) {
#if !CYTHON_USE_TYPE_SLOTS
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_DelItem(o, i);
    }
#else
    PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
    PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
    if ((!is_list) && mm && mm->mp_ass_subscript) {
        PyObject *key = PyLong_FromSsize_t(i);
        return likely(key) ? mm->mp_ass_subscript(o, key, (PyObject *)NULL) : -1;
    }
    if (likely(sm && sm->sq_ass_item)) {
        if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
            Py_ssize_t l = sm->sq_length(o);
            if (likely(l >= 0)) {
                i += l;
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    return -1;
                PyErr_Clear();
            }
        }
        return sm->sq_ass_item(o, i, (PyObject *)NULL);
    }
#endif
    return __Pyx_DelItem_Generic(o, PyLong_FromSsize_t(i));
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PySequenceMultiply */
#if CYTHON_USE_TYPE_SLOTS
static PyObject* __Pyx_PySequence_Multiply_Generic(PyObject *seq, Py_ssize_t mul) {
    PyObject *result, *pymul = PyLong_FromSsize_t(mul);
    if (unlikely(!pymul))
        return NULL;
    result = PyNumber_Multiply(seq, pymul);
    Py_DECREF(pymul);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul) {
    PyTypeObject *type = Py_TYPE(seq);
    if (likely(type->tp_as_sequence && type->tp_as_sequence->sq_repeat)) {
        return type->tp_as_sequence->sq_repeat(seq, mul);
    } else {
        return __Pyx_PySequence_Multiply_Generic(seq, mul);
    }
}
#endif

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* PxdImportShared (used by VoidPtrImport) */
#ifndef __PYX_HAVE_RT_ImportFromPxd_3_2_4
#define __PYX_HAVE_RT_ImportFromPxd_3_2_4
static int __Pyx_ImportFromPxd_3_2_4(PyObject *module, const char *name, void **p, const char *sig, const char *what) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, "__pyx_capi__");
    if (!d)
        goto bad;
#if (defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030d0000) || (!defined(Py_LIMITED_API) && PY_VERSION_HEX >= 0x030d0000)
    PyDict_GetItemStringRef(d, name, &cobj);
#else
    cobj = PyDict_GetItemString(d, name);
    Py_XINCREF(cobj);
#endif
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C %.8s %.200s",
                PyModule_GetName(module), what, name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C %.8s %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             what, PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(d);
    Py_XDECREF(cobj);
    return -1;
}
#endif

/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__27);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
#if CYTHON_COMPILING_IN_LIMITED_API
            || __Pyx_get_runtime_version() >= 0x030A0000
#endif
            )
            return result;
        {
            Py_ssize_t size = __Pyx_PySet_GET_SIZE(result);
            if (likely(size > 0))
                return result;
#if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(size < 0)) {
                Py_DECREF(result);
                return NULL;
            }
#endif
        }
        Py_DECREF(result);
#endif
    }
    return __Pyx_PyObject_CallNoArg((PyObject*) &PyFrozenSet_Type);
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CalculateMetaclass (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module_2, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc_2, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* PyUCS4InUnicode */
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character) {
    Py_ssize_t idx = PyUnicode_FindChar(unicode, character, 0, PY_SSIZE_T_MAX, 1);
    if (unlikely(idx == -2)) return -1;
    return idx >= 0;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* ObjectAsUCS4 */
static void __Pyx__PyObject_AsPy_UCS4_raise_error(long ival) {
   if (ival < 0) {
       if (!PyErr_Occurred())
           PyErr_SetString(PyExc_OverflowError,
                           "cannot convert negative value to Py_UCS4");
   } else {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to Py_UCS4");
   }
}
static Py_UCS4 __Pyx__PyObject_AsPy_UCS4(PyObject* x) {
   long ival;
   ival = __Pyx_PyLong_As_long(x);
   if (unlikely(!__Pyx_is_valid_index(ival, 1114111 + 1))) {
       __Pyx__PyObject_AsPy_UCS4_raise_error(ival);
       return (Py_UCS4)-1;
   }
   return (Py_UCS4)ival;
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module_2);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__21);
    }
    goto done;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
