/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/build/cython/src/cython/Cython/Compiler/Visitor.pxd"
        ],
        "name": "Cython.Compiler.Visitor",
        "sources": [
            "/build/cython/src/cython/Cython/Compiler/Visitor.py"
        ]
    },
    "module_name": "Cython.Compiler.Visitor"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Cython__Compiler__Visitor
#define __PYX_HAVE_API__Cython__Compiler__Visitor
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "Cython/Compiler/Visitor.py",
  "Cython/Compiler/Visitor.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor;
struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren;
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild;

/* "Cython/Compiler/Visitor.pxd":12
 *     cdef _visitchild(self, child, parent, attrname, idx)
 *     cdef dict _visitchildren(self, parent, attrs, exclude)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cdef _raise_compiler_error(self, child, e)
 * 
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Cython/Compiler/Visitor.pxd":16
 * 
 * cdef class VisitorTransform(TreeVisitor):
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
 *     cdef list _flatten_list(self, list orig_list)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Cython/Compiler/Visitor.pxd":17
 * cdef class VisitorTransform(TreeVisitor):
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)             # <<<<<<<<<<<<<<
 *     cdef list _flatten_list(self, list orig_list)
 *     cpdef visitchild(self, parent, str attr, idx=*)
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren {
  int __pyx_n;
  PyObject *attrs;
  PyObject *exclude;
};

/* "Cython/Compiler/Visitor.pxd":19
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
 *     cdef list _flatten_list(self, list orig_list)
 *     cpdef visitchild(self, parent, str attr, idx=*)             # <<<<<<<<<<<<<<
 * 
 * cdef class CythonTransform(VisitorTransform):
*/
struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild {
  int __pyx_n;
  PyObject *idx;
};

/* "Cython/Compiler/Visitor.pxd":3
 * cimport cython
 * 
 * cdef class TreeVisitor:             # <<<<<<<<<<<<<<
 *     cdef public list access_path
 *     cdef dict dispatch_table
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor {
  PyObject_HEAD
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_vtab;
  PyObject *access_path;
  PyObject *dispatch_table;
};


/* "Cython/Compiler/Visitor.pxd":15
 *     cdef _raise_compiler_error(self, child, e)
 * 
 * cdef class VisitorTransform(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef dict _process_children(self, parent, attrs=*, exclude=*)
 *     cpdef visitchildren(self, parent, attrs=*, exclude=*)
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
};


/* "Cython/Compiler/Visitor.pxd":21
 *     cpdef visitchild(self, parent, str attr, idx=*)
 * 
 * cdef class CythonTransform(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public context
 *     cdef public current_directives
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
  PyObject *context;
  PyObject *current_directives;
};


/* "Cython/Compiler/Visitor.pxd":25
 *     cdef public current_directives
 * 
 * cdef class ScopeTrackingTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public scope_type
 *     cdef public scope_node
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *scope_type;
  PyObject *scope_node;
};


/* "Cython/Compiler/Visitor.pxd":30
 *     cdef visit_scope(self, node, scope_type)
 * 
 * cdef class EnvTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     cdef public list env_stack
 * 
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *env_stack;
};


/* "Cython/Compiler/Visitor.pxd":33
 *     cdef public list env_stack
 * 
 * cdef class MethodDispatcherTransform(EnvTransform):             # <<<<<<<<<<<<<<
 *     @cython.final
 *     cdef _visit_binop_node(self, node)
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform __pyx_base;
};


/* "Cython/Compiler/Visitor.pxd":47
 *                                      node, function, arg_list, kwargs)
 * 
 * cdef class RecursiveNodeReplacer(VisitorTransform):             # <<<<<<<<<<<<<<
 *     cdef public orig_node
 *     cdef public new_node
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
  PyObject *orig_node;
  PyObject *new_node;
};


/* "Cython/Compiler/Visitor.pxd":51
 *     cdef public new_node
 * 
 * cdef class NodeFinder(TreeVisitor):             # <<<<<<<<<<<<<<
 *     cdef node
 *     cdef public bint found
*/
struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
  PyObject *node;
  int found;
};



/* "Cython/Compiler/Visitor.py":25
 * 
 * 
 * class TreeVisitor:             # <<<<<<<<<<<<<<
 *     """
 *     Base class for writing visitors for a Cython tree, contains utilities for
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor {
  PyObject *(*visit)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_visit)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
  PyObject *(*find_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
  PyObject *(*_visitchild)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_visitchildren)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *);
  PyObject *(*visitchildren)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args);
  PyObject *(*_raise_compiler_error)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_find_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *);
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *, PyObject *);
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *);


/* "Cython/Compiler/Visitor.py":226
 * 
 * 
 * class VisitorTransform(TreeVisitor):             # <<<<<<<<<<<<<<
 *     """
 *     A tree transform is a base class for visitors that wants to do stream
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
  PyObject *(*_process_children)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args);
  PyObject *(*_flatten_list)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *);
  PyObject *(*visitchild)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform;
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args);
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__flatten_list(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *);


/* "Cython/Compiler/Visitor.py":290
 * 
 * 
 * class CythonTransform(VisitorTransform):             # <<<<<<<<<<<<<<
 *     """
 *     Certain common conventions and utilities for Cython transforms.
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;


/* "Cython/Compiler/Visitor.py":319
 * 
 * 
 * class ScopeTrackingTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     # Keeps track of type of scopes
 *     #scope_type: can be either of 'module', 'function', 'cclass', 'pyclass', 'struct'
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
  PyObject *(*visit_scope)(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;


/* "Cython/Compiler/Visitor.py":351
 * 
 * 
 * class EnvTransform(CythonTransform):             # <<<<<<<<<<<<<<
 *     """
 *     This transformation keeps a stack of the environments.
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform;


/* "Cython/Compiler/Visitor.py":489
 * 
 * 
 * class MethodDispatcherTransform(EnvTransform):             # <<<<<<<<<<<<<<
 *     """
 *     Base class for transformations that want to intercept on specific
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform __pyx_base;
  PyObject *(*_visit_binop_node)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *);
  PyObject *(*_find_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, int);
  PyObject *(*_delegate_to_assigned_value)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_dispatch_to_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_dispatch_to_method_handler)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;


/* "Cython/Compiler/Visitor.py":709
 * 
 * 
 * class RecursiveNodeReplacer(VisitorTransform):             # <<<<<<<<<<<<<<
 *     """
 *     Recursively replace all occurrences of a node in a subtree by
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;


/* "Cython/Compiler/Visitor.py":737
 * 
 * 
 * class NodeFinder(TreeVisitor):             # <<<<<<<<<<<<<<
 *     """
 *     Find out if a node appears in a subtree.
*/

struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder {
  struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_base;
};
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by RejectKeywords) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyLongCompare.proto */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyRuntimeError_Check.proto */
#define __Pyx_PyExc_RuntimeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_RuntimeError)

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* CalculateMetaclass.proto (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* PyObjectCall2Args.proto (used by Py3ClassCreate) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectLookupSpecial.proto (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CyFunctionClassCell.proto */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* PyObjectVectorCallKwBuilder.proto (used by CIntToPy) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__raise_compiler_error(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_child, PyObject *__pyx_v_e); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_find_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_child, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrname, PyObject *__pyx_v_idx); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__flatten_list(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_orig_list); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attr, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_scope_type); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__visit_binop_node(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__find_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_match_name, int __pyx_v_has_kwargs); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__delegate_to_assigned_value(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs); /* proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_method_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_self_arg, PyObject *__pyx_v_is_unbound_method, PyObject *__pyx_v_type_name, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "Cython.Compiler.Visitor" */
static PyObject *__pyx_v_6Cython_8Compiler_7Visitor__PRINTABLE = 0;
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "Cython.Compiler.Visitor"
extern int __pyx_module_is_main_Cython__Compiler__Visitor;
int __pyx_module_is_main_Cython__Compiler__Visitor = 0;

/* Implementation of "Cython.Compiler.Visitor" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_enumerate;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_2dump_node(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_4_find_node_path(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_stacktrace); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_6visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_8visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_2visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attr, PyObject *__pyx_v_idx); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_4recurse_to_children(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_6__call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_root); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_2__call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_4visit_CompilerDirectivesNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_6visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_ModuleNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_2visit_CClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_4visit_PyClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_6visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_8visit_CStructOrUnionDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform___call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_root); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_2current_env(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_4current_scope_node(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_6global_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_8enter_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_scope); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_10exit_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_12visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_14visit_func_outer_attrs(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_16visit_GeneratorBodyDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_18visit_ClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_20visit_CStructOrUnionDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_22visit_ScopedExprNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_24visit_CArgDeclNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_2visit_CloneNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_4visit_ResultRefNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_6replace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_replacement); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_visit_GeneralCallNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_2visit_SimpleCallNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_4visit_PrimaryCmpNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_6visit_BinopNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_8visit_UnopNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED PyObject *__pyx_v_function_name, CYTHON_UNUSED PyObject *__pyx_v_function, CYTHON_UNUSED PyObject *__pyx_v_arg_list, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED PyObject *__pyx_v_type_name, CYTHON_UNUSED PyObject *__pyx_v_attr_name, CYTHON_UNUSED PyObject *__pyx_v_function, CYTHON_UNUSED PyObject *__pyx_v_arg_list, CYTHON_UNUSED PyObject *__pyx_v_is_unbound_method, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_orig_node, PyObject *__pyx_v_new_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_2visit_CloneNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_4visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_recursively_replace_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_old_node, PyObject *__pyx_v_new_node); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_2visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self); /* proto */
static int __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_2tree_contains(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_4replace_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_ptr, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_start, PyObject *__pyx_v_end); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_2indent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_4unindent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_6__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_phase); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_8visit_Node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_10visit_CloneNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_12_print_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_14repr_of(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_ScopeTrackingTransform(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_EnvTransform(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_MethodDispatcherTransform(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_NodeFinder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  PyObject *__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  PyTypeObject *__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop;
  PyObject *__pyx_slice[2];
  PyObject *__pyx_tuple[4];
  PyObject *__pyx_codeobj_tab[51];
  PyObject *__pyx_string_tab[430];
  PyObject *__pyx_number_tab[3];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Cannot_insert_list_here __pyx_string_tab[1]
#define __pyx_kp_u_Clean_up_references_to_nodes_th __pyx_string_tab[2]
#define __pyx_kp_u_Cython_Compiler __pyx_string_tab[3]
#define __pyx_kp_u_Cython_Compiler_ModuleNode __pyx_string_tab[4]
#define __pyx_kp_u_Cython_Compiler_Visitor_py __pyx_string_tab[5]
#define __pyx_kp_u_File __pyx_string_tab[6]
#define __pyx_kp_u_None __pyx_string_tab[7]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[8]
#define __pyx_kp_u_Parse_tree_dump_at_phase_s __pyx_string_tab[9]
#define __pyx_kp_u_Prints_a_representation_of_the_t __pyx_string_tab[10]
#define __pyx_kp_u_Visitor __pyx_string_tab[11]
#define __pyx_kp_u__10 __pyx_string_tab[12]
#define __pyx_kp_u__11 __pyx_string_tab[13]
#define __pyx_kp_u__12 __pyx_string_tab[14]
#define __pyx_kp_u__13 __pyx_string_tab[15]
#define __pyx_kp_u__14 __pyx_string_tab[16]
#define __pyx_kp_u__15 __pyx_string_tab[17]
#define __pyx_kp_u__16 __pyx_string_tab[18]
#define __pyx_kp_u__17 __pyx_string_tab[19]
#define __pyx_kp_u__18 __pyx_string_tab[20]
#define __pyx_kp_u__19 __pyx_string_tab[21]
#define __pyx_kp_u__20 __pyx_string_tab[22]
#define __pyx_kp_u__21 __pyx_string_tab[23]
#define __pyx_kp_u__22 __pyx_string_tab[24]
#define __pyx_kp_u__23 __pyx_string_tab[25]
#define __pyx_kp_u__24 __pyx_string_tab[26]
#define __pyx_kp_u__25 __pyx_string_tab[27]
#define __pyx_kp_u__26 __pyx_string_tab[28]
#define __pyx_kp_u__27 __pyx_string_tab[29]
#define __pyx_kp_u__28 __pyx_string_tab[30]
#define __pyx_kp_u__29 __pyx_string_tab[31]
#define __pyx_kp_u__3 __pyx_string_tab[32]
#define __pyx_kp_u__30 __pyx_string_tab[33]
#define __pyx_kp_u__31 __pyx_string_tab[34]
#define __pyx_kp_u__32 __pyx_string_tab[35]
#define __pyx_kp_u__33 __pyx_string_tab[36]
#define __pyx_kp_u__34 __pyx_string_tab[37]
#define __pyx_kp_u__35 __pyx_string_tab[38]
#define __pyx_kp_u__36 __pyx_string_tab[39]
#define __pyx_kp_u__37 __pyx_string_tab[40]
#define __pyx_kp_u__4 __pyx_string_tab[41]
#define __pyx_kp_u__5 __pyx_string_tab[42]
#define __pyx_kp_u__6 __pyx_string_tab[43]
#define __pyx_kp_u__7 __pyx_string_tab[44]
#define __pyx_kp_u__8 __pyx_string_tab[45]
#define __pyx_kp_u__9 __pyx_string_tab[46]
#define __pyx_kp_u_add_note __pyx_string_tab[47]
#define __pyx_kp_u_arg_2 __pyx_string_tab[48]
#define __pyx_kp_u_attribute_2 __pyx_string_tab[49]
#define __pyx_kp_u_d __pyx_string_tab[50]
#define __pyx_kp_u_d_2 __pyx_string_tab[51]
#define __pyx_kp_u_disable __pyx_string_tab[52]
#define __pyx_kp_u_does_not_accept_object __pyx_string_tab[53]
#define __pyx_kp_u_enable __pyx_string_tab[54]
#define __pyx_kp_u_gc __pyx_string_tab[55]
#define __pyx_kp_u_in __pyx_string_tab[56]
#define __pyx_kp_u_in_2 __pyx_string_tab[57]
#define __pyx_kp_u_isenabled __pyx_string_tab[58]
#define __pyx_kp_u_line __pyx_string_tab[59]
#define __pyx_kp_u_name_3 __pyx_string_tab[60]
#define __pyx_kp_u_name_4 __pyx_string_tab[61]
#define __pyx_kp_u_name_s __pyx_string_tab[62]
#define __pyx_kp_u_none __pyx_string_tab[63]
#define __pyx_kp_u_pos_2 __pyx_string_tab[64]
#define __pyx_kp_u_root_2 __pyx_string_tab[65]
#define __pyx_kp_u_type_2 __pyx_string_tab[66]
#define __pyx_kp_u_type_3 __pyx_string_tab[67]
#define __pyx_kp_u_type_s __pyx_string_tab[68]
#define __pyx_kp_u_value_2 __pyx_string_tab[69]
#define __pyx_n_u_AbortError __pyx_string_tab[70]
#define __pyx_n_u_AttributeNode __pyx_string_tab[71]
#define __pyx_n_u_Builtin __pyx_string_tab[72]
#define __pyx_n_u_CFuncDefNode __pyx_string_tab[73]
#define __pyx_n_u_CompileError __pyx_string_tab[74]
#define __pyx_n_u_CompilerCrash __pyx_string_tab[75]
#define __pyx_n_u_ConstNode __pyx_string_tab[76]
#define __pyx_n_u_CythonTransform __pyx_string_tab[77]
#define __pyx_n_u_CythonTransform_visit_CompilerDi __pyx_string_tab[78]
#define __pyx_n_u_CythonTransform_visit_Node __pyx_string_tab[79]
#define __pyx_n_u_Cython_Compiler_Visitor __pyx_string_tab[80]
#define __pyx_n_u_DebugFlags __pyx_string_tab[81]
#define __pyx_n_u_DefNode __pyx_string_tab[82]
#define __pyx_n_u_DictNode __pyx_string_tab[83]
#define __pyx_n_u_EnvTransform __pyx_string_tab[84]
#define __pyx_n_u_EnvTransform_current_env __pyx_string_tab[85]
#define __pyx_n_u_EnvTransform_current_scope_node __pyx_string_tab[86]
#define __pyx_n_u_EnvTransform_enter_scope __pyx_string_tab[87]
#define __pyx_n_u_EnvTransform_exit_scope __pyx_string_tab[88]
#define __pyx_n_u_EnvTransform_global_scope __pyx_string_tab[89]
#define __pyx_n_u_EnvTransform_visit_CArgDeclNode __pyx_string_tab[90]
#define __pyx_n_u_EnvTransform_visit_CStructOrUnio __pyx_string_tab[91]
#define __pyx_n_u_EnvTransform_visit_ClassDefNode __pyx_string_tab[92]
#define __pyx_n_u_EnvTransform_visit_FuncDefNode __pyx_string_tab[93]
#define __pyx_n_u_EnvTransform_visit_GeneratorBody __pyx_string_tab[94]
#define __pyx_n_u_EnvTransform_visit_ScopedExprNod __pyx_string_tab[95]
#define __pyx_n_u_EnvTransform_visit_func_outer_at __pyx_string_tab[96]
#define __pyx_n_u_Errors __pyx_string_tab[97]
#define __pyx_n_u_ExprNode __pyx_string_tab[98]
#define __pyx_n_u_ExprNodes __pyx_string_tab[99]
#define __pyx_n_u_Future __pyx_string_tab[100]
#define __pyx_n_u_MethodDispatcherTransform __pyx_string_tab[101]
#define __pyx_n_u_MethodDispatcherTransform__handl __pyx_string_tab[102]
#define __pyx_n_u_MethodDispatcherTransform__handl_2 __pyx_string_tab[103]
#define __pyx_n_u_MethodDispatcherTransform_visit __pyx_string_tab[104]
#define __pyx_n_u_MethodDispatcherTransform_visit_2 __pyx_string_tab[105]
#define __pyx_n_u_MethodDispatcherTransform_visit_3 __pyx_string_tab[106]
#define __pyx_n_u_MethodDispatcherTransform_visit_4 __pyx_string_tab[107]
#define __pyx_n_u_MethodDispatcherTransform_visit_5 __pyx_string_tab[108]
#define __pyx_n_u_ModuleNode __pyx_string_tab[109]
#define __pyx_n_u_NameNode __pyx_string_tab[110]
#define __pyx_n_u_Node __pyx_string_tab[111]
#define __pyx_n_u_NodeFinder __pyx_string_tab[112]
#define __pyx_n_u_NodeFinder_visit_Node __pyx_string_tab[113]
#define __pyx_n_u_NodeRefCleanupMixin __pyx_string_tab[114]
#define __pyx_n_u_NodeRefCleanupMixin___init __pyx_string_tab[115]
#define __pyx_n_u_NodeRefCleanupMixin_replace __pyx_string_tab[116]
#define __pyx_n_u_NodeRefCleanupMixin_visit_CloneN __pyx_string_tab[117]
#define __pyx_n_u_NodeRefCleanupMixin_visit_Result __pyx_string_tab[118]
#define __pyx_n_u_Nodes __pyx_string_tab[119]
#define __pyx_n_u_PrintTree __pyx_string_tab[120]
#define __pyx_n_u_PrintTree___call __pyx_string_tab[121]
#define __pyx_n_u_PrintTree___init __pyx_string_tab[122]
#define __pyx_n_u_PrintTree__print_node __pyx_string_tab[123]
#define __pyx_n_u_PrintTree_indent __pyx_string_tab[124]
#define __pyx_n_u_PrintTree_repr_of __pyx_string_tab[125]
#define __pyx_n_u_PrintTree_unindent __pyx_string_tab[126]
#define __pyx_n_u_PrintTree_visit_CloneNode __pyx_string_tab[127]
#define __pyx_n_u_PrintTree_visit_Node __pyx_string_tab[128]
#define __pyx_n_u_PyConstNode __pyx_string_tab[129]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[130]
#define __pyx_n_u_RecursiveNodeReplacer __pyx_string_tab[131]
#define __pyx_n_u_RecursiveNodeReplacer_visit_Clon __pyx_string_tab[132]
#define __pyx_n_u_RecursiveNodeReplacer_visit_Node __pyx_string_tab[133]
#define __pyx_n_u_ScopeTrackingTransform __pyx_string_tab[134]
#define __pyx_n_u_ScopeTrackingTransform_visit_CCl __pyx_string_tab[135]
#define __pyx_n_u_ScopeTrackingTransform_visit_CSt __pyx_string_tab[136]
#define __pyx_n_u_ScopeTrackingTransform_visit_Fun __pyx_string_tab[137]
#define __pyx_n_u_ScopeTrackingTransform_visit_Mod __pyx_string_tab[138]
#define __pyx_n_u_ScopeTrackingTransform_visit_PyC __pyx_string_tab[139]
#define __pyx_n_u_TreeVisitor __pyx_string_tab[140]
#define __pyx_n_u_TreeVisitor__find_node_path __pyx_string_tab[141]
#define __pyx_n_u_TreeVisitor_dump_node __pyx_string_tab[142]
#define __pyx_n_u_TreeVisitor_visit __pyx_string_tab[143]
#define __pyx_n_u_TreeVisitor_visitchildren __pyx_string_tab[144]
#define __pyx_n_u_TupleNode __pyx_string_tab[145]
#define __pyx_n_u_TypeSlots __pyx_string_tab[146]
#define __pyx_n_u_VisitorTransform __pyx_string_tab[147]
#define __pyx_n_u_VisitorTransform_recurse_to_chil __pyx_string_tab[148]
#define __pyx_n_u_VisitorTransform_visitchild __pyx_string_tab[149]
#define __pyx_n_u_VisitorTransform_visitchildren __pyx_string_tab[150]
#define __pyx_n_u__2 __pyx_string_tab[151]
#define __pyx_n_u__7 __pyx_string_tab[152]
#define __pyx_n_u_access_path __pyx_string_tab[153]
#define __pyx_n_u_add __pyx_string_tab[154]
#define __pyx_n_u_and __pyx_string_tab[155]
#define __pyx_n_u_arg __pyx_string_tab[156]
#define __pyx_n_u_arg_list __pyx_string_tab[157]
#define __pyx_n_u_arg_tuple __pyx_string_tab[158]
#define __pyx_n_u_args __pyx_string_tab[159]
#define __pyx_n_u_as_variable __pyx_string_tab[160]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[161]
#define __pyx_n_u_attr __pyx_string_tab[162]
#define __pyx_n_u_attr_name __pyx_string_tab[163]
#define __pyx_n_u_attribute __pyx_string_tab[164]
#define __pyx_n_u_attribute_names __pyx_string_tab[165]
#define __pyx_n_u_attrname __pyx_string_tab[166]
#define __pyx_n_u_attrs __pyx_string_tab[167]
#define __pyx_n_u_basename __pyx_string_tab[168]
#define __pyx_n_u_builtin_scope __pyx_string_tab[169]
#define __pyx_n_u_call __pyx_string_tab[170]
#define __pyx_n_u_cascade __pyx_string_tab[171]
#define __pyx_n_u_cclass __pyx_string_tab[172]
#define __pyx_n_u_cf_assignments __pyx_string_tab[173]
#define __pyx_n_u_cf_state __pyx_string_tab[174]
#define __pyx_n_u_child_attrs __pyx_string_tab[175]
#define __pyx_n_u_class __pyx_string_tab[176]
#define __pyx_n_u_class_getitem __pyx_string_tab[177]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[178]
#define __pyx_n_u_co_filename __pyx_string_tab[179]
#define __pyx_n_u_co_name __pyx_string_tab[180]
#define __pyx_n_u_code __pyx_string_tab[181]
#define __pyx_n_u_contains __pyx_string_tab[182]
#define __pyx_n_u_context __pyx_string_tab[183]
#define __pyx_n_u_cpp_message __pyx_string_tab[184]
#define __pyx_n_u_current_env __pyx_string_tab[185]
#define __pyx_n_u_current_scope_node __pyx_string_tab[186]
#define __pyx_n_u_d_3 __pyx_string_tab[187]
#define __pyx_n_u_debug_no_exception_intercept __pyx_string_tab[188]
#define __pyx_n_u_declared_name __pyx_string_tab[189]
#define __pyx_n_u_default __pyx_string_tab[190]
#define __pyx_n_u_dict __pyx_string_tab[191]
#define __pyx_n_u_directives __pyx_string_tab[192]
#define __pyx_n_u_div __pyx_string_tab[193]
#define __pyx_n_u_division __pyx_string_tab[194]
#define __pyx_n_u_doc __pyx_string_tab[195]
#define __pyx_n_u_doctest __pyx_string_tab[196]
#define __pyx_n_u_dump_node __pyx_string_tab[197]
#define __pyx_n_u_end __pyx_string_tab[198]
#define __pyx_n_u_endswith __pyx_string_tab[199]
#define __pyx_n_u_enter_scope __pyx_string_tab[200]
#define __pyx_n_u_entry __pyx_string_tab[201]
#define __pyx_n_u_enumerate __pyx_string_tab[202]
#define __pyx_n_u_eq __pyx_string_tab[203]
#define __pyx_n_u_exc_info __pyx_string_tab[204]
#define __pyx_n_u_exclude __pyx_string_tab[205]
#define __pyx_n_u_exit_scope __pyx_string_tab[206]
#define __pyx_n_u_expr __pyx_string_tab[207]
#define __pyx_n_u_expr_scope __pyx_string_tab[208]
#define __pyx_n_u_expression __pyx_string_tab[209]
#define __pyx_n_u_f_code __pyx_string_tab[210]
#define __pyx_n_u_f_lineno __pyx_string_tab[211]
#define __pyx_n_u_f_locals __pyx_string_tab[212]
#define __pyx_n_u_find_node_path __pyx_string_tab[213]
#define __pyx_n_u_find_special_method_for_binary_o __pyx_string_tab[214]
#define __pyx_n_u_find_special_method_for_unary_op __pyx_string_tab[215]
#define __pyx_n_u_finder __pyx_string_tab[216]
#define __pyx_n_u_floordiv __pyx_string_tab[217]
#define __pyx_n_u_frame __pyx_string_tab[218]
#define __pyx_n_u_func __pyx_string_tab[219]
#define __pyx_n_u_function __pyx_string_tab[220]
#define __pyx_n_u_function_2 __pyx_string_tab[221]
#define __pyx_n_u_function_name __pyx_string_tab[222]
#define __pyx_n_u_future_directives __pyx_string_tab[223]
#define __pyx_n_u_ge __pyx_string_tab[224]
#define __pyx_n_u_general __pyx_string_tab[225]
#define __pyx_n_u_get __pyx_string_tab[226]
#define __pyx_n_u_get_description __pyx_string_tab[227]
#define __pyx_n_u_getmro __pyx_string_tab[228]
#define __pyx_n_u_gil_message __pyx_string_tab[229]
#define __pyx_n_u_global_scope __pyx_string_tab[230]
#define __pyx_n_u_gt __pyx_string_tab[231]
#define __pyx_n_u_handle __pyx_string_tab[232]
#define __pyx_n_u_handle_any __pyx_string_tab[233]
#define __pyx_n_u_handle_function __pyx_string_tab[234]
#define __pyx_n_u_handle_method __pyx_string_tab[235]
#define __pyx_n_u_idx __pyx_string_tab[236]
#define __pyx_n_u_ignored __pyx_string_tab[237]
#define __pyx_n_u_in_3 __pyx_string_tab[238]
#define __pyx_n_u_indent __pyx_string_tab[239]
#define __pyx_n_u_indent_2 __pyx_string_tab[240]
#define __pyx_n_u_init __pyx_string_tab[241]
#define __pyx_n_u_inspect __pyx_string_tab[242]
#define __pyx_n_u_inv __pyx_string_tab[243]
#define __pyx_n_u_is_attribute __pyx_string_tab[244]
#define __pyx_n_u_is_builtin __pyx_string_tab[245]
#define __pyx_n_u_is_builtin_type __pyx_string_tab[246]
#define __pyx_n_u_is_cmethod __pyx_string_tab[247]
#define __pyx_n_u_is_coroutine __pyx_string_tab[248]
#define __pyx_n_u_is_exception_type __pyx_string_tab[249]
#define __pyx_n_u_is_name __pyx_string_tab[250]
#define __pyx_n_u_is_pyobject __pyx_string_tab[251]
#define __pyx_n_u_is_single __pyx_string_tab[252]
#define __pyx_n_u_is_unbound_method __pyx_string_tab[253]
#define __pyx_n_u_isascii __pyx_string_tab[254]
#define __pyx_n_u_items __pyx_string_tab[255]
#define __pyx_n_u_keyword_args __pyx_string_tab[256]
#define __pyx_n_u_kwargs __pyx_string_tab[257]
#define __pyx_n_u_last_traceback __pyx_string_tab[258]
#define __pyx_n_u_le __pyx_string_tab[259]
#define __pyx_n_u_line_2 __pyx_string_tab[260]
#define __pyx_n_u_line_range __pyx_string_tab[261]
#define __pyx_n_u_listidx __pyx_string_tab[262]
#define __pyx_n_u_local_scope __pyx_string_tab[263]
#define __pyx_n_u_lookup_here __pyx_string_tab[264]
#define __pyx_n_u_lshift __pyx_string_tab[265]
#define __pyx_n_u_lt __pyx_string_tab[266]
#define __pyx_n_u_main __pyx_string_tab[267]
#define __pyx_n_u_metaclass __pyx_string_tab[268]
#define __pyx_n_u_method __pyx_string_tab[269]
#define __pyx_n_u_method_name __pyx_string_tab[270]
#define __pyx_n_u_mod __pyx_string_tab[271]
#define __pyx_n_u_module __pyx_string_tab[272]
#define __pyx_n_u_module_2 __pyx_string_tab[273]
#define __pyx_n_u_mro_entries __pyx_string_tab[274]
#define __pyx_n_u_mul __pyx_string_tab[275]
#define __pyx_n_u_name __pyx_string_tab[276]
#define __pyx_n_u_name_2 __pyx_string_tab[277]
#define __pyx_n_u_ne __pyx_string_tab[278]
#define __pyx_n_u_neg __pyx_string_tab[279]
#define __pyx_n_u_new __pyx_string_tab[280]
#define __pyx_n_u_new_node __pyx_string_tab[281]
#define __pyx_n_u_node __pyx_string_tab[282]
#define __pyx_n_u_nodes __pyx_string_tab[283]
#define __pyx_n_u_not __pyx_string_tab[284]
#define __pyx_n_u_not_2 __pyx_string_tab[285]
#define __pyx_n_u_obj __pyx_string_tab[286]
#define __pyx_n_u_obj_type __pyx_string_tab[287]
#define __pyx_n_u_object __pyx_string_tab[288]
#define __pyx_n_u_old __pyx_string_tab[289]
#define __pyx_n_u_old_node __pyx_string_tab[290]
#define __pyx_n_u_operand __pyx_string_tab[291]
#define __pyx_n_u_operand1 __pyx_string_tab[292]
#define __pyx_n_u_operand2 __pyx_string_tab[293]
#define __pyx_n_u_operator __pyx_string_tab[294]
#define __pyx_n_u_or __pyx_string_tab[295]
#define __pyx_n_u_orig_node __pyx_string_tab[296]
#define __pyx_n_u_os __pyx_string_tab[297]
#define __pyx_n_u_os_path __pyx_string_tab[298]
#define __pyx_n_u_outer_attrs __pyx_string_tab[299]
#define __pyx_n_u_outer_scope __pyx_string_tab[300]
#define __pyx_n_u_parent __pyx_string_tab[301]
#define __pyx_n_u_parent_type __pyx_string_tab[302]
#define __pyx_n_u_path __pyx_string_tab[303]
#define __pyx_n_u_phase __pyx_string_tab[304]
#define __pyx_n_u_pop __pyx_string_tab[305]
#define __pyx_n_u_pos __pyx_string_tab[306]
#define __pyx_n_u_pos_3 __pyx_string_tab[307]
#define __pyx_n_u_positional_args __pyx_string_tab[308]
#define __pyx_n_u_pow __pyx_string_tab[309]
#define __pyx_n_u_prepare __pyx_string_tab[310]
#define __pyx_n_u_print __pyx_string_tab[311]
#define __pyx_n_u_print_node __pyx_string_tab[312]
#define __pyx_n_u_ptr __pyx_string_tab[313]
#define __pyx_n_u_pyclass __pyx_string_tab[314]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[315]
#define __pyx_n_u_qualname __pyx_string_tab[316]
#define __pyx_n_u_recurse_to_children __pyx_string_tab[317]
#define __pyx_n_u_recursively_replace_node __pyx_string_tab[318]
#define __pyx_n_u_replace __pyx_string_tab[319]
#define __pyx_n_u_replace_in __pyx_string_tab[320]
#define __pyx_n_u_replace_node __pyx_string_tab[321]
#define __pyx_n_u_replacement __pyx_string_tab[322]
#define __pyx_n_u_replacements __pyx_string_tab[323]
#define __pyx_n_u_repr_of __pyx_string_tab[324]
#define __pyx_n_u_result __pyx_string_tab[325]
#define __pyx_n_u_rhs __pyx_string_tab[326]
#define __pyx_n_u_root __pyx_string_tab[327]
#define __pyx_n_u_rshift __pyx_string_tab[328]
#define __pyx_n_u_scope __pyx_string_tab[329]
#define __pyx_n_u_self __pyx_string_tab[330]
#define __pyx_n_u_set_name __pyx_string_tab[331]
#define __pyx_n_u_setdefault __pyx_string_tab[332]
#define __pyx_n_u_simple __pyx_string_tab[333]
#define __pyx_n_u_slot __pyx_string_tab[334]
#define __pyx_n_u_source __pyx_string_tab[335]
#define __pyx_n_u_special_method_name __pyx_string_tab[336]
#define __pyx_n_u_special_method_names __pyx_string_tab[337]
#define __pyx_n_u_split __pyx_string_tab[338]
#define __pyx_n_u_stacktrace __pyx_string_tab[339]
#define __pyx_n_u_start __pyx_string_tab[340]
#define __pyx_n_u_startswith __pyx_string_tab[341]
#define __pyx_n_u_str __pyx_string_tab[342]
#define __pyx_n_u_struct __pyx_string_tab[343]
#define __pyx_n_u_sub __pyx_string_tab[344]
#define __pyx_n_u_subexprs __pyx_string_tab[345]
#define __pyx_n_u_super __pyx_string_tab[346]
#define __pyx_n_u_sys __pyx_string_tab[347]
#define __pyx_n_u_t __pyx_string_tab[348]
#define __pyx_n_u_tb_frame __pyx_string_tab[349]
#define __pyx_n_u_tb_next __pyx_string_tab[350]
#define __pyx_n_u_testmod __pyx_string_tab[351]
#define __pyx_n_u_tree __pyx_string_tab[352]
#define __pyx_n_u_tree_contains __pyx_string_tab[353]
#define __pyx_n_u_truediv __pyx_string_tab[354]
#define __pyx_n_u_type __pyx_string_tab[355]
#define __pyx_n_u_type_name __pyx_string_tab[356]
#define __pyx_n_u_type_type __pyx_string_tab[357]
#define __pyx_n_u_unicode __pyx_string_tab[358]
#define __pyx_n_u_unindent __pyx_string_tab[359]
#define __pyx_n_u_value __pyx_string_tab[360]
#define __pyx_n_u_values __pyx_string_tab[361]
#define __pyx_n_u_visit __pyx_string_tab[362]
#define __pyx_n_u_visit_2 __pyx_string_tab[363]
#define __pyx_n_u_visit_BinopNode __pyx_string_tab[364]
#define __pyx_n_u_visit_CArgDeclNode __pyx_string_tab[365]
#define __pyx_n_u_visit_CClassDefNode __pyx_string_tab[366]
#define __pyx_n_u_visit_CStructOrUnionDefNode __pyx_string_tab[367]
#define __pyx_n_u_visit_ClassDefNode __pyx_string_tab[368]
#define __pyx_n_u_visit_CloneNode __pyx_string_tab[369]
#define __pyx_n_u_visit_CompilerDirectivesNode __pyx_string_tab[370]
#define __pyx_n_u_visit_FuncDefNode __pyx_string_tab[371]
#define __pyx_n_u_visit_GeneralCallNode __pyx_string_tab[372]
#define __pyx_n_u_visit_GeneratorBodyDefNode __pyx_string_tab[373]
#define __pyx_n_u_visit_ModuleNode __pyx_string_tab[374]
#define __pyx_n_u_visit_Node __pyx_string_tab[375]
#define __pyx_n_u_visit_PrimaryCmpNode __pyx_string_tab[376]
#define __pyx_n_u_visit_PyClassDefNode __pyx_string_tab[377]
#define __pyx_n_u_visit_ResultRefNode __pyx_string_tab[378]
#define __pyx_n_u_visit_ScopedExprNode __pyx_string_tab[379]
#define __pyx_n_u_visit_SimpleCallNode __pyx_string_tab[380]
#define __pyx_n_u_visit_UnopNode __pyx_string_tab[381]
#define __pyx_n_u_visit_func_outer_attrs __pyx_string_tab[382]
#define __pyx_n_u_visitchild __pyx_string_tab[383]
#define __pyx_n_u_visitchildren __pyx_string_tab[384]
#define __pyx_n_u_xor __pyx_string_tab[385]
#define __pyx_kp_b_iso88591_1_9AQ_Kq_6_S_G1_c_D_A_q __pyx_string_tab[386]
#define __pyx_kp_b_iso88591_1_q_6_4_1G86_uG1_q_a_A_q __pyx_string_tab[387]
#define __pyx_kp_b_iso88591_A_1A_L_t1_N_T_Kq_q __pyx_string_tab[388]
#define __pyx_kp_b_iso88591_A_4q_1_1_t_Qa __pyx_string_tab[389]
#define __pyx_kp_b_iso88591_A_4q_AU_hd_s_s_6_AV4_2Q_awa_1_1 __pyx_string_tab[390]
#define __pyx_kp_b_iso88591_A_4q_AV4q_1_1_1_q __pyx_string_tab[391]
#define __pyx_kp_b_iso88591_A_4q_T_q_fA __pyx_string_tab[392]
#define __pyx_kp_b_iso88591_A_5_1_1_T_1_z_6d_4xt1_1F_q_D_1F __pyx_string_tab[393]
#define __pyx_kp_b_iso88591_A_5_4q_4q_4uCt1_t1_q __pyx_string_tab[394]
#define __pyx_kp_b_iso88591_A_Jd __pyx_string_tab[395]
#define __pyx_kp_b_iso88591_A_JgRvQ __pyx_string_tab[396]
#define __pyx_kp_b_iso88591_A_Kt83a __pyx_string_tab[397]
#define __pyx_kp_b_iso88591_A_L __pyx_string_tab[398]
#define __pyx_kp_b_iso88591_A_L_G1_N_1_IQ_q __pyx_string_tab[399]
#define __pyx_kp_b_iso88591_A_L_G1_t4q_4_CuCt_q_3hd_VWWX_7t8 __pyx_string_tab[400]
#define __pyx_kp_b_iso88591_A_L_t1_aq_Kq_q __pyx_string_tab[401]
#define __pyx_kp_b_iso88591_A_N_81_q __pyx_string_tab[402]
#define __pyx_kp_b_iso88591_A_N_N_aq_q __pyx_string_tab[403]
#define __pyx_kp_b_iso88591_A_N_t1 __pyx_string_tab[404]
#define __pyx_kp_b_iso88591_A_Ry_Q __pyx_string_tab[405]
#define __pyx_kp_b_iso88591_A_aq_4q_4xuA_1_D_4z_Ya_1_t1_D_1 __pyx_string_tab[406]
#define __pyx_kp_b_iso88591_A_aq_4q_85_A_t_Qk_q_9A_4q_t_z_q __pyx_string_tab[407]
#define __pyx_kp_b_iso88591_A_aq_5_4q_4q_1 __pyx_string_tab[408]
#define __pyx_kp_b_iso88591_A_aq_DAT_1_d_wa_x_D_HA_A_4_31_V7 __pyx_string_tab[409]
#define __pyx_kp_b_iso88591_A_aq_q __pyx_string_tab[410]
#define __pyx_kp_b_iso88591_A_at_4r_7_gQfG1_1_S_q_5_0_1D_1A __pyx_string_tab[411]
#define __pyx_kp_b_iso88591_A_d_4wd_aq_G4_T_q_q __pyx_string_tab[412]
#define __pyx_kp_b_iso88591_A_d_a_aq_q __pyx_string_tab[413]
#define __pyx_kp_b_iso88591_A_gQl_Ja_5_Qa_z_Q_uA_d_r_iq_A_A __pyx_string_tab[414]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[415]
#define __pyx_kp_b_iso88591_A_q_2 __pyx_string_tab[416]
#define __pyx_kp_b_iso88591_A_t1_5_5_5_t1_aq_4q_5_q_d_AV1_q __pyx_string_tab[417]
#define __pyx_kp_b_iso88591_A_t4q_4_CuCt_q_3hd_VWWX_s_4_S_q __pyx_string_tab[418]
#define __pyx_kp_b_iso88591_A_t7_1 __pyx_string_tab[419]
#define __pyx_kp_b_iso88591_A_t_Qa __pyx_string_tab[420]
#define __pyx_kp_b_iso88591_A_t_Rr __pyx_string_tab[421]
#define __pyx_kp_b_iso88591_A_t_q_a __pyx_string_tab[422]
#define __pyx_kp_b_iso88591_A_t_r_a __pyx_string_tab[423]
#define __pyx_kp_b_iso88591_Jj_xs_q_q_Q __pyx_string_tab[424]
#define __pyx_kp_b_iso88591_Q_Q_b_F_1_q __pyx_string_tab[425]
#define __pyx_kp_b_iso88591_Zq_6 __pyx_string_tab[426]
#define __pyx_kp_b_iso88591_az_aq __pyx_string_tab[427]
#define __pyx_kp_b_iso88591_t_87 __pyx_string_tab[428]
#define __pyx_kp_b_iso88591_t_QhgQ __pyx_string_tab[429]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
#define __pyx_int_neg_2 __pyx_number_tab[2]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder);
  Py_CLEAR(clear_module_state->__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder);
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_slice[i]); }
  for (int i=0; i<4; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<51; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<430; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder);
  Py_VISIT(traverse_module_state->__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder);
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_slice[i]); }
  for (int i=0; i<4; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<51; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<430; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "Cython/Compiler/Visitor.py":68
 *     out 0
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.dispatch_table = {}
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor___init__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":69
 *     """
 *     def __init__(self):
 *         super().__init__()             # <<<<<<<<<<<<<<
 *         self.dispatch_table = {}
 *         self.access_path = []
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":70
 *     def __init__(self):
 *         super().__init__()
 *         self.dispatch_table = {}             # <<<<<<<<<<<<<<
 *         self.access_path = []
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->dispatch_table);
  __Pyx_DECREF(__pyx_v_self->dispatch_table);
  __pyx_v_self->dispatch_table = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":71
 *         super().__init__()
 *         self.dispatch_table = {}
 *         self.access_path = []             # <<<<<<<<<<<<<<
 * 
 *     def dump_node(self, node):
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->access_path);
  __Pyx_DECREF(__pyx_v_self->access_path);
  __pyx_v_self->access_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":68
 *     out 0
 *     """
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.dispatch_table = {}
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":73
 *         self.access_path = []
 * 
 *     def dump_node(self, node):             # <<<<<<<<<<<<<<
 *         ignored = list(node.child_attrs or []) + [
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node = {"dump_node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_2dump_node(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_2dump_node(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_ignored = NULL;
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_source = NULL;
  PyObject *__pyx_v_os = NULL;
  PyObject *__pyx_v_attribute_names = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  PyObject *__pyx_t_9[5];
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  PyObject *__pyx_t_18[3];
  PyObject *__pyx_t_19[4];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_node", 0);

  /* "Cython/Compiler/Visitor.py":74
 * 
 *     def dump_node(self, node):
 *         ignored = list(node.child_attrs or []) + [             # <<<<<<<<<<<<<<
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
 *         values = []
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_child_attrs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 74, __pyx_L1_error)
  if (!__pyx_t_3) {
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_1 = __pyx_t_2;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_child_attrs);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_child_attrs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_mstate_global->__pyx_n_u_child_attrs) != (0)) __PYX_ERR(0, 74, __pyx_L1_error);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_pos);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_pos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_n_u_pos) != (0)) __PYX_ERR(0, 74, __pyx_L1_error);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_gil_message);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_gil_message);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_mstate_global->__pyx_n_u_gil_message) != (0)) __PYX_ERR(0, 74, __pyx_L1_error);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_cpp_message);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_cpp_message);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_mstate_global->__pyx_n_u_cpp_message) != (0)) __PYX_ERR(0, 74, __pyx_L1_error);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_subexprs);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_subexprs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 4, __pyx_mstate_global->__pyx_n_u_subexprs) != (0)) __PYX_ERR(0, 74, __pyx_L1_error);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_ignored = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":76
 *         ignored = list(node.child_attrs or []) + [
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
 *         values = []             # <<<<<<<<<<<<<<
 *         pos = getattr(node, 'pos', None)
 *         if pos:
*/
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_values = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":77
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
 *         values = []
 *         pos = getattr(node, 'pos', None)             # <<<<<<<<<<<<<<
 *         if pos:
 *             source = pos[0]
*/
  __pyx_t_4 = __Pyx_GetAttr3(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_pos = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":78
 *         values = []
 *         pos = getattr(node, 'pos', None)
 *         if pos:             # <<<<<<<<<<<<<<
 *             source = pos[0]
 *             if source:
*/
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_pos); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 78, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":79
 *         pos = getattr(node, 'pos', None)
 *         if pos:
 *             source = pos[0]             # <<<<<<<<<<<<<<
 *             if source:
 *                 import os.path
*/
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_source = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Visitor.py":80
 *         if pos:
 *             source = pos[0]
 *             if source:             # <<<<<<<<<<<<<<
 *                 import os.path
 *                 source = os.path.basename(source.get_description())
*/
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_source); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 80, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":81
 *             source = pos[0]
 *             if source:
 *                 import os.path             # <<<<<<<<<<<<<<
 *                 source = os.path.basename(source.get_description())
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))
*/
      __pyx_t_5 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os_path, 0, 0, NULL, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 81, __pyx_L1_error)
      __pyx_t_4 = __pyx_t_5;
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_os = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":82
 *             if source:
 *                 import os.path
 *                 source = os.path.basename(source.get_description())             # <<<<<<<<<<<<<<
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))
 *         attribute_names = dir(node)
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = __pyx_v_source;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_8 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_description, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __pyx_t_8 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_basename, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 82, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF_SET(__pyx_v_source, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":80
 *         if pos:
 *             source = pos[0]
 *             if source:             # <<<<<<<<<<<<<<
 *                 import os.path
 *                 source = os.path.basename(source.get_description())
*/
    }

    /* "Cython/Compiler/Visitor.py":83
 *                 import os.path
 *                 source = os.path.basename(source.get_description())
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))             # <<<<<<<<<<<<<<
 *         attribute_names = dir(node)
 *         for attr in attribute_names:
*/
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_source), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9[0] = __pyx_t_4;
    __pyx_t_9[1] = __pyx_mstate_global->__pyx_kp_u_;
    __pyx_t_9[2] = __pyx_t_6;
    __pyx_t_9[3] = __pyx_mstate_global->__pyx_kp_u_;
    __pyx_t_9[4] = __pyx_t_1;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1));
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_values, __pyx_t_2); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":78
 *         values = []
 *         pos = getattr(node, 'pos', None)
 *         if pos:             # <<<<<<<<<<<<<<
 *             source = pos[0]
 *             if source:
*/
  }

  /* "Cython/Compiler/Visitor.py":84
 *                 source = os.path.basename(source.get_description())
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))
 *         attribute_names = dir(node)             # <<<<<<<<<<<<<<
 *         for attr in attribute_names:
 *             if attr in ignored:
*/
  __pyx_t_2 = PyObject_Dir(__pyx_v_node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_attribute_names = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":85
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))
 *         attribute_names = dir(node)
 *         for attr in attribute_names:             # <<<<<<<<<<<<<<
 *             if attr in ignored:
 *                 continue
*/
  if (likely(PyList_CheckExact(__pyx_v_attribute_names)) || PyTuple_CheckExact(__pyx_v_attribute_names)) {
    __pyx_t_2 = __pyx_v_attribute_names; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_11 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_11 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_attribute_names); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 85, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 85, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_11, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_11;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 85, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_11));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_11);
        #endif
        ++__pyx_t_11;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_12(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 85, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":86
 *         attribute_names = dir(node)
 *         for attr in attribute_names:
 *             if attr in ignored:             # <<<<<<<<<<<<<<
 *                 continue
 *             if attr.startswith('_') or attr.endswith('_'):
*/
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr, __pyx_v_ignored, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 86, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":87
 *         for attr in attribute_names:
 *             if attr in ignored:
 *                 continue             # <<<<<<<<<<<<<<
 *             if attr.startswith('_') or attr.endswith('_'):
 *                 continue
*/
      goto __pyx_L7_continue;

      /* "Cython/Compiler/Visitor.py":86
 *         attribute_names = dir(node)
 *         for attr in attribute_names:
 *             if attr in ignored:             # <<<<<<<<<<<<<<
 *                 continue
 *             if attr.startswith('_') or attr.endswith('_'):
*/
    }

    /* "Cython/Compiler/Visitor.py":88
 *             if attr in ignored:
 *                 continue
 *             if attr.startswith('_') or attr.endswith('_'):             # <<<<<<<<<<<<<<
 *                 continue
 *             try:
*/
    __pyx_t_6 = __pyx_v_attr;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_n_u__2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_13) {
    } else {
      __pyx_t_3 = __pyx_t_13;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_6 = __pyx_v_attr;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_8 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_n_u__2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_endswith, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_13;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":89
 *                 continue
 *             if attr.startswith('_') or attr.endswith('_'):
 *                 continue             # <<<<<<<<<<<<<<
 *             try:
 *                 value = getattr(node, attr)
*/
      goto __pyx_L7_continue;

      /* "Cython/Compiler/Visitor.py":88
 *             if attr in ignored:
 *                 continue
 *             if attr.startswith('_') or attr.endswith('_'):             # <<<<<<<<<<<<<<
 *                 continue
 *             try:
*/
    }

    /* "Cython/Compiler/Visitor.py":90
 *             if attr.startswith('_') or attr.endswith('_'):
 *                 continue
 *             try:             # <<<<<<<<<<<<<<
 *                 value = getattr(node, attr)
 *             except AttributeError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_14, &__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      /*try:*/ {

        /* "Cython/Compiler/Visitor.py":91
 *                 continue
 *             try:
 *                 value = getattr(node, attr)             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 continue
*/
        __pyx_t_1 = __Pyx_GetAttr(__pyx_v_node, __pyx_v_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "Cython/Compiler/Visitor.py":90
 *             if attr.startswith('_') or attr.endswith('_'):
 *                 continue
 *             try:             # <<<<<<<<<<<<<<
 *                 value = getattr(node, attr)
 *             except AttributeError:
*/
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      goto __pyx_L20_try_end;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Visitor.py":92
 *             try:
 *                 value = getattr(node, attr)
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 continue
 *             if value is None or value == 0:
*/
      __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
      if (__pyx_t_16) {
        __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.dump_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 92, __pyx_L15_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_4);

        /* "Cython/Compiler/Visitor.py":93
 *                 value = getattr(node, attr)
 *             except AttributeError:
 *                 continue             # <<<<<<<<<<<<<<
 *             if value is None or value == 0:
 *                 continue
*/
        goto __pyx_L21_except_continue;
        __pyx_L21_except_continue:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L19_try_continue;
      }
      goto __pyx_L15_except_error;

      /* "Cython/Compiler/Visitor.py":90
 *             if attr.startswith('_') or attr.endswith('_'):
 *                 continue
 *             try:             # <<<<<<<<<<<<<<
 *                 value = getattr(node, attr)
 *             except AttributeError:
*/
      __pyx_L15_except_error:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_14, __pyx_t_15);
      goto __pyx_L1_error;
      __pyx_L19_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_14, __pyx_t_15);
      goto __pyx_L7_continue;
      __pyx_L20_try_end:;
    }

    /* "Cython/Compiler/Visitor.py":94
 *             except AttributeError:
 *                 continue
 *             if value is None or value == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             elif isinstance(value, list):
*/
    __pyx_t_13 = (__pyx_v_value == Py_None);
    if (!__pyx_t_13) {
    } else {
      __pyx_t_3 = __pyx_t_13;
      goto __pyx_L24_bool_binop_done;
    }
    __pyx_t_13 = (__Pyx_PyLong_BoolEqObjC(__pyx_v_value, __pyx_mstate_global->__pyx_int_0, 0, 0)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 94, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_13;
    __pyx_L24_bool_binop_done:;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":95
 *                 continue
 *             if value is None or value == 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             elif isinstance(value, list):
 *                 value = '[...]/%d' % len(value)
*/
      goto __pyx_L7_continue;

      /* "Cython/Compiler/Visitor.py":94
 *             except AttributeError:
 *                 continue
 *             if value is None or value == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             elif isinstance(value, list):
*/
    }

    /* "Cython/Compiler/Visitor.py":96
 *             if value is None or value == 0:
 *                 continue
 *             elif isinstance(value, list):             # <<<<<<<<<<<<<<
 *                 value = '[...]/%d' % len(value)
 *             elif not isinstance(value, _PRINTABLE):
*/
    __pyx_t_3 = PyList_Check(__pyx_v_value); 
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":97
 *                 continue
 *             elif isinstance(value, list):
 *                 value = '[...]/%d' % len(value)             # <<<<<<<<<<<<<<
 *             elif not isinstance(value, _PRINTABLE):
 *                 continue
*/
      __pyx_t_17 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_17 == ((Py_ssize_t)-1))) __PYX_ERR(0, 97, __pyx_L1_error)
      __pyx_t_4 = PyLong_FromSsize_t(__pyx_t_17); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_d, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Visitor.py":96
 *             if value is None or value == 0:
 *                 continue
 *             elif isinstance(value, list):             # <<<<<<<<<<<<<<
 *                 value = '[...]/%d' % len(value)
 *             elif not isinstance(value, _PRINTABLE):
*/
      goto __pyx_L23;
    }

    /* "Cython/Compiler/Visitor.py":98
 *             elif isinstance(value, list):
 *                 value = '[...]/%d' % len(value)
 *             elif not isinstance(value, _PRINTABLE):             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
*/
    __pyx_t_6 = __pyx_v_6Cython_8Compiler_7Visitor__PRINTABLE;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_value, __pyx_t_6); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_13 = (!__pyx_t_3);
    if (__pyx_t_13) {

      /* "Cython/Compiler/Visitor.py":99
 *                 value = '[...]/%d' % len(value)
 *             elif not isinstance(value, _PRINTABLE):
 *                 continue             # <<<<<<<<<<<<<<
 *             else:
 *                 value = repr(value)
*/
      goto __pyx_L7_continue;

      /* "Cython/Compiler/Visitor.py":98
 *             elif isinstance(value, list):
 *                 value = '[...]/%d' % len(value)
 *             elif not isinstance(value, _PRINTABLE):             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
*/
    }

    /* "Cython/Compiler/Visitor.py":101
 *                 continue
 *             else:
 *                 value = repr(value)             # <<<<<<<<<<<<<<
 *             values.append('%s = %s' % (attr, value))
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))
*/
    /*else*/ {
      __pyx_t_6 = PyObject_Repr(__pyx_v_value); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_6);
      __pyx_t_6 = 0;
    }
    __pyx_L23:;

    /* "Cython/Compiler/Visitor.py":102
 *             else:
 *                 value = repr(value)
 *             values.append('%s = %s' % (attr, value))             # <<<<<<<<<<<<<<
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_attr), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_value), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_18[0] = __pyx_t_6;
    __pyx_t_18[1] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_18[2] = __pyx_t_4;
    __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_18, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_values, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 102, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":85
 *             values.append('%s:%s:%s' % (source, pos[1], pos[2]))
 *         attribute_names = dir(node)
 *         for attr in attribute_names:             # <<<<<<<<<<<<<<
 *             if attr in ignored:
 *                 continue
*/
    __pyx_L7_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":103
 *                 value = repr(value)
 *             values.append('%s = %s' % (attr, value))
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))             # <<<<<<<<<<<<<<
 * 
 *     def _find_node_path(self, stacktrace):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_1), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__5, __pyx_v_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_19[0] = __pyx_t_2;
  __pyx_t_19[1] = __pyx_mstate_global->__pyx_kp_u__4;
  __pyx_t_19[2] = __pyx_t_1;
  __pyx_t_19[3] = __pyx_mstate_global->__pyx_kp_u__6;
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_19, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":73
 *         self.access_path = []
 * 
 *     def dump_node(self, node):             # <<<<<<<<<<<<<<
 *         ignored = list(node.child_attrs or []) + [
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.dump_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ignored);
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_source);
  __Pyx_XDECREF(__pyx_v_os);
  __Pyx_XDECREF(__pyx_v_attribute_names);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":105
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))
 * 
 *     def _find_node_path(self, stacktrace):             # <<<<<<<<<<<<<<
 *         import os.path
 *         last_traceback = stacktrace
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path(PyObject *__pyx_v_self, PyObject *__pyx_v_stacktrace); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path = {"_find_node_path", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path(PyObject *__pyx_v_self, PyObject *__pyx_v_stacktrace) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_find_node_path (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_4_find_node_path(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), ((PyObject *)__pyx_v_stacktrace));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_4_find_node_path(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_stacktrace) {
  PyObject *__pyx_v_os = NULL;
  PyObject *__pyx_v_last_traceback = NULL;
  PyObject *__pyx_v_nodes = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_code = NULL;
  PyObject *__pyx_v_method_name = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_find_node_path", 0);
  __Pyx_INCREF(__pyx_v_stacktrace);

  /* "Cython/Compiler/Visitor.py":106
 * 
 *     def _find_node_path(self, stacktrace):
 *         import os.path             # <<<<<<<<<<<<<<
 *         last_traceback = stacktrace
 *         nodes = []
*/
  __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os_path, 0, 0, NULL, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_os = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":107
 *     def _find_node_path(self, stacktrace):
 *         import os.path
 *         last_traceback = stacktrace             # <<<<<<<<<<<<<<
 *         nodes = []
 *         while hasattr(stacktrace, 'tb_frame'):
*/
  __Pyx_INCREF(__pyx_v_stacktrace);
  __pyx_v_last_traceback = __pyx_v_stacktrace;

  /* "Cython/Compiler/Visitor.py":108
 *         import os.path
 *         last_traceback = stacktrace
 *         nodes = []             # <<<<<<<<<<<<<<
 *         while hasattr(stacktrace, 'tb_frame'):
 *             frame = stacktrace.tb_frame
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_nodes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":109
 *         last_traceback = stacktrace
 *         nodes = []
 *         while hasattr(stacktrace, 'tb_frame'):             # <<<<<<<<<<<<<<
 *             frame = stacktrace.tb_frame
 *             node = frame.f_locals.get('self')
*/
  while (1) {
    __pyx_t_3 = __Pyx_HasAttr(__pyx_v_stacktrace, __pyx_mstate_global->__pyx_n_u_tb_frame); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 109, __pyx_L1_error)
    if (!__pyx_t_3) break;

    /* "Cython/Compiler/Visitor.py":110
 *         nodes = []
 *         while hasattr(stacktrace, 'tb_frame'):
 *             frame = stacktrace.tb_frame             # <<<<<<<<<<<<<<
 *             node = frame.f_locals.get('self')
 *             if isinstance(node, Nodes.Node):
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_stacktrace, __pyx_mstate_global->__pyx_n_u_tb_frame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_frame, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":111
 *         while hasattr(stacktrace, 'tb_frame'):
 *             frame = stacktrace.tb_frame
 *             node = frame.f_locals.get('self')             # <<<<<<<<<<<<<<
 *             if isinstance(node, Nodes.Node):
 *                 code = frame.f_code
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_locals); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_self};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":112
 *             frame = stacktrace.tb_frame
 *             node = frame.f_locals.get('self')
 *             if isinstance(node, Nodes.Node):             # <<<<<<<<<<<<<<
 *                 code = frame.f_code
 *                 method_name = code.co_name
*/
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Nodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_node, __pyx_t_5); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":113
 *             node = frame.f_locals.get('self')
 *             if isinstance(node, Nodes.Node):
 *                 code = frame.f_code             # <<<<<<<<<<<<<<
 *                 method_name = code.co_name
 *                 pos = (os.path.basename(code.co_filename),
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_code, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Visitor.py":114
 *             if isinstance(node, Nodes.Node):
 *                 code = frame.f_code
 *                 method_name = code.co_name             # <<<<<<<<<<<<<<
 *                 pos = (os.path.basename(code.co_filename),
 *                        frame.f_lineno)
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_mstate_global->__pyx_n_u_co_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_method_name, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Visitor.py":115
 *                 code = frame.f_code
 *                 method_name = code.co_name
 *                 pos = (os.path.basename(code.co_filename),             # <<<<<<<<<<<<<<
 *                        frame.f_lineno)
 *                 nodes.append((node, method_name, pos))
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_os, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_mstate_global->__pyx_n_u_co_filename); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_basename, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }

      /* "Cython/Compiler/Visitor.py":116
 *                 method_name = code.co_name
 *                 pos = (os.path.basename(code.co_filename),
 *                        frame.f_lineno)             # <<<<<<<<<<<<<<
 *                 nodes.append((node, method_name, pos))
 *                 last_traceback = stacktrace
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_lineno); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "Cython/Compiler/Visitor.py":115
 *                 code = frame.f_code
 *                 method_name = code.co_name
 *                 pos = (os.path.basename(code.co_filename),             # <<<<<<<<<<<<<<
 *                        frame.f_lineno)
 *                 nodes.append((node, method_name, pos))
*/
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5) != (0)) __PYX_ERR(0, 115, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 115, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_pos, ((PyObject*)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "Cython/Compiler/Visitor.py":117
 *                 pos = (os.path.basename(code.co_filename),
 *                        frame.f_lineno)
 *                 nodes.append((node, method_name, pos))             # <<<<<<<<<<<<<<
 *                 last_traceback = stacktrace
 *             stacktrace = stacktrace.tb_next
*/
      __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 117, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_node);
      __Pyx_GIVEREF(__pyx_v_node);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_node) != (0)) __PYX_ERR(0, 117, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_method_name);
      __Pyx_GIVEREF(__pyx_v_method_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_method_name) != (0)) __PYX_ERR(0, 117, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_pos) != (0)) __PYX_ERR(0, 117, __pyx_L1_error);
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_nodes, __pyx_t_7); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 117, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "Cython/Compiler/Visitor.py":118
 *                        frame.f_lineno)
 *                 nodes.append((node, method_name, pos))
 *                 last_traceback = stacktrace             # <<<<<<<<<<<<<<
 *             stacktrace = stacktrace.tb_next
 *         return (last_traceback, nodes)
*/
      __Pyx_INCREF(__pyx_v_stacktrace);
      __Pyx_DECREF_SET(__pyx_v_last_traceback, __pyx_v_stacktrace);

      /* "Cython/Compiler/Visitor.py":112
 *             frame = stacktrace.tb_frame
 *             node = frame.f_locals.get('self')
 *             if isinstance(node, Nodes.Node):             # <<<<<<<<<<<<<<
 *                 code = frame.f_code
 *                 method_name = code.co_name
*/
    }

    /* "Cython/Compiler/Visitor.py":119
 *                 nodes.append((node, method_name, pos))
 *                 last_traceback = stacktrace
 *             stacktrace = stacktrace.tb_next             # <<<<<<<<<<<<<<
 *         return (last_traceback, nodes)
 * 
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_stacktrace, __pyx_mstate_global->__pyx_n_u_tb_next); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF_SET(__pyx_v_stacktrace, __pyx_t_7);
    __pyx_t_7 = 0;
  }

  /* "Cython/Compiler/Visitor.py":120
 *                 last_traceback = stacktrace
 *             stacktrace = stacktrace.tb_next
 *         return (last_traceback, nodes)             # <<<<<<<<<<<<<<
 * 
 *     def _raise_compiler_error(self, child, e):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_v_last_traceback);
  __Pyx_GIVEREF(__pyx_v_last_traceback);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_last_traceback) != (0)) __PYX_ERR(0, 120, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_nodes);
  __Pyx_GIVEREF(__pyx_v_nodes);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_nodes) != (0)) __PYX_ERR(0, 120, __pyx_L1_error);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":105
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))
 * 
 *     def _find_node_path(self, stacktrace):             # <<<<<<<<<<<<<<
 *         import os.path
 *         last_traceback = stacktrace
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._find_node_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_os);
  __Pyx_XDECREF(__pyx_v_last_traceback);
  __Pyx_XDECREF(__pyx_v_nodes);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_method_name);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_stacktrace);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":122
 *         return (last_traceback, nodes)
 * 
 *     def _raise_compiler_error(self, child, e):             # <<<<<<<<<<<<<<
 *         trace = ['']
 *         for parent, attribute, index in self.access_path:
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__raise_compiler_error(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_child, PyObject *__pyx_v_e) {
  PyObject *__pyx_v_trace = NULL;
  PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_v_attribute = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_stacktrace = NULL;
  PyObject *__pyx_v_called_nodes = NULL;
  PyObject *__pyx_v_last_node = NULL;
  PyObject *__pyx_v_method_name = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10[6];
  int __pyx_t_11;
  size_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14[8];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_raise_compiler_error", 0);

  /* "Cython/Compiler/Visitor.py":123
 * 
 *     def _raise_compiler_error(self, child, e):
 *         trace = ['']             # <<<<<<<<<<<<<<
 *         for parent, attribute, index in self.access_path:
 *             node = getattr(parent, attribute)
*/
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__7);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_u__7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_mstate_global->__pyx_kp_u__7) != (0)) __PYX_ERR(0, 123, __pyx_L1_error);
  __pyx_v_trace = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":124
 *     def _raise_compiler_error(self, child, e):
 *         trace = ['']
 *         for parent, attribute, index in self.access_path:             # <<<<<<<<<<<<<<
 *             node = getattr(parent, attribute)
 *             if index is None:
*/
  if (unlikely(__pyx_v_self->access_path == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 124, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->access_path; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 124, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 124, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < (0)) __PYX_ERR(0, 124, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 124, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_parent, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_attribute, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Visitor.py":125
 *         trace = ['']
 *         for parent, attribute, index in self.access_path:
 *             node = getattr(parent, attribute)             # <<<<<<<<<<<<<<
 *             if index is None:
 *                 index = ''
*/
    __pyx_t_3 = __Pyx_GetAttr(__pyx_v_parent, __pyx_v_attribute); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":126
 *         for parent, attribute, index in self.access_path:
 *             node = getattr(parent, attribute)
 *             if index is None:             # <<<<<<<<<<<<<<
 *                 index = ''
 *             else:
*/
    __pyx_t_9 = (__pyx_v_index == Py_None);
    if (__pyx_t_9) {

      /* "Cython/Compiler/Visitor.py":127
 *             node = getattr(parent, attribute)
 *             if index is None:
 *                 index = ''             # <<<<<<<<<<<<<<
 *             else:
 *                 node = node[index]
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__7);
      __Pyx_DECREF_SET(__pyx_v_index, __pyx_mstate_global->__pyx_kp_u__7);

      /* "Cython/Compiler/Visitor.py":126
 *         for parent, attribute, index in self.access_path:
 *             node = getattr(parent, attribute)
 *             if index is None:             # <<<<<<<<<<<<<<
 *                 index = ''
 *             else:
*/
      goto __pyx_L7;
    }

    /* "Cython/Compiler/Visitor.py":129
 *                 index = ''
 *             else:
 *                 node = node[index]             # <<<<<<<<<<<<<<
 *                 index = '[%d]' % index
 *             trace.append('%s.%s%s = %s' % (
*/
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_node, __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 129, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":130
 *             else:
 *                 node = node[index]
 *                 index = '[%d]' % index             # <<<<<<<<<<<<<<
 *             trace.append('%s.%s%s = %s' % (
 *                 parent.__class__.__name__, attribute, index,
*/
      __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_d_2, __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L7:;

    /* "Cython/Compiler/Visitor.py":132
 *                 index = '[%d]' % index
 *             trace.append('%s.%s%s = %s' % (
 *                 parent.__class__.__name__, attribute, index,             # <<<<<<<<<<<<<<
 *                 self.dump_node(node)))
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_6), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_attribute), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_index), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "Cython/Compiler/Visitor.py":133
 *             trace.append('%s.%s%s = %s' % (
 *                 parent.__class__.__name__, attribute, index,
 *                 self.dump_node(node)))             # <<<<<<<<<<<<<<
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])
 *         last_node = child
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dump_node); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_node); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_10[0] = __pyx_t_3;
    __pyx_t_10[1] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_10[2] = __pyx_t_6;
    __pyx_t_10[3] = __pyx_t_5;
    __pyx_t_10[4] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_10[5] = __pyx_t_4;

    /* "Cython/Compiler/Visitor.py":131
 *                 node = node[index]
 *                 index = '[%d]' % index
 *             trace.append('%s.%s%s = %s' % (             # <<<<<<<<<<<<<<
 *                 parent.__class__.__name__, attribute, index,
 *                 self.dump_node(node)))
*/
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_10, 6, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_trace, __pyx_t_7); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "Cython/Compiler/Visitor.py":124
 *     def _raise_compiler_error(self, child, e):
 *         trace = ['']
 *         for parent, attribute, index in self.access_path:             # <<<<<<<<<<<<<<
 *             node = getattr(parent, attribute)
 *             if index is None:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":134
 *                 parent.__class__.__name__, attribute, index,
 *                 self.dump_node(node)))
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])             # <<<<<<<<<<<<<<
 *         last_node = child
 *         for node, method_name, pos in called_nodes:
*/
  __pyx_t_7 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_12 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_12 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_12 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_find_node_path, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 134, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_7);
    } else {
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 134, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 134, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_7);
    }
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
    index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L9_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_7 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 134, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L10_unpacking_done;
    __pyx_L9_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 134, __pyx_L1_error)
    __pyx_L10_unpacking_done:;
  }
  __pyx_v_stacktrace = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_called_nodes = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "Cython/Compiler/Visitor.py":135
 *                 self.dump_node(node)))
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])
 *         last_node = child             # <<<<<<<<<<<<<<
 *         for node, method_name, pos in called_nodes:
 *             last_node = node
*/
  __Pyx_INCREF(__pyx_v_child);
  __pyx_v_last_node = __pyx_v_child;

  /* "Cython/Compiler/Visitor.py":136
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])
 *         last_node = child
 *         for node, method_name, pos in called_nodes:             # <<<<<<<<<<<<<<
 *             last_node = node
 *             trace.append("File '%s', line %d, in %s: %s" % (
*/
  if (likely(PyList_CheckExact(__pyx_v_called_nodes)) || PyTuple_CheckExact(__pyx_v_called_nodes)) {
    __pyx_t_1 = __pyx_v_called_nodes; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_13 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_called_nodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 136, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_13)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 136, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 136, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 136, __pyx_L1_error)
    } else {
      __pyx_t_7 = __pyx_t_13(__pyx_t_1);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 136, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_7);
    if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
      PyObject* sequence = __pyx_t_7;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 136, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2);
        __Pyx_INCREF(__pyx_t_5);
      } else {
        __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 136, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 136, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 136, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
      }
      #else
      __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L13_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L13_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 2; __pyx_t_5 = __pyx_t_8(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L13_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_6), 3) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L14_unpacking_done;
      __pyx_L13_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 136, __pyx_L1_error)
      __pyx_L14_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_method_name, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pos, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "Cython/Compiler/Visitor.py":137
 *         last_node = child
 *         for node, method_name, pos in called_nodes:
 *             last_node = node             # <<<<<<<<<<<<<<
 *             trace.append("File '%s', line %d, in %s: %s" % (
 *                 pos[0], pos[1], method_name, self.dump_node(node)))
*/
    __Pyx_INCREF(__pyx_v_node);
    __Pyx_DECREF_SET(__pyx_v_last_node, __pyx_v_node);

    /* "Cython/Compiler/Visitor.py":139
 *             last_node = node
 *             trace.append("File '%s', line %d, in %s: %s" % (
 *                 pos[0], pos[1], method_name, self.dump_node(node)))             # <<<<<<<<<<<<<<
 *         raise Errors.CompilerCrash(
 *             getattr(last_node, 'pos', None), self.__class__.__name__,
*/
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_Long(__pyx_t_7), __pyx_mstate_global->__pyx_n_u_d_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_method_name), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dump_node); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_node); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_6), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_14[0] = __pyx_mstate_global->__pyx_kp_u_File;
    __pyx_t_14[1] = __pyx_t_5;
    __pyx_t_14[2] = __pyx_mstate_global->__pyx_kp_u_line;
    __pyx_t_14[3] = __pyx_t_4;
    __pyx_t_14[4] = __pyx_mstate_global->__pyx_kp_u_in;
    __pyx_t_14[5] = __pyx_t_7;
    __pyx_t_14[6] = __pyx_mstate_global->__pyx_kp_u__9;
    __pyx_t_14[7] = __pyx_t_3;

    /* "Cython/Compiler/Visitor.py":138
 *         for node, method_name, pos in called_nodes:
 *             last_node = node
 *             trace.append("File '%s', line %d, in %s: %s" % (             # <<<<<<<<<<<<<<
 *                 pos[0], pos[1], method_name, self.dump_node(node)))
 *         raise Errors.CompilerCrash(
*/
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_14, 8, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 5 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_trace, __pyx_t_6); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Visitor.py":136
 *         stacktrace, called_nodes = self._find_node_path(sys.exc_info()[2])
 *         last_node = child
 *         for node, method_name, pos in called_nodes:             # <<<<<<<<<<<<<<
 *             last_node = node
 *             trace.append("File '%s', line %d, in %s: %s" % (
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":140
 *             trace.append("File '%s', line %d, in %s: %s" % (
 *                 pos[0], pos[1], method_name, self.dump_node(node)))
 *         raise Errors.CompilerCrash(             # <<<<<<<<<<<<<<
 *             getattr(last_node, 'pos', None), self.__class__.__name__,
 *             '\n'.join(trace), e, stacktrace)
*/
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Errors); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_CompilerCrash); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Visitor.py":141
 *                 pos[0], pos[1], method_name, self.dump_node(node)))
 *         raise Errors.CompilerCrash(
 *             getattr(last_node, 'pos', None), self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             '\n'.join(trace), e, stacktrace)
 * 
*/
  __pyx_t_3 = __Pyx_GetAttr3(__pyx_v_last_node, __pyx_mstate_global->__pyx_n_u_pos, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":142
 *         raise Errors.CompilerCrash(
 *             getattr(last_node, 'pos', None), self.__class__.__name__,
 *             '\n'.join(trace), e, stacktrace)             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
  __pyx_t_4 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__10, __pyx_v_trace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_12 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_12 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_6, __pyx_t_3, __pyx_t_5, __pyx_t_4, __pyx_v_e, __pyx_v_stacktrace};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_12, (6-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 140, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":122
 *         return (last_traceback, nodes)
 * 
 *     def _raise_compiler_error(self, child, e):             # <<<<<<<<<<<<<<
 *         trace = ['']
 *         for parent, attribute, index in self.access_path:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._raise_compiler_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XDECREF(__pyx_v_trace);
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_attribute);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_stacktrace);
  __Pyx_XDECREF(__pyx_v_called_nodes);
  __Pyx_XDECREF(__pyx_v_last_node);
  __Pyx_XDECREF(__pyx_v_method_name);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":144
 *             '\n'.join(trace), e, stacktrace)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def find_handler(self, obj):
 *         # to resolve, try entire hierarchy
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_find_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyTypeObject *__pyx_v_cls = NULL;
  PyObject *__pyx_v_mro = NULL;
  PyObject *__pyx_v_mro_cls = NULL;
  PyObject *__pyx_v_handler_method = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  PyObject *__pyx_t_9[4];
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_handler", 0);

  /* "Cython/Compiler/Visitor.py":147
 *     def find_handler(self, obj):
 *         # to resolve, try entire hierarchy
 *         cls = type(obj)             # <<<<<<<<<<<<<<
 *         mro = inspect.getmro(cls)
 *         for mro_cls in mro:
*/
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_obj)));
  __pyx_v_cls = ((PyTypeObject*)((PyObject *)Py_TYPE(__pyx_v_obj)));

  /* "Cython/Compiler/Visitor.py":148
 *         # to resolve, try entire hierarchy
 *         cls = type(obj)
 *         mro = inspect.getmro(cls)             # <<<<<<<<<<<<<<
 *         for mro_cls in mro:
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_inspect); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_getmro); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_cls)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_mro = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":149
 *         cls = type(obj)
 *         mro = inspect.getmro(cls)
 *         for mro_cls in mro:             # <<<<<<<<<<<<<<
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
 *             if handler_method is not None:
*/
  if (likely(PyList_CheckExact(__pyx_v_mro)) || PyTuple_CheckExact(__pyx_v_mro)) {
    __pyx_t_1 = __pyx_v_mro; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_mro); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 149, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 149, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_6;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 149, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6);
        #endif
        ++__pyx_t_6;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 149, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 149, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_mro_cls, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Visitor.py":150
 *         mro = inspect.getmro(cls)
 *         for mro_cls in mro:
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)             # <<<<<<<<<<<<<<
 *             if handler_method is not None:
 *                 return handler_method
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_mro_cls, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_Add(__pyx_mstate_global->__pyx_n_u_visit, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_t_2, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_handler_method, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "Cython/Compiler/Visitor.py":151
 *         for mro_cls in mro:
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
 *             if handler_method is not None:             # <<<<<<<<<<<<<<
 *                 return handler_method
 * 
*/
    __pyx_t_8 = (__pyx_v_handler_method != Py_None);
    if (__pyx_t_8) {

      /* "Cython/Compiler/Visitor.py":152
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
 *             if handler_method is not None:
 *                 return handler_method             # <<<<<<<<<<<<<<
 * 
 *         print(type(self), cls)
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_handler_method);
      __pyx_r = __pyx_v_handler_method;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":151
 *         for mro_cls in mro:
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
 *             if handler_method is not None:             # <<<<<<<<<<<<<<
 *                 return handler_method
 * 
*/
    }

    /* "Cython/Compiler/Visitor.py":149
 *         cls = type(obj)
 *         mro = inspect.getmro(cls)
 *         for mro_cls in mro:             # <<<<<<<<<<<<<<
 *             handler_method = getattr(self, "visit_" + mro_cls.__name__, None)
 *             if handler_method is not None:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":154
 *                 return handler_method
 * 
 *         print(type(self), cls)             # <<<<<<<<<<<<<<
 *         if self.access_path:
 *             print(self.access_path)
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), ((PyObject *)__pyx_v_cls)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":155
 * 
 *         print(type(self), cls)
 *         if self.access_path:             # <<<<<<<<<<<<<<
 *             print(self.access_path)
 *             print(self.access_path[-1][0].pos)
*/
  if (__pyx_v_self->access_path == Py_None) __pyx_t_8 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->access_path);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 155, __pyx_L1_error)
    __pyx_t_8 = (__pyx_temp != 0);
  }

  if (__pyx_t_8) {

    /* "Cython/Compiler/Visitor.py":156
 *         print(type(self), cls)
 *         if self.access_path:
 *             print(self.access_path)             # <<<<<<<<<<<<<<
 *             print(self.access_path[-1][0].pos)
 *             print(self.access_path[-1][0].__dict__)
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self->access_path};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":157
 *         if self.access_path:
 *             print(self.access_path)
 *             print(self.access_path[-1][0].pos)             # <<<<<<<<<<<<<<
 *             print(self.access_path[-1][0].__dict__)
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))
*/
    __pyx_t_4 = NULL;
    if (unlikely(__pyx_v_self->access_path == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 157, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->access_path, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":158
 *             print(self.access_path)
 *             print(self.access_path[-1][0].pos)
 *             print(self.access_path[-1][0].__dict__)             # <<<<<<<<<<<<<<
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))
 * 
*/
    __pyx_t_2 = NULL;
    if (unlikely(__pyx_v_self->access_path == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 158, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->access_path, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":155
 * 
 *         print(type(self), cls)
 *         if self.access_path:             # <<<<<<<<<<<<<<
 *             print(self.access_path)
 *             print(self.access_path[-1][0].pos)
*/
  }

  /* "Cython/Compiler/Visitor.py":159
 *             print(self.access_path[-1][0].pos)
 *             print(self.access_path[-1][0].__dict__)
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))             # <<<<<<<<<<<<<<
 * 
 *     def visit(self, obj):
*/
  __pyx_t_4 = NULL;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(((PyObject *)__pyx_v_self)), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_obj), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Visitor;
  __pyx_t_9[1] = __pyx_t_2;
  __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_does_not_accept_object;
  __pyx_t_9[3] = __pyx_t_3;
  __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 4, 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 25 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_10};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 159, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":144
 *             '\n'.join(trace), e, stacktrace)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def find_handler(self, obj):
 *         # to resolve, try entire hierarchy
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.find_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_cls);
  __Pyx_XDECREF(__pyx_v_mro);
  __Pyx_XDECREF(__pyx_v_mro_cls);
  __Pyx_XDECREF(__pyx_v_handler_method);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":161
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))
 * 
 *     def visit(self, obj):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visit(obj)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_visit_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_obj};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/Visitor.py":163
 *     def visit(self, obj):
 *         # generic def entry point for calls from Python subclasses
 *         return self._visit(obj)             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit(__pyx_v_self, __pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":161
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))
 * 
 *     def visit(self, obj):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visit(obj)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit = {"visit", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_6visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_6visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visit(__pyx_v_self, __pyx_v_obj, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":165
 *         return self._visit(obj)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visit(self, obj):
 *         # fast cdef entry point for calls from Cython subclasses
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_v_handler_method = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_visit", 0);

  /* "Cython/Compiler/Visitor.py":168
 *     def _visit(self, obj):
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 handler_method = self.dispatch_table[type(obj)]
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "Cython/Compiler/Visitor.py":169
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 handler_method = self.dispatch_table[type(obj)]
 *             except KeyError:
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        /*try:*/ {

          /* "Cython/Compiler/Visitor.py":170
 *         try:
 *             try:
 *                 handler_method = self.dispatch_table[type(obj)]             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 handler_method = self.find_handler(obj)
*/
          if (unlikely(__pyx_v_self->dispatch_table == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 170, __pyx_L9_error)
          }
          __pyx_t_7 = __Pyx_PyDict_GetItem(__pyx_v_self->dispatch_table, ((PyObject *)Py_TYPE(__pyx_v_obj))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 170, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_v_handler_method = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "Cython/Compiler/Visitor.py":169
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 handler_method = self.dispatch_table[type(obj)]
 *             except KeyError:
*/
        }
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L14_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "Cython/Compiler/Visitor.py":171
 *             try:
 *                 handler_method = self.dispatch_table[type(obj)]
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 handler_method = self.find_handler(obj)
 *                 self.dispatch_table[type(obj)] = handler_method
*/
        __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
        if (__pyx_t_8) {
          __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_9, &__pyx_t_10) < 0) __PYX_ERR(0, 171, __pyx_L11_except_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);

          /* "Cython/Compiler/Visitor.py":172
 *                 handler_method = self.dispatch_table[type(obj)]
 *             except KeyError:
 *                 handler_method = self.find_handler(obj)             # <<<<<<<<<<<<<<
 *                 self.dispatch_table[type(obj)] = handler_method
 *             return handler_method(obj)
*/
          __pyx_t_11 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_find_handler(__pyx_v_self, __pyx_v_obj); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 172, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_XDECREF_SET(__pyx_v_handler_method, __pyx_t_11);
          __pyx_t_11 = 0;

          /* "Cython/Compiler/Visitor.py":173
 *             except KeyError:
 *                 handler_method = self.find_handler(obj)
 *                 self.dispatch_table[type(obj)] = handler_method             # <<<<<<<<<<<<<<
 *             return handler_method(obj)
 *         except Errors.CompileError:
*/
          if (unlikely(__pyx_v_self->dispatch_table == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 173, __pyx_L11_except_error)
          }
          if (unlikely((PyDict_SetItem(__pyx_v_self->dispatch_table, ((PyObject *)Py_TYPE(__pyx_v_obj)), __pyx_v_handler_method) < 0))) __PYX_ERR(0, 173, __pyx_L11_except_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L10_exception_handled;
        }
        goto __pyx_L11_except_error;

        /* "Cython/Compiler/Visitor.py":169
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 handler_method = self.dispatch_table[type(obj)]
 *             except KeyError:
*/
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        goto __pyx_L3_error;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        __pyx_L14_try_end:;
      }

      /* "Cython/Compiler/Visitor.py":174
 *                 handler_method = self.find_handler(obj)
 *                 self.dispatch_table[type(obj)] = handler_method
 *             return handler_method(obj)             # <<<<<<<<<<<<<<
 *         except Errors.CompileError:
 *             raise
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_9 = NULL;
      __Pyx_INCREF(__pyx_v_handler_method);
      __pyx_t_7 = __pyx_v_handler_method; 
      __pyx_t_12 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_12 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_obj};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 174, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_r = __pyx_t_10;
      __pyx_t_10 = 0;
      goto __pyx_L7_try_return;

      /* "Cython/Compiler/Visitor.py":168
 *     def _visit(self, obj):
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 handler_method = self.dispatch_table[type(obj)]
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "Cython/Compiler/Visitor.py":175
 *                 self.dispatch_table[type(obj)] = handler_method
 *             return handler_method(obj)
 *         except Errors.CompileError:             # <<<<<<<<<<<<<<
 *             raise
 *         except Errors.AbortError:
*/
    __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_7, &__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_Errors); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 175, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_CompileError); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 175, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_10, __pyx_t_13);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_ErrRestore(__pyx_t_10, __pyx_t_7, __pyx_t_9);
    __pyx_t_10 = 0; __pyx_t_7 = 0; __pyx_t_9 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_7, &__pyx_t_10) < 0) __PYX_ERR(0, 175, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_10);

      /* "Cython/Compiler/Visitor.py":176
 *             return handler_method(obj)
 *         except Errors.CompileError:
 *             raise             # <<<<<<<<<<<<<<
 *         except Errors.AbortError:
 *             raise
*/
      __Pyx_GIVEREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_7, __pyx_t_10);
      __pyx_t_9 = 0;  __pyx_t_7 = 0;  __pyx_t_10 = 0; 
      __PYX_ERR(0, 176, __pyx_L5_except_error)
    }

    /* "Cython/Compiler/Visitor.py":177
 *         except Errors.CompileError:
 *             raise
 *         except Errors.AbortError:             # <<<<<<<<<<<<<<
 *             raise
 *         except Exception as e:
*/
    __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_7, &__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_Errors); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 177, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_AbortError); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 177, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_10, __pyx_t_11);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_ErrRestore(__pyx_t_10, __pyx_t_7, __pyx_t_9);
    __pyx_t_10 = 0; __pyx_t_7 = 0; __pyx_t_9 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_7, &__pyx_t_10) < 0) __PYX_ERR(0, 177, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_10);

      /* "Cython/Compiler/Visitor.py":178
 *             raise
 *         except Errors.AbortError:
 *             raise             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             if DebugFlags.debug_no_exception_intercept:
*/
      __Pyx_GIVEREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_7, __pyx_t_10);
      __pyx_t_9 = 0;  __pyx_t_7 = 0;  __pyx_t_10 = 0; 
      __PYX_ERR(0, 178, __pyx_L5_except_error)
    }

    /* "Cython/Compiler/Visitor.py":179
 *         except Errors.AbortError:
 *             raise
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if DebugFlags.debug_no_exception_intercept:
 *                 raise
*/
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_8) {
      __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(0, 179, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_e = __pyx_t_7;
      /*try:*/ {

        /* "Cython/Compiler/Visitor.py":180
 *             raise
 *         except Exception as e:
 *             if DebugFlags.debug_no_exception_intercept:             # <<<<<<<<<<<<<<
 *                 raise
 *             self._raise_compiler_error(obj, e)
*/
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_DebugFlags); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 180, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_debug_no_exception_intercept); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 180, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 180, __pyx_L26_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(__pyx_t_14)) {

          /* "Cython/Compiler/Visitor.py":181
 *         except Exception as e:
 *             if DebugFlags.debug_no_exception_intercept:
 *                 raise             # <<<<<<<<<<<<<<
 *             self._raise_compiler_error(obj, e)
 * 
*/
          __Pyx_GIVEREF(__pyx_t_10);
          __Pyx_GIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ErrRestoreWithState(__pyx_t_10, __pyx_t_7, __pyx_t_9);
          __pyx_t_10 = 0;  __pyx_t_7 = 0;  __pyx_t_9 = 0; 
          __PYX_ERR(0, 181, __pyx_L26_error)

          /* "Cython/Compiler/Visitor.py":180
 *             raise
 *         except Exception as e:
 *             if DebugFlags.debug_no_exception_intercept:             # <<<<<<<<<<<<<<
 *                 raise
 *             self._raise_compiler_error(obj, e)
*/
        }

        /* "Cython/Compiler/Visitor.py":182
 *             if DebugFlags.debug_no_exception_intercept:
 *                 raise
 *             self._raise_compiler_error(obj, e)             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
        __pyx_t_13 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self->__pyx_vtab)->_raise_compiler_error(__pyx_v_self, __pyx_v_obj, __pyx_v_e); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 182, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }

      /* "Cython/Compiler/Visitor.py":179
 *         except Errors.AbortError:
 *             raise
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if DebugFlags.debug_no_exception_intercept:
 *                 raise
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          goto __pyx_L27;
        }
        __pyx_L26_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_8 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L5_except_error;
        }
        __pyx_L27:;
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "Cython/Compiler/Visitor.py":168
 *     def _visit(self, obj):
 *         # fast cdef entry point for calls from Cython subclasses
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 handler_method = self.dispatch_table[type(obj)]
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "Cython/Compiler/Visitor.py":165
 *         return self._visit(obj)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visit(self, obj):
 *         # fast cdef entry point for calls from Cython subclasses
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler_method);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":184
 *             self._raise_compiler_error(obj, e)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visitchild(self, child, parent, attrname, idx):
 *         # fast cdef entry point for calls from Cython subclasses
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_child, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrname, PyObject *__pyx_v_idx) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_visitchild", 0);

  /* "Cython/Compiler/Visitor.py":187
 *     def _visitchild(self, child, parent, attrname, idx):
 *         # fast cdef entry point for calls from Cython subclasses
 *         self.access_path.append((parent, attrname, idx))             # <<<<<<<<<<<<<<
 *         result = self._visit(child)
 *         self.access_path.pop()
*/
  if (unlikely(__pyx_v_self->access_path == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 187, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_parent);
  __Pyx_GIVEREF(__pyx_v_parent);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_parent) != (0)) __PYX_ERR(0, 187, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_attrname);
  __Pyx_GIVEREF(__pyx_v_attrname);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_attrname) != (0)) __PYX_ERR(0, 187, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_idx);
  __Pyx_GIVEREF(__pyx_v_idx);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_idx) != (0)) __PYX_ERR(0, 187, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_self->access_path, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":188
 *         # fast cdef entry point for calls from Cython subclasses
 *         self.access_path.append((parent, attrname, idx))
 *         result = self._visit(child)             # <<<<<<<<<<<<<<
 *         self.access_path.pop()
 *         return result
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit(__pyx_v_self, __pyx_v_child); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":189
 *         self.access_path.append((parent, attrname, idx))
 *         result = self._visit(child)
 *         self.access_path.pop()             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  if (unlikely(__pyx_v_self->access_path == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 189, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->access_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":190
 *         result = self._visit(child)
 *         self.access_path.pop()
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def visitchildren(self, parent, attrs=None, exclude=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":184
 *             self._raise_compiler_error(obj, e)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visitchild(self, child, parent, attrname, idx):
 *         # fast cdef entry point for calls from Cython subclasses
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visitchild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":192
 *         return result
 * 
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visitchildren(parent, attrs, exclude)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args) {
  PyObject *__pyx_v_attrs = ((PyObject *)Py_None);
  PyObject *__pyx_v_exclude = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchildren", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_attrs = __pyx_optional_args->attrs;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_exclude = __pyx_optional_args->exclude;
      }
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_visitchildren); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/Visitor.py":194
 *     def visitchildren(self, parent, attrs=None, exclude=None):
 *         # generic def entry point for calls from Python subclasses
 *         return self._visitchildren(parent, attrs, exclude)             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchildren(__pyx_v_self, __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":192
 *         return result
 * 
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visitchildren(parent, attrs, exclude)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren = {"visitchildren", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_parent = 0;
  PyObject *__pyx_v_attrs = 0;
  PyObject *__pyx_v_exclude = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visitchildren (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_parent,&__pyx_mstate_global->__pyx_n_u_attrs,&__pyx_mstate_global->__pyx_n_u_exclude,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 192, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 192, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 192, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 192, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visitchildren", 0) < (0)) __PYX_ERR(0, 192, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visitchildren", 0, 1, 3, i); __PYX_ERR(0, 192, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 192, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 192, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 192, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_parent = values[0];
    __pyx_v_attrs = values[1];
    __pyx_v_exclude = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visitchildren", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 192, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_8visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_8visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchildren", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.attrs = __pyx_v_attrs;
  __pyx_t_2.exclude = __pyx_v_exclude;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor->visitchildren(__pyx_v_self, __pyx_v_parent, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":196
 *         return self._visitchildren(parent, attrs, exclude)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visitchildren(self, parent, attrs, exclude):
 *         # fast cdef entry point for calls from Cython subclasses
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_v_childretval = NULL;
  Py_ssize_t __pyx_7genexpr__pyx_v_idx;
  PyObject *__pyx_7genexpr__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13[4];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_visitchildren", 0);

  /* "Cython/Compiler/Visitor.py":210
 *         idx: cython.Py_ssize_t
 * 
 *         if parent is None: return None             # <<<<<<<<<<<<<<
 *         result = {}
 *         for attr in parent.child_attrs:
*/
  __pyx_t_1 = (__pyx_v_parent == Py_None);
  if (__pyx_t_1) {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Visitor.py":211
 * 
 *         if parent is None: return None
 *         result = {}             # <<<<<<<<<<<<<<
 *         for attr in parent.child_attrs:
 *             if attrs is not None and attr not in attrs: continue
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":212
 *         if parent is None: return None
 *         result = {}
 *         for attr in parent.child_attrs:             # <<<<<<<<<<<<<<
 *             if attrs is not None and attr not in attrs: continue
 *             if exclude is not None and attr in exclude: continue
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_parent, __pyx_mstate_global->__pyx_n_u_child_attrs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 212, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 212, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_4;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 212, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4);
        #endif
        ++__pyx_t_4;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 212, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":213
 *         result = {}
 *         for attr in parent.child_attrs:
 *             if attrs is not None and attr not in attrs: continue             # <<<<<<<<<<<<<<
 *             if exclude is not None and attr in exclude: continue
 *             child = getattr(parent, attr)
*/
    __pyx_t_6 = (__pyx_v_attrs != Py_None);
    if (__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr, __pyx_v_attrs, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 213, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_1) {
      goto __pyx_L4_continue;
    }

    /* "Cython/Compiler/Visitor.py":214
 *         for attr in parent.child_attrs:
 *             if attrs is not None and attr not in attrs: continue
 *             if exclude is not None and attr in exclude: continue             # <<<<<<<<<<<<<<
 *             child = getattr(parent, attr)
 *             if child is not None:
*/
    __pyx_t_6 = (__pyx_v_exclude != Py_None);
    if (__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr, __pyx_v_exclude, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 214, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_6;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_1) {
      goto __pyx_L4_continue;
    }

    /* "Cython/Compiler/Visitor.py":215
 *             if attrs is not None and attr not in attrs: continue
 *             if exclude is not None and attr in exclude: continue
 *             child = getattr(parent, attr)             # <<<<<<<<<<<<<<
 *             if child is not None:
 *                 if type(child) is list:
*/
    __pyx_t_2 = __Pyx_GetAttr(__pyx_v_parent, __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":216
 *             if exclude is not None and attr in exclude: continue
 *             child = getattr(parent, attr)
 *             if child is not None:             # <<<<<<<<<<<<<<
 *                 if type(child) is list:
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]
*/
    __pyx_t_1 = (__pyx_v_child != Py_None);
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":217
 *             child = getattr(parent, attr)
 *             if child is not None:
 *                 if type(child) is list:             # <<<<<<<<<<<<<<
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]
 *                 else:
*/
      __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_child)) == ((PyObject *)(&PyList_Type)));
      if (__pyx_t_1) {

        /* "Cython/Compiler/Visitor.py":218
 *             if child is not None:
 *                 if type(child) is list:
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]             # <<<<<<<<<<<<<<
 *                 else:
 *                     childretval = self._visitchild(child, parent, attr, None)
*/
        { /* enter inner scope */
          __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_7 = 0;
          if (likely(PyList_CheckExact(__pyx_v_child)) || PyTuple_CheckExact(__pyx_v_child)) {
            __pyx_t_8 = __pyx_v_child; __Pyx_INCREF(__pyx_t_8);
            __pyx_t_9 = 0;
            __pyx_t_10 = NULL;
          } else {
            __pyx_t_9 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_child); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 218, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 218, __pyx_L16_error)
          }
          for (;;) {
            if (likely(!__pyx_t_10)) {
              if (likely(PyList_CheckExact(__pyx_t_8))) {
                {
                  Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_8);
                  #if !CYTHON_ASSUME_SAFE_SIZE
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 218, __pyx_L16_error)
                  #endif
                  if (__pyx_t_9 >= __pyx_temp) break;
                }
                __pyx_t_11 = __Pyx_PyList_GetItemRefFast(__pyx_t_8, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
                ++__pyx_t_9;
              } else {
                {
                  Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_8);
                  #if !CYTHON_ASSUME_SAFE_SIZE
                  if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 218, __pyx_L16_error)
                  #endif
                  if (__pyx_t_9 >= __pyx_temp) break;
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_11 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_9));
                #else
                __pyx_t_11 = __Pyx_PySequence_ITEM(__pyx_t_8, __pyx_t_9);
                #endif
                ++__pyx_t_9;
              }
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 218, __pyx_L16_error)
            } else {
              __pyx_t_11 = __pyx_t_10(__pyx_t_8);
              if (unlikely(!__pyx_t_11)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 218, __pyx_L16_error)
                  PyErr_Clear();
                }
                break;
              }
            }
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_x, __pyx_t_11);
            __pyx_t_11 = 0;
            __pyx_7genexpr__pyx_v_idx = __pyx_t_7;
            __pyx_t_7 = (__pyx_t_7 + 1);
            __pyx_t_11 = PyLong_FromSsize_t(__pyx_7genexpr__pyx_v_idx); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 218, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_12 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild(__pyx_v_self, __pyx_7genexpr__pyx_v_x, __pyx_v_parent, __pyx_v_attr, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 218, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_12))) __PYX_ERR(0, 218, __pyx_L16_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
          goto __pyx_L20_exit_scope;
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
          goto __pyx_L1_error;
          __pyx_L20_exit_scope:;
        } /* exit inner scope */
        __Pyx_XDECREF_SET(__pyx_v_childretval, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Visitor.py":217
 *             child = getattr(parent, attr)
 *             if child is not None:
 *                 if type(child) is list:             # <<<<<<<<<<<<<<
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]
 *                 else:
*/
        goto __pyx_L13;
      }

      /* "Cython/Compiler/Visitor.py":220
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]
 *                 else:
 *                     childretval = self._visitchild(child, parent, attr, None)             # <<<<<<<<<<<<<<
 *                     assert not isinstance(childretval, list), 'Cannot insert list here: %s in %r' % (attr, parent)
 *                 result[attr] = childretval
*/
      /*else*/ {
        __pyx_t_2 = __pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild(__pyx_v_self, __pyx_v_child, __pyx_v_parent, __pyx_v_attr, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_childretval, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Visitor.py":221
 *                 else:
 *                     childretval = self._visitchild(child, parent, attr, None)
 *                     assert not isinstance(childretval, list), 'Cannot insert list here: %s in %r' % (attr, parent)             # <<<<<<<<<<<<<<
 *                 result[attr] = childretval
 *         return result
*/
        #ifndef CYTHON_WITHOUT_ASSERTIONS
        if (unlikely(__pyx_assertions_enabled())) {
          __pyx_t_1 = PyList_Check(__pyx_v_childretval); 
          __pyx_t_6 = (!__pyx_t_1);
          if (unlikely(!__pyx_t_6)) {
            __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_attr), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_parent), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 221, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_13[0] = __pyx_mstate_global->__pyx_kp_u_Cannot_insert_list_here;
            __pyx_t_13[1] = __pyx_t_2;
            __pyx_t_13[2] = __pyx_mstate_global->__pyx_kp_u_in_2;
            __pyx_t_13[3] = __pyx_t_8;
            __pyx_t_12 = __Pyx_PyUnicode_Join(__pyx_t_13, 4, 25 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 4 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 221, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_12, 0, 0);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __PYX_ERR(0, 221, __pyx_L1_error)
          }
        }
        #else
        if ((1)); else __PYX_ERR(0, 221, __pyx_L1_error)
        #endif
      }
      __pyx_L13:;

      /* "Cython/Compiler/Visitor.py":222
 *                     childretval = self._visitchild(child, parent, attr, None)
 *                     assert not isinstance(childretval, list), 'Cannot insert list here: %s in %r' % (attr, parent)
 *                 result[attr] = childretval             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
      if (unlikely((PyDict_SetItem(__pyx_v_result, __pyx_v_attr, __pyx_v_childretval) < 0))) __PYX_ERR(0, 222, __pyx_L1_error)

      /* "Cython/Compiler/Visitor.py":216
 *             if exclude is not None and attr in exclude: continue
 *             child = getattr(parent, attr)
 *             if child is not None:             # <<<<<<<<<<<<<<
 *                 if type(child) is list:
 *                     childretval = [self._visitchild(x, parent, attr, idx) for idx, x in enumerate(child)]
*/
    }

    /* "Cython/Compiler/Visitor.py":212
 *         if parent is None: return None
 *         result = {}
 *         for attr in parent.child_attrs:             # <<<<<<<<<<<<<<
 *             if attrs is not None and attr not in attrs: continue
 *             if exclude is not None and attr in exclude: continue
*/
    __pyx_L4_continue:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "Cython/Compiler/Visitor.py":223
 *                     assert not isinstance(childretval, list), 'Cannot insert list here: %s in %r' % (attr, parent)
 *                 result[attr] = childretval
 *         return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":196
 *         return self._visitchildren(parent, attrs, exclude)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _visitchildren(self, parent, attrs, exclude):
 *         # fast cdef entry point for calls from Cython subclasses
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor._visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_childretval);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":4
 * 
 * cdef class TreeVisitor:
 *     cdef public list access_path             # <<<<<<<<<<<<<<
 *     cdef dict dispatch_table
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->access_path);
  __pyx_r = __pyx_v_self->access_path;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->access_path);
  __Pyx_DECREF(__pyx_v_self->access_path);
  __pyx_v_self->access_path = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.TreeVisitor.access_path.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->access_path);
  __Pyx_DECREF(__pyx_v_self->access_path);
  __pyx_v_self->access_path = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":246
 *     are within a StatListNode or similar before doing this.)
 *     """
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._process_children(parent, attrs, exclude)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren *__pyx_optional_args) {
  PyObject *__pyx_v_attrs = ((PyObject *)Py_None);
  PyObject *__pyx_v_exclude = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchildren", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_attrs = __pyx_optional_args->attrs;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_exclude = __pyx_optional_args->exclude;
      }
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_visitchildren); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/Visitor.py":248
 *     def visitchildren(self, parent, attrs=None, exclude=None):
 *         # generic def entry point for calls from Python subclasses
 *         return self._process_children(parent, attrs, exclude)             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6.__pyx_n = 2;
  __pyx_t_6.attrs = __pyx_v_attrs;
  __pyx_t_6.exclude = __pyx_v_exclude;
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children(__pyx_v_self, __pyx_v_parent, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":246
 *     are within a StatListNode or similar before doing this.)
 *     """
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._process_children(parent, attrs, exclude)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren = {"visitchildren", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_parent = 0;
  PyObject *__pyx_v_attrs = 0;
  PyObject *__pyx_v_exclude = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visitchildren (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_parent,&__pyx_mstate_global->__pyx_n_u_attrs,&__pyx_mstate_global->__pyx_n_u_exclude,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 246, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visitchildren", 0) < (0)) __PYX_ERR(0, 246, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visitchildren", 0, 1, 3, i); __PYX_ERR(0, 246, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 246, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_parent = values[0];
    __pyx_v_attrs = values[1];
    __pyx_v_exclude = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visitchildren", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 246, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attrs, PyObject *__pyx_v_exclude) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchildren", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.attrs = __pyx_v_attrs;
  __pyx_t_2.exclude = __pyx_v_exclude;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform->__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_parent, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchildren", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":250
 *         return self._process_children(parent, attrs, exclude)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _process_children(self, parent, attrs=None, exclude=None):
 *         # fast cdef entry point for calls from Cython subclasses
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args) {

  /* "Cython/Compiler/Visitor.py":251
 * 
 *     @cython.final
 *     def _process_children(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # fast cdef entry point for calls from Cython subclasses
 *         result = self._visitchildren(parent, attrs, exclude)
*/
  PyObject *__pyx_v_attrs = ((PyObject *)Py_None);
  PyObject *__pyx_v_exclude = ((PyObject *)Py_None);
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_newnode = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_process_children", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_attrs = __pyx_optional_args->attrs;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_exclude = __pyx_optional_args->exclude;
      }
    }
  }

  /* "Cython/Compiler/Visitor.py":253
 *     def _process_children(self, parent, attrs=None, exclude=None):
 *         # fast cdef entry point for calls from Cython subclasses
 *         result = self._visitchildren(parent, attrs, exclude)             # <<<<<<<<<<<<<<
 *         for attr, newnode in result.items():
 *             if type(newnode) is list:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_parent, __pyx_v_attrs, __pyx_v_exclude); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":254
 *         # fast cdef entry point for calls from Cython subclasses
 *         result = self._visitchildren(parent, attrs, exclude)
 *         for attr, newnode in result.items():             # <<<<<<<<<<<<<<
 *             if type(newnode) is list:
 *                 newnode = self._flatten_list(newnode)
*/
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_result == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 254, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_result, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_newnode, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "Cython/Compiler/Visitor.py":255
 *         result = self._visitchildren(parent, attrs, exclude)
 *         for attr, newnode in result.items():
 *             if type(newnode) is list:             # <<<<<<<<<<<<<<
 *                 newnode = self._flatten_list(newnode)
 *             setattr(parent, attr, newnode)
*/
    __pyx_t_8 = (((PyObject *)Py_TYPE(__pyx_v_newnode)) == ((PyObject *)(&PyList_Type)));
    if (__pyx_t_8) {

      /* "Cython/Compiler/Visitor.py":256
 *         for attr, newnode in result.items():
 *             if type(newnode) is list:
 *                 newnode = self._flatten_list(newnode)             # <<<<<<<<<<<<<<
 *             setattr(parent, attr, newnode)
 *         return result
*/
      __pyx_t_6 = __pyx_v_newnode;
      __Pyx_INCREF(__pyx_t_6);
      if (!(likely(PyList_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_6))) __PYX_ERR(0, 256, __pyx_L1_error)
      __pyx_t_5 = __pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__flatten_list(__pyx_v_self, ((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_newnode, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Visitor.py":255
 *         result = self._visitchildren(parent, attrs, exclude)
 *         for attr, newnode in result.items():
 *             if type(newnode) is list:             # <<<<<<<<<<<<<<
 *                 newnode = self._flatten_list(newnode)
 *             setattr(parent, attr, newnode)
*/
    }

    /* "Cython/Compiler/Visitor.py":257
 *             if type(newnode) is list:
 *                 newnode = self._flatten_list(newnode)
 *             setattr(parent, attr, newnode)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    __pyx_t_9 = PyObject_SetAttr(__pyx_v_parent, __pyx_v_attr, __pyx_v_newnode); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 257, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":258
 *                 newnode = self._flatten_list(newnode)
 *             setattr(parent, attr, newnode)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @cython.final
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":250
 *         return self._process_children(parent, attrs, exclude)
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _process_children(self, parent, attrs=None, exclude=None):
 *         # fast cdef entry point for calls from Cython subclasses
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform._process_children", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_newnode);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":260
 *         return result
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _flatten_list(self, orig_list):
 *         # Flatten the list one level and remove any None
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__flatten_list(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_orig_list) {
  PyObject *__pyx_v_newlist = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_flatten_list", 0);

  /* "Cython/Compiler/Visitor.py":263
 *     def _flatten_list(self, orig_list):
 *         # Flatten the list one level and remove any None
 *         newlist = []             # <<<<<<<<<<<<<<
 *         for x in orig_list:
 *             if x is not None:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_newlist = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":264
 *         # Flatten the list one level and remove any None
 *         newlist = []
 *         for x in orig_list:             # <<<<<<<<<<<<<<
 *             if x is not None:
 *                 if type(x) is list:
*/
  if (unlikely(__pyx_v_orig_list == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 264, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_orig_list; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 264, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":265
 *         newlist = []
 *         for x in orig_list:
 *             if x is not None:             # <<<<<<<<<<<<<<
 *                 if type(x) is list:
 *                     newlist.extend(x)
*/
    __pyx_t_4 = (__pyx_v_x != Py_None);
    if (__pyx_t_4) {

      /* "Cython/Compiler/Visitor.py":266
 *         for x in orig_list:
 *             if x is not None:
 *                 if type(x) is list:             # <<<<<<<<<<<<<<
 *                     newlist.extend(x)
 *                 else:
*/
      __pyx_t_4 = (((PyObject *)Py_TYPE(__pyx_v_x)) == ((PyObject *)(&PyList_Type)));
      if (__pyx_t_4) {

        /* "Cython/Compiler/Visitor.py":267
 *             if x is not None:
 *                 if type(x) is list:
 *                     newlist.extend(x)             # <<<<<<<<<<<<<<
 *                 else:
 *                     newlist.append(x)
*/
        __pyx_t_5 = __Pyx_PyList_Extend(__pyx_v_newlist, __pyx_v_x); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 267, __pyx_L1_error)

        /* "Cython/Compiler/Visitor.py":266
 *         for x in orig_list:
 *             if x is not None:
 *                 if type(x) is list:             # <<<<<<<<<<<<<<
 *                     newlist.extend(x)
 *                 else:
*/
        goto __pyx_L6;
      }

      /* "Cython/Compiler/Visitor.py":269
 *                     newlist.extend(x)
 *                 else:
 *                     newlist.append(x)             # <<<<<<<<<<<<<<
 *         return newlist
 * 
*/
      /*else*/ {
        __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_newlist, __pyx_v_x); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 269, __pyx_L1_error)
      }
      __pyx_L6:;

      /* "Cython/Compiler/Visitor.py":265
 *         newlist = []
 *         for x in orig_list:
 *             if x is not None:             # <<<<<<<<<<<<<<
 *                 if type(x) is list:
 *                     newlist.extend(x)
*/
    }

    /* "Cython/Compiler/Visitor.py":264
 *         # Flatten the list one level and remove any None
 *         newlist = []
 *         for x in orig_list:             # <<<<<<<<<<<<<<
 *             if x is not None:
 *                 if type(x) is list:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":270
 *                 else:
 *                     newlist.append(x)
 *         return newlist             # <<<<<<<<<<<<<<
 * 
 *     def visitchild(self, parent, attr, idx=0):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_newlist);
  __pyx_r = __pyx_v_newlist;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":260
 *         return result
 * 
 *     @cython.final             # <<<<<<<<<<<<<<
 *     def _flatten_list(self, orig_list):
 *         # Flatten the list one level and remove any None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform._flatten_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_newlist);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":272
 *         return newlist
 * 
 *     def visitchild(self, parent, attr, idx=0):             # <<<<<<<<<<<<<<
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
*/

static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attr, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild *__pyx_optional_args) {
  PyObject *__pyx_v_idx = ((PyObject *)__pyx_mstate_global->__pyx_int_0);
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchild", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_idx = __pyx_optional_args->idx;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_visitchild); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_parent, __pyx_v_attr, __pyx_v_idx};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Cython/Compiler/Visitor.py":274
 *     def visitchild(self, parent, attr, idx=0):
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)             # <<<<<<<<<<<<<<
 *         if child is not None:
 *             node = self._visitchild(child, parent, attr, idx)
*/
  __pyx_t_1 = __Pyx_GetAttr(__pyx_v_parent, __pyx_v_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_child = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":275
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
 *         if child is not None:             # <<<<<<<<<<<<<<
 *             node = self._visitchild(child, parent, attr, idx)
 *             if node is not child:
*/
  __pyx_t_6 = (__pyx_v_child != Py_None);
  if (__pyx_t_6) {

    /* "Cython/Compiler/Visitor.py":276
 *         child = getattr(parent, attr)
 *         if child is not None:
 *             node = self._visitchild(child, parent, attr, idx)             # <<<<<<<<<<<<<<
 *             if node is not child:
 *                 setattr(parent, attr, node)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._visitchild(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_child, __pyx_v_parent, __pyx_v_attr, __pyx_v_idx); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":277
 *         if child is not None:
 *             node = self._visitchild(child, parent, attr, idx)
 *             if node is not child:             # <<<<<<<<<<<<<<
 *                 setattr(parent, attr, node)
 *             child = node
*/
    __pyx_t_6 = (__pyx_v_node != __pyx_v_child);
    if (__pyx_t_6) {

      /* "Cython/Compiler/Visitor.py":278
 *             node = self._visitchild(child, parent, attr, idx)
 *             if node is not child:
 *                 setattr(parent, attr, node)             # <<<<<<<<<<<<<<
 *             child = node
 *         return child
*/
      __pyx_t_7 = PyObject_SetAttr(__pyx_v_parent, __pyx_v_attr, __pyx_v_node); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 278, __pyx_L1_error)

      /* "Cython/Compiler/Visitor.py":277
 *         if child is not None:
 *             node = self._visitchild(child, parent, attr, idx)
 *             if node is not child:             # <<<<<<<<<<<<<<
 *                 setattr(parent, attr, node)
 *             child = node
*/
    }

    /* "Cython/Compiler/Visitor.py":279
 *             if node is not child:
 *                 setattr(parent, attr, node)
 *             child = node             # <<<<<<<<<<<<<<
 *         return child
 * 
*/
    __Pyx_INCREF(__pyx_v_node);
    __Pyx_DECREF_SET(__pyx_v_child, __pyx_v_node);

    /* "Cython/Compiler/Visitor.py":275
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
 *         if child is not None:             # <<<<<<<<<<<<<<
 *             node = self._visitchild(child, parent, attr, idx)
 *             if node is not child:
*/
  }

  /* "Cython/Compiler/Visitor.py":280
 *                 setattr(parent, attr, node)
 *             child = node
 *         return child             # <<<<<<<<<<<<<<
 * 
 *     def recurse_to_children(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_child);
  __pyx_r = __pyx_v_child;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":272
 *         return newlist
 * 
 *     def visitchild(self, parent, attr, idx=0):             # <<<<<<<<<<<<<<
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild = {"visitchild", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_parent = 0;
  PyObject *__pyx_v_attr = 0;
  PyObject *__pyx_v_idx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visitchild (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_parent,&__pyx_mstate_global->__pyx_n_u_attr,&__pyx_mstate_global->__pyx_n_u_idx,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 272, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visitchild", 0) < (0)) __PYX_ERR(0, 272, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_int_0));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visitchild", 0, 2, 3, i); __PYX_ERR(0, 272, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 272, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 272, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_int_0));
    }
    __pyx_v_parent = values[0];
    __pyx_v_attr = ((PyObject*)values[1]);
    __pyx_v_idx = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visitchild", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 272, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_attr), (&PyUnicode_Type), 1, "attr", 1))) __PYX_ERR(0, 272, __pyx_L1_error)
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_2visitchild(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_parent, __pyx_v_attr, __pyx_v_idx);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_2visitchild(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_attr, PyObject *__pyx_v_idx) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visitchild", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.idx = __pyx_v_idx;
  __pyx_t_1 = __pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform->visitchild(__pyx_v_self, __pyx_v_parent, __pyx_v_attr, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.visitchild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":282
 *         return child
 * 
 *     def recurse_to_children(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children = {"recurse_to_children", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recurse_to_children (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_4recurse_to_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_4recurse_to_children(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("recurse_to_children", 0);

  /* "Cython/Compiler/Visitor.py":283
 * 
 *     def recurse_to_children(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children(__pyx_v_self, __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":284
 *     def recurse_to_children(self, node):
 *         self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, root):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":282
 *         return child
 * 
 *     def recurse_to_children(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.recurse_to_children", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":286
 *         return node
 * 
 *     def __call__(self, root):             # <<<<<<<<<<<<<<
 *         return self._visit(root)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_7__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_7__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_root = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_root,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 286, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 286, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 286, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 286, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 286, __pyx_L3_error)
    }
    __pyx_v_root = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 286, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_6__call__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_root);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_16VisitorTransform_6__call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *__pyx_v_self, PyObject *__pyx_v_root) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Compiler/Visitor.py":287
 * 
 *     def __call__(self, root):
 *         return self._visit(root)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_root); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":286
 *         return node
 * 
 *     def __call__(self, root):             # <<<<<<<<<<<<<<
 *         return self._visit(root)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.VisitorTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":297
 *      - Tracks directives in effect in self.current_directives
 *     """
 *     def __init__(self, context):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.context = context
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_context = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_context,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 297, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 297, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 297, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 297, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 297, __pyx_L3_error)
    }
    __pyx_v_context = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 297, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform___init__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), __pyx_v_context);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_context) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":298
 *     """
 *     def __init__(self, context):
 *         super().__init__()             # <<<<<<<<<<<<<<
 *         self.context = context
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":299
 *     def __init__(self, context):
 *         super().__init__()
 *         self.context = context             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, node):
*/
  __Pyx_INCREF(__pyx_v_context);
  __Pyx_GIVEREF(__pyx_v_context);
  __Pyx_GOTREF(__pyx_v_self->context);
  __Pyx_DECREF(__pyx_v_self->context);
  __pyx_v_self->context = __pyx_v_context;

  /* "Cython/Compiler/Visitor.py":297
 *      - Tracks directives in effect in self.current_directives
 *     """
 *     def __init__(self, context):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.context = context
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":301
 *         self.context = context
 * 
 *     def __call__(self, node):             # <<<<<<<<<<<<<<
 *         from .ModuleNode import ModuleNode
 *         if isinstance(node, ModuleNode):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_node = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 301, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 301, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 301, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 301, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 301, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 301, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_2__call__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_2__call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_ModuleNode = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Compiler/Visitor.py":302
 * 
 *     def __call__(self, node):
 *         from .ModuleNode import ModuleNode             # <<<<<<<<<<<<<<
 *         if isinstance(node, ModuleNode):
 *             self.current_directives = node.directives
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ModuleNode};
    __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_ModuleNode, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler_ModuleNode, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_t_2;
  __Pyx_GOTREF(__pyx_t_1);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ModuleNode};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_1, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_ModuleNode = __pyx_t_4;
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":303
 *     def __call__(self, node):
 *         from .ModuleNode import ModuleNode
 *         if isinstance(node, ModuleNode):             # <<<<<<<<<<<<<<
 *             self.current_directives = node.directives
 *         return super().__call__(node)
*/
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_node, __pyx_v_ModuleNode); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 303, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":304
 *         from .ModuleNode import ModuleNode
 *         if isinstance(node, ModuleNode):
 *             self.current_directives = node.directives             # <<<<<<<<<<<<<<
 *         return super().__call__(node)
 * 
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->current_directives);
    __Pyx_DECREF(__pyx_v_self->current_directives);
    __pyx_v_self->current_directives = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":303
 *     def __call__(self, node):
 *         from .ModuleNode import ModuleNode
 *         if isinstance(node, ModuleNode):             # <<<<<<<<<<<<<<
 *             self.current_directives = node.directives
 *         return super().__call__(node)
*/
  }

  /* "Cython/Compiler/Visitor.py":305
 *         if isinstance(node, ModuleNode):
 *             self.current_directives = node.directives
 *         return super().__call__(node)             # <<<<<<<<<<<<<<
 * 
 *     def visit_CompilerDirectivesNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform), ((PyObject *)__pyx_v_self)};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_t_4 = __pyx_t_6;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_8 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_call, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":301
 *         self.context = context
 * 
 *     def __call__(self, node):             # <<<<<<<<<<<<<<
 *         from .ModuleNode import ModuleNode
 *         if isinstance(node, ModuleNode):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ModuleNode);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":307
 *         return super().__call__(node)
 * 
 *     def visit_CompilerDirectivesNode(self, node):             # <<<<<<<<<<<<<<
 *         old = self.current_directives
 *         self.current_directives = node.directives
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode = {"visit_CompilerDirectivesNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CompilerDirectivesNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_4visit_CompilerDirectivesNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_4visit_CompilerDirectivesNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_old = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CompilerDirectivesNode", 0);

  /* "Cython/Compiler/Visitor.py":308
 * 
 *     def visit_CompilerDirectivesNode(self, node):
 *         old = self.current_directives             # <<<<<<<<<<<<<<
 *         self.current_directives = node.directives
 *         self._process_children(node)
*/
  __pyx_t_1 = __pyx_v_self->current_directives;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_old = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":309
 *     def visit_CompilerDirectivesNode(self, node):
 *         old = self.current_directives
 *         self.current_directives = node.directives             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         self.current_directives = old
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_directives); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->current_directives);
  __Pyx_DECREF(__pyx_v_self->current_directives);
  __pyx_v_self->current_directives = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":310
 *         old = self.current_directives
 *         self.current_directives = node.directives
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         self.current_directives = old
 *         return node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":311
 *         self.current_directives = node.directives
 *         self._process_children(node)
 *         self.current_directives = old             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __Pyx_INCREF(__pyx_v_old);
  __Pyx_GIVEREF(__pyx_v_old);
  __Pyx_GOTREF(__pyx_v_self->current_directives);
  __Pyx_DECREF(__pyx_v_self->current_directives);
  __pyx_v_self->current_directives = __pyx_v_old;

  /* "Cython/Compiler/Visitor.py":312
 *         self._process_children(node)
 *         self.current_directives = old
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_Node(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":307
 *         return super().__call__(node)
 * 
 *     def visit_CompilerDirectivesNode(self, node):             # <<<<<<<<<<<<<<
 *         old = self.current_directives
 *         self.current_directives = node.directives
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.visit_CompilerDirectivesNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_old);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":314
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node = {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_6visit_Node(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_6visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/Visitor.py":315
 * 
 *     def visit_Node(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":316
 *     def visit_Node(self, node):
 *         self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":314
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.CythonTransform.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":22
 * 
 * cdef class CythonTransform(VisitorTransform):
 *     cdef public context             # <<<<<<<<<<<<<<
 *     cdef public current_directives
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->context);
  __pyx_r = __pyx_v_self->context;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->context);
  __Pyx_DECREF(__pyx_v_self->context);
  __pyx_v_self->context = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_7context_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->context);
  __Pyx_DECREF(__pyx_v_self->context);
  __pyx_v_self->context = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":23
 * cdef class CythonTransform(VisitorTransform):
 *     cdef public context
 *     cdef public current_directives             # <<<<<<<<<<<<<<
 * 
 * cdef class ScopeTrackingTransform(CythonTransform):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->current_directives);
  __pyx_r = __pyx_v_self->current_directives;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->current_directives);
  __Pyx_DECREF(__pyx_v_self->current_directives);
  __pyx_v_self->current_directives = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->current_directives);
  __Pyx_DECREF(__pyx_v_self->current_directives);
  __pyx_v_self->current_directives = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":324
 *     #scope_node: the node that owns the current scope
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         self.scope_type = 'module'
 *         self.scope_node = node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode = {"visit_ModuleNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ModuleNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_ModuleNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_ModuleNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ModuleNode", 0);

  /* "Cython/Compiler/Visitor.py":325
 * 
 *     def visit_ModuleNode(self, node):
 *         self.scope_type = 'module'             # <<<<<<<<<<<<<<
 *         self.scope_node = node
 *         self._process_children(node)
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_module);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_module);
  __Pyx_GOTREF(__pyx_v_self->scope_type);
  __Pyx_DECREF(__pyx_v_self->scope_type);
  __pyx_v_self->scope_type = __pyx_mstate_global->__pyx_n_u_module;

  /* "Cython/Compiler/Visitor.py":326
 *     def visit_ModuleNode(self, node):
 *         self.scope_type = 'module'
 *         self.scope_node = node             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/
  __Pyx_INCREF(__pyx_v_node);
  __Pyx_GIVEREF(__pyx_v_node);
  __Pyx_GOTREF(__pyx_v_self->scope_node);
  __Pyx_DECREF(__pyx_v_self->scope_node);
  __pyx_v_self->scope_node = __pyx_v_node;

  /* "Cython/Compiler/Visitor.py":327
 *         self.scope_type = 'module'
 *         self.scope_node = node
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":328
 *         self.scope_node = node
 *         self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_scope(self, node, scope_type):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":324
 *     #scope_node: the node that owns the current scope
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         self.scope_type = 'module'
 *         self.scope_node = node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_ModuleNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":330
 *         return node
 * 
 *     def visit_scope(self, node, scope_type):             # <<<<<<<<<<<<<<
 *         prev = self.scope_type, self.scope_node
 *         self.scope_type = scope_type
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_scope_type) {
  PyObject *__pyx_v_prev = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_scope", 0);

  /* "Cython/Compiler/Visitor.py":331
 * 
 *     def visit_scope(self, node, scope_type):
 *         prev = self.scope_type, self.scope_node             # <<<<<<<<<<<<<<
 *         self.scope_type = scope_type
 *         self.scope_node = node
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->scope_type);
  __Pyx_GIVEREF(__pyx_v_self->scope_type);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->scope_type) != (0)) __PYX_ERR(0, 331, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->scope_node);
  __Pyx_GIVEREF(__pyx_v_self->scope_node);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->scope_node) != (0)) __PYX_ERR(0, 331, __pyx_L1_error);
  __pyx_v_prev = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":332
 *     def visit_scope(self, node, scope_type):
 *         prev = self.scope_type, self.scope_node
 *         self.scope_type = scope_type             # <<<<<<<<<<<<<<
 *         self.scope_node = node
 *         self._process_children(node)
*/
  __Pyx_INCREF(__pyx_v_scope_type);
  __Pyx_GIVEREF(__pyx_v_scope_type);
  __Pyx_GOTREF(__pyx_v_self->scope_type);
  __Pyx_DECREF(__pyx_v_self->scope_type);
  __pyx_v_self->scope_type = __pyx_v_scope_type;

  /* "Cython/Compiler/Visitor.py":333
 *         prev = self.scope_type, self.scope_node
 *         self.scope_type = scope_type
 *         self.scope_node = node             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         self.scope_type, self.scope_node = prev
*/
  __Pyx_INCREF(__pyx_v_node);
  __Pyx_GIVEREF(__pyx_v_node);
  __Pyx_GOTREF(__pyx_v_self->scope_node);
  __Pyx_DECREF(__pyx_v_self->scope_node);
  __pyx_v_self->scope_node = __pyx_v_node;

  /* "Cython/Compiler/Visitor.py":334
 *         self.scope_type = scope_type
 *         self.scope_node = node
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         self.scope_type, self.scope_node = prev
 *         return node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":335
 *         self.scope_node = node
 *         self._process_children(node)
 *         self.scope_type, self.scope_node = prev             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  if (1) {
    PyObject* sequence = __pyx_v_prev;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 335, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->scope_type);
  __Pyx_DECREF(__pyx_v_self->scope_type);
  __pyx_v_self->scope_type = __pyx_t_1;
  __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->scope_node);
  __Pyx_DECREF(__pyx_v_self->scope_node);
  __pyx_v_self->scope_node = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":336
 *         self._process_children(node)
 *         self.scope_type, self.scope_node = prev
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CClassDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":330
 *         return node
 * 
 *     def visit_scope(self, node, scope_type):             # <<<<<<<<<<<<<<
 *         prev = self.scope_type, self.scope_node
 *         self.scope_type = scope_type
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_scope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_prev);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":338
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'cclass')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode = {"visit_CClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CClassDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_2visit_CClassDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_2visit_CClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CClassDefNode", 0);

  /* "Cython/Compiler/Visitor.py":339
 * 
 *     def visit_CClassDefNode(self, node):
 *         return self.visit_scope(node, 'cclass')             # <<<<<<<<<<<<<<
 * 
 *     def visit_PyClassDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->visit_scope(__pyx_v_self, __pyx_v_node, __pyx_mstate_global->__pyx_n_u_cclass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":338
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'cclass')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_CClassDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":341
 *         return self.visit_scope(node, 'cclass')
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'pyclass')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode = {"visit_PyClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_PyClassDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_4visit_PyClassDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_4visit_PyClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_PyClassDefNode", 0);

  /* "Cython/Compiler/Visitor.py":342
 * 
 *     def visit_PyClassDefNode(self, node):
 *         return self.visit_scope(node, 'pyclass')             # <<<<<<<<<<<<<<
 * 
 *     def visit_FuncDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->visit_scope(__pyx_v_self, __pyx_v_node, __pyx_mstate_global->__pyx_n_u_pyclass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":341
 *         return self.visit_scope(node, 'cclass')
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'pyclass')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_PyClassDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":344
 *         return self.visit_scope(node, 'pyclass')
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'function')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode = {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_FuncDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_6visit_FuncDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_6visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_FuncDefNode", 0);

  /* "Cython/Compiler/Visitor.py":345
 * 
 *     def visit_FuncDefNode(self, node):
 *         return self.visit_scope(node, 'function')             # <<<<<<<<<<<<<<
 * 
 *     def visit_CStructOrUnionDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->visit_scope(__pyx_v_self, __pyx_v_node, __pyx_mstate_global->__pyx_n_u_function); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":344
 *         return self.visit_scope(node, 'pyclass')
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'function')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_FuncDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":347
 *         return self.visit_scope(node, 'function')
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'struct')
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode = {"visit_CStructOrUnionDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CStructOrUnionDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_8visit_CStructOrUnionDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_8visit_CStructOrUnionDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CStructOrUnionDefNode", 0);

  /* "Cython/Compiler/Visitor.py":348
 * 
 *     def visit_CStructOrUnionDefNode(self, node):
 *         return self.visit_scope(node, 'struct')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->visit_scope(__pyx_v_self, __pyx_v_node, __pyx_mstate_global->__pyx_n_u_struct); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":347
 *         return self.visit_scope(node, 'function')
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'struct')
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.ScopeTrackingTransform.visit_CStructOrUnionDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":26
 * 
 * cdef class ScopeTrackingTransform(CythonTransform):
 *     cdef public scope_type             # <<<<<<<<<<<<<<
 *     cdef public scope_node
 *     cdef visit_scope(self, node, scope_type)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->scope_type);
  __pyx_r = __pyx_v_self->scope_type;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->scope_type);
  __Pyx_DECREF(__pyx_v_self->scope_type);
  __pyx_v_self->scope_type = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->scope_type);
  __Pyx_DECREF(__pyx_v_self->scope_type);
  __pyx_v_self->scope_type = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":27
 * cdef class ScopeTrackingTransform(CythonTransform):
 *     cdef public scope_type
 *     cdef public scope_node             # <<<<<<<<<<<<<<
 *     cdef visit_scope(self, node, scope_type)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->scope_node);
  __pyx_r = __pyx_v_self->scope_node;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->scope_node);
  __Pyx_DECREF(__pyx_v_self->scope_node);
  __pyx_v_self->scope_node = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->scope_node);
  __Pyx_DECREF(__pyx_v_self->scope_node);
  __pyx_v_self->scope_node = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":355
 *     This transformation keeps a stack of the environments.
 *     """
 *     def __call__(self, root):             # <<<<<<<<<<<<<<
 *         self.env_stack = []
 *         self.enter_scope(root, root.scope)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_root = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_root,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 355, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 355, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 355, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 355, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 355, __pyx_L3_error)
    }
    __pyx_v_root = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 355, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform___call__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), __pyx_v_root);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform___call__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_root) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Compiler/Visitor.py":356
 *     """
 *     def __call__(self, root):
 *         self.env_stack = []             # <<<<<<<<<<<<<<
 *         self.enter_scope(root, root.scope)
 *         return super().__call__(root)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->env_stack);
  __Pyx_DECREF(__pyx_v_self->env_stack);
  __pyx_v_self->env_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":357
 *     def __call__(self, root):
 *         self.env_stack = []
 *         self.enter_scope(root, root.scope)             # <<<<<<<<<<<<<<
 *         return super().__call__(root)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_root, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_root, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":358
 *         self.env_stack = []
 *         self.enter_scope(root, root.scope)
 *         return super().__call__(root)             # <<<<<<<<<<<<<<
 * 
 *     def current_env(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform), ((PyObject *)__pyx_v_self)};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_3 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_root};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_call, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":355
 *     This transformation keeps a stack of the environments.
 *     """
 *     def __call__(self, root):             # <<<<<<<<<<<<<<
 *         self.env_stack = []
 *         self.enter_scope(root, root.scope)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":360
 *         return super().__call__(root)
 * 
 *     def current_env(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][1]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env = {"current_env", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("current_env (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_2current_env(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_2current_env(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("current_env", 0);

  /* "Cython/Compiler/Visitor.py":361
 * 
 *     def current_env(self):
 *         return self.env_stack[-1][1]             # <<<<<<<<<<<<<<
 * 
 *     def current_scope_node(self):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->env_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 361, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->env_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":360
 *         return super().__call__(root)
 * 
 *     def current_env(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][1]
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.current_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":363
 *         return self.env_stack[-1][1]
 * 
 *     def current_scope_node(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][0]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node = {"current_scope_node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("current_scope_node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_4current_scope_node(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_4current_scope_node(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("current_scope_node", 0);

  /* "Cython/Compiler/Visitor.py":364
 * 
 *     def current_scope_node(self):
 *         return self.env_stack[-1][0]             # <<<<<<<<<<<<<<
 * 
 *     def global_scope(self):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->env_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 364, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->env_stack, -1L, long, 1, __Pyx_PyLong_From_long, 1, 1, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":363
 *         return self.env_stack[-1][1]
 * 
 *     def current_scope_node(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][0]
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.current_scope_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":366
 *         return self.env_stack[-1][0]
 * 
 *     def global_scope(self):             # <<<<<<<<<<<<<<
 *         return self.current_env().global_scope()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope = {"global_scope", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("global_scope (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_6global_scope(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_6global_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("global_scope", 0);

  /* "Cython/Compiler/Visitor.py":367
 * 
 *     def global_scope(self):
 *         return self.current_env().global_scope()             # <<<<<<<<<<<<<<
 * 
 *     def enter_scope(self, node, scope):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_current_env, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_global_scope, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":366
 *         return self.env_stack[-1][0]
 * 
 *     def global_scope(self):             # <<<<<<<<<<<<<<
 *         return self.current_env().global_scope()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.global_scope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":369
 *         return self.current_env().global_scope()
 * 
 *     def enter_scope(self, node, scope):             # <<<<<<<<<<<<<<
 *         self.env_stack.append((node, scope))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope = {"enter_scope", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_scope = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enter_scope (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_scope,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 369, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 369, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 369, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "enter_scope", 0) < (0)) __PYX_ERR(0, 369, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("enter_scope", 1, 2, 2, i); __PYX_ERR(0, 369, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 369, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 369, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
    __pyx_v_scope = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enter_scope", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 369, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.enter_scope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_8enter_scope(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), __pyx_v_node, __pyx_v_scope);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_8enter_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_scope) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enter_scope", 0);

  /* "Cython/Compiler/Visitor.py":370
 * 
 *     def enter_scope(self, node, scope):
 *         self.env_stack.append((node, scope))             # <<<<<<<<<<<<<<
 * 
 *     def exit_scope(self):
*/
  if (unlikely(__pyx_v_self->env_stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 370, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_node);
  __Pyx_GIVEREF(__pyx_v_node);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_node) != (0)) __PYX_ERR(0, 370, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_scope);
  __Pyx_GIVEREF(__pyx_v_scope);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_scope) != (0)) __PYX_ERR(0, 370, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyList_Append(__pyx_v_self->env_stack, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":369
 *         return self.current_env().global_scope()
 * 
 *     def enter_scope(self, node, scope):             # <<<<<<<<<<<<<<
 *         self.env_stack.append((node, scope))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.enter_scope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":372
 *         self.env_stack.append((node, scope))
 * 
 *     def exit_scope(self):             # <<<<<<<<<<<<<<
 *         self.env_stack.pop()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope = {"exit_scope", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope, METH_NOARGS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exit_scope (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_10exit_scope(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_10exit_scope(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exit_scope", 0);

  /* "Cython/Compiler/Visitor.py":373
 * 
 *     def exit_scope(self):
 *         self.env_stack.pop()             # <<<<<<<<<<<<<<
 * 
 *     def visit_FuncDefNode(self, node):
*/
  if (unlikely(__pyx_v_self->env_stack == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(0, 373, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Pop(__pyx_v_self->env_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":372
 *         self.env_stack.append((node, scope))
 * 
 *     def exit_scope(self):             # <<<<<<<<<<<<<<
 *         self.env_stack.pop()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.exit_scope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":375
 *         self.env_stack.pop()
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visit_func_outer_attrs(node)
 *         self.enter_scope(node, node.local_scope)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode = {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_FuncDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_12visit_FuncDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_12visit_FuncDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_FuncDefNode", 0);

  /* "Cython/Compiler/Visitor.py":376
 * 
 *     def visit_FuncDefNode(self, node):
 *         self.visit_func_outer_attrs(node)             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.local_scope)
 *         self.visitchildren(node, attrs=None, exclude=node.outer_attrs)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visit_func_outer_attrs, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":377
 *     def visit_FuncDefNode(self, node):
 *         self.visit_func_outer_attrs(node)
 *         self.enter_scope(node, node.local_scope)             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, attrs=None, exclude=node.outer_attrs)
 *         self.exit_scope()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_local_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_node, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":378
 *         self.visit_func_outer_attrs(node)
 *         self.enter_scope(node, node.local_scope)
 *         self.visitchildren(node, attrs=None, exclude=node.outer_attrs)             # <<<<<<<<<<<<<<
 *         self.exit_scope()
 *         return node
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_outer_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5.__pyx_n = 2;
  __pyx_t_5.attrs = Py_None;
  __pyx_t_5.exclude = __pyx_t_1;
  __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":379
 *         self.enter_scope(node, node.local_scope)
 *         self.visitchildren(node, attrs=None, exclude=node.outer_attrs)
 *         self.exit_scope()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "Cython/Compiler/Visitor.py":380
 *         self.visitchildren(node, attrs=None, exclude=node.outer_attrs)
 *         self.exit_scope()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_func_outer_attrs(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":375
 *         self.env_stack.pop()
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visit_func_outer_attrs(node)
 *         self.enter_scope(node, node.local_scope)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_FuncDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":382
 *         return node
 * 
 *     def visit_func_outer_attrs(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs = {"visit_func_outer_attrs", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_func_outer_attrs (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_14visit_func_outer_attrs(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_14visit_func_outer_attrs(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_func_outer_attrs", 0);

  /* "Cython/Compiler/Visitor.py":383
 * 
 *     def visit_func_outer_attrs(self, node):
 *         self.visitchildren(node, attrs=node.outer_attrs)             # <<<<<<<<<<<<<<
 * 
 *     def visit_GeneratorBodyDefNode(self, node):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_outer_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.attrs = __pyx_t_1;
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":382
 *         return node
 * 
 *     def visit_func_outer_attrs(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_func_outer_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":385
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode = {"visit_GeneratorBodyDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_GeneratorBodyDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_16visit_GeneratorBodyDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_16visit_GeneratorBodyDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_GeneratorBodyDefNode", 0);

  /* "Cython/Compiler/Visitor.py":386
 * 
 *     def visit_GeneratorBodyDefNode(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":387
 *     def visit_GeneratorBodyDefNode(self, node):
 *         self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ClassDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":385
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_GeneratorBodyDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":389
 *         return node
 * 
 *     def visit_ClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode = {"visit_ClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ClassDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_18visit_ClassDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_18visit_ClassDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ClassDefNode", 0);

  /* "Cython/Compiler/Visitor.py":390
 * 
 *     def visit_ClassDefNode(self, node):
 *         self.enter_scope(node, node.scope)             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         self.exit_scope()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_node, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":391
 *     def visit_ClassDefNode(self, node):
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         self.exit_scope()
 *         return node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":392
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
 *         self.exit_scope()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":393
 *         self._process_children(node)
 *         self.exit_scope()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CStructOrUnionDefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":389
 *         return node
 * 
 *     def visit_ClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_ClassDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":395
 *         return node
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode = {"visit_CStructOrUnionDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CStructOrUnionDefNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_20visit_CStructOrUnionDefNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_20visit_CStructOrUnionDefNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CStructOrUnionDefNode", 0);

  /* "Cython/Compiler/Visitor.py":396
 * 
 *     def visit_CStructOrUnionDefNode(self, node):
 *         self.enter_scope(node, node.scope)             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         self.exit_scope()
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_node, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":397
 *     def visit_CStructOrUnionDefNode(self, node):
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         self.exit_scope()
 *         return node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":398
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
 *         self.exit_scope()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":399
 *         self._process_children(node)
 *         self.exit_scope()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ScopedExprNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":395
 *         return node
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_CStructOrUnionDefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":401
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.enter_scope(node, node.expr_scope)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode = {"visit_ScopedExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ScopedExprNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_22visit_ScopedExprNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_22visit_ScopedExprNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ScopedExprNode", 0);

  /* "Cython/Compiler/Visitor.py":402
 * 
 *     def visit_ScopedExprNode(self, node):
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.enter_scope(node, node.expr_scope)
 *             self._process_children(node)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":403
 *     def visit_ScopedExprNode(self, node):
 *         if node.expr_scope:
 *             self.enter_scope(node, node.expr_scope)             # <<<<<<<<<<<<<<
 *             self._process_children(node)
 *             self.exit_scope()
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expr_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_node, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":404
 *         if node.expr_scope:
 *             self.enter_scope(node, node.expr_scope)
 *             self._process_children(node)             # <<<<<<<<<<<<<<
 *             self.exit_scope()
 *         else:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":405
 *             self.enter_scope(node, node.expr_scope)
 *             self._process_children(node)
 *             self.exit_scope()             # <<<<<<<<<<<<<<
 *         else:
 *             self._process_children(node)
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":402
 * 
 *     def visit_ScopedExprNode(self, node):
 *         if node.expr_scope:             # <<<<<<<<<<<<<<
 *             self.enter_scope(node, node.expr_scope)
 *             self._process_children(node)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":407
 *             self.exit_scope()
 *         else:
 *             self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":408
 *         else:
 *             self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CArgDeclNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":401
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.enter_scope(node, node.expr_scope)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_ScopedExprNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":410
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         # default arguments are evaluated in the outer scope
 *         if node.default:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode = {"visit_CArgDeclNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CArgDeclNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_24visit_CArgDeclNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_24visit_CArgDeclNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_attr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CArgDeclNode", 0);

  /* "Cython/Compiler/Visitor.py":412
 *     def visit_CArgDeclNode(self, node):
 *         # default arguments are evaluated in the outer scope
 *         if node.default:             # <<<<<<<<<<<<<<
 *             attrs = [attr for attr in node.child_attrs if attr != 'default']
 *             self._process_children(node, attrs)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_default); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":413
 *         # default arguments are evaluated in the outer scope
 *         if node.default:
 *             attrs = [attr for attr in node.child_attrs if attr != 'default']             # <<<<<<<<<<<<<<
 *             self._process_children(node, attrs)
 *             self.enter_scope(node, self.current_env().outer_scope)
*/
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_child_attrs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 413, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 413, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 413, __pyx_L6_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 413, __pyx_L6_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_5;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 413, __pyx_L6_error)
              #endif
              if (__pyx_t_5 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5));
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5);
            #endif
            ++__pyx_t_5;
          }
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 413, __pyx_L6_error)
        } else {
          __pyx_t_3 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 413, __pyx_L6_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_attr, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_8genexpr1__pyx_v_attr, __pyx_mstate_global->__pyx_n_u_default, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 413, __pyx_L6_error)
        if (__pyx_t_2) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr1__pyx_v_attr))) __PYX_ERR(0, 413, __pyx_L6_error)
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_attr); __pyx_8genexpr1__pyx_v_attr = 0;
      goto __pyx_L11_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_attr); __pyx_8genexpr1__pyx_v_attr = 0;
      goto __pyx_L1_error;
      __pyx_L11_exit_scope:;
    } /* exit inner scope */
    __pyx_v_attrs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":414
 *         if node.default:
 *             attrs = [attr for attr in node.child_attrs if attr != 'default']
 *             self._process_children(node, attrs)             # <<<<<<<<<<<<<<
 *             self.enter_scope(node, self.current_env().outer_scope)
 *             self.visitchildren(node, ('default',))
*/
    __pyx_t_7.__pyx_n = 1;
    __pyx_t_7.attrs = __pyx_v_attrs;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":415
 *             attrs = [attr for attr in node.child_attrs if attr != 'default']
 *             self._process_children(node, attrs)
 *             self.enter_scope(node, self.current_env().outer_scope)             # <<<<<<<<<<<<<<
 *             self.visitchildren(node, ('default',))
 *             self.exit_scope()
*/
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_8 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_current_env, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_outer_scope); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_node, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":416
 *             self._process_children(node, attrs)
 *             self.enter_scope(node, self.current_env().outer_scope)
 *             self.visitchildren(node, ('default',))             # <<<<<<<<<<<<<<
 *             self.exit_scope()
 *         else:
*/
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.attrs = __pyx_mstate_global->__pyx_tuple[0];
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, 0, &__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":417
 *             self.enter_scope(node, self.current_env().outer_scope)
 *             self.visitchildren(node, ('default',))
 *             self.exit_scope()             # <<<<<<<<<<<<<<
 *         else:
 *             self._process_children(node)
*/
    __pyx_t_8 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":412
 *     def visit_CArgDeclNode(self, node):
 *         # default arguments are evaluated in the outer scope
 *         if node.default:             # <<<<<<<<<<<<<<
 *             attrs = [attr for attr in node.child_attrs if attr != 'default']
 *             self._process_children(node, attrs)
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":419
 *             self.exit_scope()
 *         else:
 *             self._process_children(node)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":420
 *         else:
 *             self._process_children(node)
 *         return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":410
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         # default arguments are evaluated in the outer scope
 *         if node.default:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.visit_CArgDeclNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_attr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":31
 * 
 * cdef class EnvTransform(CythonTransform):
 *     cdef public list env_stack             # <<<<<<<<<<<<<<
 * 
 * cdef class MethodDispatcherTransform(EnvTransform):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->env_stack);
  __pyx_r = __pyx_v_self->env_stack;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 31, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->env_stack);
  __Pyx_DECREF(__pyx_v_self->env_stack);
  __pyx_v_self->env_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.EnvTransform.env_stack.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->env_stack);
  __Pyx_DECREF(__pyx_v_self->env_stack);
  __pyx_v_self->env_stack = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":433
 *     and by ordering the "child_attrs" of nodes appropriately.
 *     """
 *     def __init__(self, *args):             # <<<<<<<<<<<<<<
 *         super().__init__(*args)
 *         self._replacements = {}
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 433, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 433, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, used_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 433, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 1, i); __PYX_ERR(0, 433, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 433, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 433, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin___init__(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":434
 *     """
 *     def __init__(self, *args):
 *         super().__init__(*args)             # <<<<<<<<<<<<<<
 *         self._replacements = {}
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = __Pyx_CyFunction_GetClassObj(__pyx_self);
  if (!__pyx_t_3) { PyErr_SetString(PyExc_RuntimeError, "super(): empty __class__ cell"); __PYX_ERR(0, 434, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_v_args, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":435
 *     def __init__(self, *args):
 *         super().__init__(*args)
 *         self._replacements = {}             # <<<<<<<<<<<<<<
 * 
 *     def visit_CloneNode(self, node):
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements, __pyx_t_1) < (0)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":433
 *     and by ordering the "child_attrs" of nodes appropriately.
 *     """
 *     def __init__(self, *args):             # <<<<<<<<<<<<<<
 *         super().__init__(*args)
 *         self._replacements = {}
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":437
 *         self._replacements = {}
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         arg = node.arg
 *         if arg not in self._replacements:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_3visit_CloneNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_3visit_CloneNode = {"visit_CloneNode", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_3visit_CloneNode, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_3visit_CloneNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CloneNode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 437, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 437, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 437, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visit_CloneNode", 0) < (0)) __PYX_ERR(0, 437, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visit_CloneNode", 1, 2, 2, i); __PYX_ERR(0, 437, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 437, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 437, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visit_CloneNode", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 437, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.visit_CloneNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_2visit_CloneNode(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_2visit_CloneNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CloneNode", 0);

  /* "Cython/Compiler/Visitor.py":438
 * 
 *     def visit_CloneNode(self, node):
 *         arg = node.arg             # <<<<<<<<<<<<<<
 *         if arg not in self._replacements:
 *             self.visitchildren(arg)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_arg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":439
 *     def visit_CloneNode(self, node):
 *         arg = node.arg
 *         if arg not in self._replacements:             # <<<<<<<<<<<<<<
 *             self.visitchildren(arg)
 *         node.arg = self._replacements.get(arg, arg)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_arg, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":440
 *         arg = node.arg
 *         if arg not in self._replacements:
 *             self.visitchildren(arg)             # <<<<<<<<<<<<<<
 *         node.arg = self._replacements.get(arg, arg)
 *         return node
*/
    __pyx_t_3 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_arg};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":439
 *     def visit_CloneNode(self, node):
 *         arg = node.arg
 *         if arg not in self._replacements:             # <<<<<<<<<<<<<<
 *             self.visitchildren(arg)
 *         node.arg = self._replacements.get(arg, arg)
*/
  }

  /* "Cython/Compiler/Visitor.py":441
 *         if arg not in self._replacements:
 *             self.visitchildren(arg)
 *         node.arg = self._replacements.get(arg, arg)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_arg, __pyx_v_arg};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg, __pyx_t_1) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":442
 *             self.visitchildren(arg)
 *         node.arg = self._replacements.get(arg, arg)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_ResultRefNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":437
 *         self._replacements = {}
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         arg = node.arg
 *         if arg not in self._replacements:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.visit_CloneNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":444
 *         return node
 * 
 *     def visit_ResultRefNode(self, node):             # <<<<<<<<<<<<<<
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_5visit_ResultRefNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_5visit_ResultRefNode = {"visit_ResultRefNode", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_5visit_ResultRefNode, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_5visit_ResultRefNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_ResultRefNode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 444, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 444, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 444, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visit_ResultRefNode", 0) < (0)) __PYX_ERR(0, 444, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visit_ResultRefNode", 1, 2, 2, i); __PYX_ERR(0, 444, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 444, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 444, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visit_ResultRefNode", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 444, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.visit_ResultRefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_4visit_ResultRefNode(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_4visit_ResultRefNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_ResultRefNode", 0);

  /* "Cython/Compiler/Visitor.py":445
 * 
 *     def visit_ResultRefNode(self, node):
 *         expr = node.expression             # <<<<<<<<<<<<<<
 *         if expr is None or expr not in self._replacements:
 *             self.visitchildren(node)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expression); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":446
 *     def visit_ResultRefNode(self, node):
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:             # <<<<<<<<<<<<<<
 *             self.visitchildren(node)
 *             expr = node.expression
*/
  __pyx_t_3 = (__pyx_v_expr == Py_None);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_expr, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":447
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:
 *             self.visitchildren(node)             # <<<<<<<<<<<<<<
 *             expr = node.expression
 *         if expr is not None:
*/
    __pyx_t_4 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_node};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":448
 *         if expr is None or expr not in self._replacements:
 *             self.visitchildren(node)
 *             expr = node.expression             # <<<<<<<<<<<<<<
 *         if expr is not None:
 *             node.expression = self._replacements.get(expr, expr)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expression); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":446
 *     def visit_ResultRefNode(self, node):
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:             # <<<<<<<<<<<<<<
 *             self.visitchildren(node)
 *             expr = node.expression
*/
  }

  /* "Cython/Compiler/Visitor.py":449
 *             self.visitchildren(node)
 *             expr = node.expression
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             node.expression = self._replacements.get(expr, expr)
 *         return node
*/
  __pyx_t_2 = (__pyx_v_expr != Py_None);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":450
 *             expr = node.expression
 *         if expr is not None:
 *             node.expression = self._replacements.get(expr, expr)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_expr, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_expression, __pyx_t_1) < (0)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":449
 *             self.visitchildren(node)
 *             expr = node.expression
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             node.expression = self._replacements.get(expr, expr)
 *         return node
*/
  }

  /* "Cython/Compiler/Visitor.py":451
 *         if expr is not None:
 *             node.expression = self._replacements.get(expr, expr)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def replace(self, node, replacement):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":444
 *         return node
 * 
 *     def visit_ResultRefNode(self, node):             # <<<<<<<<<<<<<<
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.visit_ResultRefNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":453
 *         return node
 * 
 *     def replace(self, node, replacement):             # <<<<<<<<<<<<<<
 *         self._replacements[node] = replacement
 *         return replacement
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_7replace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_7replace = {"replace", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_7replace, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_7replace(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_replacement = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replace (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_replacement,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 453, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 453, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "replace", 0) < (0)) __PYX_ERR(0, 453, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("replace", 1, 3, 3, i); __PYX_ERR(0, 453, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 453, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 453, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 453, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
    __pyx_v_replacement = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("replace", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.replace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_6replace(__pyx_self, __pyx_v_self, __pyx_v_node, __pyx_v_replacement);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_6replace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_replacement) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replace", 0);

  /* "Cython/Compiler/Visitor.py":454
 * 
 *     def replace(self, node, replacement):
 *         self._replacements[node] = replacement             # <<<<<<<<<<<<<<
 *         return replacement
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_replacements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_node, __pyx_v_replacement) < 0))) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":455
 *     def replace(self, node, replacement):
 *         self._replacements[node] = replacement
 *         return replacement             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_replacement);
  __pyx_r = __pyx_v_replacement;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":453
 *         return node
 * 
 *     def replace(self, node, replacement):             # <<<<<<<<<<<<<<
 *         self._replacements[node] = replacement
 *         return replacement
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeRefCleanupMixin.replace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":503
 *     """
 *     # only visit call nodes and Python operations
 *     def visit_GeneralCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode = {"visit_GeneralCallNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_GeneralCallNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_visit_GeneralCallNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_visit_GeneralCallNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_function = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_v_keyword_args = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_GeneralCallNode", 0);

  /* "Cython/Compiler/Visitor.py":504
 *     # only visit call nodes and Python operations
 *     def visit_GeneralCallNode(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         function = node.function
 *         if not function.type.is_pyobject:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":505
 *     def visit_GeneralCallNode(self, node):
 *         self._process_children(node)
 *         function = node.function             # <<<<<<<<<<<<<<
 *         if not function.type.is_pyobject:
 *             return node
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_function); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_function = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":506
 *         self._process_children(node)
 *         function = node.function
 *         if not function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             return node
 *         arg_tuple = node.positional_args
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "Cython/Compiler/Visitor.py":507
 *         function = node.function
 *         if not function.type.is_pyobject:
 *             return node             # <<<<<<<<<<<<<<
 *         arg_tuple = node.positional_args
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":506
 *         self._process_children(node)
 *         function = node.function
 *         if not function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             return node
 *         arg_tuple = node.positional_args
*/
  }

  /* "Cython/Compiler/Visitor.py":508
 *         if not function.type.is_pyobject:
 *             return node
 *         arg_tuple = node.positional_args             # <<<<<<<<<<<<<<
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *             return node
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_positional_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_arg_tuple = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":509
 *             return node
 *         arg_tuple = node.positional_args
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *             return node
 *         keyword_args = node.keyword_args
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TupleNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_arg_tuple, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (!__pyx_t_4);
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":510
 *         arg_tuple = node.positional_args
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *             return node             # <<<<<<<<<<<<<<
 *         keyword_args = node.keyword_args
 *         if keyword_args and not isinstance(keyword_args, ExprNodes.DictNode):
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":509
 *             return node
 *         arg_tuple = node.positional_args
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *             return node
 *         keyword_args = node.keyword_args
*/
  }

  /* "Cython/Compiler/Visitor.py":511
 *         if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *             return node
 *         keyword_args = node.keyword_args             # <<<<<<<<<<<<<<
 *         if keyword_args and not isinstance(keyword_args, ExprNodes.DictNode):
 *             # can't handle **kwargs
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_keyword_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_keyword_args = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":512
 *             return node
 *         keyword_args = node.keyword_args
 *         if keyword_args and not isinstance(keyword_args, ExprNodes.DictNode):             # <<<<<<<<<<<<<<
 *             # can't handle **kwargs
 *             return node
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_keyword_args); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 512, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_DictNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_keyword_args, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  __pyx_t_3 = __pyx_t_5;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":514
 *         if keyword_args and not isinstance(keyword_args, ExprNodes.DictNode):
 *             # can't handle **kwargs
 *             return node             # <<<<<<<<<<<<<<
 *         args = arg_tuple.args
 *         return self._dispatch_to_handler(node, function, args, keyword_args)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":512
 *             return node
 *         keyword_args = node.keyword_args
 *         if keyword_args and not isinstance(keyword_args, ExprNodes.DictNode):             # <<<<<<<<<<<<<<
 *             # can't handle **kwargs
 *             return node
*/
  }

  /* "Cython/Compiler/Visitor.py":515
 *             # can't handle **kwargs
 *             return node
 *         args = arg_tuple.args             # <<<<<<<<<<<<<<
 *         return self._dispatch_to_handler(node, function, args, keyword_args)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_tuple, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_args = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":516
 *             return node
 *         args = arg_tuple.args
 *         return self._dispatch_to_handler(node, function, args, keyword_args)             # <<<<<<<<<<<<<<
 * 
 *     def visit_SimpleCallNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_handler(__pyx_v_self, __pyx_v_node, __pyx_v_function, __pyx_v_args, __pyx_v_keyword_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":503
 *     """
 *     # only visit call nodes and Python operations
 *     def visit_GeneralCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform.visit_GeneralCallNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_function);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XDECREF(__pyx_v_keyword_args);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":518
 *         return self._dispatch_to_handler(node, function, args, keyword_args)
 * 
 *     def visit_SimpleCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode = {"visit_SimpleCallNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_SimpleCallNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_2visit_SimpleCallNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_2visit_SimpleCallNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_function = NULL;
  PyObject *__pyx_v_arg_tuple = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_SimpleCallNode", 0);

  /* "Cython/Compiler/Visitor.py":519
 * 
 *     def visit_SimpleCallNode(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         function = node.function
 *         if function.type.is_pyobject:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":520
 *     def visit_SimpleCallNode(self, node):
 *         self._process_children(node)
 *         function = node.function             # <<<<<<<<<<<<<<
 *         if function.type.is_pyobject:
 *             arg_tuple = node.arg_tuple
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_function); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_function = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":521
 *         self._process_children(node)
 *         function = node.function
 *         if function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             arg_tuple = node.arg_tuple
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":522
 *         function = node.function
 *         if function.type.is_pyobject:
 *             arg_tuple = node.arg_tuple             # <<<<<<<<<<<<<<
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *                 return node
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg_tuple); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_arg_tuple = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":523
 *         if function.type.is_pyobject:
 *             arg_tuple = node.arg_tuple
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *                 return node
 *             args = arg_tuple.args
*/
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TupleNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_arg_tuple, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 523, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = (!__pyx_t_3);
    if (__pyx_t_4) {

      /* "Cython/Compiler/Visitor.py":524
 *             arg_tuple = node.arg_tuple
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *                 return node             # <<<<<<<<<<<<<<
 *             args = arg_tuple.args
 *         else:
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":523
 *         if function.type.is_pyobject:
 *             arg_tuple = node.arg_tuple
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):             # <<<<<<<<<<<<<<
 *                 return node
 *             args = arg_tuple.args
*/
    }

    /* "Cython/Compiler/Visitor.py":525
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):
 *                 return node
 *             args = arg_tuple.args             # <<<<<<<<<<<<<<
 *         else:
 *             args = node.args
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_tuple, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_args = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":521
 *         self._process_children(node)
 *         function = node.function
 *         if function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *             arg_tuple = node.arg_tuple
 *             if not isinstance(arg_tuple, ExprNodes.TupleNode):
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":527
 *             args = arg_tuple.args
 *         else:
 *             args = node.args             # <<<<<<<<<<<<<<
 *         return self._dispatch_to_handler(node, function, args, None)
 * 
*/
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_args = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":528
 *         else:
 *             args = node.args
 *         return self._dispatch_to_handler(node, function, args, None)             # <<<<<<<<<<<<<<
 * 
 *     def visit_PrimaryCmpNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_handler(__pyx_v_self, __pyx_v_node, __pyx_v_function, __pyx_v_args, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":518
 *         return self._dispatch_to_handler(node, function, args, keyword_args)
 * 
 *     def visit_SimpleCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform.visit_SimpleCallNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_function);
  __Pyx_XDECREF(__pyx_v_arg_tuple);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":530
 *         return self._dispatch_to_handler(node, function, args, None)
 * 
 *     def visit_PrimaryCmpNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.cascade:
 *             # not currently handled below
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode = {"visit_PrimaryCmpNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_PrimaryCmpNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_4visit_PrimaryCmpNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_4visit_PrimaryCmpNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_PrimaryCmpNode", 0);

  /* "Cython/Compiler/Visitor.py":531
 * 
 *     def visit_PrimaryCmpNode(self, node):
 *         if node.cascade:             # <<<<<<<<<<<<<<
 *             # not currently handled below
 *             self._process_children(node)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_cascade); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":533
 *         if node.cascade:
 *             # not currently handled below
 *             self._process_children(node)             # <<<<<<<<<<<<<<
 *             return node
 *         return self._visit_binop_node(node)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":534
 *             # not currently handled below
 *             self._process_children(node)
 *             return node             # <<<<<<<<<<<<<<
 *         return self._visit_binop_node(node)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":531
 * 
 *     def visit_PrimaryCmpNode(self, node):
 *         if node.cascade:             # <<<<<<<<<<<<<<
 *             # not currently handled below
 *             self._process_children(node)
*/
  }

  /* "Cython/Compiler/Visitor.py":535
 *             self._process_children(node)
 *             return node
 *         return self._visit_binop_node(node)             # <<<<<<<<<<<<<<
 * 
 *     def visit_BinopNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_visit_binop_node(__pyx_v_self, __pyx_v_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":530
 *         return self._dispatch_to_handler(node, function, args, None)
 * 
 *     def visit_PrimaryCmpNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.cascade:
 *             # not currently handled below
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform.visit_PrimaryCmpNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":537
 *         return self._visit_binop_node(node)
 * 
 *     def visit_BinopNode(self, node):             # <<<<<<<<<<<<<<
 *         return self._visit_binop_node(node)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode = {"visit_BinopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_BinopNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_6visit_BinopNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_6visit_BinopNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_BinopNode", 0);

  /* "Cython/Compiler/Visitor.py":538
 * 
 *     def visit_BinopNode(self, node):
 *         return self._visit_binop_node(node)             # <<<<<<<<<<<<<<
 * 
 *     def _visit_binop_node(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_visit_binop_node(__pyx_v_self, __pyx_v_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":537
 *         return self._visit_binop_node(node)
 * 
 *     def visit_BinopNode(self, node):             # <<<<<<<<<<<<<<
 *         return self._visit_binop_node(node)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform.visit_BinopNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":540
 *         return self._visit_binop_node(node)
 * 
 *     def _visit_binop_node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         # FIXME: could special case 'not_in'
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__visit_binop_node(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_special_method_name = NULL;
  PyObject *__pyx_v_operand1 = NULL;
  PyObject *__pyx_v_operand2 = NULL;
  PyObject *__pyx_v_obj_type = NULL;
  PyObject *__pyx_v_type_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_visit_binop_node", 0);
  __Pyx_INCREF(__pyx_v_node);

  /* "Cython/Compiler/Visitor.py":541
 * 
 *     def _visit_binop_node(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         # FIXME: could special case 'not_in'
 *         special_method_name = find_special_method_for_binary_operator(node.operator)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":543
 *         self._process_children(node)
 *         # FIXME: could special case 'not_in'
 *         special_method_name = find_special_method_for_binary_operator(node.operator)             # <<<<<<<<<<<<<<
 *         if special_method_name:
 *             operand1, operand2 = node.operand1, node.operand2
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_find_special_method_for_binary_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operator); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_special_method_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":544
 *         # FIXME: could special case 'not_in'
 *         special_method_name = find_special_method_for_binary_operator(node.operator)
 *         if special_method_name:             # <<<<<<<<<<<<<<
 *             operand1, operand2 = node.operand1, node.operand2
 *             if special_method_name == '__contains__':
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_special_method_name); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 544, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Visitor.py":545
 *         special_method_name = find_special_method_for_binary_operator(node.operator)
 *         if special_method_name:
 *             operand1, operand2 = node.operand1, node.operand2             # <<<<<<<<<<<<<<
 *             if special_method_name == '__contains__':
 *                 operand1, operand2 = operand2, operand1
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_operand1 = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v_operand2 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":546
 *         if special_method_name:
 *             operand1, operand2 = node.operand1, node.operand2
 *             if special_method_name == '__contains__':             # <<<<<<<<<<<<<<
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_special_method_name, __pyx_mstate_global->__pyx_n_u_contains, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 546, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Visitor.py":547
 *             operand1, operand2 = node.operand1, node.operand2
 *             if special_method_name == '__contains__':
 *                 operand1, operand2 = operand2, operand1             # <<<<<<<<<<<<<<
 *             elif special_method_name == '__div__':
 *                 if Future.division in self.current_env().context.future_directives:
*/
      __pyx_t_7 = __pyx_v_operand2;
      __pyx_t_8 = __pyx_v_operand1;
      __pyx_v_operand1 = __pyx_t_7;
      __pyx_t_7 = 0;
      __pyx_v_operand2 = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "Cython/Compiler/Visitor.py":546
 *         if special_method_name:
 *             operand1, operand2 = node.operand1, node.operand2
 *             if special_method_name == '__contains__':             # <<<<<<<<<<<<<<
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":548
 *             if special_method_name == '__contains__':
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':             # <<<<<<<<<<<<<<
 *                 if Future.division in self.current_env().context.future_directives:
 *                     special_method_name = '__truediv__'
*/
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_special_method_name, __pyx_mstate_global->__pyx_n_u_div, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 548, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "Cython/Compiler/Visitor.py":549
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':
 *                 if Future.division in self.current_env().context.future_directives:             # <<<<<<<<<<<<<<
 *                     special_method_name = '__truediv__'
 *             obj_type = operand1.type
*/
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Future); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_division); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_4 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_current_env, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 549, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_context); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_future_directives); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 549, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {

        /* "Cython/Compiler/Visitor.py":550
 *             elif special_method_name == '__div__':
 *                 if Future.division in self.current_env().context.future_directives:
 *                     special_method_name = '__truediv__'             # <<<<<<<<<<<<<<
 *             obj_type = operand1.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_truediv);
        __Pyx_DECREF_SET(__pyx_v_special_method_name, __pyx_mstate_global->__pyx_n_u_truediv);

        /* "Cython/Compiler/Visitor.py":549
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':
 *                 if Future.division in self.current_env().context.future_directives:             # <<<<<<<<<<<<<<
 *                     special_method_name = '__truediv__'
 *             obj_type = operand1.type
*/
      }

      /* "Cython/Compiler/Visitor.py":548
 *             if special_method_name == '__contains__':
 *                 operand1, operand2 = operand2, operand1
 *             elif special_method_name == '__div__':             # <<<<<<<<<<<<<<
 *                 if Future.division in self.current_env().context.future_directives:
 *                     special_method_name = '__truediv__'
*/
    }
    __pyx_L4:;

    /* "Cython/Compiler/Visitor.py":551
 *                 if Future.division in self.current_env().context.future_directives:
 *                     special_method_name = '__truediv__'
 *             obj_type = operand1.type             # <<<<<<<<<<<<<<
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 type_name = obj_type.name
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_operand1, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_obj_type = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":552
 *                     special_method_name = '__truediv__'
 *             obj_type = operand1.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 type_name = obj_type.name
 *             else:
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_builtin_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_6 = __pyx_t_9;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_exception_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = (!__pyx_t_9);
    __pyx_t_6 = __pyx_t_10;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Visitor.py":553
 *             obj_type = operand1.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 type_name = obj_type.name             # <<<<<<<<<<<<<<
 *             else:
 *                 type_name = "object"  # safety measure
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_type_name = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":552
 *                     special_method_name = '__truediv__'
 *             obj_type = operand1.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 type_name = obj_type.name
 *             else:
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Visitor.py":555
 *                 type_name = obj_type.name
 *             else:
 *                 type_name = "object"  # safety measure             # <<<<<<<<<<<<<<
 *             node = self._dispatch_to_method_handler(
 *                 special_method_name, None, False, type_name,
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_object);
      __pyx_v_type_name = __pyx_mstate_global->__pyx_n_u_object;
    }
    __pyx_L6:;

    /* "Cython/Compiler/Visitor.py":558
 *             node = self._dispatch_to_method_handler(
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand1, operand2], None)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_operand1);
    __Pyx_GIVEREF(__pyx_v_operand1);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_operand1) != (0)) __PYX_ERR(0, 558, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_operand2);
    __Pyx_GIVEREF(__pyx_v_operand2);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_v_operand2) != (0)) __PYX_ERR(0, 558, __pyx_L1_error);

    /* "Cython/Compiler/Visitor.py":556
 *             else:
 *                 type_name = "object"  # safety measure
 *             node = self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand1, operand2], None)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_method_handler(__pyx_v_self, __pyx_v_special_method_name, Py_None, Py_False, __pyx_v_type_name, __pyx_v_node, Py_None, __pyx_t_3, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":544
 *         # FIXME: could special case 'not_in'
 *         special_method_name = find_special_method_for_binary_operator(node.operator)
 *         if special_method_name:             # <<<<<<<<<<<<<<
 *             operand1, operand2 = node.operand1, node.operand2
 *             if special_method_name == '__contains__':
*/
  }

  /* "Cython/Compiler/Visitor.py":559
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand1, operand2], None)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_UnopNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":540
 *         return self._visit_binop_node(node)
 * 
 *     def _visit_binop_node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         # FIXME: could special case 'not_in'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._visit_binop_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_special_method_name);
  __Pyx_XDECREF(__pyx_v_operand1);
  __Pyx_XDECREF(__pyx_v_operand2);
  __Pyx_XDECREF(__pyx_v_obj_type);
  __Pyx_XDECREF(__pyx_v_type_name);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":561
 *         return node
 * 
 *     def visit_UnopNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode = {"visit_UnopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_UnopNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_8visit_UnopNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_8visit_UnopNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_special_method_name = NULL;
  PyObject *__pyx_v_operand = NULL;
  PyObject *__pyx_v_obj_type = NULL;
  PyObject *__pyx_v_type_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_UnopNode", 0);
  __Pyx_INCREF(__pyx_v_node);

  /* "Cython/Compiler/Visitor.py":562
 * 
 *     def visit_UnopNode(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
 *         if special_method_name:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":563
 *     def visit_UnopNode(self, node):
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)             # <<<<<<<<<<<<<<
 *         if special_method_name:
 *             operand = node.operand
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_find_special_method_for_unary_op); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operator); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_special_method_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":564
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
 *         if special_method_name:             # <<<<<<<<<<<<<<
 *             operand = node.operand
 *             obj_type = operand.type
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_special_method_name); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 564, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "Cython/Compiler/Visitor.py":565
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
 *         if special_method_name:
 *             operand = node.operand             # <<<<<<<<<<<<<<
 *             obj_type = operand.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_operand); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_operand = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":566
 *         if special_method_name:
 *             operand = node.operand
 *             obj_type = operand.type             # <<<<<<<<<<<<<<
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 type_name = obj_type.name
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_operand, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_obj_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":567
 *             operand = node.operand
 *             obj_type = operand.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 type_name = obj_type.name
 *             else:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_builtin_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_exception_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = (!__pyx_t_7);
    __pyx_t_6 = __pyx_t_8;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_6) {

      /* "Cython/Compiler/Visitor.py":568
 *             obj_type = operand.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 type_name = obj_type.name             # <<<<<<<<<<<<<<
 *             else:
 *                 type_name = "object"  # safety measure
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_type_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Visitor.py":567
 *             operand = node.operand
 *             obj_type = operand.type
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 type_name = obj_type.name
 *             else:
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":570
 *                 type_name = obj_type.name
 *             else:
 *                 type_name = "object"  # safety measure             # <<<<<<<<<<<<<<
 *             node = self._dispatch_to_method_handler(
 *                 special_method_name, None, False, type_name,
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_object);
      __pyx_v_type_name = __pyx_mstate_global->__pyx_n_u_object;
    }
    __pyx_L4:;

    /* "Cython/Compiler/Visitor.py":573
 *             node = self._dispatch_to_method_handler(
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand], None)             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_operand);
    __Pyx_GIVEREF(__pyx_v_operand);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_operand) != (0)) __PYX_ERR(0, 573, __pyx_L1_error);

    /* "Cython/Compiler/Visitor.py":571
 *             else:
 *                 type_name = "object"  # safety measure
 *             node = self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand], None)
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_method_handler(__pyx_v_self, __pyx_v_special_method_name, Py_None, Py_False, __pyx_v_type_name, __pyx_v_node, Py_None, __pyx_t_1, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_node, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":564
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
 *         if special_method_name:             # <<<<<<<<<<<<<<
 *             operand = node.operand
 *             obj_type = operand.type
*/
  }

  /* "Cython/Compiler/Visitor.py":574
 *                 special_method_name, None, False, type_name,
 *                 node, None, [operand], None)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     ### dispatch to specific handlers
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":561
 *         return node
 * 
 *     def visit_UnopNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform.visit_UnopNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_special_method_name);
  __Pyx_XDECREF(__pyx_v_operand);
  __Pyx_XDECREF(__pyx_v_obj_type);
  __Pyx_XDECREF(__pyx_v_type_name);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":578
 *     ### dispatch to specific handlers
 * 
 *     def _find_handler(self, match_name, has_kwargs):             # <<<<<<<<<<<<<<
 *         if not match_name.isascii():
 *             # Classes with unicode names won't have specific handlers.
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__find_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_match_name, int __pyx_v_has_kwargs) {
  PyObject *__pyx_v_call_type = NULL;
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6[4];
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_find_handler", 0);

  /* "Cython/Compiler/Visitor.py":579
 * 
 *     def _find_handler(self, match_name, has_kwargs):
 *         if not match_name.isascii():             # <<<<<<<<<<<<<<
 *             # Classes with unicode names won't have specific handlers.
 *             return None
*/
  __pyx_t_2 = __pyx_v_match_name;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_isascii, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":581
 *         if not match_name.isascii():
 *             # Classes with unicode names won't have specific handlers.
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         call_type = 'general' if has_kwargs else 'simple'
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":579
 * 
 *     def _find_handler(self, match_name, has_kwargs):
 *         if not match_name.isascii():             # <<<<<<<<<<<<<<
 *             # Classes with unicode names won't have specific handlers.
 *             return None
*/
  }

  /* "Cython/Compiler/Visitor.py":583
 *             return None
 * 
 *         call_type = 'general' if has_kwargs else 'simple'             # <<<<<<<<<<<<<<
 *         handler = getattr(self, f'_handle_{call_type}_{match_name}', None)
 *         if handler is None:
*/
  if (__pyx_v_has_kwargs) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_general);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_general;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_simple);
    __pyx_t_1 = __pyx_mstate_global->__pyx_n_u_simple;
  }
  __pyx_v_call_type = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":584
 * 
 *         call_type = 'general' if has_kwargs else 'simple'
 *         handler = getattr(self, f'_handle_{call_type}_{match_name}', None)             # <<<<<<<<<<<<<<
 *         if handler is None:
 *             handler = getattr(self, f'_handle_any_{match_name}', None)
*/
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_call_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_match_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6[0] = __pyx_mstate_global->__pyx_n_u_handle;
  __pyx_t_6[1] = __pyx_t_1;
  __pyx_t_6[2] = __pyx_mstate_global->__pyx_n_u__2;
  __pyx_t_6[3] = __pyx_t_2;
  __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_6, 4, 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_t_7, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_handler = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":585
 *         call_type = 'general' if has_kwargs else 'simple'
 *         handler = getattr(self, f'_handle_{call_type}_{match_name}', None)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             handler = getattr(self, f'_handle_any_{match_name}', None)
 *         return handler
*/
  __pyx_t_5 = (__pyx_v_handler == Py_None);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":586
 *         handler = getattr(self, f'_handle_{call_type}_{match_name}', None)
 *         if handler is None:
 *             handler = getattr(self, f'_handle_any_{match_name}', None)             # <<<<<<<<<<<<<<
 *         return handler
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_match_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_n_u_handle_any, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_t_7, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_handler, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":585
 *         call_type = 'general' if has_kwargs else 'simple'
 *         handler = getattr(self, f'_handle_{call_type}_{match_name}', None)
 *         if handler is None:             # <<<<<<<<<<<<<<
 *             handler = getattr(self, f'_handle_any_{match_name}', None)
 *         return handler
*/
  }

  /* "Cython/Compiler/Visitor.py":587
 *         if handler is None:
 *             handler = getattr(self, f'_handle_any_{match_name}', None)
 *         return handler             # <<<<<<<<<<<<<<
 * 
 *     def _delegate_to_assigned_value(self, node, function, arg_list, kwargs):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_handler);
  __pyx_r = __pyx_v_handler;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":578
 *     ### dispatch to specific handlers
 * 
 *     def _find_handler(self, match_name, has_kwargs):             # <<<<<<<<<<<<<<
 *         if not match_name.isascii():
 *             # Classes with unicode names won't have specific handlers.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._find_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_call_type);
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":589
 *         return handler
 * 
 *     def _delegate_to_assigned_value(self, node, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         assignment = function.cf_state[0]
 *         value = assignment.rhs
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__delegate_to_assigned_value(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_assignment = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_delegate_to_assigned_value", 0);

  /* "Cython/Compiler/Visitor.py":590
 * 
 *     def _delegate_to_assigned_value(self, node, function, arg_list, kwargs):
 *         assignment = function.cf_state[0]             # <<<<<<<<<<<<<<
 *         value = assignment.rhs
 *         if value.is_name:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_assignment = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":591
 *     def _delegate_to_assigned_value(self, node, function, arg_list, kwargs):
 *         assignment = function.cf_state[0]
 *         value = assignment.rhs             # <<<<<<<<<<<<<<
 *         if value.is_name:
 *             if not value.entry or len(value.entry.cf_assignments) > 1:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_assignment, __pyx_mstate_global->__pyx_n_u_rhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_value = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":592
 *         assignment = function.cf_state[0]
 *         value = assignment.rhs
 *         if value.is_name:             # <<<<<<<<<<<<<<
 *             if not value.entry or len(value.entry.cf_assignments) > 1:
 *                 # the variable might have been reassigned => play safe
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":593
 *         value = assignment.rhs
 *         if value.is_name:
 *             if not value.entry or len(value.entry.cf_assignments) > 1:             # <<<<<<<<<<<<<<
 *                 # the variable might have been reassigned => play safe
 *                 return node
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = (!__pyx_t_4);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_cf_assignments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_6 > 1);
    __pyx_t_3 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":595
 *             if not value.entry or len(value.entry.cf_assignments) > 1:
 *                 # the variable might have been reassigned => play safe
 *                 return node             # <<<<<<<<<<<<<<
 *         elif value.is_attribute and value.obj.is_name:
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":593
 *         value = assignment.rhs
 *         if value.is_name:
 *             if not value.entry or len(value.entry.cf_assignments) > 1:             # <<<<<<<<<<<<<<
 *                 # the variable might have been reassigned => play safe
 *                 return node
*/
    }

    /* "Cython/Compiler/Visitor.py":592
 *         assignment = function.cf_state[0]
 *         value = assignment.rhs
 *         if value.is_name:             # <<<<<<<<<<<<<<
 *             if not value.entry or len(value.entry.cf_assignments) > 1:
 *                 # the variable might have been reassigned => play safe
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":596
 *                 # the variable might have been reassigned => play safe
 *                 return node
 *         elif value.is_attribute and value.obj.is_name:             # <<<<<<<<<<<<<<
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:
 *                 # the underlying variable might have been reassigned => play safe
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_is_attribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_5;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":597
 *                 return node
 *         elif value.is_attribute and value.obj.is_name:
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:             # <<<<<<<<<<<<<<
 *                 # the underlying variable might have been reassigned => play safe
 *                 return node
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_obj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = (!__pyx_t_5);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_cf_assignments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_t_6 > 1);
    __pyx_t_3 = __pyx_t_4;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":599
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:
 *                 # the underlying variable might have been reassigned => play safe
 *                 return node             # <<<<<<<<<<<<<<
 *         else:
 *             return node
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":597
 *                 return node
 *         elif value.is_attribute and value.obj.is_name:
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:             # <<<<<<<<<<<<<<
 *                 # the underlying variable might have been reassigned => play safe
 *                 return node
*/
    }

    /* "Cython/Compiler/Visitor.py":596
 *                 # the variable might have been reassigned => play safe
 *                 return node
 *         elif value.is_attribute and value.obj.is_name:             # <<<<<<<<<<<<<<
 *             if not value.obj.entry or len(value.obj.entry.cf_assignments) > 1:
 *                 # the underlying variable might have been reassigned => play safe
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":601
 *                 return node
 *         else:
 *             return node             # <<<<<<<<<<<<<<
 *         return self._dispatch_to_handler(
 *             node, value, arg_list, kwargs)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":602
 *         else:
 *             return node
 *         return self._dispatch_to_handler(             # <<<<<<<<<<<<<<
 *             node, value, arg_list, kwargs)
 * 
*/
  __Pyx_XDECREF(__pyx_r);

  /* "Cython/Compiler/Visitor.py":603
 *             return node
 *         return self._dispatch_to_handler(
 *             node, value, arg_list, kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _dispatch_to_handler(self, node, function, arg_list, kwargs):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_handler(__pyx_v_self, __pyx_v_node, __pyx_v_value, __pyx_v_arg_list, __pyx_v_kwargs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":589
 *         return handler
 * 
 *     def _delegate_to_assigned_value(self, node, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         assignment = function.cf_state[0]
 *         value = assignment.rhs
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._delegate_to_assigned_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_assignment);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":605
 *             node, value, arg_list, kwargs)
 * 
 *     def _dispatch_to_handler(self, node, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         if function.is_name:
 *             # we only consider functions that are either builtin
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_v_is_builtin = NULL;
  PyObject *__pyx_v_function_handler = NULL;
  PyObject *__pyx_v_attr_name = NULL;
  PyObject *__pyx_v_self_arg = NULL;
  PyObject *__pyx_v_obj_type = NULL;
  int __pyx_v_is_unbound_method;
  PyObject *__pyx_v_type_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dispatch_to_handler", 0);
  __Pyx_INCREF(__pyx_v_arg_list);

  /* "Cython/Compiler/Visitor.py":606
 * 
 *     def _dispatch_to_handler(self, node, function, arg_list, kwargs):
 *         if function.is_name:             # <<<<<<<<<<<<<<
 *             # we only consider functions that are either builtin
 *             # Python functions or builtins that were already replaced
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":610
 *             # Python functions or builtins that were already replaced
 *             # into a C function call (defined in the builtin scope)
 *             if not function.entry:             # <<<<<<<<<<<<<<
 *                 return node
 *             entry = function.entry
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (!__pyx_t_2);
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":611
 *             # into a C function call (defined in the builtin scope)
 *             if not function.entry:
 *                 return node             # <<<<<<<<<<<<<<
 *             entry = function.entry
 *             is_builtin = (
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":610
 *             # Python functions or builtins that were already replaced
 *             # into a C function call (defined in the builtin scope)
 *             if not function.entry:             # <<<<<<<<<<<<<<
 *                 return node
 *             entry = function.entry
*/
    }

    /* "Cython/Compiler/Visitor.py":612
 *             if not function.entry:
 *                 return node
 *             entry = function.entry             # <<<<<<<<<<<<<<
 *             is_builtin = (
 *                 entry.is_builtin or
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_entry = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":614
 *             entry = function.entry
 *             is_builtin = (
 *                 entry.is_builtin or             # <<<<<<<<<<<<<<
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))
 *             if not is_builtin:
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_builtin); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 614, __pyx_L1_error)
    if (!__pyx_t_3) {
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_1 = __pyx_t_4;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L5_bool_binop_done;
    }

    /* "Cython/Compiler/Visitor.py":615
 *             is_builtin = (
 *                 entry.is_builtin or
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))             # <<<<<<<<<<<<<<
 *             if not is_builtin:
 *                 if function.cf_state and function.cf_state.is_single:
*/
    __pyx_t_9 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_current_env, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __pyx_t_7 = __pyx_t_8;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_builtin_scope, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_5 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lookup_here, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_3 = (__pyx_v_entry == __pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_L5_bool_binop_done:;
    __pyx_v_is_builtin = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":616
 *                 entry.is_builtin or
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))
 *             if not is_builtin:             # <<<<<<<<<<<<<<
 *                 if function.cf_state and function.cf_state.is_single:
 *                     # we know the value of the variable
*/
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_is_builtin); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
    __pyx_t_2 = (!__pyx_t_3);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":617
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))
 *             if not is_builtin:
 *                 if function.cf_state and function.cf_state.is_single:             # <<<<<<<<<<<<<<
 *                     # we know the value of the variable
 *                     # => see if it's usable instead
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_cf_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_single); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 617, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __pyx_t_3;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Visitor.py":620
 *                     # we know the value of the variable
 *                     # => see if it's usable instead
 *                     return self._delegate_to_assigned_value(             # <<<<<<<<<<<<<<
 *                         node, function, arg_list, kwargs)
 *                 if (arg_list and entry.is_cmethod and entry.scope and
*/
        __Pyx_XDECREF(__pyx_r);

        /* "Cython/Compiler/Visitor.py":621
 *                     # => see if it's usable instead
 *                     return self._delegate_to_assigned_value(
 *                         node, function, arg_list, kwargs)             # <<<<<<<<<<<<<<
 *                 if (arg_list and entry.is_cmethod and entry.scope and
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
*/
        __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_delegate_to_assigned_value(__pyx_v_self, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 620, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L0;

        /* "Cython/Compiler/Visitor.py":617
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))
 *             if not is_builtin:
 *                 if function.cf_state and function.cf_state.is_single:             # <<<<<<<<<<<<<<
 *                     # we know the value of the variable
 *                     # => see if it's usable instead
*/
      }

      /* "Cython/Compiler/Visitor.py":622
 *                     return self._delegate_to_assigned_value(
 *                         node, function, arg_list, kwargs)
 *                 if (arg_list and entry.is_cmethod and entry.scope and             # <<<<<<<<<<<<<<
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
 *                     if entry.scope.parent_type is arg_list[0].type:
*/
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_arg_list); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 622, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_cmethod); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L12_bool_binop_done;
      }

      /* "Cython/Compiler/Visitor.py":623
 *                         node, function, arg_list, kwargs)
 *                 if (arg_list and entry.is_cmethod and entry.scope and
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):             # <<<<<<<<<<<<<<
 *                     if entry.scope.parent_type is arg_list[0].type:
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_parent_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_builtin_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_parent_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_exception_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = (!__pyx_t_3);
      __pyx_t_2 = __pyx_t_11;
      __pyx_L12_bool_binop_done:;

      /* "Cython/Compiler/Visitor.py":622
 *                     return self._delegate_to_assigned_value(
 *                         node, function, arg_list, kwargs)
 *                 if (arg_list and entry.is_cmethod and entry.scope and             # <<<<<<<<<<<<<<
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
 *                     if entry.scope.parent_type is arg_list[0].type:
*/
      if (__pyx_t_2) {

        /* "Cython/Compiler/Visitor.py":624
 *                 if (arg_list and entry.is_cmethod and entry.scope and
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
 *                     if entry.scope.parent_type is arg_list[0].type:             # <<<<<<<<<<<<<<
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
 *                         return self._dispatch_to_method_handler(
*/
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_parent_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_arg_list, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = (__pyx_t_1 == __pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_2) {

          /* "Cython/Compiler/Visitor.py":626
 *                     if entry.scope.parent_type is arg_list[0].type:
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
 *                         return self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                             entry.name, self_arg=None, is_unbound_method=True,
 *                             type_name=entry.scope.parent_type.name,
*/
          __Pyx_XDECREF(__pyx_r);

          /* "Cython/Compiler/Visitor.py":627
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
 *                         return self._dispatch_to_method_handler(
 *                             entry.name, self_arg=None, is_unbound_method=True,             # <<<<<<<<<<<<<<
 *                             type_name=entry.scope.parent_type.name,
 *                             node=node, function=function, arg_list=arg_list, kwargs=kwargs)
*/
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 627, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);

          /* "Cython/Compiler/Visitor.py":628
 *                         return self._dispatch_to_method_handler(
 *                             entry.name, self_arg=None, is_unbound_method=True,
 *                             type_name=entry.scope.parent_type.name,             # <<<<<<<<<<<<<<
 *                             node=node, function=function, arg_list=arg_list, kwargs=kwargs)
 *                 return node
*/
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_parent_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 628, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "Cython/Compiler/Visitor.py":626
 *                     if entry.scope.parent_type is arg_list[0].type:
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
 *                         return self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                             entry.name, self_arg=None, is_unbound_method=True,
 *                             type_name=entry.scope.parent_type.name,
*/
          __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_method_handler(__pyx_v_self, __pyx_t_6, Py_None, Py_True, __pyx_t_1, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 626, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L0;

          /* "Cython/Compiler/Visitor.py":624
 *                 if (arg_list and entry.is_cmethod and entry.scope and
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
 *                     if entry.scope.parent_type is arg_list[0].type:             # <<<<<<<<<<<<<<
 *                         # Optimised (unbound) method of a builtin type => try to "de-optimise".
 *                         return self._dispatch_to_method_handler(
*/
        }

        /* "Cython/Compiler/Visitor.py":622
 *                     return self._delegate_to_assigned_value(
 *                         node, function, arg_list, kwargs)
 *                 if (arg_list and entry.is_cmethod and entry.scope and             # <<<<<<<<<<<<<<
 *                         entry.scope.parent_type.is_builtin_type and not entry.scope.parent_type.is_exception_type):
 *                     if entry.scope.parent_type is arg_list[0].type:
*/
      }

      /* "Cython/Compiler/Visitor.py":630
 *                             type_name=entry.scope.parent_type.name,
 *                             node=node, function=function, arg_list=arg_list, kwargs=kwargs)
 *                 return node             # <<<<<<<<<<<<<<
 *             function_handler = self._find_handler(
 *                 f"function_{function.name}", kwargs)
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":616
 *                 entry.is_builtin or
 *                 entry is self.current_env().builtin_scope().lookup_here(function.name))
 *             if not is_builtin:             # <<<<<<<<<<<<<<
 *                 if function.cf_state and function.cf_state.is_single:
 *                     # we know the value of the variable
*/
    }

    /* "Cython/Compiler/Visitor.py":632
 *                 return node
 *             function_handler = self._find_handler(
 *                 f"function_{function.name}", kwargs)             # <<<<<<<<<<<<<<
 *             if function_handler is None:
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_n_u_function_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 632, __pyx_L1_error)

    /* "Cython/Compiler/Visitor.py":631
 *                             node=node, function=function, arg_list=arg_list, kwargs=kwargs)
 *                 return node
 *             function_handler = self._find_handler(             # <<<<<<<<<<<<<<
 *                 f"function_{function.name}", kwargs)
 *             if function_handler is None:
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_find_handler(__pyx_v_self, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_function_handler = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":633
 *             function_handler = self._find_handler(
 *                 f"function_{function.name}", kwargs)
 *             if function_handler is None:             # <<<<<<<<<<<<<<
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
 *             if kwargs:
*/
    __pyx_t_2 = (__pyx_v_function_handler == Py_None);
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":634
 *                 f"function_{function.name}", kwargs)
 *             if function_handler is None:
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)             # <<<<<<<<<<<<<<
 *             if kwargs:
 *                 return function_handler(node, function, arg_list, kwargs)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = 0;
      {
        PyObject *__pyx_callargs[6] = {__pyx_t_4, __pyx_v_node, __pyx_t_6, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_function, __pyx_callargs+__pyx_t_10, (6-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 634, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":633
 *             function_handler = self._find_handler(
 *                 f"function_{function.name}", kwargs)
 *             if function_handler is None:             # <<<<<<<<<<<<<<
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
 *             if kwargs:
*/
    }

    /* "Cython/Compiler/Visitor.py":635
 *             if function_handler is None:
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
 *             if kwargs:             # <<<<<<<<<<<<<<
 *                 return function_handler(node, function, arg_list, kwargs)
 *             else:
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":636
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
 *             if kwargs:
 *                 return function_handler(node, function, arg_list, kwargs)             # <<<<<<<<<<<<<<
 *             else:
 *                 return function_handler(node, function, arg_list)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_function_handler);
      __pyx_t_4 = __pyx_v_function_handler; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_10, (5-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 636, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":635
 *             if function_handler is None:
 *                 return self._handle_function(node, function.name, function, arg_list, kwargs)
 *             if kwargs:             # <<<<<<<<<<<<<<
 *                 return function_handler(node, function, arg_list, kwargs)
 *             else:
*/
    }

    /* "Cython/Compiler/Visitor.py":638
 *                 return function_handler(node, function, arg_list, kwargs)
 *             else:
 *                 return function_handler(node, function, arg_list)             # <<<<<<<<<<<<<<
 *         elif function.is_attribute:
 *             attr_name = function.attribute
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_function_handler);
      __pyx_t_6 = __pyx_v_function_handler; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_10, (4-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "Cython/Compiler/Visitor.py":606
 * 
 *     def _dispatch_to_handler(self, node, function, arg_list, kwargs):
 *         if function.is_name:             # <<<<<<<<<<<<<<
 *             # we only consider functions that are either builtin
 *             # Python functions or builtins that were already replaced
*/
  }

  /* "Cython/Compiler/Visitor.py":639
 *             else:
 *                 return function_handler(node, function, arg_list)
 *         elif function.is_attribute:             # <<<<<<<<<<<<<<
 *             attr_name = function.attribute
 *             if function.type.is_pyobject:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_is_attribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":640
 *                 return function_handler(node, function, arg_list)
 *         elif function.is_attribute:
 *             attr_name = function.attribute             # <<<<<<<<<<<<<<
 *             if function.type.is_pyobject:
 *                 self_arg = function.obj
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_attribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_attr_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":641
 *         elif function.is_attribute:
 *             attr_name = function.attribute
 *             if function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *                 self_arg = function.obj
 *             elif node.self and function.entry:
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 641, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":642
 *             attr_name = function.attribute
 *             if function.type.is_pyobject:
 *                 self_arg = function.obj             # <<<<<<<<<<<<<<
 *             elif node.self and function.entry:
 *                 entry = function.entry.as_variable
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_obj); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_self_arg = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "Cython/Compiler/Visitor.py":641
 *         elif function.is_attribute:
 *             attr_name = function.attribute
 *             if function.type.is_pyobject:             # <<<<<<<<<<<<<<
 *                 self_arg = function.obj
 *             elif node.self and function.entry:
*/
      goto __pyx_L20;
    }

    /* "Cython/Compiler/Visitor.py":643
 *             if function.type.is_pyobject:
 *                 self_arg = function.obj
 *             elif node.self and function.entry:             # <<<<<<<<<<<<<<
 *                 entry = function.entry.as_variable
 *                 if not entry or not entry.is_builtin:
*/
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_11) {
    } else {
      __pyx_t_2 = __pyx_t_11;
      goto __pyx_L21_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __pyx_t_11;
    __pyx_L21_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":644
 *                 self_arg = function.obj
 *             elif node.self and function.entry:
 *                 entry = function.entry.as_variable             # <<<<<<<<<<<<<<
 *                 if not entry or not entry.is_builtin:
 *                     return node
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_function, __pyx_mstate_global->__pyx_n_u_entry); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_as_variable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_entry = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Visitor.py":645
 *             elif node.self and function.entry:
 *                 entry = function.entry.as_variable
 *                 if not entry or not entry.is_builtin:             # <<<<<<<<<<<<<<
 *                     return node
 *                 # C implementation of a Python builtin method - see if we find further matches
*/
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_entry); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 645, __pyx_L1_error)
      __pyx_t_3 = (!__pyx_t_11);
      if (!__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_entry, __pyx_mstate_global->__pyx_n_u_is_builtin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = (!__pyx_t_3);
      __pyx_t_2 = __pyx_t_11;
      __pyx_L24_bool_binop_done:;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Visitor.py":646
 *                 entry = function.entry.as_variable
 *                 if not entry or not entry.is_builtin:
 *                     return node             # <<<<<<<<<<<<<<
 *                 # C implementation of a Python builtin method - see if we find further matches
 *                 self_arg = node.self
*/
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_node);
        __pyx_r = __pyx_v_node;
        goto __pyx_L0;

        /* "Cython/Compiler/Visitor.py":645
 *             elif node.self and function.entry:
 *                 entry = function.entry.as_variable
 *                 if not entry or not entry.is_builtin:             # <<<<<<<<<<<<<<
 *                     return node
 *                 # C implementation of a Python builtin method - see if we find further matches
*/
      }

      /* "Cython/Compiler/Visitor.py":648
 *                     return node
 *                 # C implementation of a Python builtin method - see if we find further matches
 *                 self_arg = node.self             # <<<<<<<<<<<<<<
 *                 arg_list = arg_list[1:]  # drop CloneNode of self argument
 *             else:
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_self_arg = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Visitor.py":649
 *                 # C implementation of a Python builtin method - see if we find further matches
 *                 self_arg = node.self
 *                 arg_list = arg_list[1:]  # drop CloneNode of self argument             # <<<<<<<<<<<<<<
 *             else:
 *                 return node
*/
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_arg_list, 1, 0, NULL, NULL, &__pyx_mstate_global->__pyx_slice[0], 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 649, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_arg_list, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "Cython/Compiler/Visitor.py":643
 *             if function.type.is_pyobject:
 *                 self_arg = function.obj
 *             elif node.self and function.entry:             # <<<<<<<<<<<<<<
 *                 entry = function.entry.as_variable
 *                 if not entry or not entry.is_builtin:
*/
      goto __pyx_L20;
    }

    /* "Cython/Compiler/Visitor.py":651
 *                 arg_list = arg_list[1:]  # drop CloneNode of self argument
 *             else:
 *                 return node             # <<<<<<<<<<<<<<
 *             obj_type = self_arg.type
 *             is_unbound_method = False
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_node);
      __pyx_r = __pyx_v_node;
      goto __pyx_L0;
    }
    __pyx_L20:;

    /* "Cython/Compiler/Visitor.py":652
 *             else:
 *                 return node
 *             obj_type = self_arg.type             # <<<<<<<<<<<<<<
 *             is_unbound_method = False
 *             # Exceptions aren't necessarily exact types so could have unknown methods
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self_arg, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_obj_type = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":653
 *                 return node
 *             obj_type = self_arg.type
 *             is_unbound_method = False             # <<<<<<<<<<<<<<
 *             # Exceptions aren't necessarily exact types so could have unknown methods
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
*/
    __pyx_v_is_unbound_method = 0;

    /* "Cython/Compiler/Visitor.py":655
 *             is_unbound_method = False
 *             # Exceptions aren't necessarily exact types so could have unknown methods
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 if obj_type is Builtin.type_type and self_arg.is_name and arg_list and arg_list[0].type.is_pyobject:
 *                     # calling an unbound method like 'list.append(L,x)'
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_builtin_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_11) {
    } else {
      __pyx_t_2 = __pyx_t_11;
      goto __pyx_L27_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_is_exception_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (!__pyx_t_11);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L27_bool_binop_done:;
    if (__pyx_t_2) {

      /* "Cython/Compiler/Visitor.py":656
 *             # Exceptions aren't necessarily exact types so could have unknown methods
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 if obj_type is Builtin.type_type and self_arg.is_name and arg_list and arg_list[0].type.is_pyobject:             # <<<<<<<<<<<<<<
 *                     # calling an unbound method like 'list.append(L,x)'
 *                     # (ignoring 'type.mro()' here ...)
*/
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Builtin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_type_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = (__pyx_v_obj_type == __pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self_arg, __pyx_mstate_global->__pyx_n_u_is_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_arg_list); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 656, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __pyx_t_2 = __pyx_t_3;
        goto __pyx_L30_bool_binop_done;
      }
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_arg_list, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_pyobject); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 656, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_2 = __pyx_t_3;
      __pyx_L30_bool_binop_done:;
      if (__pyx_t_2) {

        /* "Cython/Compiler/Visitor.py":659
 *                     # calling an unbound method like 'list.append(L,x)'
 *                     # (ignoring 'type.mro()' here ...)
 *                     type_name = self_arg.name             # <<<<<<<<<<<<<<
 *                     self_arg = None
 *                     is_unbound_method = True
*/
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self_arg, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 659, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_type_name = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Visitor.py":660
 *                     # (ignoring 'type.mro()' here ...)
 *                     type_name = self_arg.name
 *                     self_arg = None             # <<<<<<<<<<<<<<
 *                     is_unbound_method = True
 *                 else:
*/
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_self_arg, Py_None);

        /* "Cython/Compiler/Visitor.py":661
 *                     type_name = self_arg.name
 *                     self_arg = None
 *                     is_unbound_method = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     type_name = obj_type.name
*/
        __pyx_v_is_unbound_method = 1;

        /* "Cython/Compiler/Visitor.py":656
 *             # Exceptions aren't necessarily exact types so could have unknown methods
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:
 *                 if obj_type is Builtin.type_type and self_arg.is_name and arg_list and arg_list[0].type.is_pyobject:             # <<<<<<<<<<<<<<
 *                     # calling an unbound method like 'list.append(L,x)'
 *                     # (ignoring 'type.mro()' here ...)
*/
        goto __pyx_L29;
      }

      /* "Cython/Compiler/Visitor.py":663
 *                     is_unbound_method = True
 *                 else:
 *                     type_name = obj_type.name             # <<<<<<<<<<<<<<
 *                 if type_name == 'str':
 *                     # We traditionally used the type name 'unicode' for 'str' dispatch methods.
*/
      /*else*/ {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj_type, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 663, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_type_name = __pyx_t_6;
        __pyx_t_6 = 0;
      }
      __pyx_L29:;

      /* "Cython/Compiler/Visitor.py":664
 *                 else:
 *                     type_name = obj_type.name
 *                 if type_name == 'str':             # <<<<<<<<<<<<<<
 *                     # We traditionally used the type name 'unicode' for 'str' dispatch methods.
 *                     type_name = 'unicode'
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_type_name, __pyx_mstate_global->__pyx_n_u_str, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 664, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "Cython/Compiler/Visitor.py":666
 *                 if type_name == 'str':
 *                     # We traditionally used the type name 'unicode' for 'str' dispatch methods.
 *                     type_name = 'unicode'             # <<<<<<<<<<<<<<
 *             else:
 *                 type_name = "object"  # safety measure
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_unicode);
        __Pyx_DECREF_SET(__pyx_v_type_name, __pyx_mstate_global->__pyx_n_u_unicode);

        /* "Cython/Compiler/Visitor.py":664
 *                 else:
 *                     type_name = obj_type.name
 *                 if type_name == 'str':             # <<<<<<<<<<<<<<
 *                     # We traditionally used the type name 'unicode' for 'str' dispatch methods.
 *                     type_name = 'unicode'
*/
      }

      /* "Cython/Compiler/Visitor.py":655
 *             is_unbound_method = False
 *             # Exceptions aren't necessarily exact types so could have unknown methods
 *             if obj_type.is_builtin_type and not obj_type.is_exception_type:             # <<<<<<<<<<<<<<
 *                 if obj_type is Builtin.type_type and self_arg.is_name and arg_list and arg_list[0].type.is_pyobject:
 *                     # calling an unbound method like 'list.append(L,x)'
*/
      goto __pyx_L26;
    }

    /* "Cython/Compiler/Visitor.py":668
 *                     type_name = 'unicode'
 *             else:
 *                 type_name = "object"  # safety measure             # <<<<<<<<<<<<<<
 *             return self._dispatch_to_method_handler(
 *                 attr_name, self_arg, is_unbound_method, type_name,
*/
    /*else*/ {
      __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_object);
      __pyx_v_type_name = __pyx_mstate_global->__pyx_n_u_object;
    }
    __pyx_L26:;

    /* "Cython/Compiler/Visitor.py":669
 *             else:
 *                 type_name = "object"  # safety measure
 *             return self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                 attr_name, self_arg, is_unbound_method, type_name,
 *                 node, function, arg_list, kwargs)
*/
    __Pyx_XDECREF(__pyx_r);

    /* "Cython/Compiler/Visitor.py":670
 *                 type_name = "object"  # safety measure
 *             return self._dispatch_to_method_handler(
 *                 attr_name, self_arg, is_unbound_method, type_name,             # <<<<<<<<<<<<<<
 *                 node, function, arg_list, kwargs)
 *         else:
*/
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_is_unbound_method); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "Cython/Compiler/Visitor.py":669
 *             else:
 *                 type_name = "object"  # safety measure
 *             return self._dispatch_to_method_handler(             # <<<<<<<<<<<<<<
 *                 attr_name, self_arg, is_unbound_method, type_name,
 *                 node, function, arg_list, kwargs)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_dispatch_to_method_handler(__pyx_v_self, __pyx_v_attr_name, __pyx_v_self_arg, __pyx_t_6, __pyx_v_type_name, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":639
 *             else:
 *                 return function_handler(node, function, arg_list)
 *         elif function.is_attribute:             # <<<<<<<<<<<<<<
 *             attr_name = function.attribute
 *             if function.type.is_pyobject:
*/
  }

  /* "Cython/Compiler/Visitor.py":673
 *                 node, function, arg_list, kwargs)
 *         else:
 *             return node             # <<<<<<<<<<<<<<
 * 
 *     def _dispatch_to_method_handler(self, attr_name, self_arg,
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Visitor.py":605
 *             node, value, arg_list, kwargs)
 * 
 *     def _dispatch_to_handler(self, node, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         if function.is_name:
 *             # we only consider functions that are either builtin
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._dispatch_to_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_is_builtin);
  __Pyx_XDECREF(__pyx_v_function_handler);
  __Pyx_XDECREF(__pyx_v_attr_name);
  __Pyx_XDECREF(__pyx_v_self_arg);
  __Pyx_XDECREF(__pyx_v_obj_type);
  __Pyx_XDECREF(__pyx_v_type_name);
  __Pyx_XDECREF(__pyx_v_arg_list);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":675
 *             return node
 * 
 *     def _dispatch_to_method_handler(self, attr_name, self_arg,             # <<<<<<<<<<<<<<
 *                                     is_unbound_method, type_name,
 *                                     node, function, arg_list, kwargs):
*/

static PyObject *__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_method_handler(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_attr_name, PyObject *__pyx_v_self_arg, PyObject *__pyx_v_is_unbound_method, PyObject *__pyx_v_type_name, PyObject *__pyx_v_node, PyObject *__pyx_v_function, PyObject *__pyx_v_arg_list, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_method_handler = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3[4];
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dispatch_to_method_handler", 0);
  __Pyx_INCREF(__pyx_v_arg_list);

  /* "Cython/Compiler/Visitor.py":679
 *                                     node, function, arg_list, kwargs):
 *         method_handler = self._find_handler(
 *             f"method_{type_name}_{attr_name}", kwargs)             # <<<<<<<<<<<<<<
 *         if method_handler is None:
 *             if (attr_name in TypeSlots.special_method_names
*/
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_type_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_attr_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3[0] = __pyx_mstate_global->__pyx_n_u_method;
  __pyx_t_3[1] = __pyx_t_1;
  __pyx_t_3[2] = __pyx_mstate_global->__pyx_n_u__2;
  __pyx_t_3[3] = __pyx_t_2;
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 679, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":678
 *                                     is_unbound_method, type_name,
 *                                     node, function, arg_list, kwargs):
 *         method_handler = self._find_handler(             # <<<<<<<<<<<<<<
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_find_handler(__pyx_v_self, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_method_handler = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":680
 *         method_handler = self._find_handler(
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:             # <<<<<<<<<<<<<<
 *             if (attr_name in TypeSlots.special_method_names
 *                     or attr_name in ['__new__', '__class__']):
*/
  __pyx_t_5 = (__pyx_v_method_handler == Py_None);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":681
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:
 *             if (attr_name in TypeSlots.special_method_names             # <<<<<<<<<<<<<<
 *                     or attr_name in ['__new__', '__class__']):
 *                 method_handler = self._find_handler(
*/
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TypeSlots); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_special_method_names); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr_name, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }

    /* "Cython/Compiler/Visitor.py":682
 *         if method_handler is None:
 *             if (attr_name in TypeSlots.special_method_names
 *                     or attr_name in ['__new__', '__class__']):             # <<<<<<<<<<<<<<
 *                 method_handler = self._find_handler(
 *                     f"slot{attr_name}", kwargs)
*/
    __Pyx_INCREF(__pyx_v_attr_name);
    __pyx_t_4 = __pyx_v_attr_name;
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_new, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 682, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_class, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 682, __pyx_L1_error)
    __pyx_t_6 = __pyx_t_7;
    __pyx_L7_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __pyx_t_6;
    __pyx_t_5 = __pyx_t_7;
    __pyx_L5_bool_binop_done:;

    /* "Cython/Compiler/Visitor.py":681
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:
 *             if (attr_name in TypeSlots.special_method_names             # <<<<<<<<<<<<<<
 *                     or attr_name in ['__new__', '__class__']):
 *                 method_handler = self._find_handler(
*/
    if (__pyx_t_5) {

      /* "Cython/Compiler/Visitor.py":684
 *                     or attr_name in ['__new__', '__class__']):
 *                 method_handler = self._find_handler(
 *                     f"slot{attr_name}", kwargs)             # <<<<<<<<<<<<<<
 *             if method_handler is None:
 *                 return self._handle_method(
*/
      __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_attr_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_n_u_slot, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 684, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 684, __pyx_L1_error)

      /* "Cython/Compiler/Visitor.py":683
 *             if (attr_name in TypeSlots.special_method_names
 *                     or attr_name in ['__new__', '__class__']):
 *                 method_handler = self._find_handler(             # <<<<<<<<<<<<<<
 *                     f"slot{attr_name}", kwargs)
 *             if method_handler is None:
*/
      __pyx_t_4 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_find_handler(__pyx_v_self, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_method_handler, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":681
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:
 *             if (attr_name in TypeSlots.special_method_names             # <<<<<<<<<<<<<<
 *                     or attr_name in ['__new__', '__class__']):
 *                 method_handler = self._find_handler(
*/
    }

    /* "Cython/Compiler/Visitor.py":685
 *                 method_handler = self._find_handler(
 *                     f"slot{attr_name}", kwargs)
 *             if method_handler is None:             # <<<<<<<<<<<<<<
 *                 return self._handle_method(
 *                     node, type_name, attr_name, function,
*/
    __pyx_t_5 = (__pyx_v_method_handler == Py_None);
    if (__pyx_t_5) {

      /* "Cython/Compiler/Visitor.py":686
 *                     f"slot{attr_name}", kwargs)
 *             if method_handler is None:
 *                 return self._handle_method(             # <<<<<<<<<<<<<<
 *                     node, type_name, attr_name, function,
 *                     arg_list, is_unbound_method, kwargs)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_2);

      /* "Cython/Compiler/Visitor.py":688
 *                 return self._handle_method(
 *                     node, type_name, attr_name, function,
 *                     arg_list, is_unbound_method, kwargs)             # <<<<<<<<<<<<<<
 *         if self_arg is not None:
 *             arg_list = [self_arg] + list(arg_list)
*/
      __pyx_t_8 = 0;
      {
        PyObject *__pyx_callargs[8] = {__pyx_t_2, __pyx_v_node, __pyx_v_type_name, __pyx_v_attr_name, __pyx_v_function, __pyx_v_arg_list, __pyx_v_is_unbound_method, __pyx_v_kwargs};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_handle_method, __pyx_callargs+__pyx_t_8, (8-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "Cython/Compiler/Visitor.py":685
 *                 method_handler = self._find_handler(
 *                     f"slot{attr_name}", kwargs)
 *             if method_handler is None:             # <<<<<<<<<<<<<<
 *                 return self._handle_method(
 *                     node, type_name, attr_name, function,
*/
    }

    /* "Cython/Compiler/Visitor.py":680
 *         method_handler = self._find_handler(
 *             f"method_{type_name}_{attr_name}", kwargs)
 *         if method_handler is None:             # <<<<<<<<<<<<<<
 *             if (attr_name in TypeSlots.special_method_names
 *                     or attr_name in ['__new__', '__class__']):
*/
  }

  /* "Cython/Compiler/Visitor.py":689
 *                     node, type_name, attr_name, function,
 *                     arg_list, is_unbound_method, kwargs)
 *         if self_arg is not None:             # <<<<<<<<<<<<<<
 *             arg_list = [self_arg] + list(arg_list)
 *         if kwargs:
*/
  __pyx_t_5 = (__pyx_v_self_arg != Py_None);
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":690
 *                     arg_list, is_unbound_method, kwargs)
 *         if self_arg is not None:
 *             arg_list = [self_arg] + list(arg_list)             # <<<<<<<<<<<<<<
 *         if kwargs:
 *             result = method_handler(
*/
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self_arg);
    __Pyx_GIVEREF(__pyx_v_self_arg);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self_arg) != (0)) __PYX_ERR(0, 690, __pyx_L1_error);
    __pyx_t_2 = PySequence_List(__pyx_v_arg_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_arg_list, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":689
 *                     node, type_name, attr_name, function,
 *                     arg_list, is_unbound_method, kwargs)
 *         if self_arg is not None:             # <<<<<<<<<<<<<<
 *             arg_list = [self_arg] + list(arg_list)
 *         if kwargs:
*/
  }

  /* "Cython/Compiler/Visitor.py":691
 *         if self_arg is not None:
 *             arg_list = [self_arg] + list(arg_list)
 *         if kwargs:             # <<<<<<<<<<<<<<
 *             result = method_handler(
 *                 node, function, arg_list, is_unbound_method, kwargs)
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 691, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "Cython/Compiler/Visitor.py":692
 *             arg_list = [self_arg] + list(arg_list)
 *         if kwargs:
 *             result = method_handler(             # <<<<<<<<<<<<<<
 *                 node, function, arg_list, is_unbound_method, kwargs)
 *         else:
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_method_handler);
    __pyx_t_4 = __pyx_v_method_handler; 

    /* "Cython/Compiler/Visitor.py":693
 *         if kwargs:
 *             result = method_handler(
 *                 node, function, arg_list, is_unbound_method, kwargs)             # <<<<<<<<<<<<<<
 *         else:
 *             result = method_handler(
*/
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[6] = {__pyx_t_2, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_is_unbound_method, __pyx_v_kwargs};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_8, (6-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "Cython/Compiler/Visitor.py":691
 *         if self_arg is not None:
 *             arg_list = [self_arg] + list(arg_list)
 *         if kwargs:             # <<<<<<<<<<<<<<
 *             result = method_handler(
 *                 node, function, arg_list, is_unbound_method, kwargs)
*/
    goto __pyx_L11;
  }

  /* "Cython/Compiler/Visitor.py":695
 *                 node, function, arg_list, is_unbound_method, kwargs)
 *         else:
 *             result = method_handler(             # <<<<<<<<<<<<<<
 *                 node, function, arg_list, is_unbound_method)
 *         return result
*/
  /*else*/ {
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_method_handler);
    __pyx_t_2 = __pyx_v_method_handler; 

    /* "Cython/Compiler/Visitor.py":696
 *         else:
 *             result = method_handler(
 *                 node, function, arg_list, is_unbound_method)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_node, __pyx_v_function, __pyx_v_arg_list, __pyx_v_is_unbound_method};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_8, (5-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L11:;

  /* "Cython/Compiler/Visitor.py":697
 *             result = method_handler(
 *                 node, function, arg_list, is_unbound_method)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def _handle_function(self, node, function_name, function, arg_list, kwargs):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":675
 *             return node
 * 
 *     def _dispatch_to_method_handler(self, attr_name, self_arg,             # <<<<<<<<<<<<<<
 *                                     is_unbound_method, type_name,
 *                                     node, function, arg_list, kwargs):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._dispatch_to_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_method_handler);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_arg_list);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":699
 *         return result
 * 
 *     def _handle_function(self, node, function_name, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         """Fallback handler"""
 *         return node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function, "Fallback handler");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function = {"_handle_function", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  CYTHON_UNUSED PyObject *__pyx_v_function_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_function = 0;
  CYTHON_UNUSED PyObject *__pyx_v_arg_list = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_function (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_function_name,&__pyx_mstate_global->__pyx_n_u_function,&__pyx_mstate_global->__pyx_n_u_arg_list,&__pyx_mstate_global->__pyx_n_u_kwargs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 699, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 699, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 699, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 699, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 699, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 699, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_handle_function", 0) < (0)) __PYX_ERR(0, 699, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_handle_function", 1, 5, 5, i); __PYX_ERR(0, 699, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 699, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 699, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 699, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 699, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 699, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
    __pyx_v_function_name = values[1];
    __pyx_v_function = values[2];
    __pyx_v_arg_list = values[3];
    __pyx_v_kwargs = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_handle_function", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 699, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._handle_function", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), __pyx_v_node, __pyx_v_function_name, __pyx_v_function, __pyx_v_arg_list, __pyx_v_kwargs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED PyObject *__pyx_v_function_name, CYTHON_UNUSED PyObject *__pyx_v_function, CYTHON_UNUSED PyObject *__pyx_v_arg_list, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_function", 0);

  /* "Cython/Compiler/Visitor.py":701
 *     def _handle_function(self, node, function_name, function, arg_list, kwargs):
 *         """Fallback handler"""
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def _handle_method(self, node, type_name, attr_name, function,
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":699
 *         return result
 * 
 *     def _handle_function(self, node, function_name, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         """Fallback handler"""
 *         return node
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":703
 *         return node
 * 
 *     def _handle_method(self, node, type_name, attr_name, function,             # <<<<<<<<<<<<<<
 *                        arg_list, is_unbound_method, kwargs):
 *         """Fallback handler"""
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method, "Fallback handler");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method = {"_handle_method", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  CYTHON_UNUSED PyObject *__pyx_v_type_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_attr_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_function = 0;
  CYTHON_UNUSED PyObject *__pyx_v_arg_list = 0;
  CYTHON_UNUSED PyObject *__pyx_v_is_unbound_method = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_method (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_type_name,&__pyx_mstate_global->__pyx_n_u_attr_name,&__pyx_mstate_global->__pyx_n_u_function,&__pyx_mstate_global->__pyx_n_u_arg_list,&__pyx_mstate_global->__pyx_n_u_is_unbound_method,&__pyx_mstate_global->__pyx_n_u_kwargs,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 703, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 703, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_handle_method", 0) < (0)) __PYX_ERR(0, 703, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 7; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_handle_method", 1, 7, 7, i); __PYX_ERR(0, 703, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 7)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 703, __pyx_L3_error)
      values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 703, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
    __pyx_v_type_name = values[1];
    __pyx_v_attr_name = values[2];
    __pyx_v_function = values[3];
    __pyx_v_arg_list = values[4];
    __pyx_v_is_unbound_method = values[5];
    __pyx_v_kwargs = values[6];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_handle_method", 1, 7, 7, __pyx_nargs); __PYX_ERR(0, 703, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.MethodDispatcherTransform._handle_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method(((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)__pyx_v_self), __pyx_v_node, __pyx_v_type_name, __pyx_v_attr_name, __pyx_v_function, __pyx_v_arg_list, __pyx_v_is_unbound_method, __pyx_v_kwargs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method(CYTHON_UNUSED struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *__pyx_v_self, PyObject *__pyx_v_node, CYTHON_UNUSED PyObject *__pyx_v_type_name, CYTHON_UNUSED PyObject *__pyx_v_attr_name, CYTHON_UNUSED PyObject *__pyx_v_function, CYTHON_UNUSED PyObject *__pyx_v_arg_list, CYTHON_UNUSED PyObject *__pyx_v_is_unbound_method, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_method", 0);

  /* "Cython/Compiler/Visitor.py":706
 *                        arg_list, is_unbound_method, kwargs):
 *         """Fallback handler"""
 *         return node             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":703
 *         return node
 * 
 *     def _handle_method(self, node, type_name, attr_name, function,             # <<<<<<<<<<<<<<
 *                        arg_list, is_unbound_method, kwargs):
 *         """Fallback handler"""
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":714
 *     another node.
 *     """
 *     def __init__(self, orig_node, new_node):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.orig_node, self.new_node = orig_node, new_node
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_orig_node = 0;
  PyObject *__pyx_v_new_node = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_orig_node,&__pyx_mstate_global->__pyx_n_u_new_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 714, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 714, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 714, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 714, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 714, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 714, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 714, __pyx_L3_error)
    }
    __pyx_v_orig_node = values[0];
    __pyx_v_new_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 714, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.RecursiveNodeReplacer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer___init__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self), __pyx_v_orig_node, __pyx_v_new_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_orig_node, PyObject *__pyx_v_new_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":715
 *     """
 *     def __init__(self, orig_node, new_node):
 *         super().__init__()             # <<<<<<<<<<<<<<
 *         self.orig_node, self.new_node = orig_node, new_node
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":716
 *     def __init__(self, orig_node, new_node):
 *         super().__init__()
 *         self.orig_node, self.new_node = orig_node, new_node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CloneNode(self, node):
*/
  __pyx_t_1 = __pyx_v_orig_node;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = __pyx_v_new_node;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->orig_node);
  __Pyx_DECREF(__pyx_v_self->orig_node);
  __pyx_v_self->orig_node = __pyx_t_1;
  __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->new_node);
  __Pyx_DECREF(__pyx_v_self->new_node);
  __pyx_v_self->new_node = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Visitor.py":714
 *     another node.
 *     """
 *     def __init__(self, orig_node, new_node):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.orig_node, self.new_node = orig_node, new_node
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.RecursiveNodeReplacer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":718
 *         self.orig_node, self.new_node = orig_node, new_node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         if node is self.orig_node:
 *             return self.new_node
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode = {"visit_CloneNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CloneNode (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_2visit_CloneNode(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_2visit_CloneNode(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CloneNode", 0);

  /* "Cython/Compiler/Visitor.py":719
 * 
 *     def visit_CloneNode(self, node):
 *         if node is self.orig_node:             # <<<<<<<<<<<<<<
 *             return self.new_node
 *         if node.arg is self.orig_node:
*/
  __pyx_t_1 = (__pyx_v_node == __pyx_v_self->orig_node);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Visitor.py":720
 *     def visit_CloneNode(self, node):
 *         if node is self.orig_node:
 *             return self.new_node             # <<<<<<<<<<<<<<
 *         if node.arg is self.orig_node:
 *             node.arg = self.new_node
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->new_node);
    __pyx_r = __pyx_v_self->new_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":719
 * 
 *     def visit_CloneNode(self, node):
 *         if node is self.orig_node:             # <<<<<<<<<<<<<<
 *             return self.new_node
 *         if node.arg is self.orig_node:
*/
  }

  /* "Cython/Compiler/Visitor.py":721
 *         if node is self.orig_node:
 *             return self.new_node
 *         if node.arg is self.orig_node:             # <<<<<<<<<<<<<<
 *             node.arg = self.new_node
 *         return node
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__pyx_t_2 == __pyx_v_self->orig_node);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "Cython/Compiler/Visitor.py":722
 *             return self.new_node
 *         if node.arg is self.orig_node:
 *             node.arg = self.new_node             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
    __pyx_t_2 = __pyx_v_self->new_node;
    __Pyx_INCREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg, __pyx_t_2) < (0)) __PYX_ERR(0, 722, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":721
 *         if node is self.orig_node:
 *             return self.new_node
 *         if node.arg is self.orig_node:             # <<<<<<<<<<<<<<
 *             node.arg = self.new_node
 *         return node
*/
  }

  /* "Cython/Compiler/Visitor.py":723
 *         if node.arg is self.orig_node:
 *             node.arg = self.new_node
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_Node(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":718
 *         self.orig_node, self.new_node = orig_node, new_node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         if node is self.orig_node:
 *             return self.new_node
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.RecursiveNodeReplacer.visit_CloneNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":725
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         if node is self.orig_node:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node = {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_4visit_Node(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_4visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/Visitor.py":726
 * 
 *     def visit_Node(self, node):
 *         self._process_children(node)             # <<<<<<<<<<<<<<
 *         if node is self.orig_node:
 *             return self.new_node
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._process_children(((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)__pyx_v_self), __pyx_v_node, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":727
 *     def visit_Node(self, node):
 *         self._process_children(node)
 *         if node is self.orig_node:             # <<<<<<<<<<<<<<
 *             return self.new_node
 *         else:
*/
  __pyx_t_2 = (__pyx_v_node == __pyx_v_self->orig_node);
  if (__pyx_t_2) {

    /* "Cython/Compiler/Visitor.py":728
 *         self._process_children(node)
 *         if node is self.orig_node:
 *             return self.new_node             # <<<<<<<<<<<<<<
 *         else:
 *             return node
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->new_node);
    __pyx_r = __pyx_v_self->new_node;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":727
 *     def visit_Node(self, node):
 *         self._process_children(node)
 *         if node is self.orig_node:             # <<<<<<<<<<<<<<
 *             return self.new_node
 *         else:
*/
  }

  /* "Cython/Compiler/Visitor.py":730
 *             return self.new_node
 *         else:
 *             return node             # <<<<<<<<<<<<<<
 * 
 * def recursively_replace_node(tree, old_node, new_node):
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_node);
    __pyx_r = __pyx_v_node;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Visitor.py":725
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         if node is self.orig_node:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.RecursiveNodeReplacer.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":48
 * 
 * cdef class RecursiveNodeReplacer(VisitorTransform):
 *     cdef public orig_node             # <<<<<<<<<<<<<<
 *     cdef public new_node
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->orig_node);
  __pyx_r = __pyx_v_self->orig_node;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->orig_node);
  __Pyx_DECREF(__pyx_v_self->orig_node);
  __pyx_v_self->orig_node = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->orig_node);
  __Pyx_DECREF(__pyx_v_self->orig_node);
  __pyx_v_self->orig_node = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":49
 * cdef class RecursiveNodeReplacer(VisitorTransform):
 *     cdef public orig_node
 *     cdef public new_node             # <<<<<<<<<<<<<<
 * 
 * cdef class NodeFinder(TreeVisitor):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->new_node);
  __pyx_r = __pyx_v_self->new_node;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->new_node);
  __Pyx_DECREF(__pyx_v_self->new_node);
  __pyx_v_self->new_node = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_4__del__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_4__del__(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->new_node);
  __Pyx_DECREF(__pyx_v_self->new_node);
  __pyx_v_self->new_node = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":732
 *             return node
 * 
 * def recursively_replace_node(tree, old_node, new_node):             # <<<<<<<<<<<<<<
 *     replace_in = RecursiveNodeReplacer(old_node, new_node)
 *     replace_in(tree)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_1recursively_replace_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_1recursively_replace_node = {"recursively_replace_node", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_1recursively_replace_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_1recursively_replace_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tree = 0;
  PyObject *__pyx_v_old_node = 0;
  PyObject *__pyx_v_new_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recursively_replace_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tree,&__pyx_mstate_global->__pyx_n_u_old_node,&__pyx_mstate_global->__pyx_n_u_new_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 732, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "recursively_replace_node", 0) < (0)) __PYX_ERR(0, 732, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("recursively_replace_node", 1, 3, 3, i); __PYX_ERR(0, 732, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 732, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 732, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 732, __pyx_L3_error)
    }
    __pyx_v_tree = values[0];
    __pyx_v_old_node = values[1];
    __pyx_v_new_node = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("recursively_replace_node", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 732, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.recursively_replace_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_recursively_replace_node(__pyx_self, __pyx_v_tree, __pyx_v_old_node, __pyx_v_new_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_recursively_replace_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_old_node, PyObject *__pyx_v_new_node) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *__pyx_v_replace_in = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("recursively_replace_node", 0);

  /* "Cython/Compiler/Visitor.py":733
 * 
 * def recursively_replace_node(tree, old_node, new_node):
 *     replace_in = RecursiveNodeReplacer(old_node, new_node)             # <<<<<<<<<<<<<<
 *     replace_in(tree)
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_old_node, __pyx_v_new_node};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_replace_in = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":734
 * def recursively_replace_node(tree, old_node, new_node):
 *     replace_in = RecursiveNodeReplacer(old_node, new_node)
 *     replace_in(tree)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF((PyObject *)__pyx_v_replace_in);
  __pyx_t_4 = ((PyObject *)__pyx_v_replace_in); 
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_tree};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":732
 *             return node
 * 
 * def recursively_replace_node(tree, old_node, new_node):             # <<<<<<<<<<<<<<
 *     replace_in = RecursiveNodeReplacer(old_node, new_node)
 *     replace_in(tree)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.recursively_replace_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_replace_in);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":741
 *     Find out if a node appears in a subtree.
 *     """
 *     def __init__(self, node):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.node = node
*/

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_node = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 741, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 741, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 741, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 741, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 741, __pyx_L3_error)
    }
    __pyx_v_node = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 741, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeFinder.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder___init__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_self), __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder___init__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":742
 *     """
 *     def __init__(self, node):
 *         super().__init__()             # <<<<<<<<<<<<<<
 *         self.node = node
 *         self.found = False
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":743
 *     def __init__(self, node):
 *         super().__init__()
 *         self.node = node             # <<<<<<<<<<<<<<
 *         self.found = False
 * 
*/
  __Pyx_INCREF(__pyx_v_node);
  __Pyx_GIVEREF(__pyx_v_node);
  __Pyx_GOTREF(__pyx_v_self->node);
  __Pyx_DECREF(__pyx_v_self->node);
  __pyx_v_self->node = __pyx_v_node;

  /* "Cython/Compiler/Visitor.py":744
 *         super().__init__()
 *         self.node = node
 *         self.found = False             # <<<<<<<<<<<<<<
 * 
 *     def visit_Node(self, node):
*/
  __pyx_v_self->found = 0;

  /* "Cython/Compiler/Visitor.py":741
 *     Find out if a node appears in a subtree.
 *     """
 *     def __init__(self, node):             # <<<<<<<<<<<<<<
 *         super().__init__()
 *         self.node = node
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeFinder.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":746
 *         self.found = False
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         if self.found:
 *             pass  # short-circuit
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node = {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node(PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_2visit_Node(((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_self), ((PyObject *)__pyx_v_node));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_2visit_Node(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/Visitor.py":747
 * 
 *     def visit_Node(self, node):
 *         if self.found:             # <<<<<<<<<<<<<<
 *             pass  # short-circuit
 *         elif node is self.node:
*/
  if (__pyx_v_self->found) {
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":749
 *         if self.found:
 *             pass  # short-circuit
 *         elif node is self.node:             # <<<<<<<<<<<<<<
 *             self.found = True
 *         else:
*/
  __pyx_t_1 = (__pyx_v_node == __pyx_v_self->node);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Visitor.py":750
 *             pass  # short-circuit
 *         elif node is self.node:
 *             self.found = True             # <<<<<<<<<<<<<<
 *         else:
 *             self._visitchildren(node, None, None)
*/
    __pyx_v_self->found = 1;

    /* "Cython/Compiler/Visitor.py":749
 *         if self.found:
 *             pass  # short-circuit
 *         elif node is self.node:             # <<<<<<<<<<<<<<
 *             self.found = True
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":752
 *             self.found = True
 *         else:
 *             self._visitchildren(node, None, None)             # <<<<<<<<<<<<<<
 * 
 * def tree_contains(tree, node):
*/
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._visitchildren(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_self), __pyx_v_node, Py_None, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":746
 *         self.found = False
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         if self.found:
 *             pass  # short-circuit
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeFinder.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.pxd":53
 * cdef class NodeFinder(TreeVisitor):
 *     cdef node
 *     cdef public bint found             # <<<<<<<<<<<<<<
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found___get__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found___get__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->found); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeFinder.found.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found_2__set__(((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6Cython_8Compiler_7Visitor_10NodeFinder_5found_2__set__(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 53, __pyx_L1_error)
  __pyx_v_self->found = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("Cython.Compiler.Visitor.NodeFinder.found.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":754
 *             self._visitchildren(node, None, None)
 * 
 * def tree_contains(tree, node):             # <<<<<<<<<<<<<<
 *     finder = NodeFinder(node)
 *     finder.visit(tree)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_3tree_contains(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_3tree_contains = {"tree_contains", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_3tree_contains, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_3tree_contains(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tree = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tree_contains (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_tree,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 754, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 754, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 754, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "tree_contains", 0) < (0)) __PYX_ERR(0, 754, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("tree_contains", 1, 2, 2, i); __PYX_ERR(0, 754, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 754, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 754, __pyx_L3_error)
    }
    __pyx_v_tree = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tree_contains", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 754, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.tree_contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_2tree_contains(__pyx_self, __pyx_v_tree, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_2tree_contains(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_node) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *__pyx_v_finder = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tree_contains", 0);

  /* "Cython/Compiler/Visitor.py":755
 * 
 * def tree_contains(tree, node):
 *     finder = NodeFinder(node)             # <<<<<<<<<<<<<<
 *     finder.visit(tree)
 *     return finder.found
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_finder = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":756
 * def tree_contains(tree, node):
 *     finder = NodeFinder(node)
 *     finder.visit(tree)             # <<<<<<<<<<<<<<
 *     return finder.found
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder *)__pyx_v_finder->__pyx_base.__pyx_vtab)->__pyx_base.visit(((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)__pyx_v_finder), __pyx_v_tree, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":757
 *     finder = NodeFinder(node)
 *     finder.visit(tree)
 *     return finder.found             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_finder->found); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":754
 *             self._visitchildren(node, None, None)
 * 
 * def tree_contains(tree, node):             # <<<<<<<<<<<<<<
 *     finder = NodeFinder(node)
 *     finder.visit(tree)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.tree_contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_finder);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":761
 * 
 * # Utils
 * def replace_node(ptr, value):             # <<<<<<<<<<<<<<
 *     """Replaces a node. ptr is of the form used on the access path stack
 *     (parent, attrname, listidx|None)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_5replace_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6Cython_8Compiler_7Visitor_4replace_node, "Replaces a node. ptr is of the form used on the access path stack\n    (parent, attrname, listidx|None)\n    ");
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_5replace_node = {"replace_node", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_5replace_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_7Visitor_4replace_node};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_5replace_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ptr = 0;
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replace_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ptr,&__pyx_mstate_global->__pyx_n_u_value,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 761, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 761, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 761, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "replace_node", 0) < (0)) __PYX_ERR(0, 761, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("replace_node", 1, 2, 2, i); __PYX_ERR(0, 761, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 761, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 761, __pyx_L3_error)
    }
    __pyx_v_ptr = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("replace_node", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 761, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.replace_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_4replace_node(__pyx_self, __pyx_v_ptr, __pyx_v_value);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_4replace_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_ptr, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_v_attrname = NULL;
  PyObject *__pyx_v_listidx = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("replace_node", 0);

  /* "Cython/Compiler/Visitor.py":765
 *     (parent, attrname, listidx|None)
 *     """
 *     parent, attrname, listidx = ptr             # <<<<<<<<<<<<<<
 *     if listidx is None:
 *         setattr(parent, attrname, value)
*/
  if ((likely(PyTuple_CheckExact(__pyx_v_ptr))) || (PyList_CheckExact(__pyx_v_ptr))) {
    PyObject* sequence = __pyx_v_ptr;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 765, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2);
      __Pyx_INCREF(__pyx_t_3);
    } else {
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 765, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_3);
    }
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_v_ptr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
    index = 0; __pyx_t_1 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 2; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 3) < (0)) __PYX_ERR(0, 765, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 765, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_parent = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_attrname = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_listidx = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "Cython/Compiler/Visitor.py":766
 *     """
 *     parent, attrname, listidx = ptr
 *     if listidx is None:             # <<<<<<<<<<<<<<
 *         setattr(parent, attrname, value)
 *     else:
*/
  __pyx_t_6 = (__pyx_v_listidx == Py_None);
  if (__pyx_t_6) {

    /* "Cython/Compiler/Visitor.py":767
 *     parent, attrname, listidx = ptr
 *     if listidx is None:
 *         setattr(parent, attrname, value)             # <<<<<<<<<<<<<<
 *     else:
 *         getattr(parent, attrname)[listidx] = value
*/
    __pyx_t_7 = PyObject_SetAttr(__pyx_v_parent, __pyx_v_attrname, __pyx_v_value); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 767, __pyx_L1_error)

    /* "Cython/Compiler/Visitor.py":766
 *     """
 *     parent, attrname, listidx = ptr
 *     if listidx is None:             # <<<<<<<<<<<<<<
 *         setattr(parent, attrname, value)
 *     else:
*/
    goto __pyx_L5;
  }

  /* "Cython/Compiler/Visitor.py":769
 *         setattr(parent, attrname, value)
 *     else:
 *         getattr(parent, attrname)[listidx] = value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_GetAttr(__pyx_v_parent, __pyx_v_attrname); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_v_listidx, __pyx_v_value) < 0))) __PYX_ERR(0, 769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L5:;

  /* "Cython/Compiler/Visitor.py":761
 * 
 * # Utils
 * def replace_node(ptr, value):             # <<<<<<<<<<<<<<
 *     """Replaces a node. ptr is of the form used on the access path stack
 *     (parent, attrname, listidx|None)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.replace_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_attrname);
  __Pyx_XDECREF(__pyx_v_listidx);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":776
 *     Subclass and override repr_of to provide more information
 *     about nodes. """
 *     def __init__(self, start=None, end=None):             # <<<<<<<<<<<<<<
 *         TreeVisitor.__init__(self)
 *         self._indent = ""
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_end = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_start,&__pyx_mstate_global->__pyx_n_u_end,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 776, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 776, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 776, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 776, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 776, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 3, i); __PYX_ERR(0, 776, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 776, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 776, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 776, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_start = values[1];
    __pyx_v_end = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 776, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree___init__(__pyx_self, __pyx_v_self, __pyx_v_start, __pyx_v_end);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_start, PyObject *__pyx_v_end) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Cython/Compiler/Visitor.py":777
 *     about nodes. """
 *     def __init__(self, start=None, end=None):
 *         TreeVisitor.__init__(self)             # <<<<<<<<<<<<<<
 *         self._indent = ""
 *         if start is not None or end is not None:
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":778
 *     def __init__(self, start=None, end=None):
 *         TreeVisitor.__init__(self)
 *         self._indent = ""             # <<<<<<<<<<<<<<
 *         if start is not None or end is not None:
 *             self._line_range = (start or 0, end or 2**30)
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent, __pyx_mstate_global->__pyx_kp_u__7) < (0)) __PYX_ERR(0, 778, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":779
 *         TreeVisitor.__init__(self)
 *         self._indent = ""
 *         if start is not None or end is not None:             # <<<<<<<<<<<<<<
 *             self._line_range = (start or 0, end or 2**30)
 *         else:
*/
  __pyx_t_5 = (__pyx_v_start != Py_None);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (__pyx_v_end != Py_None);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Visitor.py":780
 *         self._indent = ""
 *         if start is not None or end is not None:
 *             self._line_range = (start or 0, end or 2**30)             # <<<<<<<<<<<<<<
 *         else:
 *             self._line_range = None
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_start); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 780, __pyx_L1_error)
    if (!__pyx_t_4) {
    } else {
      __Pyx_INCREF(__pyx_v_start);
      __pyx_t_1 = __pyx_v_start;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyLong_From_long(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_L6_bool_binop_done:;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_end); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 780, __pyx_L1_error)
    if (!__pyx_t_4) {
    } else {
      __Pyx_INCREF(__pyx_v_end);
      __pyx_t_2 = __pyx_v_end;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyLong_From_long(0x40000000); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_L8_bool_binop_done:;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 780, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 780, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range, __pyx_t_6) < (0)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Visitor.py":779
 *         TreeVisitor.__init__(self)
 *         self._indent = ""
 *         if start is not None or end is not None:             # <<<<<<<<<<<<<<
 *             self._line_range = (start or 0, end or 2**30)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "Cython/Compiler/Visitor.py":782
 *             self._line_range = (start or 0, end or 2**30)
 *         else:
 *             self._line_range = None             # <<<<<<<<<<<<<<
 * 
 *     def indent(self):
*/
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range, Py_None) < (0)) __PYX_ERR(0, 782, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "Cython/Compiler/Visitor.py":776
 *     Subclass and override repr_of to provide more information
 *     about nodes. """
 *     def __init__(self, start=None, end=None):             # <<<<<<<<<<<<<<
 *         TreeVisitor.__init__(self)
 *         self._indent = ""
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":784
 *             self._line_range = None
 * 
 *     def indent(self):             # <<<<<<<<<<<<<<
 *         self._indent += "  "
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_3indent(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_3indent = {"indent", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_3indent, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_3indent(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("indent (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_2indent(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_2indent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("indent", 0);

  /* "Cython/Compiler/Visitor.py":785
 * 
 *     def indent(self):
 *         self._indent += "  "             # <<<<<<<<<<<<<<
 * 
 *     def unindent(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent, __pyx_t_2) < (0)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":784
 *             self._line_range = None
 * 
 *     def indent(self):             # <<<<<<<<<<<<<<
 *         self._indent += "  "
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.indent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":787
 *         self._indent += "  "
 * 
 *     def unindent(self):             # <<<<<<<<<<<<<<
 *         self._indent = self._indent[:-2]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_5unindent(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_5unindent = {"unindent", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_5unindent, METH_O, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_5unindent(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unindent (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_4unindent(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_4unindent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unindent", 0);

  /* "Cython/Compiler/Visitor.py":788
 * 
 *     def unindent(self):
 *         self._indent = self._indent[:-2]             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, tree, phase=None):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, -2L, NULL, NULL, &__pyx_mstate_global->__pyx_slice[1], 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent, __pyx_t_2) < (0)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":787
 *         self._indent += "  "
 * 
 *     def unindent(self):             # <<<<<<<<<<<<<<
 *         self._indent = self._indent[:-2]
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.unindent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":790
 *         self._indent = self._indent[:-2]
 * 
 *     def __call__(self, tree, phase=None):             # <<<<<<<<<<<<<<
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_7__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_7__call__ = {"__call__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_7__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_7__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_tree = 0;
  PyObject *__pyx_v_phase = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_tree,&__pyx_mstate_global->__pyx_n_u_phase,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 790, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 790, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 790, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 790, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 790, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 0, 2, 3, i); __PYX_ERR(0, 790, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 790, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 790, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 790, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_tree = values[1];
    __pyx_v_phase = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 790, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_6__call__(__pyx_self, __pyx_v_self, __pyx_v_tree, __pyx_v_phase);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_6__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tree, PyObject *__pyx_v_phase) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "Cython/Compiler/Visitor.py":791
 * 
 *     def __call__(self, tree, phase=None):
 *         print("Parse tree dump at phase '%s'" % phase)             # <<<<<<<<<<<<<<
 *         self.visit(tree)
 *         return tree
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_Parse_tree_dump_at_phase_s, __pyx_v_phase); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":792
 *     def __call__(self, tree, phase=None):
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)             # <<<<<<<<<<<<<<
 *         return tree
 * 
*/
  __pyx_t_3 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tree};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visit_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":793
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)
 *         return tree             # <<<<<<<<<<<<<<
 * 
 *     # Don't do anything about process_list, the defaults gives
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tree);
  __pyx_r = __pyx_v_tree;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":790
 *         self._indent = self._indent[:-2]
 * 
 *     def __call__(self, tree, phase=None):             # <<<<<<<<<<<<<<
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":799
 *     # under the parent-node, not displaying the list itself in
 *     # the hierarchy.
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_9visit_Node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_9visit_Node = {"visit_Node", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_9visit_Node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_9visit_Node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_Node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 799, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 799, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 799, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visit_Node", 0) < (0)) __PYX_ERR(0, 799, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visit_Node", 1, 2, 2, i); __PYX_ERR(0, 799, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 799, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 799, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visit_Node", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 799, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_8visit_Node(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_8visit_Node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_Node", 0);

  /* "Cython/Compiler/Visitor.py":800
 *     # the hierarchy.
 *     def visit_Node(self, node):
 *         self._print_node(node)             # <<<<<<<<<<<<<<
 *         self.indent()
 *         self.visitchildren(node)
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_print_node, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":801
 *     def visit_Node(self, node):
 *         self._print_node(node)
 *         self.indent()             # <<<<<<<<<<<<<<
 *         self.visitchildren(node)
 *         self.unindent()
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_indent_2, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":802
 *         self._print_node(node)
 *         self.indent()
 *         self.visitchildren(node)             # <<<<<<<<<<<<<<
 *         self.unindent()
 *         return node
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 802, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":803
 *         self.indent()
 *         self.visitchildren(node)
 *         self.unindent()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unindent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":804
 *         self.visitchildren(node)
 *         self.unindent()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def visit_CloneNode(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":799
 *     # under the parent-node, not displaying the list itself in
 *     # the hierarchy.
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.visit_Node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":806
 *         return node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_11visit_CloneNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_11visit_CloneNode = {"visit_CloneNode", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_11visit_CloneNode, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_11visit_CloneNode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("visit_CloneNode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 806, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 806, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 806, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "visit_CloneNode", 0) < (0)) __PYX_ERR(0, 806, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("visit_CloneNode", 1, 2, 2, i); __PYX_ERR(0, 806, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 806, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 806, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("visit_CloneNode", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 806, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.visit_CloneNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_10visit_CloneNode(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_10visit_CloneNode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("visit_CloneNode", 0);

  /* "Cython/Compiler/Visitor.py":807
 * 
 *     def visit_CloneNode(self, node):
 *         self._print_node(node)             # <<<<<<<<<<<<<<
 *         self.indent()
 *         line = node.pos[1]
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_node};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_print_node, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 807, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":808
 *     def visit_CloneNode(self, node):
 *         self._print_node(node)
 *         self.indent()             # <<<<<<<<<<<<<<
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_indent_2, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 808, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Cython/Compiler/Visitor.py":809
 *         self._print_node(node)
 *         self.indent()
 *         line = node.pos[1]             # <<<<<<<<<<<<<<
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":810
 *         self.indent()
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:             # <<<<<<<<<<<<<<
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))
 *         self.indent()
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_v_line, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_2)) {
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_6, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_line, __pyx_t_7, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "Cython/Compiler/Visitor.py":811
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))             # <<<<<<<<<<<<<<
 *         self.indent()
 *         self.visitchildren(node.arg)
*/
    __pyx_t_1 = NULL;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_7), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_repr_of); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_9), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_10[0] = __pyx_t_6;
    __pyx_t_10[1] = __pyx_mstate_global->__pyx_kp_u_arg_2;
    __pyx_t_10[2] = __pyx_t_8;
    __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_10, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_3 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_9};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "Cython/Compiler/Visitor.py":810
 *         self.indent()
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:             # <<<<<<<<<<<<<<
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))
 *         self.indent()
*/
  }

  /* "Cython/Compiler/Visitor.py":812
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))
 *         self.indent()             # <<<<<<<<<<<<<<
 *         self.visitchildren(node.arg)
 *         self.unindent()
*/
  __pyx_t_9 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_9);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_indent_2, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":813
 *             print("%s- %s: %s" % (self._indent, 'arg', self.repr_of(node.arg)))
 *         self.indent()
 *         self.visitchildren(node.arg)             # <<<<<<<<<<<<<<
 *         self.unindent()
 *         self.unindent()
*/
  __pyx_t_9 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_1};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":814
 *         self.indent()
 *         self.visitchildren(node.arg)
 *         self.unindent()             # <<<<<<<<<<<<<<
 *         self.unindent()
 *         return node
*/
  __pyx_t_1 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unindent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":815
 *         self.visitchildren(node.arg)
 *         self.unindent()
 *         self.unindent()             # <<<<<<<<<<<<<<
 *         return node
 * 
*/
  __pyx_t_1 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unindent, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 815, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":816
 *         self.unindent()
 *         self.unindent()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def _print_node(self, node):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "Cython/Compiler/Visitor.py":806
 *         return node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.visit_CloneNode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":818
 *         return node
 * 
 *     def _print_node(self, node):             # <<<<<<<<<<<<<<
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_13_print_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_13_print_node = {"_print_node", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_13_print_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_13_print_node(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_print_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 818, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 818, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 818, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_print_node", 0) < (0)) __PYX_ERR(0, 818, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_print_node", 1, 2, 2, i); __PYX_ERR(0, 818, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 818, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 818, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_print_node", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 818, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree._print_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_12_print_node(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_12_print_node(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_line = NULL;
  PyObject *__pyx_v_name = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_parent = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_idx = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10[4];
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[5];
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_print_node", 0);

  /* "Cython/Compiler/Visitor.py":819
 * 
 *     def _print_node(self, node):
 *         line = node.pos[1]             # <<<<<<<<<<<<<<
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             if len(self.access_path) == 0:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":820
 *     def _print_node(self, node):
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:             # <<<<<<<<<<<<<<
 *             if len(self.access_path) == 0:
 *                 name = "(root)"
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_v_line, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_2)) {
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_line_range); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_5, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_line, __pyx_t_6, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "Cython/Compiler/Visitor.py":821
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             if len(self.access_path) == 0:             # <<<<<<<<<<<<<<
 *                 name = "(root)"
 *             else:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_access_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = (__pyx_t_7 == 0);
    if (__pyx_t_3) {

      /* "Cython/Compiler/Visitor.py":822
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             if len(self.access_path) == 0:
 *                 name = "(root)"             # <<<<<<<<<<<<<<
 *             else:
 *                 parent, attr, idx = self.access_path[-1]
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_root_2);
      __pyx_v_name = __pyx_mstate_global->__pyx_kp_u_root_2;

      /* "Cython/Compiler/Visitor.py":821
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
 *             if len(self.access_path) == 0:             # <<<<<<<<<<<<<<
 *                 name = "(root)"
 *             else:
*/
      goto __pyx_L6;
    }

    /* "Cython/Compiler/Visitor.py":824
 *                 name = "(root)"
 *             else:
 *                 parent, attr, idx = self.access_path[-1]             # <<<<<<<<<<<<<<
 *                 if idx is not None:
 *                     name = "%s[%d]" % (attr, idx)
*/
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_access_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 824, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2);
          __Pyx_INCREF(__pyx_t_5);
        } else {
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 824, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 824, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 2, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 824, __pyx_L1_error)
          __Pyx_XGOTREF(__pyx_t_5);
        }
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
        index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 2; __pyx_t_5 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < (0)) __PYX_ERR(0, 824, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 824, __pyx_L1_error)
        __pyx_L8_unpacking_done:;
      }
      __pyx_v_parent = __pyx_t_2;
      __pyx_t_2 = 0;
      __pyx_v_attr = __pyx_t_6;
      __pyx_t_6 = 0;
      __pyx_v_idx = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "Cython/Compiler/Visitor.py":825
 *             else:
 *                 parent, attr, idx = self.access_path[-1]
 *                 if idx is not None:             # <<<<<<<<<<<<<<
 *                     name = "%s[%d]" % (attr, idx)
 *                 else:
*/
      __pyx_t_3 = (__pyx_v_idx != Py_None);
      if (__pyx_t_3) {

        /* "Cython/Compiler/Visitor.py":826
 *                 parent, attr, idx = self.access_path[-1]
 *                 if idx is not None:
 *                     name = "%s[%d]" % (attr, idx)             # <<<<<<<<<<<<<<
 *                 else:
 *                     name = attr
*/
        __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_attr), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_Long(__pyx_v_idx), __pyx_mstate_global->__pyx_n_u_d_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10[0] = __pyx_t_1;
        __pyx_t_10[1] = __pyx_mstate_global->__pyx_kp_u__12;
        __pyx_t_10[2] = __pyx_t_5;
        __pyx_t_10[3] = __pyx_mstate_global->__pyx_kp_u__13;
        __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 826, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_name = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "Cython/Compiler/Visitor.py":825
 *             else:
 *                 parent, attr, idx = self.access_path[-1]
 *                 if idx is not None:             # <<<<<<<<<<<<<<
 *                     name = "%s[%d]" % (attr, idx)
 *                 else:
*/
        goto __pyx_L9;
      }

      /* "Cython/Compiler/Visitor.py":828
 *                     name = "%s[%d]" % (attr, idx)
 *                 else:
 *                     name = attr             # <<<<<<<<<<<<<<
 *             print("%s- %s: %s" % (self._indent, name, self.repr_of(node)))
 * 
*/
      /*else*/ {
        __Pyx_INCREF(__pyx_v_attr);
        __pyx_v_name = __pyx_v_attr;
      }
      __pyx_L9:;
    }
    __pyx_L6:;

    /* "Cython/Compiler/Visitor.py":829
 *                 else:
 *                     name = attr
 *             print("%s- %s: %s" % (self._indent, name, self.repr_of(node)))             # <<<<<<<<<<<<<<
 * 
 *     def repr_of(self, node):
*/
    __pyx_t_5 = NULL;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_indent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_1), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_name), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_repr_of); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_node); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_11), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_12[0] = __pyx_t_2;
    __pyx_t_12[1] = __pyx_mstate_global->__pyx_kp_u__14;
    __pyx_t_12[2] = __pyx_t_1;
    __pyx_t_12[3] = __pyx_mstate_global->__pyx_kp_u__9;
    __pyx_t_12[4] = __pyx_t_8;
    __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_12, 5, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_13 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_print, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "Cython/Compiler/Visitor.py":820
 *     def _print_node(self, node):
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:             # <<<<<<<<<<<<<<
 *             if len(self.access_path) == 0:
 *                 name = "(root)"
*/
  }

  /* "Cython/Compiler/Visitor.py":818
 *         return node
 * 
 *     def _print_node(self, node):             # <<<<<<<<<<<<<<
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree._print_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_parent);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Cython/Compiler/Visitor.py":831
 *             print("%s- %s: %s" % (self._indent, name, self.repr_of(node)))
 * 
 *     def repr_of(self, node):             # <<<<<<<<<<<<<<
 *         if node is None:
 *             return "(none)"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_15repr_of(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_15repr_of = {"repr_of", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_15repr_of, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6Cython_8Compiler_7Visitor_9PrintTree_15repr_of(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("repr_of (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_node,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 831, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 831, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 831, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "repr_of", 0) < (0)) __PYX_ERR(0, 831, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("repr_of", 1, 2, 2, i); __PYX_ERR(0, 831, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 831, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 831, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_node = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("repr_of", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 831, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.repr_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_14repr_of(__pyx_self, __pyx_v_self, __pyx_v_node);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6Cython_8Compiler_7Visitor_9PrintTree_14repr_of(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_pos = NULL;
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5[5];
  int __pyx_t_6;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[7];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("repr_of", 0);

  /* "Cython/Compiler/Visitor.py":832
 * 
 *     def repr_of(self, node):
 *         if node is None:             # <<<<<<<<<<<<<<
 *             return "(none)"
 *         else:
*/
  __pyx_t_1 = (__pyx_v_node == Py_None);
  if (__pyx_t_1) {

    /* "Cython/Compiler/Visitor.py":833
 *     def repr_of(self, node):
 *         if node is None:
 *             return "(none)"             # <<<<<<<<<<<<<<
 *         else:
 *             result = node.__class__.__name__
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_none);
    __pyx_r = __pyx_mstate_global->__pyx_kp_u_none;
    goto __pyx_L0;

    /* "Cython/Compiler/Visitor.py":832
 * 
 *     def repr_of(self, node):
 *         if node is None:             # <<<<<<<<<<<<<<
 *             return "(none)"
 *         else:
*/
  }

  /* "Cython/Compiler/Visitor.py":835
 *             return "(none)"
 *         else:
 *             result = node.__class__.__name__             # <<<<<<<<<<<<<<
 *             if isinstance(node, ExprNodes.NameNode):
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
*/
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "Cython/Compiler/Visitor.py":836
 *         else:
 *             result = node.__class__.__name__
 *             if isinstance(node, ExprNodes.NameNode):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
 *             elif isinstance(node, Nodes.DefNode):
*/
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_NameNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":837
 *             result = node.__class__.__name__
 *             if isinstance(node, ExprNodes.NameNode):
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)             # <<<<<<<<<<<<<<
 *             elif isinstance(node, Nodes.DefNode):
 *                 result += "(name=\"%s\")" % node.name
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyObject_Repr(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u_type_2;
      __pyx_t_5[1] = __pyx_t_2;
      __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u_name_3;
      __pyx_t_5[3] = __pyx_t_4;
      __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u__15;
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":836
 *         else:
 *             result = node.__class__.__name__
 *             if isinstance(node, ExprNodes.NameNode):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
 *             elif isinstance(node, Nodes.DefNode):
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":838
 *             if isinstance(node, ExprNodes.NameNode):
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
 *             elif isinstance(node, Nodes.DefNode):             # <<<<<<<<<<<<<<
 *                 result += "(name=\"%s\")" % node.name
 *             elif isinstance(node, Nodes.CFuncDefNode):
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Nodes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DefNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 838, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":839
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
 *             elif isinstance(node, Nodes.DefNode):
 *                 result += "(name=\"%s\")" % node.name             # <<<<<<<<<<<<<<
 *             elif isinstance(node, Nodes.CFuncDefNode):
 *                 result += "(name=\"%s\", type=\"%s\")" % (
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_name_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":838
 *             if isinstance(node, ExprNodes.NameNode):
 *                 result += "(type=%s, name=\"%s\")" % (repr(node.type), node.name)
 *             elif isinstance(node, Nodes.DefNode):             # <<<<<<<<<<<<<<
 *                 result += "(name=\"%s\")" % node.name
 *             elif isinstance(node, Nodes.CFuncDefNode):
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":840
 *             elif isinstance(node, Nodes.DefNode):
 *                 result += "(name=\"%s\")" % node.name
 *             elif isinstance(node, Nodes.CFuncDefNode):             # <<<<<<<<<<<<<<
 *                 result += "(name=\"%s\", type=\"%s\")" % (
 *                     node.declared_name(), getattr(node, "type", None))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Nodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_CFuncDefNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_4); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":842
 *             elif isinstance(node, Nodes.CFuncDefNode):
 *                 result += "(name=\"%s\", type=\"%s\")" % (
 *                     node.declared_name(), getattr(node, "type", None))             # <<<<<<<<<<<<<<
 *             elif isinstance(node, ExprNodes.AttributeNode):
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_declared_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_GetAttr3(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_type, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 842, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u_name_4;
      __pyx_t_5[1] = __pyx_t_4;
      __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u_type_3;
      __pyx_t_5[3] = __pyx_t_2;
      __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u__15;

      /* "Cython/Compiler/Visitor.py":841
 *                 result += "(name=\"%s\")" % node.name
 *             elif isinstance(node, Nodes.CFuncDefNode):
 *                 result += "(name=\"%s\", type=\"%s\")" % (             # <<<<<<<<<<<<<<
 *                     node.declared_name(), getattr(node, "type", None))
 *             elif isinstance(node, ExprNodes.AttributeNode):
*/
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "Cython/Compiler/Visitor.py":840
 *             elif isinstance(node, Nodes.DefNode):
 *                 result += "(name=\"%s\")" % node.name
 *             elif isinstance(node, Nodes.CFuncDefNode):             # <<<<<<<<<<<<<<
 *                 result += "(name=\"%s\", type=\"%s\")" % (
 *                     node.declared_name(), getattr(node, "type", None))
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":843
 *                 result += "(name=\"%s\", type=\"%s\")" % (
 *                     node.declared_name(), getattr(node, "type", None))
 *             elif isinstance(node, ExprNodes.AttributeNode):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
*/
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AttributeNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 843, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":844
 *                     node.declared_name(), getattr(node, "type", None))
 *             elif isinstance(node, ExprNodes.AttributeNode):
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)             # <<<<<<<<<<<<<<
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyObject_Repr(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u_type_2;
      __pyx_t_5[1] = __pyx_t_3;
      __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u_attribute_2;
      __pyx_t_5[3] = __pyx_t_4;
      __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u__15;
      __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 13 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 844, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":843
 *                 result += "(name=\"%s\", type=\"%s\")" % (
 *                     node.declared_name(), getattr(node, "type", None))
 *             elif isinstance(node, ExprNodes.AttributeNode):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":845
 *             elif isinstance(node, ExprNodes.AttributeNode):
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
 *             elif isinstance(node, ExprNodes.ExprNode):
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ConstNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PyConstNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = PyObject_IsInstance(__pyx_v_node, __pyx_t_2); 
    if (!__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_6 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); 
    __pyx_t_1 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":846
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)             # <<<<<<<<<<<<<<
 *             elif isinstance(node, ExprNodes.ExprNode):
 *                 t = node.type
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyObject_Repr(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u_type_2;
      __pyx_t_5[1] = __pyx_t_2;
      __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u_value_2;
      __pyx_t_5[3] = __pyx_t_4;
      __pyx_t_5[4] = __pyx_mstate_global->__pyx_kp_u__6;
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "Cython/Compiler/Visitor.py":845
 *             elif isinstance(node, ExprNodes.AttributeNode):
 *                 result += "(type=%s, attribute=\"%s\")" % (repr(node.type), node.attribute)
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):             # <<<<<<<<<<<<<<
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
 *             elif isinstance(node, ExprNodes.ExprNode):
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":847
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
 *             elif isinstance(node, ExprNodes.ExprNode):             # <<<<<<<<<<<<<<
 *                 t = node.type
 *                 result += "(type=%s)" % repr(t)
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ExprNodes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 847, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ExprNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 847, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = PyObject_IsInstance(__pyx_v_node, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 847, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":848
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
 *             elif isinstance(node, ExprNodes.ExprNode):
 *                 t = node.type             # <<<<<<<<<<<<<<
 *                 result += "(type=%s)" % repr(t)
 *             elif node.pos:
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 848, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_t = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":849
 *             elif isinstance(node, ExprNodes.ExprNode):
 *                 t = node.type
 *                 result += "(type=%s)" % repr(t)             # <<<<<<<<<<<<<<
 *             elif node.pos:
 *                 pos = node.pos
*/
      __pyx_t_3 = PyObject_Repr(__pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_type_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 849, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":847
 *             elif isinstance(node, (ExprNodes.ConstNode, ExprNodes.PyConstNode)):
 *                 result += "(type=%s, value=%r)" % (repr(node.type), node.value)
 *             elif isinstance(node, ExprNodes.ExprNode):             # <<<<<<<<<<<<<<
 *                 t = node.type
 *                 result += "(type=%s)" % repr(t)
*/
      goto __pyx_L4;
    }

    /* "Cython/Compiler/Visitor.py":850
 *                 t = node.type
 *                 result += "(type=%s)" % repr(t)
 *             elif node.pos:             # <<<<<<<<<<<<<<
 *                 pos = node.pos
 *                 path = pos[0].get_description()
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "Cython/Compiler/Visitor.py":851
 *                 result += "(type=%s)" % repr(t)
 *             elif node.pos:
 *                 pos = node.pos             # <<<<<<<<<<<<<<
 *                 path = pos[0].get_description()
 *                 if '/' in path:
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_pos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 851, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_pos = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":852
 *             elif node.pos:
 *                 pos = node.pos
 *                 path = pos[0].get_description()             # <<<<<<<<<<<<<<
 *                 if '/' in path:
 *                     path = path.split('/')[-1]
*/
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 852, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_description, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 852, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_v_path = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "Cython/Compiler/Visitor.py":853
 *                 pos = node.pos
 *                 path = pos[0].get_description()
 *                 if '/' in path:             # <<<<<<<<<<<<<<
 *                     path = path.split('/')[-1]
 *                 if '\\' in path:
*/
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__16, __pyx_v_path, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 853, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "Cython/Compiler/Visitor.py":854
 *                 path = pos[0].get_description()
 *                 if '/' in path:
 *                     path = path.split('/')[-1]             # <<<<<<<<<<<<<<
 *                 if '\\' in path:
 *                     path = path.split('\\')[-1]
*/
        __pyx_t_2 = __pyx_v_path;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__16};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 854, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "Cython/Compiler/Visitor.py":853
 *                 pos = node.pos
 *                 path = pos[0].get_description()
 *                 if '/' in path:             # <<<<<<<<<<<<<<
 *                     path = path.split('/')[-1]
 *                 if '\\' in path:
*/
      }

      /* "Cython/Compiler/Visitor.py":855
 *                 if '/' in path:
 *                     path = path.split('/')[-1]
 *                 if '\\' in path:             # <<<<<<<<<<<<<<
 *                     path = path.split('\\')[-1]
 *                 result += "(pos=(%s:%s:%s))" % (path, pos[1], pos[2])
*/
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__17, __pyx_v_path, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 855, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "Cython/Compiler/Visitor.py":856
 *                     path = path.split('/')[-1]
 *                 if '\\' in path:
 *                     path = path.split('\\')[-1]             # <<<<<<<<<<<<<<
 *                 result += "(pos=(%s:%s:%s))" % (path, pos[1], pos[2])
 * 
*/
        __pyx_t_3 = __pyx_v_path;
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u__17};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 856, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 856, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "Cython/Compiler/Visitor.py":855
 *                 if '/' in path:
 *                     path = path.split('/')[-1]
 *                 if '\\' in path:             # <<<<<<<<<<<<<<
 *                     path = path.split('\\')[-1]
 *                 result += "(pos=(%s:%s:%s))" % (path, pos[1], pos[2])
*/
      }

      /* "Cython/Compiler/Visitor.py":857
 *                 if '\\' in path:
 *                     path = path.split('\\')[-1]
 *                 result += "(pos=(%s:%s:%s))" % (path, pos[1], pos[2])             # <<<<<<<<<<<<<<
 * 
 *             return result
*/
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_path), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_pos, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_pos_2;
      __pyx_t_9[1] = __pyx_t_3;
      __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_;
      __pyx_t_9[3] = __pyx_t_4;
      __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u_;
      __pyx_t_9[5] = __pyx_t_8;
      __pyx_t_9[6] = __pyx_mstate_global->__pyx_kp_u__18;
      __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_9, 7, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "Cython/Compiler/Visitor.py":850
 *                 t = node.type
 *                 result += "(type=%s)" % repr(t)
 *             elif node.pos:             # <<<<<<<<<<<<<<
 *                 pos = node.pos
 *                 path = pos[0].get_description()
*/
    }
    __pyx_L4:;

    /* "Cython/Compiler/Visitor.py":859
 *                 result += "(pos=(%s:%s:%s))" % (path, pos[1], pos[2])
 * 
 *             return result             # <<<<<<<<<<<<<<
 * 
 * if __name__ == "__main__":
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;
  }

  /* "Cython/Compiler/Visitor.py":831
 *             print("%s- %s: %s" % (self._indent, name, self.repr_of(node)))
 * 
 *     def repr_of(self, node):             # <<<<<<<<<<<<<<
 *         if node is None:
 *             return "(none)"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Cython.Compiler.Visitor.PrintTree.repr_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_pos);
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)o);
  p->__pyx_vtab = __pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;
  p->access_path = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->dispatch_table = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->access_path);
  Py_CLEAR(p->dispatch_table);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->access_path) {
    e = (*v)(p->access_path, a); if (e) return e;
  }
  if (p->dispatch_table) {
    e = (*v)(p->dispatch_table, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *)o;
  tmp = ((PyObject*)p->access_path);
  p->access_path = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->dispatch_table);
  p->dispatch_table = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_11TreeVisitor_access_path(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_11TreeVisitor_access_path(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_11access_path_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_TreeVisitor[] = {
  {"dump_node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node, METH_O, 0},
  {"_find_node_path", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_TreeVisitor[] = {
  {"access_path", __pyx_getprop_6Cython_8Compiler_7Visitor_11TreeVisitor_access_path, __pyx_setprop_6Cython_8Compiler_7Visitor_11TreeVisitor_access_path, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Base class for writing visitors for a Cython tree, contains utilities for\n    recursing such trees using visitors. Each node is\n    expected to have a child_attrs iterable containing the names of attributes\n    containing child nodes or lists of child nodes. Lists are not considered\n    part of the tree structure (i.e. contained nodes are considered direct\n    children of the parent node).\n\n    visit_children visits each of the children of a given node (see the visit_children\n    documentation). When recursing the tree using visit_children, an attribute\n    access_path is maintained which gives information about the current location\n    in the tree as a stack of tuples: (parent_node, attrname, index), representing\n    the node, attribute and optional list index that was taken in each step in the path to\n    the current node.\n\n    Example:\n\n    >>> class SampleNode(object):\n    ...     child_attrs = [\"head\", \"body\"]\n    ...     def __init__(self, value, head=None, body=None):\n    ...         self.value = value\n    ...         self.head = head\n    ...         self.body = body\n    ...     def __repr__(self): return \"SampleNode(%s)\" % self.value\n    ...\n    >>> tree = SampleNode(0, SampleNode(1), [SampleNode(2), SampleNode(3)])\n    >>> class MyVisitor(TreeVisitor):\n    ...     def visit_SampleNode(self, node):\n    ...         print(\"in %s %s\" % (node.value, self.access_path))\n    ...         self.visitchildren(node)\n    ...         print(\"out %s\" % node.value)\n    ...\n    >>> MyVisitor().visit(tree)\n    in 0 []\n    in 1 [(SampleNode(0), 'head', None)]\n    out 1\n    in 2 [(SampleNode(0), 'body', 0)]\n    out 2\n    in 3 [(SampleNode(0), 'body', 1)]\n    out 3\n    out 0\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor_spec = {
  "Cython.Compiler.Visitor.TreeVisitor",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""TreeVisitor", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Base class for writing visitors for a Cython tree, contains utilities for\n    recursing such trees using visitors. Each node is\n    expected to have a child_attrs iterable containing the names of attributes\n    containing child nodes or lists of child nodes. Lists are not considered\n    part of the tree structure (i.e. contained nodes are considered direct\n    children of the parent node).\n\n    visit_children visits each of the children of a given node (see the visit_children\n    documentation). When recursing the tree using visit_children, an attribute\n    access_path is maintained which gives information about the current location\n    in the tree as a stack of tuples: (parent_node, attrname, index), representing\n    the node, attribute and optional list index that was taken in each step in the path to\n    the current node.\n\n    Example:\n\n    >>> class SampleNode(object):\n    ...     child_attrs = [\"head\", \"body\"]\n    ...     def __init__(self, value, head=None, body=None):\n    ...         self.value = value\n    ...         self.head = head\n    ...         self.body = body\n    ...     def __repr__(self): return \"SampleNode(%s)\" % self.value\n    ...\n    >>> tree = SampleNode(0, SampleNode(1), [SampleNode(2), SampleNode(3)])\n    >>> class MyVisitor(TreeVisitor):\n    ...     def visit_SampleNode(self, node):\n    ...         print(\"in %s %s\" % (node.value, self.access_path))\n    ...         self.visitchildren(node)\n    ...         print(\"out %s\" % node.value)\n    ...\n    >>> MyVisitor().visit(tree)\n    in 0 []\n    in 1 [(SampleNode(0), 'head', None)]\n    out 1\n    in 2 [(SampleNode(0), 'body', 0)]\n    out 2\n    in 3 [(SampleNode(0), 'body', 1)]\n    out 3\n    out 0\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_VisitorTransform __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform;
  return o;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_VisitorTransform[] = {
  {"recurse_to_children", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_call, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_7__call__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    A tree transform is a base class for visitors that wants to do stream\n    processing of the structure (rather than attributes etc.) of a tree.\n\n    It implements __call__ to simply visit the argument node.\n\n    It requires the visitor methods to return the nodes which should take\n    the place of the visited node in the result tree (which can be the same\n    or one or more replacement). Specifically, if the return value from\n    a visitor method is:\n\n    - [] or None; the visited node will be removed (set to None if an attribute and\n    removed if in a list)\n    - A single node; the visited node will be replaced by the returned node.\n    - A list of nodes; the visited nodes will be replaced by all the nodes in the\n    list. This will only work if the node was already a member of a list; if it\n    was not, an exception will be raised. (Typically you want to ensure that you\n    are within a StatListNode or similar before doing this.)\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_VisitorTransform},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform_spec = {
  "Cython.Compiler.Visitor.VisitorTransform",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""VisitorTransform", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_7__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    A tree transform is a base class for visitors that wants to do stream\n    processing of the structure (rather than attributes etc.) of a tree.\n\n    It implements __call__ to simply visit the argument node.\n\n    It requires the visitor methods to return the nodes which should take\n    the place of the visited node in the result tree (which can be the same\n    or one or more replacement). Specifically, if the return value from\n    a visitor method is:\n\n    - [] or None; the visited node will be removed (set to None if an attribute and\n    removed if in a list)\n    - A single node; the visited node will be replaced by the returned node.\n    - A list of nodes; the visited nodes will be replaced by all the nodes in the\n    list. This will only work if the node was already a member of a list; if it\n    was not, an exception will be raised. (Typically you want to ensure that you\n    are within a StatListNode or similar before doing this.)\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_VisitorTransform, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_11TreeVisitor_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_CythonTransform __pyx_vtable_6Cython_8Compiler_7Visitor_CythonTransform;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;
  p->context = Py_None; Py_INCREF(Py_None);
  p->current_directives = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->context);
  Py_CLEAR(p->current_directives);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor(o);
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_CythonTransform(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)o;
  e = __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor(o, v, a); if (e) return e;
  if (p->context) {
    e = (*v)(p->context, a); if (e) return e;
  }
  if (p->current_directives) {
    e = (*v)(p->current_directives, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_CythonTransform(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform *)o;
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor(o);
  tmp = ((PyObject*)p->context);
  p->context = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->current_directives);
  p->current_directives = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_15CythonTransform_context(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_15CythonTransform_context(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7context_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_15CythonTransform_current_directives(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_15CythonTransform_current_directives(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_18current_directives_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_CythonTransform[] = {
  {"visit_CompilerDirectivesNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode, METH_O, 0},
  {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_CythonTransform[] = {
  {"context", __pyx_getprop_6Cython_8Compiler_7Visitor_15CythonTransform_context, __pyx_setprop_6Cython_8Compiler_7Visitor_15CythonTransform_context, 0, 0},
  {"current_directives", __pyx_getprop_6Cython_8Compiler_7Visitor_15CythonTransform_current_directives, __pyx_setprop_6Cython_8Compiler_7Visitor_15CythonTransform_current_directives, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_CythonTransform_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform},
  {Py_tp_call, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_3__call__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Certain common conventions and utilities for Cython transforms.\n\n     - Sets up the context of the pipeline in self.context\n     - Tracks directives in effect in self.current_directives\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_CythonTransform},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_CythonTransform},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_CythonTransform},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_CythonTransform},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_CythonTransform_spec = {
  "Cython.Compiler.Visitor.CythonTransform",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_CythonTransform_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_CythonTransform = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""CythonTransform", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_CythonTransform), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Certain common conventions and utilities for Cython transforms.\n\n     - Sets up the context of the pipeline in self.context\n     - Tracks directives in effect in self.current_directives\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_ScopeTrackingTransform __pyx_vtable_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_ScopeTrackingTransform(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  p->scope_type = Py_None; Py_INCREF(Py_None);
  p->scope_node = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_ScopeTrackingTransform(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->scope_type);
  Py_CLEAR(p->scope_node);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform(o);
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_ScopeTrackingTransform(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)o;
  e = __pyx_tp_traverse_6Cython_8Compiler_7Visitor_CythonTransform(o, v, a); if (e) return e;
  if (p->scope_type) {
    e = (*v)(p->scope_type, a); if (e) return e;
  }
  if (p->scope_node) {
    e = (*v)(p->scope_node, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_ScopeTrackingTransform(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *)o;
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_CythonTransform(o);
  tmp = ((PyObject*)p->scope_type);
  p->scope_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->scope_node);
  p->scope_node = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_type(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_type_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_node(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_node(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_10scope_node_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_ScopeTrackingTransform[] = {
  {"visit_ModuleNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode, METH_O, 0},
  {"visit_CClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode, METH_O, 0},
  {"visit_PyClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode, METH_O, 0},
  {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode, METH_O, 0},
  {"visit_CStructOrUnionDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_ScopeTrackingTransform[] = {
  {"scope_type", __pyx_getprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_type, __pyx_setprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_type, 0, 0},
  {"scope_node", __pyx_getprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_node, __pyx_setprop_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_scope_node, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_ScopeTrackingTransform},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform_spec = {
  "Cython.Compiler.Visitor.ScopeTrackingTransform",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""ScopeTrackingTransform", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_3__call__, /*tp_call*/
  #else
  0, /*tp_call*/
  #endif
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_EnvTransform __pyx_vtable_6Cython_8Compiler_7Visitor_EnvTransform;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_EnvTransform(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_CythonTransform(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform;
  p->env_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->env_stack);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_CythonTransform(o);
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_EnvTransform(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)o;
  e = __pyx_tp_traverse_6Cython_8Compiler_7Visitor_CythonTransform(o, v, a); if (e) return e;
  if (p->env_stack) {
    e = (*v)(p->env_stack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_EnvTransform(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform *)o;
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_CythonTransform(o);
  tmp = ((PyObject*)p->env_stack);
  p->env_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_12EnvTransform_env_stack(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_12EnvTransform_env_stack(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9env_stack_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_EnvTransform[] = {
  {"current_env", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env, METH_NOARGS, 0},
  {"current_scope_node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node, METH_NOARGS, 0},
  {"global_scope", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope, METH_NOARGS, 0},
  {"enter_scope", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"exit_scope", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope, METH_NOARGS, 0},
  {"visit_FuncDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode, METH_O, 0},
  {"visit_func_outer_attrs", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs, METH_O, 0},
  {"visit_GeneratorBodyDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode, METH_O, 0},
  {"visit_ClassDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode, METH_O, 0},
  {"visit_CStructOrUnionDefNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode, METH_O, 0},
  {"visit_ScopedExprNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode, METH_O, 0},
  {"visit_CArgDeclNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_EnvTransform[] = {
  {"env_stack", __pyx_getprop_6Cython_8Compiler_7Visitor_12EnvTransform_env_stack, __pyx_setprop_6Cython_8Compiler_7Visitor_12EnvTransform_env_stack, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_EnvTransform_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_call, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_1__call__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    This transformation keeps a stack of the environments.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_EnvTransform},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_EnvTransform_spec = {
  "Cython.Compiler.Visitor.EnvTransform",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_EnvTransform_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_EnvTransform = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""EnvTransform", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_EnvTransform), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_1__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    This transformation keeps a stack of the environments.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_MethodDispatcherTransform __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_MethodDispatcherTransform(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_EnvTransform(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  return o;
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_MethodDispatcherTransform[] = {
  {"visit_GeneralCallNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode, METH_O, 0},
  {"visit_SimpleCallNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode, METH_O, 0},
  {"visit_PrimaryCmpNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode, METH_O, 0},
  {"visit_BinopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode, METH_O, 0},
  {"visit_UnopNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode, METH_O, 0},
  {"_handle_function", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_10_handle_function},
  {"_handle_method", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_12_handle_method},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Base class for transformations that want to intercept on specific\n    builtin functions or methods of builtin types, including special\n    methods triggered by Python operators.  Must run after declaration\n    analysis when entries were assigned.\n\n    Naming pattern for handler methods is as follows:\n\n    * builtin functions: _handle_(general|simple|any)_function_NAME\n\n    * builtin methods: _handle_(general|simple|any)_method_TYPENAME_METHODNAME\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_EnvTransform},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_MethodDispatcherTransform},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_MethodDispatcherTransform},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform_spec = {
  "Cython.Compiler.Visitor.MethodDispatcherTransform",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""MethodDispatcherTransform", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_12EnvTransform_1__call__, /*tp_call*/
  #else
  0, /*tp_call*/
  #endif
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Base class for transformations that want to intercept on specific\n    builtin functions or methods of builtin types, including special\n    methods triggered by Python operators.  Must run after declaration\n    analysis when entries were assigned.\n\n    Naming pattern for handler methods is as follows:\n\n    * builtin functions: _handle_(general|simple|any)_function_NAME\n\n    * builtin methods: _handle_(general|simple|any)_method_TYPENAME_METHODNAME\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_EnvTransform, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_15CythonTransform_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer __pyx_vtable_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_VisitorTransform(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  p->orig_node = Py_None; Py_INCREF(Py_None);
  p->new_node = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->orig_node);
  Py_CLEAR(p->new_node);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor(o);
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)o;
  e = __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor(o, v, a); if (e) return e;
  if (p->orig_node) {
    e = (*v)(p->orig_node, a); if (e) return e;
  }
  if (p->new_node) {
    e = (*v)(p->new_node, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer *)o;
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor(o);
  tmp = ((PyObject*)p->orig_node);
  p->orig_node = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->new_node);
  p->new_node = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_orig_node(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_orig_node(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_9orig_node_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_new_node(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_new_node(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_3__set__(o, v);
  }
  else {
    return __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_8new_node_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer[] = {
  {"visit_CloneNode", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode, METH_O, 0},
  {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer[] = {
  {"orig_node", __pyx_getprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_orig_node, __pyx_setprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_orig_node, 0, 0},
  {"new_node", __pyx_getprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_new_node, __pyx_setprop_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_new_node, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Recursively replace all occurrences of a node in a subtree by\n    another node.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer_spec = {
  "Cython.Compiler.Visitor.RecursiveNodeReplacer",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""RecursiveNodeReplacer", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6Cython_8Compiler_7Visitor_16VisitorTransform_7__call__, /*tp_call*/
  #else
  0, /*tp_call*/
  #endif
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Recursively replace all occurrences of a node in a subtree by\n    another node.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_NodeFinder __pyx_vtable_6Cython_8Compiler_7Visitor_NodeFinder;

static PyObject *__pyx_tp_new_6Cython_8Compiler_7Visitor_NodeFinder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *p;
  PyObject *o = __pyx_tp_new_6Cython_8Compiler_7Visitor_TreeVisitor(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6Cython_8Compiler_7Visitor_TreeVisitor*)__pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder;
  p->node = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_NodeFinder(PyObject *o) {
  struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_NodeFinder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->node);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_TreeVisitor(o);
}

static int __pyx_tp_traverse_6Cython_8Compiler_7Visitor_NodeFinder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)o;
  e = __pyx_tp_traverse_6Cython_8Compiler_7Visitor_TreeVisitor(o, v, a); if (e) return e;
  if (p->node) {
    e = (*v)(p->node, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6Cython_8Compiler_7Visitor_NodeFinder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *p = (struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder *)o;
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_TreeVisitor(o);
  tmp = ((PyObject*)p->node);
  p->node = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6Cython_8Compiler_7Visitor_10NodeFinder_found(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_1__get__(o);
}

static int __pyx_setprop_6Cython_8Compiler_7Visitor_10NodeFinder_found(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_5found_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_6Cython_8Compiler_7Visitor_NodeFinder[] = {
  {"visit_Node", (PyCFunction)__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6Cython_8Compiler_7Visitor_NodeFinder[] = {
  {"found", __pyx_getprop_6Cython_8Compiler_7Visitor_10NodeFinder_found, __pyx_setprop_6Cython_8Compiler_7Visitor_10NodeFinder_found, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6Cython_8Compiler_7Visitor_NodeFinder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6Cython_8Compiler_7Visitor_NodeFinder},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Find out if a node appears in a subtree.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6Cython_8Compiler_7Visitor_NodeFinder},
  {Py_tp_clear, (void *)__pyx_tp_clear_6Cython_8Compiler_7Visitor_NodeFinder},
  {Py_tp_methods, (void *)__pyx_methods_6Cython_8Compiler_7Visitor_NodeFinder},
  {Py_tp_getset, (void *)__pyx_getsets_6Cython_8Compiler_7Visitor_NodeFinder},
  {Py_tp_init, (void *)__pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6Cython_8Compiler_7Visitor_NodeFinder},
  {0, 0},
};
static PyType_Spec __pyx_type_6Cython_8Compiler_7Visitor_NodeFinder_spec = {
  "Cython.Compiler.Visitor.NodeFinder",
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6Cython_8Compiler_7Visitor_NodeFinder_slots,
};
#else

static PyTypeObject __pyx_type_6Cython_8Compiler_7Visitor_NodeFinder = {
  PyVarObject_HEAD_INIT(0, 0)
  "Cython.Compiler.Visitor.""NodeFinder", /*tp_name*/
  sizeof(struct __pyx_obj_6Cython_8Compiler_7Visitor_NodeFinder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Find out if a node appears in a subtree.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_traverse*/
  __pyx_tp_clear_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6Cython_8Compiler_7Visitor_10NodeFinder_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6Cython_8Compiler_7Visitor_NodeFinder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6Cython_8Compiler_7Visitor__PRINTABLE = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor = &__pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor.visit = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visit;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor._visit = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visit;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor.find_handler = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_find_handler;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor._visitchild = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchild;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor._visitchildren = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__visitchildren;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor.visitchildren = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren;
  __pyx_vtable_6Cython_8Compiler_7Visitor_TreeVisitor._raise_compiler_error = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_11TreeVisitor__raise_compiler_error;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)) __PYX_ERR(0, 25, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor = &__pyx_type_6Cython_8Compiler_7Visitor_TreeVisitor;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, __pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TreeVisitor, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform = &__pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;
  __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform.__pyx_base.visitchildren = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_TreeVisitor *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_11TreeVisitor_visitchildren *__pyx_optional_args))__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchildren;
  __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform._process_children = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children *__pyx_optional_args))__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__process_children;
  __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform._flatten_list = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform__flatten_list;
  __pyx_vtable_6Cython_8Compiler_7Visitor_VisitorTransform.visitchild = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_VisitorTransform *, PyObject *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild *__pyx_optional_args))__pyx_f_6Cython_8Compiler_7Visitor_16VisitorTransform_visitchild;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform)) __PYX_ERR(0, 226, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform) < (0)) __PYX_ERR(0, 226, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform = &__pyx_type_6Cython_8Compiler_7Visitor_VisitorTransform;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform) < (0)) __PYX_ERR(0, 226, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform, __pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform) < (0)) __PYX_ERR(0, 226, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform) < (0)) __PYX_ERR(0, 226, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_VisitorTransform, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform) < (0)) __PYX_ERR(0, 226, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform = &__pyx_vtable_6Cython_8Compiler_7Visitor_CythonTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_CythonTransform.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform)) __PYX_ERR(0, 290, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform = &__pyx_type_6Cython_8Compiler_7Visitor_CythonTransform;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, __pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CythonTransform, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform) < (0)) __PYX_ERR(0, 290, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = &__pyx_vtable_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_ScopeTrackingTransform.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_ScopeTrackingTransform.visit_scope = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_ScopeTrackingTransform *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_visit_scope;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform)) __PYX_ERR(0, 319, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform = &__pyx_type_6Cython_8Compiler_7Visitor_ScopeTrackingTransform;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_vtabptr_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform) < (0)) __PYX_ERR(0, 319, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform = &__pyx_vtable_6Cython_8Compiler_7Visitor_EnvTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_EnvTransform.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_CythonTransform;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform)) __PYX_ERR(0, 351, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform = &__pyx_type_6Cython_8Compiler_7Visitor_EnvTransform;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_EnvTransform, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform) < (0)) __PYX_ERR(0, 351, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = &__pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_EnvTransform;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform._visit_binop_node = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__visit_binop_node;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform._find_handler = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, int))__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__find_handler;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform._delegate_to_assigned_value = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__delegate_to_assigned_value;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform._dispatch_to_handler = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_handler;
  __pyx_vtable_6Cython_8Compiler_7Visitor_MethodDispatcherTransform._dispatch_to_method_handler = (PyObject *(*)(struct __pyx_obj_6Cython_8Compiler_7Visitor_MethodDispatcherTransform *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform__dispatch_to_method_handler;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform)) __PYX_ERR(0, 489, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform = &__pyx_type_6Cython_8Compiler_7Visitor_MethodDispatcherTransform;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_vtabptr_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = &__pyx_vtable_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  __pyx_vtable_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_VisitorTransform;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer)) __PYX_ERR(0, 709, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer = &__pyx_type_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, __pyx_vtabptr_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_RecursiveNodeReplacer, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer) < (0)) __PYX_ERR(0, 709, __pyx_L1_error)
  __pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder = &__pyx_vtable_6Cython_8Compiler_7Visitor_NodeFinder;
  __pyx_vtable_6Cython_8Compiler_7Visitor_NodeFinder.__pyx_base = *__pyx_vtabptr_6Cython_8Compiler_7Visitor_TreeVisitor;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder)) __PYX_ERR(0, 737, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder_spec, __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder) < (0)) __PYX_ERR(0, 737, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder = &__pyx_type_6Cython_8Compiler_7Visitor_NodeFinder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder->tp_base = __pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder) < (0)) __PYX_ERR(0, 737, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder->tp_dictoffset && __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder, __pyx_vtabptr_6Cython_8Compiler_7Visitor_NodeFinder) < (0)) __PYX_ERR(0, 737, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder) < (0)) __PYX_ERR(0, 737, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NodeFinder, (PyObject *) __pyx_mstate->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder) < (0)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_Visitor(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_Visitor},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "Visitor",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_Visitor(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_Visitor(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_Visitor(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'Visitor' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "Visitor" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_Visitor", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_Cython__Compiler__Visitor) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Cython.Compiler.Visitor")) {
      if (unlikely((PyDict_SetItemString(modules, "Cython.Compiler.Visitor", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "Cython/Compiler/Visitor.py":8
 * 
 * 
 * import sys             # <<<<<<<<<<<<<<
 * import inspect
 * 
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_sys, __pyx_t_2) < (0)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":9
 * 
 * import sys
 * import inspect             # <<<<<<<<<<<<<<
 * 
 * from . import TypeSlots
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_inspect, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_inspect, __pyx_t_2) < (0)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":11
 * import inspect
 * 
 * from . import TypeSlots             # <<<<<<<<<<<<<<
 * from . import Builtin
 * from . import Nodes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TypeSlots};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 11, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TypeSlots};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":12
 * 
 * from . import TypeSlots
 * from . import Builtin             # <<<<<<<<<<<<<<
 * from . import Nodes
 * from . import ExprNodes
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Builtin};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":13
 * from . import TypeSlots
 * from . import Builtin
 * from . import Nodes             # <<<<<<<<<<<<<<
 * from . import ExprNodes
 * from . import Errors
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Nodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":14
 * from . import Builtin
 * from . import Nodes
 * from . import ExprNodes             # <<<<<<<<<<<<<<
 * from . import Errors
 * from . import DebugFlags
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExprNodes};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":15
 * from . import Nodes
 * from . import ExprNodes
 * from . import Errors             # <<<<<<<<<<<<<<
 * from . import DebugFlags
 * from . import Future
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Errors};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":16
 * from . import ExprNodes
 * from . import Errors
 * from . import DebugFlags             # <<<<<<<<<<<<<<
 * from . import Future
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_DebugFlags};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_DebugFlags};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":17
 * from . import Errors
 * from . import DebugFlags
 * from . import Future             # <<<<<<<<<<<<<<
 * 
 * import cython
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Future};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_Cython_Compiler, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Future};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":22
 * 
 * 
 * _PRINTABLE = cython.declare(tuple, (bytes, str, int, float, complex))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = PyTuple_Pack(5, ((PyObject *)(&PyBytes_Type)), ((PyObject *)(&PyUnicode_Type)), ((PyObject *)(&PyLong_Type)), ((PyObject *)(&PyFloat_Type)), ((PyObject *)(&PyComplex_Type))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6Cython_8Compiler_7Visitor__PRINTABLE);
  __Pyx_DECREF_SET(__pyx_v_6Cython_8Compiler_7Visitor__PRINTABLE, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":73
 *         self.access_path = []
 * 
 *     def dump_node(self, node):             # <<<<<<<<<<<<<<
 *         ignored = list(node.child_attrs or []) + [
 *             'child_attrs', 'pos', 'gil_message', 'cpp_message', 'subexprs']
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_3dump_node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TreeVisitor_dump_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, __pyx_mstate_global->__pyx_n_u_dump_node, __pyx_t_2) < (0)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":105
 *         return '%s(%s)' % (node.__class__.__name__, ',\n    '.join(values))
 * 
 *     def _find_node_path(self, stacktrace):             # <<<<<<<<<<<<<<
 *         import os.path
 *         last_traceback = stacktrace
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_5_find_node_path, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TreeVisitor__find_node_path, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, __pyx_mstate_global->__pyx_n_u_find_node_path, __pyx_t_2) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":161
 *         raise RuntimeError("Visitor %r does not accept object: %s" % (self, obj))
 * 
 *     def visit(self, obj):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visit(obj)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_7visit, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TreeVisitor_visit, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, __pyx_mstate_global->__pyx_n_u_visit_2, __pyx_t_2) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":192
 *         return result
 * 
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visitchildren(parent, attrs, exclude)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_11TreeVisitor_9visitchildren, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TreeVisitor_visitchildren, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[1]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor, __pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_t_2) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":246
 *     are within a StatListNode or similar before doing this.)
 *     """
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._process_children(parent, attrs, exclude)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_1visitchildren, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_VisitorTransform_visitchildren, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[1]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform, __pyx_mstate_global->__pyx_n_u_visitchildren, __pyx_t_2) < (0)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":272
 *         return newlist
 * 
 *     def visitchild(self, parent, attr, idx=0):             # <<<<<<<<<<<<<<
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_3visitchild, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_VisitorTransform_visitchild, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[2]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform, __pyx_mstate_global->__pyx_n_u_visitchild, __pyx_t_2) < (0)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":282
 *         return child
 * 
 *     def recurse_to_children(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_16VisitorTransform_5recurse_to_children, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_VisitorTransform_recurse_to_chil, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_VisitorTransform, __pyx_mstate_global->__pyx_n_u_recurse_to_children, __pyx_t_2) < (0)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":307
 *         return super().__call__(node)
 * 
 *     def visit_CompilerDirectivesNode(self, node):             # <<<<<<<<<<<<<<
 *         old = self.current_directives
 *         self.current_directives = node.directives
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_15CythonTransform_5visit_CompilerDirectivesNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CythonTransform_visit_CompilerDi, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, __pyx_mstate_global->__pyx_n_u_visit_CompilerDirectivesNode, __pyx_t_2) < (0)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":314
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_15CythonTransform_7visit_Node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CythonTransform_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_CythonTransform, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_2) < (0)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":324
 *     #scope_node: the node that owns the current scope
 * 
 *     def visit_ModuleNode(self, node):             # <<<<<<<<<<<<<<
 *         self.scope_type = 'module'
 *         self.scope_node = node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_1visit_ModuleNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform_visit_Mod, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_mstate_global->__pyx_n_u_visit_ModuleNode, __pyx_t_2) < (0)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":338
 *         return node
 * 
 *     def visit_CClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'cclass')
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_3visit_CClassDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform_visit_CCl, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_mstate_global->__pyx_n_u_visit_CClassDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":341
 *         return self.visit_scope(node, 'cclass')
 * 
 *     def visit_PyClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'pyclass')
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_5visit_PyClassDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform_visit_PyC, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_mstate_global->__pyx_n_u_visit_PyClassDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":344
 *         return self.visit_scope(node, 'pyclass')
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'function')
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_7visit_FuncDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform_visit_Fun, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_mstate_global->__pyx_n_u_visit_FuncDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":347
 *         return self.visit_scope(node, 'function')
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         return self.visit_scope(node, 'struct')
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_22ScopeTrackingTransform_9visit_CStructOrUnionDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ScopeTrackingTransform_visit_CSt, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_ScopeTrackingTransform, __pyx_mstate_global->__pyx_n_u_visit_CStructOrUnionDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":360
 *         return super().__call__(root)
 * 
 *     def current_env(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][1]
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_3current_env, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_current_env, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_current_env, __pyx_t_2) < (0)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":363
 *         return self.env_stack[-1][1]
 * 
 *     def current_scope_node(self):             # <<<<<<<<<<<<<<
 *         return self.env_stack[-1][0]
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_5current_scope_node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_current_scope_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_current_scope_node, __pyx_t_2) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":366
 *         return self.env_stack[-1][0]
 * 
 *     def global_scope(self):             # <<<<<<<<<<<<<<
 *         return self.current_env().global_scope()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_7global_scope, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_global_scope, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_global_scope, __pyx_t_2) < (0)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":369
 *         return self.current_env().global_scope()
 * 
 *     def enter_scope(self, node, scope):             # <<<<<<<<<<<<<<
 *         self.env_stack.append((node, scope))
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_9enter_scope, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_enter_scope, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_enter_scope, __pyx_t_2) < (0)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":372
 *         self.env_stack.append((node, scope))
 * 
 *     def exit_scope(self):             # <<<<<<<<<<<<<<
 *         self.env_stack.pop()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_11exit_scope, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_exit_scope, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_exit_scope, __pyx_t_2) < (0)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":375
 *         self.env_stack.pop()
 * 
 *     def visit_FuncDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.visit_func_outer_attrs(node)
 *         self.enter_scope(node, node.local_scope)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_13visit_FuncDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_FuncDefNode, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_FuncDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":382
 *         return node
 * 
 *     def visit_func_outer_attrs(self, node):             # <<<<<<<<<<<<<<
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_15visit_func_outer_attrs, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_func_outer_at, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_func_outer_attrs, __pyx_t_2) < (0)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":385
 *         self.visitchildren(node, attrs=node.outer_attrs)
 * 
 *     def visit_GeneratorBodyDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         return node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_17visit_GeneratorBodyDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_GeneratorBody, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_GeneratorBodyDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":389
 *         return node
 * 
 *     def visit_ClassDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_19visit_ClassDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_ClassDefNode, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_ClassDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":395
 *         return node
 * 
 *     def visit_CStructOrUnionDefNode(self, node):             # <<<<<<<<<<<<<<
 *         self.enter_scope(node, node.scope)
 *         self._process_children(node)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_21visit_CStructOrUnionDefNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_CStructOrUnio, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_CStructOrUnionDefNode, __pyx_t_2) < (0)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":401
 *         return node
 * 
 *     def visit_ScopedExprNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.expr_scope:
 *             self.enter_scope(node, node.expr_scope)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_23visit_ScopedExprNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_ScopedExprNod, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_ScopedExprNode, __pyx_t_2) < (0)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":410
 *         return node
 * 
 *     def visit_CArgDeclNode(self, node):             # <<<<<<<<<<<<<<
 *         # default arguments are evaluated in the outer scope
 *         if node.default:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_12EnvTransform_25visit_CArgDeclNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_EnvTransform_visit_CArgDeclNode, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_EnvTransform, __pyx_mstate_global->__pyx_n_u_visit_CArgDeclNode, __pyx_t_2) < (0)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":423
 * 
 * 
 * class NodeRefCleanupMixin:             # <<<<<<<<<<<<<<
 *     """
 *     Clean up references to nodes that were replaced.
*/
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_kp_u_Clean_up_references_to_nodes_th); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "Cython/Compiler/Visitor.py":433
 *     and by ordering the "child_attrs" of nodes appropriately.
 *     """
 *     def __init__(self, *args):             # <<<<<<<<<<<<<<
 *         super().__init__(*args)
 *         self._replacements = {}
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_1__init__, 0, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  PyList_Append(__pyx_t_4, __pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_5) < (0)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":437
 *         self._replacements = {}
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         arg = node.arg
 *         if arg not in self._replacements:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_3visit_CloneNode, 0, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin_visit_CloneN, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_visit_CloneNode, __pyx_t_5) < (0)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":444
 *         return node
 * 
 *     def visit_ResultRefNode(self, node):             # <<<<<<<<<<<<<<
 *         expr = node.expression
 *         if expr is None or expr not in self._replacements:
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_5visit_ResultRefNode, 0, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin_visit_Result, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_visit_ResultRefNode, __pyx_t_5) < (0)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":453
 *         return node
 * 
 *     def replace(self, node, replacement):             # <<<<<<<<<<<<<<
 *         self._replacements[node] = replacement
 *         return replacement
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_19NodeRefCleanupMixin_7replace, 0, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin_replace, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_replace, __pyx_t_5) < (0)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":423
 * 
 * 
 * class NodeRefCleanupMixin:             # <<<<<<<<<<<<<<
 *     """
 *     Clean up references to nodes that were replaced.
*/
  __pyx_t_5 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_CyFunction_InitClassCell(__pyx_t_4, __pyx_t_5) < (0)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_NodeRefCleanupMixin, __pyx_t_5) < (0)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":459
 * 
 * find_special_method_for_binary_operator = {
 *     '<':  '__lt__',             # <<<<<<<<<<<<<<
 *     '<=': '__le__',
 *     '==': '__eq__',
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__19, __pyx_mstate_global->__pyx_n_u_lt) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__20, __pyx_mstate_global->__pyx_n_u_le) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__21, __pyx_mstate_global->__pyx_n_u_eq) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__22, __pyx_mstate_global->__pyx_n_u_ne) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__23, __pyx_mstate_global->__pyx_n_u_ge) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__24, __pyx_mstate_global->__pyx_n_u_gt) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__25, __pyx_mstate_global->__pyx_n_u_add) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__26, __pyx_mstate_global->__pyx_n_u_and) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__16, __pyx_mstate_global->__pyx_n_u_div) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__27, __pyx_mstate_global->__pyx_n_u_floordiv) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__28, __pyx_mstate_global->__pyx_n_u_lshift) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__29, __pyx_mstate_global->__pyx_n_u_mod) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__30, __pyx_mstate_global->__pyx_n_u_mul) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__31, __pyx_mstate_global->__pyx_n_u_or) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__32, __pyx_mstate_global->__pyx_n_u_pow) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__33, __pyx_mstate_global->__pyx_n_u_rshift) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__34, __pyx_mstate_global->__pyx_n_u_sub) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__35, __pyx_mstate_global->__pyx_n_u_xor) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_in_3, __pyx_mstate_global->__pyx_n_u_contains) < (0)) __PYX_ERR(0, 459, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":478
 *     '^':  '__xor__',
 *     'in': '__contains__',
 * }.get             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_find_special_method_for_binary_o, __pyx_t_5) < (0)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":482
 * 
 * find_special_method_for_unary_operator = {
 *     'not': '__not__',             # <<<<<<<<<<<<<<
 *     '~':   '__inv__',
 *     '-':   '__neg__',
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_not, __pyx_mstate_global->__pyx_n_u_not_2) < (0)) __PYX_ERR(0, 482, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__36, __pyx_mstate_global->__pyx_n_u_inv) < (0)) __PYX_ERR(0, 482, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__34, __pyx_mstate_global->__pyx_n_u_neg) < (0)) __PYX_ERR(0, 482, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__25, __pyx_mstate_global->__pyx_n_u_pos_3) < (0)) __PYX_ERR(0, 482, __pyx_L1_error)

  /* "Cython/Compiler/Visitor.py":486
 *     '-':   '__neg__',
 *     '+':   '__pos__',
 * }.get             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_find_special_method_for_unary_op, __pyx_t_2) < (0)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":503
 *     """
 *     # only visit call nodes and Python operations
 *     def visit_GeneralCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_1visit_GeneralCallNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform_visit, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_visit_GeneralCallNode, __pyx_t_2) < (0)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":518
 *         return self._dispatch_to_handler(node, function, args, keyword_args)
 * 
 *     def visit_SimpleCallNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         function = node.function
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_3visit_SimpleCallNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform_visit_2, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_visit_SimpleCallNode, __pyx_t_2) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":530
 *         return self._dispatch_to_handler(node, function, args, None)
 * 
 *     def visit_PrimaryCmpNode(self, node):             # <<<<<<<<<<<<<<
 *         if node.cascade:
 *             # not currently handled below
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_5visit_PrimaryCmpNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform_visit_3, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_visit_PrimaryCmpNode, __pyx_t_2) < (0)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":537
 *         return self._visit_binop_node(node)
 * 
 *     def visit_BinopNode(self, node):             # <<<<<<<<<<<<<<
 *         return self._visit_binop_node(node)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_7visit_BinopNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform_visit_4, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_visit_BinopNode, __pyx_t_2) < (0)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":561
 *         return node
 * 
 *     def visit_UnopNode(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         special_method_name = find_special_method_for_unary_operator(node.operator)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_9visit_UnopNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform_visit_5, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_visit_UnopNode, __pyx_t_2) < (0)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":699
 *         return result
 * 
 *     def _handle_function(self, node, function_name, function, arg_list, kwargs):             # <<<<<<<<<<<<<<
 *         """Fallback handler"""
 *         return node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_11_handle_function, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform__handl, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_handle_function, __pyx_t_2) < (0)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":703
 *         return node
 * 
 *     def _handle_method(self, node, type_name, attr_name, function,             # <<<<<<<<<<<<<<
 *                        arg_list, is_unbound_method, kwargs):
 *         """Fallback handler"""
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_25MethodDispatcherTransform_13_handle_method, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MethodDispatcherTransform__handl_2, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_MethodDispatcherTransform, __pyx_mstate_global->__pyx_n_u_handle_method, __pyx_t_2) < (0)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":718
 *         self.orig_node, self.new_node = orig_node, new_node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         if node is self.orig_node:
 *             return self.new_node
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_3visit_CloneNode, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RecursiveNodeReplacer_visit_Clon, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, __pyx_mstate_global->__pyx_n_u_visit_CloneNode, __pyx_t_2) < (0)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":725
 *         return node
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._process_children(node)
 *         if node is self.orig_node:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_21RecursiveNodeReplacer_5visit_Node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RecursiveNodeReplacer_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_RecursiveNodeReplacer, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_2) < (0)) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":732
 *             return node
 * 
 * def recursively_replace_node(tree, old_node, new_node):             # <<<<<<<<<<<<<<
 *     replace_in = RecursiveNodeReplacer(old_node, new_node)
 *     replace_in(tree)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_1recursively_replace_node, 0, __pyx_mstate_global->__pyx_n_u_recursively_replace_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_recursively_replace_node, __pyx_t_2) < (0)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":746
 *         self.found = False
 * 
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         if self.found:
 *             pass  # short-circuit
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_10NodeFinder_3visit_Node, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NodeFinder_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_NodeFinder, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_2) < (0)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":754
 *             self._visitchildren(node, None, None)
 * 
 * def tree_contains(tree, node):             # <<<<<<<<<<<<<<
 *     finder = NodeFinder(node)
 *     finder.visit(tree)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_3tree_contains, 0, __pyx_mstate_global->__pyx_n_u_tree_contains, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_tree_contains, __pyx_t_2) < (0)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":761
 * 
 * # Utils
 * def replace_node(ptr, value):             # <<<<<<<<<<<<<<
 *     """Replaces a node. ptr is of the form used on the access path stack
 *     (parent, attrname, listidx|None)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_5replace_node, 0, __pyx_mstate_global->__pyx_n_u_replace_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_replace_node, __pyx_t_2) < (0)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":772
 * 
 * 
 * class PrintTree(TreeVisitor):             # <<<<<<<<<<<<<<
 *     """Prints a representation of the tree to standard output.
 *     Subclass and override repr_of to provide more information
*/
  __pyx_t_2 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6Cython_8Compiler_7Visitor_TreeVisitor)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_4, __pyx_t_5, __pyx_mstate_global->__pyx_n_u_PrintTree, __pyx_mstate_global->__pyx_n_u_PrintTree, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_kp_u_Prints_a_representation_of_the_t); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_5 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 772, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":776
 *     Subclass and override repr_of to provide more information
 *     about nodes. """
 *     def __init__(self, start=None, end=None):             # <<<<<<<<<<<<<<
 *         TreeVisitor.__init__(self)
 *         self._indent = ""
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_1__init__, 0, __pyx_mstate_global->__pyx_n_u_PrintTree___init, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[1]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_2) < (0)) __PYX_ERR(0, 776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":784
 *             self._line_range = None
 * 
 *     def indent(self):             # <<<<<<<<<<<<<<
 *         self._indent += "  "
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_3indent, 0, __pyx_mstate_global->__pyx_n_u_PrintTree_indent, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_indent_2, __pyx_t_2) < (0)) __PYX_ERR(0, 784, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":787
 *         self._indent += "  "
 * 
 *     def unindent(self):             # <<<<<<<<<<<<<<
 *         self._indent = self._indent[:-2]
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_5unindent, 0, __pyx_mstate_global->__pyx_n_u_PrintTree_unindent, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_unindent, __pyx_t_2) < (0)) __PYX_ERR(0, 787, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":790
 *         self._indent = self._indent[:-2]
 * 
 *     def __call__(self, tree, phase=None):             # <<<<<<<<<<<<<<
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_7__call__, 0, __pyx_mstate_global->__pyx_n_u_PrintTree___call, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[3]);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_call, __pyx_t_2) < (0)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":799
 *     # under the parent-node, not displaying the list itself in
 *     # the hierarchy.
 *     def visit_Node(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_9visit_Node, 0, __pyx_mstate_global->__pyx_n_u_PrintTree_visit_Node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_visit_Node, __pyx_t_2) < (0)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":806
 *         return node
 * 
 *     def visit_CloneNode(self, node):             # <<<<<<<<<<<<<<
 *         self._print_node(node)
 *         self.indent()
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_11visit_CloneNode, 0, __pyx_mstate_global->__pyx_n_u_PrintTree_visit_CloneNode, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_visit_CloneNode, __pyx_t_2) < (0)) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":818
 *         return node
 * 
 *     def _print_node(self, node):             # <<<<<<<<<<<<<<
 *         line = node.pos[1]
 *         if self._line_range is None or self._line_range[0] <= line <= self._line_range[1]:
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_13_print_node, 0, __pyx_mstate_global->__pyx_n_u_PrintTree__print_node, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_print_node, __pyx_t_2) < (0)) __PYX_ERR(0, 818, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":831
 *             print("%s- %s: %s" % (self._indent, name, self.repr_of(node)))
 * 
 *     def repr_of(self, node):             # <<<<<<<<<<<<<<
 *         if node is None:
 *             return "(none)"
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6Cython_8Compiler_7Visitor_9PrintTree_15repr_of, 0, __pyx_mstate_global->__pyx_n_u_PrintTree_repr_of, NULL, __pyx_mstate_global->__pyx_n_u_Cython_Compiler_Visitor, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_repr_of, __pyx_t_2) < (0)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "Cython/Compiler/Visitor.py":772
 * 
 * 
 * class PrintTree(TreeVisitor):             # <<<<<<<<<<<<<<
 *     """Prints a representation of the tree to standard output.
 *     Subclass and override repr_of to provide more information
*/
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PrintTree, __pyx_t_5, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PrintTree, __pyx_t_2) < (0)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "Cython/Compiler/Visitor.py":861
 *             return result
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 *     import doctest
 *     doctest.testmod()
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_main, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_7) {

    /* "Cython/Compiler/Visitor.py":862
 * 
 * if __name__ == "__main__":
 *     import doctest             # <<<<<<<<<<<<<<
 *     doctest.testmod()
*/
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_doctest, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 862, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_1;
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_doctest, __pyx_t_5) < (0)) __PYX_ERR(0, 862, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Visitor.py":863
 * if __name__ == "__main__":
 *     import doctest
 *     doctest.testmod()             # <<<<<<<<<<<<<<
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_doctest); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_testmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 863, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "Cython/Compiler/Visitor.py":861
 *             return result
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 *     import doctest
 *     doctest.testmod()
*/
  }

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init Cython.Compiler.Visitor", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Cython.Compiler.Visitor");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_super); if (!__pyx_builtin_super) __PYX_ERR(0, 69, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_print); if (!__pyx_builtin_print) __PYX_ERR(0, 154, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 218, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "Cython/Compiler/Visitor.py":416
 *             self._process_children(node, attrs)
 *             self.enter_scope(node, self.current_env().outer_scope)
 *             self.visitchildren(node, ('default',))             # <<<<<<<<<<<<<<
 *             self.exit_scope()
 *         else:
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_default); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "Cython/Compiler/Visitor.py":649
 *                 # C implementation of a Python builtin method - see if we find further matches
 *                 self_arg = node.self
 *                 arg_list = arg_list[1:]  # drop CloneNode of self argument             # <<<<<<<<<<<<<<
 *             else:
 *                 return node
*/
  __pyx_mstate_global->__pyx_slice[0] = PySlice_New(__pyx_mstate_global->__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[0])) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[0]);

  /* "Cython/Compiler/Visitor.py":788
 * 
 *     def unindent(self):
 *         self._indent = self._indent[:-2]             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, tree, phase=None):
*/
  __pyx_mstate_global->__pyx_slice[1] = PySlice_New(Py_None, __pyx_mstate_global->__pyx_int_neg_2, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_slice[1])) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_slice[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_slice[1]);

  /* "Cython/Compiler/Visitor.py":192
 *         return result
 * 
 *     def visitchildren(self, parent, attrs=None, exclude=None):             # <<<<<<<<<<<<<<
 *         # generic def entry point for calls from Python subclasses
 *         return self._visitchildren(parent, attrs, exclude)
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "Cython/Compiler/Visitor.py":272
 *         return newlist
 * 
 *     def visitchild(self, parent, attr, idx=0):             # <<<<<<<<<<<<<<
 *         # Helper to visit specific children from Python subclasses
 *         child = getattr(parent, attr)
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "Cython/Compiler/Visitor.py":790
 *         self._indent = self._indent[:-2]
 * 
 *     def __call__(self, tree, phase=None):             # <<<<<<<<<<<<<<
 *         print("Parse tree dump at phase '%s'" % phase)
 *         self.visit(tree)
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<4; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_slice;
    for (Py_ssize_t i=0; i<2; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{1},{25},{371},{16},{26},{26},{6},{4},{179},{29},{135},{8},{1},{2},{1},{1},{2},{2},{1},{1},{2},{1},{2},{2},{2},{2},{1},{1},{1},{2},{2},{1},{3},{1},{1},{2},{2},{1},{1},{1},{1},{1},{6},{1},{0},{1},{2},{8},{7},{13},{8},{4},{7},{25},{6},{2},{5},{4},{9},{8},{8},{7},{11},{6},{6},{6},{6},{9},{9},{8},{10},{13},{7},{12},{12},{13},{9},{15},{44},{26},{23},{10},{7},{8},{12},{24},{31},{24},{23},{25},{31},{40},{31},{30},{39},{33},{35},{6},{8},{9},{6},{25},{42},{40},{47},{46},{46},{41},{40},{10},{8},{4},{10},{21},{19},{28},{27},{35},{39},{5},{9},{18},{18},{21},{16},{17},{18},{25},{20},{11},{20},{21},{37},{32},{22},{42},{50},{40},{39},{43},{11},{27},{21},{17},{25},{9},{9},{16},{36},{27},{30},{1},{0},{11},{7},{7},{3},{8},{9},{4},{11},{18},{4},{9},{9},{15},{8},{5},{8},{13},{8},{7},{6},{14},{8},{11},{9},{17},{18},{11},{7},{4},{12},{7},{11},{11},{18},{1},{28},{13},{7},{8},{10},{7},{8},{7},{7},{9},{3},{8},{11},{5},{9},{6},{8},{7},{10},{4},{10},{10},{6},{8},{8},{15},{39},{38},{6},{12},{5},{8},{8},{9},{13},{17},{6},{7},{3},{15},{6},{11},{12},{6},{8},{12},{16},{14},{3},{7},{2},{7},{6},{8},{7},{7},{12},{10},{15},{10},{13},{17},{7},{11},{9},{17},{7},{5},{12},{6},{14},{6},{4},{11},{7},{11},{11},{10},{6},{8},{13},{7},{11},{7},{6},{10},{15},{7},{8},{4},{6},{7},{7},{8},{4},{5},{3},{7},{3},{8},{6},{3},{8},{7},{8},{8},{8},{6},{9},{2},{7},{11},{11},{6},{11},{4},{5},{3},{3},{7},{15},{7},{11},{5},{11},{3},{7},{14},{12},{19},{24},{7},{10},{12},{11},{13},{7},{6},{3},{4},{10},{5},{4},{12},{10},{6},{4},{6},{19},{20},{5},{10},{5},{10},{3},{6},{7},{8},{5},{3},{1},{8},{7},{7},{4},{13},{11},{4},{9},{9},{7},{8},{5},{6},{6},{5},{15},{18},{19},{27},{18},{15},{28},{17},{21},{26},{16},{10},{20},{20},{19},{20},{20},{14},{22},{10},{13},{7},{65},{72},{52},{36},{94},{54},{38},{305},{47},{11},{15},{15},{9},{39},{124},{37},{18},{31},{15},{21},{118},{87},{35},{106},{17},{282},{51},{42},{126},{7},{9},{75},{130},{13},{14},{17},{15},{15},{48},{31},{27},{21},{22},{23}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (3426 bytes) */
const char* const cstring = "(\265/\375`\341\034\305j\000\372{\240\031G\360\224\324\001\314\300\354\204\007\026*\023\266rX\235)n*`\t)\334\224\270t\256\342\333-#\355\026\311\242\204\244\245\335\244\306\223\220\340V\001\374E@e\340\307,\341\211\205-\002\274\214\010OIs\000\262<\372U\023\021l\001a\001\224\001\033\225\357\227\223\336\241\350Wn\007w\222\203;q\331\241iZ\016\223\031\317\037\252J\026\031\243\302T\266\370\3448*c\264\025\026\025\022Bx\264\214\030\221!\003\220\014rF\236\310\310\270\270\240h\03013b\206433##\263\262\242\303e\305D\266\354\310\201\302\227\345\272\323\271\212\357M\376\274\374]\311a\232\337\337q\266\025\307H\371\223\247+\317c\371c\032C\363\357h\215\273*\256\234L\231)\376\322>\365\276\373\222)\025R{\367^\271\253\037\352\375\237v\033\352{\371y\363\036\216_`^Zb\234\210!-\366\274U\234_bG\325\316\253\364l\357\213\024Y\363\3624|i\270\270\274\360\356\343\256\013\r{W=\326\245\321\354]\345\227\366\352<\323\212=\232\272\322\344q\316t\2328\207\257\245\251\317\336\305\236\2442Si\262\242\302uu\265\345\372\325\245\245:\177\223\256\243\233|\241$\347*K1\246\222s\2678Rj\035}\354.\352\216\263\354(\013_\213?\016\343/%_\226J\225\2559\327\325M9J\262\344\3075%\335^\356\253d}\377T\332[3\315\326Y\336y\254*\277\306\234\300\201\361\242\200\306\371F;/Gf\272\342\256\2257\313\367\315\246\034K\357\223\226zG#\013\310\030\307\276\222\371k'3\366\267U\346k-\245\211\t\025o\357\334LM\234\302\367v\251\371\315\027\246\266\242\346\354h\335\334\373\277\327\316\324c\317\271\257\233\263\345\254\317\372\013\257r\315y\316z~\317\333\375\352\332*7g\356>\232r\216s\354\\\365|\323\361\311q\256\242?=o{[i\266\227\353\356\206\362<Y\236kv\225g\253\2523\265m\316\321\355\375)\352\347\273\255\371\273\370n\332\255\233}=\212VL]\363\351\347i\347\234\377s\336<\035k\237ow\363\341\254fjj*[}l\330U\037\177\233\313\320q\235\327\313~\336\234\356\030\347s\367\275\313\260w\332:\247f\253Nu\341})\227\201\235\263\265\206E_\314\270\266\232\360X4/LY7\035\245\351X\336q\226\256\246\266e\352}=q\356\302\361\227\277\232\377\357\316\024\366tNp7/\356\232""\240\330\255\243\260\267\332\031\030F\336>\234o\272\315O*l\352(\352v\252\\u\260kv\272w\267wY\237\331:\306\337\246\271\354\211\255\236^E\273\032\325\207\362\323\237&N~{iVO1M\312O\233\375jhL\230\360\305\370D\306\027e\232\361\257\243.\311\262\362'\222Ee%\337\213UTf\376z*+n\257UY1\371\023\025\026\265nk'YR\270\257,\233\312\272\214A]\231=\337\002\022>l\241 \343\360\034\350@4\263\001\033\204\246\360\023\2426\213G\237@\006DN\261\024\343gl\211/b\207\030\311\330\"\014\261Q\330\304\220\235\210\244\210}b-\021+1\320\210\"\216\304\024\004\372\001\203\031I{L\302\014\255}\262ktIK\030\315JDrLg|\031I#'~\210 \213 \"\331(z\244\177Dh\000\n\000=\230\302\324H\223h\034\360\002\250\340\300NI\033\240;GS\215\300F\344 \002\331/\233F\010\034\205\037f\244\330\217'\343\213-!\267W\032\203\236\001\356\230\206\320m\263O\026\310r\211\264MvZ\260\027\034Q\310\226\321$\375\"k\007\332\243[\300.\204d\241!-X\002\320\314\0042\010\315h\211hV\322(\300\017\226 4\033\215\037D\230\027pAh\346\361l\220n\201#\240\010\264S\n5|d-\235\000\024\205vL\342G<\205\013\302m\023\330R$\023\205f\245\020\305\376\354\033=@\227\200\037`\006@\263\026\310\002\026\002\315l\264I\207\000\027\200f\245\r\004,\371\310t\346W\373\271E\345\374\257\377\376Q\337g\234?\327\316{\337\360w\377\263\247:\177|\361\2570~\226\255\363\325\341\216~-\024\315.\357\345\341\354\341\216\326\353y\327\243\236\366\367U\225C\211\263\\w\257\375\034U\367\275\327y1\315\316J\325\325c_M\357\3631g\316\361\3619/\367\361\265>g\277\213\262_\367/o\233\357\272:\\\355\252\352bV6\242*\\\301\220\360\214Z\230\001Fa\010\304\037\233n\224\221l4\372x@\024X\201\017\016\330\201\032\021\025j\010d6\037\231M\250\201d\207\264\013h\020\2503d\3443\363\354\036\340\n\330\201\001\000@E<ChHA\206\264G\033\307\200\330Q\031\271\036\273\264\023\202\212&\304Px\"@\002\177\244!j#%\021\t\000\002E< \010\233$\272\330)mB\327\000\033L(\231\265v\325\r4\336\234\256 *\331\003\030l\222\025\235\007\024A\000\315D\tHt\207'8[H+\207\004r1Rl\306\250B\224\020\376\000\022\272v\313gg\217\340\360\2047\233\3036P\032""\271\030,h\351\021\375@4;`#\232\304\020T\213\030\201)\350\005\035a,\235\304\222(@\004\205Z\n\250 Tb\203\014%\364\240\025h\010\242\331\203\222Y\353\006\205\r\250\202!\000G1\013\242\313\006\241%\204f#\021\207/\241\200p\206\202\030@\005\033G\nDHc\237\210\035Jd\246\035\323N\241'\214\240O\250R\"\323\241:\007,\t\215\210\340\304L\261S\005Y\005\021B\350C\333\350\230\0070\255\321\301\370#t\020zB\225\027\204qDH\n\013\354\223\376\350\231\022\032\336\330\032L\372\003u4\205\000\372\005\223\001; \003Cu\205V)\0063f\021\004\212\014\3036Q \033\201\243\320\314F\rY\r\0322\026\"\\l5v\030\005\310\204y\323\354O\323\350 *@\024\272\303\206a!C\253V\300Ft\006i\300\257\265C\212\215b\333\210a\034\215\233H@\334\300!\364\222\026\240=\2308\227~\321\001\203Z\250\302\263\022*\206\210dD\n\222\244\220\3062\020\014\034\014\3444\030t\017\322\261\264\203R\031cDDDFDDRP\222\202\2445Z\002y[\335I\375\314\020\315K\211\220 \344\273\345\346\220\271+\347\034\314\243\313#\004\216?\265>\322t\370%\343S#=\253\023u\327\"\330\024\030t\361.\022\375,?\210\010\342\005\340k\006E\301\352wQ\034'yp\200\360\233\025c*\214\376\225\006\273\362\340\333\264\254jb\265wB\275\330\010)\326\020\000\247xy\003\3137\245w\214%-9\373'i\376\363\363\222\314Q?\262\370\017e\004\034f\r\364M\032\237j\230N5\352\326Y\000)\211\206\234\t\371O\034\221\232\210\371\204\255\205\\o\277|&\036KV\234\366\213m\370(D.\200\267\203\326j\t\204\002\215^\207\237\211\362\206\\\203\030ig\312\365\246`\302,d;=U\243pQ\263\371\326\323\314\217dh\020\207\307\324\\\360\037\322\311\216\226\324\203\215\036\000f\257\2525\010\265\246\305\212M\250WI\262\272T\020\206\010\rY=>\331\340\024M\2072JT\000\222I$\"\301p\242/\332\220\277 ^\225\265m\342I\326\037\350\362\t&\345\335%\367sNm!-\214\034=gL\367\n\273\354\3206P)\245k\316-J\304r\302Z]%\237b\236%\004\014\000\265\0001\037\320\241\027b\247\3070\205\034\340\376\247\013Q'\304[\2615\316[\360K1\247J\033\360}sa\200\370ca\234MuA\266)[a\350\223\355(\004\313\230y\200\000\261\023\2227_\365\000%\306_\026\276\254\210H\333)\"\363C\321\001%c<%""\023J\030\252!W\235<\031\003\001\205JQE\n\240\264\331HZc'\334\254\010\206\216B}\235I> re\263\013\2639\224\200id\n\022\300\307\371\324\201@]\324l\\\271C+T\026Y\243\321\232N\000\313>\243\006\241\253o\374\204\373Wg\253!\013%\335\231\370\315B\022\324`7j\265\366\334\002\034\275\331LP\007*'!<\316\356@*\035:\277\252\250\336\014y\013\201 H\257r\205]\244\205\310\200\030\301$\004\365-\265\357\272H\346\221\0002\271\232\330\242\020\020\357/2Rz&M \320s\326\235\346\007R\032:\001\237 0\370O\267\210zi\331)-\r\367\"\343\330\261{\311^<\357\317\274\221\341\336\370k\007\005\224\033I\361X\224q\213\234D\254\275F\245\031\303>$q\265\353@\256\311\006b\347\361\270\217\255J\204\240s\225T}\306\244\277;\320\306\334\324\267]saGk\030$\t\264\235\274\005/\210\2220\000\237}'\355\036pF\271\024\3619\221-\214)\022\201c\240\341\007\2745R\003\n\320=\020;\370[\001\305\322%\255\267\270L\205\354\200i\334\251\261\252\210\007\244S\250R\270\\@q?\036\257\17729n/n9\244\321\240\002h\026\375\2754B.\tY\364\335hX\237\025'\323\262W~h+\275\305\024\256\373\0074\027\014\255\211I\004q\230\230\374\202\277\241^*\217\235H\226)`4\320oQ\032+d\362\257\302\200E6g\001-K)n\261\022\350\310-\263c\315\212\356\246\263\004\010\030\3564\034t\"\325\026\347\327] g\224\221=%\362\313Gk\206\034lIh\001\232;\034\242GHO\030\376\210\354\272\351\244B\200v&=\032\261\334\312\330\024\027^p3\003%\273v\360\2739\306@\345 '2\207\225\327\374\251\234R\023\247<\235\311\025\3607\333F\357}\243\272\250\374\002\307\322\376R\270j\330\250\357\333\270p\340\225\343\312.\337\3043\"\"\020\026\331\023\272\341G\\\212\225\346^1\332\340\276-\335=\373\367\376\264\177\005\354\277\327\265\313\220\305\356\025F.H]\023\"OF1\005`\266\264\232\371zVD,\212?\231(Q\231\2456;&\310\2774y\0360c$@\311\327\212\217<\314QR[\024\245\333\310\340$\363H\305\247\267\023\243\205\010\342c\353\236\013J\230X\001\273\003\210\251\317\245S\214\300r\241F\023>r\035\200>\245=^\274\265v\315\010\214\260?\026:xf\336\307\272\240\320!\372t\273\335\023\336\342\365\257\036\320A-\255Ss\213\2436t\225\330\021""\tp\227^\246\262d\000\236\374\375\360\007\235e\331\340\245b\305L\033\332]\027'\025t\340;G\301\214\232\322\244\033\227\204\274d\271\347\024\000\034 \204\323\360\334\206\rQ\376_}\036\222\256\006\225 w\257\264\273<:\272r\306`\317pa\376\005F\232H\3227p\2039\252\247$\317\323N\350O\025eF|\014@\301\013n\307\017\222\377\357\036\002A\244\367\0252:\314\010\313\306\211\031Y\351\017h\2751\204v\247\273C^\260VMT\335\250X\262\210*0^/L\215VZ\241\031\244|\272\225I5\302\233\240\036\330g\002\207\206\016\027!\324N^\327\374\250\315\343\317l\010\325\231B8\302\311\271i\260\023\364DH\303\030\342T \371\343\016\003o\014\014\271\3761\t\232\326\214\2412\264\235D\304\020\222\333\257[U\313W\244q'\232U\212\321\275\207\276\017\276\327z>k\001\325\217\"\0368Z\242Q\232\310\311\273\"\315\305Z\304t\207&\303\231<\215 \331m\002\231CQ\262\201B\027\353\242\320\246\244]\2605\334\370\"\244Q\3642T9\346\026\240M\207\240 \301D\232\323\007\213\224\032\035_\n\031GN\rjn\316E[/g\213\251v+\020\217\251U\tx\013\262 \324\352\333t \217\213/\215\216]\227\366G\001\245\206\210)\":G\255xK\265\375\375\235\035kN\000\363\212\373\226\262$\322y\027\363\3254\224\371\342W\332\260\235@\301\231\210\353E&+\036k\n\340\202\227\373\214\366f\337y\2776\336\234\225E\003\t\001\352\034G M\017\r:i\360TR\270\221\004\272}zH\267\376\354d\007\207\026\265\314\340l\225\275\007\004B3\203\014\343\341\370\033\247\243\253X\321\241\021\315\310w,|e\366\3067;\014\016\264\363\374\3534\005\2769@\007\245<\352\302\315\001t\032\354Q\317\373\2437\225\302b\300\022?\275\372\331yvF6B\326\270\315[|m\200l*\\\360\237\340\263V5{+-\364\355:P\215\013\201\344\211A\302K\273\334\313\"4e\006\345\344B\312\235\370\325T\265\324\355\271B\246\024\235x\264\303\207\2559Dsp\002j\206\303\\\021\005\316+F\n\005sA\320]\340K=\023\204\376Y\024\256\324\260\314\202\223\033o\326\000Z";
    PyObject *data = __Pyx_DecompressString(cstring, 3426, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (3475 bytes) */
const char* const cstring = "BZh91AY&SY\214W\353\265\000\002y\177\377\377\377\377\377\377\377\377\377\377\377\377\377\277\377\377\367@@@@@@@@@@@@@\000@\000`\016\033\340\343\244wwwr\257mP\252@\250\244\n\000\243Z\252\245U\255\3277\2007p52\024\310\247\232P\331&OFj\rLM1\211\214\223M2\236\211\200\214i4\321\210\311\243CA\240\362\230\231=L\023L \224\020\004&H\36542\206S\311\244\306\251\246\201\241\243@\000\000\000\000\000\000\0004\000~\250\r4\324\320\225\000\320\003!\240\032h\000\r\r\000\000\365\000\r\000\000h\321\246\200\000\365\007\250\003ORDDm\023i\244\303B\036\246\230\236\243L\0024\321\240dd\0321\031\006\021\350!\240d\304b=@\001\2102`\004\300&&L\230\000\023\002`&&\t\200\000\000\000\023#\0010!\204\000\221 @@F\202`(\332\231\017D\324\315F'\2504\003@\000\006\200\000\000\001\246\215\r\006\232V\227\240\016\310$\000H\373[\266\354>\354\236\330,\377\213\223\225\300E\r\311\316\020\254P\031kQ{\"\366QE\205UJ\337\246\245}\250\201T\336\305Ne1^\323\022@\306\r\246\306\320\332E\n\030\335\216\024\241y?\027\355\361m\227#\365}_^\325\331\216<H\t0\314\236\264#`\330\333C\033hm\003h\337\005D\205Cl\002\247,\027t\332$\026\013\357\222AQ\203m\200\301\261\314\220\202\341\210l\260\332\037E\n\202l^<\300\245\246R\344ddn\344\346\312\251\r\364%\006\360\252\272\265+6\252\262\306+\201\327\206$r\212\016\004\025T\220\242\253,\343\242\243\220\213_\315\3619\006\263\270\305L\212\227\"\205\226zf;\252x\373d\360\265\252\204\"\267\025\014\004\252Qi\n\255#|\235\300\205\264\334!\360\277\243\000\201\030 F(\324\367@\320d\3618\377\217Y|d\253\222d\363c\233\376\303\332<W\220\013\203\200s\276\310|\033&\206\306\2053r\006$\031\333\373\312\370I\325r\245\261%.O\340\355\234qH\322T\261I1\266\304\360\206rb\360t?\266s\026\221\336r\365\370;\006D\203\211\325\331\345:'4Y+)&\240f\202H\315\355>\000\242\030)O\320.E\000\320\200\375Fo\303E\251\237\276\335\274\034\0044\310\200\373B\367\255\241\"\311\213k\026\312\310\241\205\366b\372\241\010\202\241\0341&\022\325qm\301\005\265\276\263\035:V\031\263\006\304Cb\013\306\270\255\223\002\003\3341^\302\253K\321\264\213&""\016\005\220\273v\013h\224 \222\215$\234Pr\314$\262\252Q \220d\222f.\\\"\303`\237)j\356\350f0\265\330\3532t\326^\346o\306?e\241\261X\354\356NU\240\310\033!\316J\0069:\221\022\357\223\234\342\334\363\223%YBQ\177%\354}\177e\200\205\321\022\201B\326\241\031 \241!\222U\224c3\213\331\262\240\312\336\260\024\245Y\311\265on\263\324Ar%\231\250@\017\305\344\266\220\213sb\357Qp\236\274YH}\326\377\261\030cG8\261\203\336\r\027%\230]\226\r2\315yDB\243\202\355E5\312\026\013\250\234\303\255\251\366\017\322\226\216\373\210\363\373\310\220H\257R\346\316\207\370\254\271\257\265\307}\233\306\263hS\302z\035<j\330\263\273\014\254\355V\221\332\005\213[\2257}=\347\235\373\375\r\277\357b!\332\272lVm\333\\\327\207:O\263\214\034\0305t\324v\351\342\302\t\252\244\325\003\223o6\315\024>\032;Q\244\323\311)>x\215\233\247\322\303\226L\246\024\031\001j\304<\242\005$\341\232siN(\364gW\234\\\224_\321\226h\237\266\311\352u\365\332bQE\226*\331^#\251\273g\027\000\310\027\006\251\314d\251'\022\244\034\317z\374\3323Mbc\211\3034LD\326\255\224\244)Knd\224\322\227\021\220\213 &\217\007xA\340\350\024\035\340T0/\\\235d\267-\307\337\242fG\301\316eS\302\246\375q\350\341\035L\363\271\217\362=2<\360\235\275\336\255^\353]<\375\340\\\002I\260c=\230\200\030'\326\366\310\025w\246o\322Um\375\315.\024\302\023\2473\264\305\357_\266=\335\370\274$\306\305\362`Y'\335\022jd\246r.QM\271\035\270\217\371;\364\331\347g\257\034.\2136\240\242\367\303\"\221g,`\223\010\270\303Arg\240\270,\211\227t\222\244\325_\324E\264\212:\272\225Q\357\252\274\362\212\217&\035\235\025o\226P\2663qfe\203\326\362\035\263x\306$\340\267M\243\033\010\335]3\243A`\262\203M\266d\2548\254\320I\330\315\312\223\243\340\307t!\030V\244wH\336B\035\323<q\226HTP\027\214Q(B;lO\232B\274\313\\0.\237\222\020\276s\365x\325\313\301h\000o\233n\315e\010\325AIe\346B@Y\023\342^^\032\250\374\267\2215\341\234\274\371\034\246\207.\253\267r\351\236j\202e\203l\223\212D\n\344\370d\214\346\246,mq\204\232\206v\212y\235\320\356\367{\240\244\333d\342;\033x1.u\230\30124m\221C\345!\373""\271Z\245\026E\020s\014\270P,\275Jb\365(\315r\352\210s\361\324p\250\360z\231\240v\321\212\250\252\301\nI\001\323}e\327\343aB\231>\345\304mk\025\354\t\203\030\243\273\242U\257\002dDl\324\211\201f\372\240\\\007\037\202U\334\310L\270\010\037W\322:\351:\320\200\223\253 \225!p\224\314\252\020\251=R4\272\313\216\351\215\r4\314\03260Cu\244\217NqJED\312\345\3058\025\"\311Sn\021]\005\016\223\244:M\365\276y\307_\026\021\243\226Z\245\267\231\360\273F\316\325\246\360\213\251)\201n\332\353(\370\360\310iI4\241\245VRP\335oYH\311P\211\303\302H\013\322j\020\34779]w\215:\030N\030\3125\035\212YX\244\322\005H\340B@J\244\317\343GXH <\017:\013\202\031\224\036\302q\2368\330\245\367\306\233@\203AJ\312 \301\031\t\261\014\222@\322\263\276\031Z\013\030\317aZJ\206k\260\242\266\225B\274\353'3\277\246`\243\031G'F\031Qi\302\361\217~\323!\331\003G$\302\201\304\213e\r\0022\225\264\315%%`f\200\r\0012I&\034N:C\266g\224\255SRy<<\017\204\032\021rC\350\203+N\232\264\312\3526M\306\203Y>,\270\035\207\036\300\022\021\006\354\244\361\263\02015M7S\0059<\374\351\343\350\250\177]j\210\203\253k7\203\260b\234\330\235\347\232\221\344D\001\334\2470\300\352\222\227Q\324e$,\232\260\222w\253\017_\024\225[n\250\226o~\327\227^\026\355\232;5\346\250.\"\0227\200\3339P\230\210\361R\001,\036\366\367\224N\300\367\2326\366\316It\270\3028\207\243\263\r\335\025\021\346\357x\355.T`w\215\374\232\3170o\265\246\\/\253 \346\337\235#IM\301F\351\214\264M\352\351\026\231\331z\343\322_\027\002m\356\252\315;\232M\224\325\3023E\346\371\205\375\0045{\261^!!z \236\000lY\202F\t\233\206\226\034}\302HU\321\031*\3000\217!\034\374a\251\365tn/ix\361n\020\236ck\235\313SK\221\013\226\247\204M*\311,(\030\314k#(\371\363\273!Q#\024\351i\200\272\030\256\374n\233\035\241Z\201q\301LB\274\235:\356+\250\357\275(f\232+\326\356t\200\213E\207A\004\327#\270\221x\354\341^\305\017\215\233+\244f\3402\013\355\204Nw\301\016pJ$\244\r\260mA\021\003!\2152\007\363K\360\263\337f\213\020\005\330\240\221\345\3021\023\230D\340\010J#\024\253\013\003\010(\207\023)!\264\212""\221\026_\351@n\241T\0274^\240\316\266n\330W^\333\341\337p`\220\017\"J\0204\323\010\030D@C\t!\373\304)D\215b\2235]\264\330y\231\355\303>\325G\320\203\274\322\357%\213B\033\000mc\000\330\210\034@\202D\372\201\236An\\\326&\017N\365u\366\200\332f\3300i\201;\265\006\231\252\232\224\314\n\204\201\021o\345\263\371\350+\323m\002lm)\364\355;8\270\237]\224)\004@\035n[\253\206!\262e\324U\325x\216jQp\334\257s1\345\253\244O4\334JF\215n\327\001z\362\247\232\3016\003c\242!\0206\333K\010\206[,\000\224\254\nEFZ]Yb\266c\315\270,\237DA:\254\256s\240r=z\366\\O\016\370\216\306\332\016\332;\201\335\363\225):\r\246\014#\271x\r\023\304@P \316\234*iS\t\014\002@*\224\010g\020\306\317ID&\236\231\251\r\312K\300).\201\255Z\251A\001\333\242R\036\375\325A\307WmP\326\275\021\235\022\302\"\234\251\341B\342\342\0236^6\275\007e\211\362EMO2\377@if\347\002\311\323\3215\345\010*\237-\020\202\274\347>\213\026I\r+\334/\345H\022WX\304\321A\347\253\022'\031\220AAyw\234)\014\357\223c%(\\\017G\240\240\310\354\250\250L-(\227\024\022\251X\235\342\353\2245L\225\212I\350<cV\321\004\213F\212z0\244YmS\236\243\242\001\n\326V\225\362hB\311\241P7fdR\352T\013\212\030\337^\274\201Q0c\272\345\230\362\3062z\263\254)N\311@X\245\205\216\225\263\364\232\235}q3\262\347N^ib\245mNKJ\033W\033\216\270A\276\220\246\322\016\212p9\322\221\202\254eB\204@C\035\361\036l\2472\020\313m\236\200,,\264\316\353\032K1\266X\306K\001U\254\324\221\310!<\335\340 n\001\310\3370\245\313<\222\351\212\253Q\335l\321|b.\002u\025\206&\261\307\032\236\033\244\302\376\034\346\214\257\214\332$\375\262\213D\313F\2436\315\t\355}\023\251D-\264\244t\363\r\244\201\3257\210oC\244\363P\345\364(\215\236-\233\232\336\r\361\263\313^\006\274nAT\340otIl<!\322\006\215\336K\335T:-\345\350\242\230t\010^\035: \310\231Crp8&B'|U\317L\270\243\024/1\322rb\220I\001\0000\002\000\000H\000\000\000\016&M\252\3251\301;\305\250k\225\0172\231\225ra\206H0\330y\001\321=\335|K\311\306\371\017,\346\036#\343\254\312J5\306\316\005\310\304O\260\r8[4op\366\036\234\370I\301\374Ai:\332\007k""\375\243\332\346F$\231\221\202AiAH<%\213\336\364\006a\335f\030d\001\257Q\037\225\013\357\261c\365\210c\363\330\0041\214\364\331\r\236\245}`aN\206eF\255K\035^\316\344\243\320\226\242\264\356\252\362\tl\021!\223\241(\242z\004Db\023z\327\343\254\235\006\"\312m\245\330\371\275\240\250\376r7\032|\021\376\342\251\376\247o\330!\020\266\316\354JR\276\276\2010H\270\326\210\323uH\341\317Q$\343\346<QT(=\223)\035H\331\027\303\210\261xS\216\240j\277\376\353\310$\0162R+(\266\246\240\310`\362\004H2\007/\006\210XP\337S\211S\006`\371\377T\306\251\273\314\t\177n\260\274\220\030 \307\014\355\334$\221\320\345\tF\366Y!\005\320XT0\311j\347\367\322\360\263^\227\216\231R\024H\001\344y\214\023\214\024\260\222\325\253\207G>\222I+1H/\032\206%\361\034\275\304\0162\327\237\244\224T\001\342\251^\316\236\340hT\240\262H]\005\376B\202\245\324\236\211\356\316Y\347\375\306\211\203v\265p\236N\211SJ\346a\316P\346 \231\333\246\222y\270\354\251\315\007M\304p\223\217\0273x\026\237\315\305UsE\335\212\307\246d*\352a9\2678\0300\340\223\312.\276\272n8\361\2049*^!\026\321\270\376dyy\311\251\326\334\237\005\346`\272\217\224\301\362\346\036\305\306]~<\241\263uqK(\243\332\305\032\330\376\237Cm\343\227\233\026ia\206\373\320\343F\026\270H\310\367N\237\002\330s;\033d\333\232CZd\330\255\374rc\214\001\022At\365Zwl\251\355cX\367/\341\013\346\341\350\330\335\270>O\005\274ah\317\016t6\212H\010N\342\021\333C(\017\346\370Y]P\235\312\227\337^u\334T\300W=kK\252#h'\214\200\235\343\010w\210\252\244\"9\310S\030\335\207\025\224\202q\025j\266\261VP\202\035\034:\222$\300\250x\233\250\200\233,\224\017\362rE\202a\335\341X\254\223\224\364\225\212\265z4\245$\r \030\250\235)\205'U\212\225TjB\305\226%fb\301\022\252Ry\"\035Y`\207\245\032F\202(\234D\022\222\221T3\377\213\271\"\234(HF+\365\332\200";
    PyObject *data = __Pyx_DecompressString(cstring, 3475, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (3443 bytes) */
const char* const cstring = "x\332\225XKw\323H\026\356\014i\010\020\300\346\025\036\003\243\244\t$\020L\033\302s\010=!\341\321\017h\002\201\236\351\236\036\035Y*;jdIVII\314a\372\364\322K-\265\324RK/\275\314\222\245\227^\346'\364O\230\357VI\266cL\272\207\023W\225\252\356\255\272u\357w\037\305\275%\315\266\035_1m\316<_\261L\356+k\314c\367\224\003\n\376-YL\263\225\300U<V\306\254\2553\256\370\216b;\006\r\3264_\331\3004V]K\323\231Q8 \270\236\177\277\372\350\036\226M\256\230U\327bUf\373\232o:\266\242q\036T3V\177\255\313I\024\212\311\005\267\341\330L)\233\036\367\347\224\022+;\330\177\315\364}\323\256(\232]W\312\201\007F\257_\"#\360\260*\230m\307\253j\226\342{\214\241\321\326\231\3075\253\240(\253$\214\315\230!\344/1E\363<\315\2560C)\325\025]\263\254l\203)\316\254ra\335\344\246\257\257\231\226\201#ff\247\024\210\253)\256\347\2708YH\014\215\211\013\340\020\233C\310\252\340\326l\261\241\343\031\214D\022\024Sb\037U\363}\217O)N9\325\236\346\322v\236\251\371\314\252\027\244\266\353\376\232c\027\226\234\252kZ\314+\014~?s\214\300b\317\301.W\256e+\327\336\220\274\216Wp\353\217\361\255\\z\016\035>w|&\025-\251\241_\305`\226Yb\2368S\341\276g\352>.\004\"[y\361\350\305\325\371;\363\342\n\036\373\205\351>WxP\322-\330\014\342B\356R`Z>]\273\3562^P\276.+u'\020J%\235\272\240\353g\300\325m\2053i\346K\002e\002\003*\330\241\232K\212az8\304\\g\304\375X\2638+\274\320<\316\244\361\214\240\352\222\326\3355\rS\227\246\371\245\027\320(d\322\0103\036\343]LA2i\010&v\342>n\240y\206\342\004\276\033\370R\263\257R\271\304\355\034\240\3023\r\001>O%v\207L\273NSU\202\233i\223A\305\356\322\252%\354%\315VPRU\223\177\374\364\363Uej\366\332\277gg\357\337_XX\230\\x\260\360\340\312\305k\327\356\337\237V\026\224\313\357/_~\360\340\352\177~\375jfNl3[\270\247h\206\241B\023\354*\000X\271\247\314)\004\013\263\024\370la\352\247B\241\360\363\265i\343\247i\343g\303\344Z\t\2264\034\250\222\034T\323u\346\372\212S\"\313\334S\230M\313\025}\216pH?\223\313)\343\322\034\274\030\0364\247\330Z\025\273\316\354\350\246\371\324\354\214\rt\314\316\270\016_\230""\231\361\034\307\237\235!\223.L\315)\262\227\237\323|vNY\327\254\200-,\226\034\317\177\344y\216\267\230\211K(|(\001\261\3648\260\365eV\026\300\224\210\024\264\031:\227<\215\257-96\367{\320]\315\334f\340Sz\236\232\261.g\030\341CXS\332\336J\317SR#-\263RPyli\025\236\212\267\014\300S\377\310^\357n\323?.\350\201\007\217\367Uf\257\017\235\347:B\200j\017lQ\300\022\363\344\342\316\371M\323\0372]\261\234\222f\rYHo\277\350U\226\231n\rJ\232-\277\362\275@\367\277\367^\333@hz\263at\204\370O/\367Ym\310\352\023fS\234p\274\207\216Q\3774\331+\272\202\361h\323\365>AP\306)*\334\007\352\021\021P \203w\031\322\236?\016\374\300c\317\030\314h,\233\334\325\020}\231\327\335\354\223\013\005\025\261\313\260\2308\207\034\366\217)\253\202\342\323t\375\367\267\226\220\032H\300?\"\177%\022\335\237\245F(\253j^}\251\352\376\031\352\207\246\355\374)\302\327\031]7O<\207\323\213>\375=6md\246\336\250\317\205\350\367\222\225E\306\017\334g\346\246i\017\231*\250\252i\203C\035\266\226&\363aK\031\"E^2v!y\311x`\371/%\340\0044D\334_Et\357\016 \004\245lU\355\237\221b\365\315\2704\024\256\332\233\244K\333~\357;\315\000\275\211\300\036$\031\220|pA\314\325\273\321\r\022\3247\361\243@\243>g\233t\223\227\014\321\203#\210\311[\013\035yC'\007\017\333\215\210\246\204\367\001\005\372[d\324.\032\206\317f{\367G\205\335)\207\205\231]9\372\"\312\256t=|\356J\006\265\366\311J:O\303z\337\260\240\226a0ae\025^\261\326\277D%\204X\351\237\024[\1774\221\225z\253\201+\005[E\006|e9>\357\036\231\3126\370\r\010\221\215\230\352;j\266\313G4\2753vY\002\243JY\236sq\023U\245Z\001\377\020\265\320x\025\374\251T\237S\357\223\234\030p\215\253\353\032\212Hd~\215\327m\335t\n\272\343!\336\242\004\340\024p\351\247R\356\357\026\032\335\201\230\026D\331:/iTFTYZ\352\245\351.\3656]\343\272f0]TRzYEkVl*\335\351\013\202\371\254\257\324\005=\321\321\r\344\240\302|\323gU\372\204p\360W\025\322\351\254\004\343\353\016\314h\211\2231\224\035\371\222\356\240\310\303\323D\216\340M\272\353\"~s\256UX_\246\37689\033\006e~\014U\266Iu\023\325\235&\345h\372\300\025,""\315c\2068\310`e\r\001GU\r\362X\265[\224r\032\257\213\006\026\002\273j8\272h|\306\375.\264\030E\013\203o\230T\356vk\000\014\275:\263\361\324\241R[UYM%AT*,\321[\001\030\273\225\001C\016\244_\337\027\247\023\313*)\241\254\222\266l\007\275\0033\360\001\274\213/\3562\335D=!3\233\n\\\251%\323F\202Q\351\275BI\374Sd\301GT\270\202Z\266\034\274`\350\366e\017*Re\022\357\246\330\254\357N\010E\226E\006\337\241\300\n\243\237\310\2430>\376T\204s\3353\205=\360Y\365\234\212ie\006\355/\212\300\007cd\031;\353\361\374S\007\363\375\316\254n\032\233\200$jx\303$\203S$\227m\226\037\000&hA\014p=\223\253]o\3008E}oDo\025Z\320S\225\3210\363.\214{\330J\351H\017\350\334\272,\3231\344\210k\026\315\0056\036\0210B*'\034W7M\362\007\376\226\3257\240nrq\376v\203Z\270\213\337s\016U%\025\010\237\021\215x\267R \300e\005&\244\312`\263\267\201\253\322\343\035\324|\315,\223\006UK\264Ux\221\350\231\257\245n\231^)\355la\347*F\324\004\026\353\365\030y\360#@\332d\302\235\253\201E\235dI[Ag\263\212\3546dC(\315~\034\217\030U\025\r\224\203?\2413\251'\3072\360'\310\005\024m#\355\212i\177=C(\230\305\317\254Hj\356\360\002\271A_\201)\207B%\256FaA\266\3428\"\025\017J\327q\361\374Q\325\2541\311\212\320$i\237&6\350\036pD\342U\323J\242WO\270\276\347\326S5\272H\367\353>\305_b\251\005\232%52$-xY6\267\352jZ*\211\355\322q6e\332C\026)\312\252}c\236V.\236(\227\2745N\3578\234\232\332]\\\237\376'\003C\270\235\024\t\2434\332qQ\255r\312oN\200\2308\020\031D^\0302\305]\313\364\021\347\365\267\002\234\224\212|\331P\374\343P\276\250\030pRP\022\r\0053\316\003\030\217\327\271\357\227d<Ao#\226S\034\005\306\350\335N\277\276`\217]\230\010?d3\372\211\343\305\200\032\324h\024\031\263RM<QE\303e\335 \332\201\322\371\343\207\325\220rh\227\272\347\343\027\325@\251\266\333\273\365\243\352h\350\023\343\323\357\256\301\252\251W\000\016{N\014+\236\206\324\326\303\336o\303\3362;\237\026\303\037u\275\"fg9\243n\222\273\266G'\302\367q\2613v,\274\033-F+\235\261\361\306\267a\2553v\260q+\234\210>\217^\305\243\361\223\244\330\031\317\265sJ\2747\326\223c\311r""s\264\271\270=\236\013\217D\265\366\350\225\244\270=\226\013\367\205\265h,\036\3118G:\343\307\302y\332\033\354w\232\267Z\371\316\370\221F\020>\211\212\235\334\204\240\335\033k\235\361\343\341bg\354H\243\366\033\272\361\366\370\027\240\247Q\343\273h$:\031\371$\332x\343y4\031\335\217\177m\256b\227L\300\224\347`c\276Q\333&\351\246\342IP\343\324\"-\372\355c\323\361J\254\375\266\270-i\304Q\341\353\350B\264\026\033\311\325&oM\267\370\326d'c\275\225@\302\\8\016-\274\211\347\343\367\315\353\315\025\2328\034i\321\006I\232\013\017F\305\276\223vH\320\317Z\353\364\211\263+\327\366\241\243\341\027\341j$N\336\037\345S\235B3\345dQR\335\014\367\204\362V\333\343'@z\2066=\322x\027\345\243\213\361~\310\234;\323>s\253i\264&[\363\255\315-\377C\261\223?\033\025\243\307\3614\004\241\305\313\311\024,6\262s:\232\354\034?\025\035\206&.5\363\315\213\255\261\255.\301,\254M|\177\307\206\265\255\321\255\247\037\226\333/V\344\352\223\370n\362]k\377\226<\366Fs\276Yk\215\266\236n-\177\330\311~<\\\006\002p\314\\\\JF\223\305\004\374'\302\225N\356dh\340h\000\200\303\244\327\333\347\256b%G@\341$\321\331h>Z\207\325\014\210\274H\3637\243=\300Kw\236%\327\211\036G\177\331\334\333\324[\371\326\205\226\276\225\337\232\334&\005\365\0246\017\200\010\370\325\244\242\203p)\364#a\215}b\320E\\\343\033\022(\033V\242\227t\216\374\374\026\224w\342\033\004\241\024\220\335A$`\370$\354\202S\014\276\306\005{\033\357$\003 I\234hD\n\364\337h)\n\342\245\330O\356C\203{Z7Zk[\306\207\271\366\233\037\332?\374\2633\236\017\363\355\243S\361\205\366\305\333M\277ug\253(\024\274\363\310\371\250\326=t\330\331\231\363\264\307\317\003\301\265A\277\221\233\334\211\213;gz]\227o\007\303}\210,\024}\250\361\262Q\217\376\222\222\236\213VR\007N\231\372\224\277\031\006\321b\352\227\022\027b\232\020|%\376W\242\245K\023\3220\007\033\013\321h\264\034\037H&\223\007\255\323\251iI\212:q\n\307\236IF\222\223\311\273\326\311V\355\023\247\336\001r\020\201Na\253Er\027?\274\027\255Do\223\323M\001>\201\016\304\273\355\014$\273o;\010\252.\332z$\347\333\347""\227\267\026\267V?\344\211\034H\223@\037\237\0107\"\215$\330lO\314\300\023\226\233c-8\306_\243\247\361\3426:\241\230\371\366\304\215&\274f:~\223\334&\tO\206e\304\222\037\343Z\177h\334i\216\243\341\205P\203\312\026\222=\311|\3425\021B\316F\267\343k\315\277\301\223\307\000\240\316\330\341F%\\\301NO\342b*\324\211\360\225@%\344\251u&Nur\247\243\243\321M\n#\311\305\366\227\377\000\347\370\321\360\022\014SH\306\232{\232\305\3462\260Yl\341\2703\321\027P\240F0x\032.\312P\276\004\205\344\362R\275\177\207p\022\320w\233\213\010\2344\177\250\223;\025\355\023\341L\353\034;\236\322\256C\006J+\224J\3624\227\006\226\"Q\037\214\257\307\257`\206<\205\213\037\301\272\217\242U~;',\211\364\224\312w5^O\004\340\337\303\017\336%g\233_\267^oMn\t\243\034n\030\341\244\304\330\2064\202\014\3425\351@\363\341\257\361*.<\235\364\224\231\262@\311p\272X\333\341547\231Q\036\311u\306N\223[\347\302\221L\301\026\226\221[\276\211\004\222oF\373\343\343\224xzQ\372\363x\205@G^\220;\037\031\261\200\240\027\235\210\314\270F\301\2613A8\310\235\010\177\210\036F\345\370\031l\231\233\214\241\254\323\"\332\217\211\314;B\211L\010\361\373\336\317\366\347\244\334\244\371b\206O\212\2257\2410_d\353\364\312\275(x\2232\264\\0\342\002e\360\346\233V\317\373\377\277\000u\244\301\303I\241JXKx\024\231h/\244_N\306\233\017\233\232\014\352\204}\004\357\273\330\010\366\332\306\260\330\013n\361/\210\341FkF\332m[Hp\233bi*N7\201K\341\356!6{q>\236\314&\356Kd\365>\275\370\\\242\3756\362\373\330g\237\037B0\377\005\305\310\350\276\3376ITq\315p,:\020On\247\303\375\330\353J\262\322\036=GU\317\241\306J\373p!)5E\230}\214\313\245\252\301\036\207\032?\n\305\214\036h\\\014G\340Y\243T\342\344i)\337\316_\214\265\370\035L6z\270\2415P\016]N\n\255\021y\233\257\220\361\357\220G\367\317\312k\255%\225\346\312\377\000Y\351\260\237";
    PyObject *data = __Pyx_DecompressString(cstring, 3443, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (7649 bytes) */
const char* const bytes = ":Cannot insert list here: \n    Clean up references to nodes that were replaced.\n\n    NOTE: this implementation assumes that the replacement is\n    done first, before hitting any further references during\n    normal tree traversal.  This needs to be arranged by calling\n    \"self.visitchildren()\" at a proper place in the transform\n    and by ordering the \"child_attrs\" of nodes appropriately.\n    Cython.Compiler.Cython.Compiler.ModuleNodeCython/Compiler/Visitor.pyFile 'NoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Parse tree dump at phase '%s'Prints a representation of the tree to standard output.\n    Subclass and override repr_of to provide more information\n    about nodes. Visitor \n  []- \")/\\))<<===!=>=>+&//<<% = *|**>>-^~?(,\n    ).: add_note- arg: , attribute=\"[...]/%d[%d]disable does not accept object: enablegc, in  in isenabled', line , name=\"(name=\"(name=\"%s\")(none)(pos=((root)(type=\", type=\"(type=%s), value=AbortErrorAttributeNodeBuiltinCFuncDefNodeCompileErrorCompilerCrashConstNodeCythonTransformCythonTransform.visit_CompilerDirectivesNodeCythonTransform.visit_NodeCython.Compiler.VisitorDebugFlagsDefNodeDictNodeEnvTransformEnvTransform.current_envEnvTransform.current_scope_nodeEnvTransform.enter_scopeEnvTransform.exit_scopeEnvTransform.global_scopeEnvTransform.visit_CArgDeclNodeEnvTransform.visit_CStructOrUnionDefNodeEnvTransform.visit_ClassDefNodeEnvTransform.visit_FuncDefNodeEnvTransform.visit_GeneratorBodyDefNodeEnvTransform.visit_ScopedExprNodeEnvTransform.visit_func_outer_attrsErrorsExprNodeExprNodesFutureMethodDispatcherTransformMethodDispatcherTransform._handle_functionMethodDispatcherTransform._handle_methodMethodDispatcherTransform.visit_GeneralCallNodeMethodDispatcherTransform.visit_SimpleCallNodeMethodDispatcherTransform.visit_PrimaryCmpNodeMethodDispatcherTransform.visit_BinopNodeMethodDisp""atcherTransform.visit_UnopNodeModuleNodeNameNodeNodeNodeFinderNodeFinder.visit_NodeNodeRefCleanupMixinNodeRefCleanupMixin.__init__NodeRefCleanupMixin.replaceNodeRefCleanupMixin.visit_CloneNodeNodeRefCleanupMixin.visit_ResultRefNodeNodesPrintTreePrintTree.__call__PrintTree.__init__PrintTree._print_nodePrintTree.indentPrintTree.repr_ofPrintTree.unindentPrintTree.visit_CloneNodePrintTree.visit_NodePyConstNode__Pyx_PyDict_NextRefRecursiveNodeReplacerRecursiveNodeReplacer.visit_CloneNodeRecursiveNodeReplacer.visit_NodeScopeTrackingTransformScopeTrackingTransform.visit_CClassDefNodeScopeTrackingTransform.visit_CStructOrUnionDefNodeScopeTrackingTransform.visit_FuncDefNodeScopeTrackingTransform.visit_ModuleNodeScopeTrackingTransform.visit_PyClassDefNodeTreeVisitorTreeVisitor._find_node_pathTreeVisitor.dump_nodeTreeVisitor.visitTreeVisitor.visitchildrenTupleNodeTypeSlotsVisitorTransformVisitorTransform.recurse_to_childrenVisitorTransform.visitchildVisitorTransform.visitchildren_access_path__add____and__argarg_listarg_tupleargsas_variableasyncio.coroutinesattrattr_nameattributeattribute_namesattrnameattrsbasenamebuiltin_scope__call__cascadecclasscf_assignmentscf_statechild_attrs__class____class_getitem__cline_in_tracebackco_filenameco_namecode__contains__contextcpp_messagecurrent_envcurrent_scope_nodeddebug_no_exception_interceptdeclared_namedefault__dict__directives__div__division__doc__doctestdump_nodeendendswithenter_scopeentryenumerate__eq__exc_infoexcludeexit_scopeexprexpr_scopeexpressionf_codef_linenof_locals_find_node_pathfind_special_method_for_binary_operatorfind_special_method_for_unary_operatorfinder__floordiv__frame__func__functionfunction_function_namefuture_directives__ge__generalgetget_descriptiongetmrogil_messageglobal_scope__gt___handle__handle_any__handle_function_handle_methodidxignoredin_indentindent__init__inspect__inv__is_attributeis_builtinis_builtin_typeis_cmethod_is_coroutineis_exception_typeis_nameis_pyobjectis_singleis_unbound_methodisasciiitemskeyw""ord_argskwargslast_traceback__le__line_line_rangelistidxlocal_scopelookup_here__lshift____lt____main____metaclass__method_method_name__mod__module__module____mro_entries____mul____name__name__ne____neg____new__new_nodenodenodesnot__not__objobj_typeobjectoldold_nodeoperandoperand1operand2operator__or__orig_nodeosos.pathouter_attrsouter_scopeparentparent_typepathphasepoppos__pos__positional_args__pow____prepare__print_print_nodeptrpyclass__pyx_vtable____qualname__recurse_to_childrenrecursively_replace_nodereplacereplace_inreplace_nodereplacement_replacementsrepr_ofresultrhsroot__rshift__scopeself__set_name__setdefaultsimpleslotsourcespecial_method_namespecial_method_namessplitstacktracestartstartswithstrstruct__sub__subexprssupersysttb_frametb_nexttestmodtreetree_contains__truediv__typetype_nametype_typeunicodeunindentvaluevaluesvisit_visitvisit_BinopNodevisit_CArgDeclNodevisit_CClassDefNodevisit_CStructOrUnionDefNodevisit_ClassDefNodevisit_CloneNodevisit_CompilerDirectivesNodevisit_FuncDefNodevisit_GeneralCallNodevisit_GeneratorBodyDefNodevisit_ModuleNodevisit_Nodevisit_PrimaryCmpNodevisit_PyClassDefNodevisit_ResultRefNodevisit_ScopedExprNodevisit_SimpleCallNodevisit_UnopNodevisit_func_outer_attrsvisitchildvisitchildren__xor__\320\004\027\220|\2401\330\010\023\2209\230A\230Q\330\010\014\210K\220q\330\010\013\2106\220\027\230\005\230S\240\004\240G\2501\330\014\020\320\020 \240\006\240c\250\023\250D\260\004\260A\340\014\020\220\017\230q\320\004+\2501\340\010\020\220\007\220q\230\010\240\001\330\010\013\2106\220\027\230\001\330\014\023\2204\220|\2401\240G\2508\2606\270\021\330\014\017\210u\220G\2301\330\020\027\220q\230\010\240\006\240a\330\014\024\220A\330\010\017\210q\200A\330\010\014\320\014#\2401\240A\330\010\014\210L\230\001\230\026\230t\2401\330\010\014\210N\230!\230<\240~\260T\270\021\330\010\014\210K\220q\330\010\017\210q\200A\330\010\013\2104\210q\340\014\020\320\020\"\240!\2401\330\014\023\2201\330\010\017\210t\320\023%\240Q\240a\200A\340\010\013\2104\210q""\330\014\024\220A\220U\230$\230h\240d\250-\260s\270%\270s\300!\330\014\020\320\020\"\240!\2406\250\021\330\014\020\220\014\230A\230V\2404\240|\2602\260Q\330\014\020\220\016\230a\230w\240a\330\014\020\220\013\2301\340\014\020\320\020\"\240!\2401\330\010\017\210q\200A\330\010\013\2104\210q\330\014\020\220\014\230A\230V\2404\240q\330\014\020\320\020\"\240!\2401\330\014\020\220\013\2301\340\014\020\320\020\"\240!\2401\330\010\017\210q\200A\330\010\013\2104\210q\340\r\022\220#\220T\230\021\330\014\020\220\t\230\021\340\014\020\220\017\230q\240\006\240f\250A\200A\330\010\013\2105\220\003\2201\330\014\023\2201\340\014\025\220T\230\032\2401\330\014\017\210z\230\021\230&\240\t\250\021\330\020\032\320\0326\260d\270!\2704\270x\300t\3101\330\021\033\2301\230F\240%\240q\330\020\032\320\032*\250\"\250D\260\001\330\021\033\2301\230F\240%\240q\330\020\032\230!\330\024\030\230\016\240d\250'\260\021\260&\270\010\300\001\330\021\033\2301\230F\240)\2501\330\020\032\320\032;\2704\270q\300\004\300H\310D\320PQ\330\021\033\2301\230G\2409\250L\270\t\300\021\330\020\032\320\0323\2604\260q\270\004\270H\300D\310\001\330\021\033\2301\230F\240)\2501\330\020\024\220D\230\001\330\020\032\230,\240b\250\004\250A\250Q\330\021\025\220Q\330\020\026\220d\230!\330\020\027\220s\230!\2302\320\035-\250Q\330\020\023\2204\220s\230!\330\024\033\2304\230v\240Q\240d\250\"\250A\330\020\023\2205\230\003\2301\330\024\033\2304\230v\240Q\240e\2502\250Q\330\020\032\320\0320\260\006\260c\270\021\270$\270c\300\021\300!\340\014\023\2201\200A\330\010\013\2105\220\003\2204\220q\330\014\023\2204\220q\330\010\013\2104\210u\220C\220t\2301\330\014\020\220\007\220t\2301\330\010\017\210q\200A\330\010\014\210J\220d\230!\200A\330\010\014\210J\220g\230R\230v\240Q\200A\330\010\014\210K\220t\2308\2403\240a\200A\330\010\014\210L\230\001\200A\330\010\014\210L\230\001\230\021\330\010\014\210G\2201\330\010\014\210N\230!\2301\330\010\014\210I\220Q\330\010\017\210q\200A\330\010\014\210L\230\001\230\021\330\010\014\210G\2201\330\010\017""\210t\2204\220q\230\001\330\010\013\2104\210}\230C\230u\240C\240t\250<\260q\270\003\2703\270h\300d\310,\320VW\320WX\330\014\021\220\021\320\022\"\240$\320&7\260t\2708\3001\300D\310\001\330\010\014\210G\2201\330\010\014\210N\230!\2304\230q\330\010\014\210I\220Q\330\010\014\210I\220Q\330\010\017\210q\200A\330\010\014\210L\230\001\230\026\230t\2401\330\010\014\320\014\036\230a\230q\330\010\014\210K\220q\330\010\017\210q\200A\330\010\014\210N\230!\2308\2401\330\010\017\210q\200A\330\010\014\210N\230!\330\010\014\210N\230!\330\010\014\320\014\036\230a\230q\330\010\017\210q\200A\330\010\014\210N\230!\230<\240t\2501\200A\330\010\r\210R\210y\230\002\230!\330\010\014\320\014\035\230Q\200A\330\010\014\320\014\036\230a\230q\330\010\023\2204\220q\330\010\013\2104\210x\220u\230A\330\014\023\2201\330\010\024\220D\230\001\330\010\013\2104\210z\230\021\230+\240Y\250a\330\014\023\2201\330\010\027\220t\2301\330\010\013\210=\230\004\230D\240\n\250!\250>\270\031\300!\340\014\023\2201\330\010\017\210y\230\001\330\010\017\210t\320\023(\250\001\250\026\250z\270\026\270q\200A\330\010\014\320\014\036\230a\230q\330\010\023\2204\220q\330\010\013\2108\2205\230\001\330\014\030\230\004\230A\330\014\017\210t\220:\230Q\230k\250\031\260!\330\020\027\220q\330\014\023\2209\230A\340\014\023\2204\220q\330\010\017\210t\320\023(\250\001\250\026\250z\270\026\270q\200A\330\010\014\320\014\036\230a\230q\330\010\013\2105\220\003\2204\220q\330\014\023\2204\220q\340\014\023\2201\200A\330\010\014\320\014\036\230a\230q\330\010\036\320\036D\300A\300T\310\021\330\010\013\2101\330\014\026\220d\230!\330\014\027\220w\230a\330\014\017\210x\320\027(\250\004\250D\260\010\270\001\330\020\034\230H\240A\340\020\034\230A\330\014\023\2204\320\0273\2601\330\020%\240V\2507\260!\330\020\026\220f\230A\230Z\240q\330\010\017\210q\200A\330\010\014\320\014\036\230a\230q\330\010\017\210q\200A\330\010\022\220$\220a\220t\230=\250\003\2504\250r\260\021\330\014\033\2307\240/\260\037\300\001\330\010\021\220\021\330\010\016\210g\220Q\220f""\230G\2401\330\010\013\2101\330\014\025\220S\230\001\230\021\330\014\017\210q\330\027\030\330\020\031\230\022\2305\240\t\250\021\250&\3200@\300\001\330\014\022\220'\230\021\230.\250\010\260\003\2601\260D\270\003\2701\270A\330\010\032\230#\230Q\230a\330\010\014\210H\220A\330\014\017\210u\220C\220q\330\020\021\330\014\017\210t\220;\230a\230u\240C\240t\2509\260A\260Q\330\020\021\330\014\r\330\020\030\230\007\230q\240\006\240a\330\023\024\330\020\021\330\014\017\210v\220S\230\005\230S\240\006\240c\250\021\330\020\021\330\021\033\2301\230G\2401\330\020\030\230\013\2402\240S\250\001\250\021\330\021\025\220Z\230q\240\007\240q\330\020\021\340\020\030\230\004\230A\230Q\330\014\022\220'\230\021\230-\240v\250Q\330\010\017\210|\2304\230z\250\033\260I\270U\300!\3001\200A\330\010\016\210d\220!\330\010\013\2104\210w\220d\230!\330\014\020\220\016\230a\230q\330\010\014\210G\2204\220~\240T\250\021\250%\250q\330\010\017\210q\200A\330\010\016\210d\220!\330\010\014\320\014\"\240$\240a\330\010\014\320\014\036\230a\230q\330\010\014\320\014\"\240!\330\010\017\210q\200A\330\017\020\330\010\031\230\021\330\010\020\220\001\330\010\016\210g\220Q\220l\240!\330\014\024\220J\230a\330\014\023\2205\230\t\240\024\240Q\240a\330\014\017\210z\230\021\230&\240\005\240Q\330\020\027\220u\230A\330\020\036\230d\240!\330\020\027\220r\230\025\230i\240q\250\004\250A\330\027\034\230A\330\020\025\220W\230B\230f\240M\260\021\330\020!\240\021\330\014\031\230\032\2401\330\010\020\320\020 \240\001\200A\340\010\017\210q\200A\360\006\000\t\020\210q\200A\330\010\017\210t\2201\330\010\013\2105\220\003\2205\230\003\2305\240\007\240t\2501\330\014\020\220\016\230a\230q\330\014\023\2204\220q\330\010\013\2105\220\007\220q\330\014\020\220\016\230d\240.\260\004\260A\260V\2701\330\010\017\210q\200A\330\010\017\210t\2204\220q\230\001\330\010\013\2104\210}\230C\230u\240C\240t\250<\260q\270\003\2703\270h\300d\310,\320VW\320WX\330\014\017\210s\220!\2204\220~\240S\250\001\330\020\027\220q\340\020\030\230\006\230f\240D\250\014\260B""\260a\330\020\023\2204\220w\230a\330\024\033\2309\240C\240v\250Q\340\024\033\2301\330\014\021\220\021\320\022\"\240$\240j\260\006\260d\270(\300!\3001\200A\340\010\017\210t\2207\230!\2301\200A\330\010\017\210t\320\023%\240Q\240a\200A\330\010\017\210t\220:\230R\230r\240\021\240!\200A\330\010\017\210t\220<\230q\240\006\240a\200A\330\010\017\210t\220<\230r\240\035\250a\200\001\360\010\000\005\r\210J\220j\240\001\330\004\007\200x\210s\220!\330\010\017\210q\220\010\230\n\240!\340\010\017\210q\220\010\230\t\240\021\240+\250Q\320\004\035\230Q\330\010\r\210Q\320\016.\250b\260\001\330\010\014\210F\220!\2201\330\010\017\210q\200\001\330\004\r\210Z\220q\230\001\330\004\n\210&\220\001\220\021\330\004\013\2106\220\021\200\001\330\004\021\320\021&\240a\240z\260\021\330\004\016\210a\210q\320\004*\250.\270\001\340\010\017\210t\220?\240!\2408\2507\260!\320\004*\250.\270\001\340\010\017\210t\320\023%\240Q\240h\250g\260Q";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 386; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 70) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 386; i < 430; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 430; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 386;
      for (Py_ssize_t i=0; i<44; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1,-2};
    for (int i = 0; i < 3; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<3; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 4;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 73};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_ignored, __pyx_mstate->__pyx_n_u_values, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_source, __pyx_mstate->__pyx_n_u_os, __pyx_mstate->__pyx_n_u_attribute_names, __pyx_mstate->__pyx_n_u_attr, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_dump_node, __pyx_mstate->__pyx_kp_b_iso88591_A_at_4r_7_gQfG1_1_S_q_5_0_1D_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 105};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_stacktrace, __pyx_mstate->__pyx_n_u_os, __pyx_mstate->__pyx_n_u_last_traceback, __pyx_mstate->__pyx_n_u_nodes, __pyx_mstate->__pyx_n_u_frame, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_method_name, __pyx_mstate->__pyx_n_u_pos};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_find_node_path, __pyx_mstate->__pyx_kp_b_iso88591_A_gQl_Ja_5_Qa_z_Q_uA_d_r_iq_A_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 161};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_2, __pyx_mstate->__pyx_kp_b_iso88591_A_t7_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 192};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_attrs, __pyx_mstate->__pyx_n_u_exclude};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visitchildren, __pyx_mstate->__pyx_kp_b_iso88591_t_87, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 246};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_attrs, __pyx_mstate->__pyx_n_u_exclude};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visitchildren, __pyx_mstate->__pyx_kp_b_iso88591_t_QhgQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 272};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_attr, __pyx_mstate->__pyx_n_u_idx};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visitchild, __pyx_mstate->__pyx_kp_b_iso88591_1_q_6_4_1G86_uG1_q_a_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 282};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_recurse_to_children, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 307};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_old};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CompilerDirectivesNode, __pyx_mstate->__pyx_kp_b_iso88591_A_d_a_aq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 314};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 324};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_ModuleNode, __pyx_mstate->__pyx_kp_b_iso88591_A_N_N_aq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 338};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CClassDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 341};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_PyClassDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 344};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_FuncDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 347};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CStructOrUnionDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 360};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_current_env, __pyx_mstate->__pyx_kp_b_iso88591_A_t_Rr, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 363};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_current_scope_node, __pyx_mstate->__pyx_kp_b_iso88591_A_t_Rr, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 366};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_global_scope, __pyx_mstate->__pyx_kp_b_iso88591_A_t_r_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 369};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_scope};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_enter_scope, __pyx_mstate->__pyx_kp_b_iso88591_A_JgRvQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 372};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_exit_scope, __pyx_mstate->__pyx_kp_b_iso88591_A_Jd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 375};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_FuncDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_1A_L_t1_N_T_Kq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 382};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_func_outer_attrs, __pyx_mstate->__pyx_kp_b_iso88591_A_N_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 385};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_GeneratorBodyDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 389};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_ClassDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_L_t1_aq_Kq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 395};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CStructOrUnionDefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_L_t1_aq_Kq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 401};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_ScopedExprNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_AV4q_1_1_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 410};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_attrs, __pyx_mstate->__pyx_n_u_attr};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CArgDeclNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_AU_hd_s_s_6_AV4_2Q_awa_1_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS), 433};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_args};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_Ry_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 437};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CloneNode, __pyx_mstate->__pyx_kp_b_iso88591_A_d_4wd_aq_G4_T_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 444};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_expr};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_ResultRefNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t1_5_5_5_t1_aq_4q_5_q_d_AV1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 453};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_replacement};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_replace, __pyx_mstate->__pyx_kp_b_iso88591_A_N_81_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 503};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_function, __pyx_mstate->__pyx_n_u_arg_tuple, __pyx_mstate->__pyx_n_u_keyword_args, __pyx_mstate->__pyx_n_u_args};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_GeneralCallNode, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_4q_4xuA_1_D_4z_Ya_1_t1_D_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 518};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_function, __pyx_mstate->__pyx_n_u_arg_tuple, __pyx_mstate->__pyx_n_u_args};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_SimpleCallNode, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_4q_85_A_t_Qk_q_9A_4q_t_z_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 530};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_PrimaryCmpNode, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_1_1_t_Qa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 537};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_BinopNode, __pyx_mstate->__pyx_kp_b_iso88591_A_t_Qa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 561};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_special_method_name, __pyx_mstate->__pyx_n_u_operand, __pyx_mstate->__pyx_n_u_obj_type, __pyx_mstate->__pyx_n_u_type_name};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_UnopNode, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_DAT_1_d_wa_x_D_HA_A_4_31_V7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {6, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 699};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_function_name, __pyx_mstate->__pyx_n_u_function, __pyx_mstate->__pyx_n_u_arg_list, __pyx_mstate->__pyx_n_u_kwargs};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_handle_function, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {8, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 703};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_type_name, __pyx_mstate->__pyx_n_u_attr_name, __pyx_mstate->__pyx_n_u_function, __pyx_mstate->__pyx_n_u_arg_list, __pyx_mstate->__pyx_n_u_is_unbound_method, __pyx_mstate->__pyx_n_u_kwargs};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_handle_method, __pyx_mstate->__pyx_kp_b_iso88591_A_q_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 718};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CloneNode, __pyx_mstate->__pyx_kp_b_iso88591_A_5_4q_4q_4uCt1_t1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 725};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_aq_5_4q_4q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 732};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tree, __pyx_mstate->__pyx_n_u_old_node, __pyx_mstate->__pyx_n_u_new_node, __pyx_mstate->__pyx_n_u_replace_in};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_recursively_replace_node, __pyx_mstate->__pyx_kp_b_iso88591_az_aq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 746};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_T_q_fA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 754};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_tree, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_finder};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_tree_contains, __pyx_mstate->__pyx_kp_b_iso88591_Zq_6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 761};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ptr, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_attrname, __pyx_mstate->__pyx_n_u_listidx};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_replace_node, __pyx_mstate->__pyx_kp_b_iso88591_Jj_xs_q_q_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 776};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_n_u_end};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_1_9AQ_Kq_6_S_G1_c_D_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 784};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_indent_2, __pyx_mstate->__pyx_kp_b_iso88591_A_L, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 787};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_unindent, __pyx_mstate->__pyx_kp_b_iso88591_A_Kt83a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 790};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_tree, __pyx_mstate->__pyx_n_u_phase};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_call, __pyx_mstate->__pyx_kp_b_iso88591_Q_Q_b_F_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 799};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_Node, __pyx_mstate->__pyx_kp_b_iso88591_A_L_G1_N_1_IQ_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 806};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_line_2};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_visit_CloneNode, __pyx_mstate->__pyx_kp_b_iso88591_A_L_G1_t4q_4_CuCt_q_3hd_VWWX_7t8, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 818};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_line_2, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_parent, __pyx_mstate->__pyx_n_u_attr, __pyx_mstate->__pyx_n_u_idx};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_print_node, __pyx_mstate->__pyx_kp_b_iso88591_A_t4q_4_CuCt_q_3hd_VWWX_s_4_S_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 831};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_t, __pyx_mstate->__pyx_n_u_pos, __pyx_mstate->__pyx_n_u_path};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_Cython_Compiler_Visitor_py, __pyx_mstate->__pyx_n_u_repr_of, __pyx_mstate->__pyx_kp_b_iso88591_A_5_1_1_T_1_z_6d_4xt1_1F_q_D_1F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by RejectKeywords) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* PyLongCompare */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = __Pyx_PyFloat_AS_DOUBLE(op1);
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (__Pyx_IS_TYPE(L, &PySet_Type)) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_mstate_global->__pyx_n_u_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__8);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyLong_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyLong_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CalculateMetaclass (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectCall2Args (used by Py3ClassCreate) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectLookupSpecial (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module_2, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CyFunctionClassCell */
static int __Pyx_CyFunction_InitClassCell(PyObject *cyfunctions, PyObject *classobj) {
    Py_ssize_t i, count = __Pyx_PyList_GET_SIZE(cyfunctions);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(count < 0)) return -1;
    #endif
    for (i = 0; i < count; i++) {
        __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *)
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && !CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
            PyList_GET_ITEM(cyfunctions, i);
#else
            __Pyx_PySequence_ITEM(cyfunctions, i);
        if (unlikely(!m))
            return -1;
#endif
        __Pyx_CyFunction_SetClassObj(m, classobj);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && !CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
        Py_DECREF((PyObject*)m);
#endif
    }
    return 0;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* PyObjectVectorCallKwBuilder (used by CIntToPy) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module_2);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__37);
    }
    goto done;
}
#endif

/* CIntFromPyVerify (used by CIntFromPy) */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
